package com.androlua;

import android.app.AlertDialog;
import android.app.DownloadManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.widget.EditText;
import java.io.File;
import java.util.HashMap;
/* loaded from: classes.dex */
public class Download {
    private EditText file_input_field;
    private long mContentLength;
    private final LuaContext mContext;
    private String mDestinationDir;
    private HashMap<Long, String[]> mDownload = new HashMap<>();
    private DownloadBroadcastReceiver mDownloadBroadcastReceiver;
    private String mFilename;
    private String mMessage;
    private String mMimeType;
    private OnDownloadCompleteListener mOnDownloadCompleteListener;
    private String mUrl;
    private String mUserAgent;

    /* loaded from: classes.dex */
    public interface OnDownloadCompleteListener {
        void onDownloadComplete(String str, String str2);
    }

    public String getDestinationDir() {
        return this.mDestinationDir;
    }

    public void setDestinationDir(String destinationDir) {
        this.mDestinationDir = destinationDir;
    }

    public Download(LuaContext context) {
        this.mContext = context;
    }

    public String getUserAgent() {
        return this.mUserAgent;
    }

    public void setUserAgent(String userAgent) {
        this.mUserAgent = userAgent;
    }

    public String getUrl() {
        return this.mUrl;
    }

    public void setUrl(String url) {
        this.mUrl = url;
    }

    public String getMimeType() {
        return this.mMimeType;
    }

    public void setMimeType(String mimeType) {
        this.mMimeType = mimeType;
    }

    public long getContentLength() {
        return this.mContentLength;
    }

    public void setContentLength(long contentLength) {
        this.mContentLength = contentLength;
    }

    public String getFilePath() {
        return this.mFilename;
    }

    public void setFilePath(String filename) {
        this.mFilename = filename;
    }

    public void setMessage(String message) {
        this.mMessage = message;
    }

    public void setOnDownloadCompleteListener(OnDownloadCompleteListener listener) {
        this.mOnDownloadCompleteListener = listener;
    }

    public void start() {
    }

    public void start(String url, String destinationDir, String filename, String message) {
        this.mUrl = url;
        this.mMessage = message;
        Uri uri = Uri.parse(this.mUrl);
        this.mFilename = filename;
        if (filename == null) {
            this.mFilename = uri.getLastPathSegment();
        }
        if (destinationDir == null) {
            this.mDestinationDir = "Download";
        }
        this.file_input_field = new EditText(this.mContext.getContext());
        this.file_input_field.setText(this.mFilename);
        if (this.mMessage == null) {
            this.mMessage = url;
        }
        new AlertDialog.Builder(this.mContext.getContext()).setTitle("Download").setMessage(this.mMessage).setView(this.file_input_field).setPositiveButton("Download", new DialogInterface.OnClickListener() { // from class: com.androlua.Download.2
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface p1, int p2) {
                Download.this.mFilename = Download.this.file_input_field.getText().toString();
                Download.this.start(false);
            }
        }).setNegativeButton("Cancel", (DialogInterface.OnClickListener) null).setNeutralButton("Only Wifi", new DialogInterface.OnClickListener() { // from class: com.androlua.Download.1
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface p1, int p2) {
                Download.this.mFilename = Download.this.file_input_field.getText().toString();
                Download.this.start(true);
            }
        }).create().show();
    }

    public long start(boolean isWifi) {
        if (this.mDownloadBroadcastReceiver == null) {
            IntentFilter filter = new IntentFilter();
            filter.addAction("android.intent.action.DOWNLOAD_COMPLETE");
            this.mDownloadBroadcastReceiver = new DownloadBroadcastReceiver();
            this.mContext.getContext().registerReceiver(this.mDownloadBroadcastReceiver, filter);
        }
        DownloadManager downloadManager = (DownloadManager) this.mContext.getContext().getSystemService("download");
        Uri uri = Uri.parse(this.mUrl);
        uri.getLastPathSegment();
        DownloadManager.Request request = new DownloadManager.Request(uri);
        if (this.mDestinationDir == null) {
            this.mDestinationDir = "Download";
        }
        request.setDestinationInExternalPublicDir(this.mDestinationDir, this.mFilename);
        request.setTitle(this.mFilename);
        request.setDescription(this.mUrl);
        if (isWifi) {
            request.setAllowedNetworkTypes(2);
        }
        if (this.mMimeType == null) {
            this.mMimeType = "*/*";
        }
        request.setMimeType(this.mMimeType);
        long downloadId = downloadManager.enqueue(request);
        this.mDownload.put(Long.valueOf(downloadId), new String[]{new File(this.mDestinationDir, this.mFilename).getAbsolutePath(), this.mMimeType});
        return downloadId;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class DownloadBroadcastReceiver extends BroadcastReceiver {
        private DownloadBroadcastReceiver() {
        }

        @Override // android.content.BroadcastReceiver
        public void onReceive(Context p1, Intent p2) {
            long id = p2.getLongExtra("extra_download_id", 0L);
            p2.getExtras();
            if (Download.this.mDownload.containsKey(Long.valueOf(id)) && Download.this.mOnDownloadCompleteListener != null) {
                String[] data = (String[]) Download.this.mDownload.get(Long.valueOf(id));
                Download.this.mOnDownloadCompleteListener.onDownloadComplete(data[0], data[1]);
            }
        }
    }
}
