package com.androlua;

import android.app.Service;
import android.content.Intent;
import android.os.IBinder;
import com.tencent.smtt.sdk.TbsVideoCacheTask;
import java.io.File;
/* loaded from: classes.dex */
public class DownloadService extends Service {
    static final int Flag_Done = 3;
    static final int Flag_Down = 1;
    static final int Flag_Init = 0;
    static final int Flag_Pause = 2;
    private static DownloadService instance;
    Downloader downloader;
    String filetype;
    private int flag;
    DownThread mThread;
    String url;
    private int progress = 0;
    private DownloadListener downListener = new DownloadListener() { // from class: com.androlua.DownloadService.1
        int fileSize;
        Intent intent = new Intent();

        @Override // com.androlua.DownloadListener
        public void onSuccess(File file) {
            this.intent.setAction(LuaActivity.ACTION_DOWNLOAD_SUCCESS);
            this.intent.putExtra("progress", 100);
            this.intent.putExtra("file", file);
            DownloadService.this.sendBroadcast(this.intent);
        }

        @Override // com.androlua.DownloadListener
        public void onStart(int fileByteSize) {
            this.fileSize = fileByteSize;
            DownloadService.this.flag = 1;
        }

        @Override // com.androlua.DownloadListener
        public void onResume() {
            DownloadService.this.flag = 1;
        }

        @Override // com.androlua.DownloadListener
        public void onProgress(int receivedBytes) {
            if (DownloadService.this.flag == 1) {
                DownloadService.this.progress = (int) ((receivedBytes / this.fileSize) * 100.0f);
                this.intent.setAction(LuaActivity.ACTION_DOWNLOAD_PROGRESS);
                this.intent.putExtra("progress", DownloadService.this.progress);
                DownloadService.this.sendBroadcast(this.intent);
                if (DownloadService.this.progress == 100) {
                    DownloadService.this.flag = 3;
                }
            }
        }

        @Override // com.androlua.DownloadListener
        public void onPause() {
            DownloadService.this.flag = 2;
        }

        @Override // com.androlua.DownloadListener
        public void onFail() {
            this.intent.setAction(LuaActivity.ACTION_DOWNLOAD_FAIL);
            DownloadService.this.sendBroadcast(this.intent);
            DownloadService.this.flag = 0;
        }

        @Override // com.androlua.DownloadListener
        public void onCancel() {
            DownloadService.this.progress = 0;
            DownloadService.this.flag = 0;
        }
    };

    public int getProgress() {
        return this.progress;
    }

    public int getFlag() {
        return this.flag;
    }

    public static DownloadService getInstance() {
        return instance;
    }

    @Override // android.app.Service
    public IBinder onBind(Intent intent) {
        return null;
    }

    @Override // android.app.Service
    public void onCreate() {
        instance = this;
        this.flag = 0;
        super.onCreate();
    }

    @Override // android.app.Service
    public void onStart(Intent intent, int startId) {
    }

    @Override // android.app.Service
    public int onStartCommand(Intent intent, int flags, int startId) {
        String msg = intent.getExtras().getString("flag");
        this.url = intent.getExtras().getString(TbsVideoCacheTask.KEY_VIDEO_CACHE_PARAM_URL);
        this.filetype = intent.getExtras().getString("filetype");
        if (this.mThread == null) {
            this.mThread = new DownThread();
        }
        if (this.downloader == null) {
            this.downloader = new Downloader(this, this.url, this.filetype);
        }
        this.downloader.setDownloadListener(this.downListener);
        if (msg.equals("start")) {
            startDownload();
        } else if (msg.equals("pause")) {
            this.downloader.pause();
        } else if (msg.equals("resume")) {
            this.downloader.resume();
        } else if (msg.equals("stop")) {
            this.downloader.cancel();
            stopSelf();
        }
        return super.onStartCommand(intent, flags, startId);
    }

    private void startDownload() {
        if (this.flag == 0 || this.flag == 2) {
            if (this.mThread != null && !this.mThread.isAlive()) {
                this.mThread = new DownThread();
            }
            this.mThread.start();
        }
    }

    @Override // android.app.Service
    public void onDestroy() {
        try {
            this.flag = 0;
            this.mThread.join();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        this.mThread = null;
        super.onDestroy();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public class DownThread extends Thread {
        DownThread() {
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            if (DownloadService.this.flag == 0 || DownloadService.this.flag == 3) {
                DownloadService.this.flag = 1;
            }
            DownloadService.this.downloader.start();
        }
    }
}
