package com.androlua;

import android.content.Context;
import android.os.Environment;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
/* loaded from: classes.dex */
public class Downloader {
    DownloadListener downloadListener;
    String fileName;
    String filePath;
    private boolean isCancel;
    private boolean isPause;
    String urlStr;

    public void setDownloadListener(DownloadListener listener) {
        this.downloadListener = listener;
    }

    public Downloader(Context context, String url, String filePath, String fileName) {
        this.urlStr = url;
        this.filePath = filePath;
        this.fileName = fileName;
    }

    public Downloader(Context context, String url, String fileName) {
        this(context, url, "/download/", fileName);
    }

    public void start() {
        int len;
        try {
            URL url = new URL(this.urlStr);
            try {
                HttpURLConnection urlCon = (HttpURLConnection) url.openConnection();
                urlCon.setDoInput(true);
                urlCon.setRequestMethod("GET");
                urlCon.setRequestProperty("Content-Type", "application/x-www-form-urlencoded;charset=utf-8");
                urlCon.connect();
                int length = urlCon.getContentLength();
                this.downloadListener.onStart(length);
                if (urlCon.getResponseCode() == 200) {
                    File path = Environment.getExternalStoragePublicDirectory(this.filePath);
                    File file = new File(path, this.fileName);
                    BufferedInputStream is = new BufferedInputStream(urlCon.getInputStream());
                    BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(file));
                    byte[] buffer = new byte[10240];
                    int receivedBytes = 0;
                    loop0: while (true) {
                        if (this.isPause) {
                            this.downloadListener.onPause();
                        }
                        if (this.isCancel) {
                            this.downloadListener.onCancel();
                            break;
                        }
                        try {
                            Thread.sleep(50L);
                        } catch (InterruptedException e) {
                            e.printStackTrace();
                        }
                        while (!this.isPause && (len = is.read(buffer)) > 0) {
                            out.write(buffer, 0, len);
                            receivedBytes += len;
                            this.downloadListener.onProgress(receivedBytes);
                            if (receivedBytes == length) {
                                this.downloadListener.onSuccess(file);
                                break loop0;
                            } else if (this.isCancel) {
                                this.downloadListener.onCancel();
                                file.delete();
                                break loop0;
                            }
                        }
                    }
                    is.close();
                    out.close();
                }
            } catch (MalformedURLException e2) {
                e = e2;
                e.printStackTrace();
                this.downloadListener.onFail();
            } catch (IOException e3) {
                e = e3;
                e.printStackTrace();
                this.downloadListener.onFail();
            }
        } catch (MalformedURLException e4) {
            e = e4;
        } catch (IOException e5) {
            e = e5;
        }
    }

    public void pause() {
        this.isPause = true;
    }

    public void resume() {
        this.isPause = false;
        this.isCancel = false;
        this.downloadListener.onResume();
    }

    public void cancel() {
        this.isCancel = true;
    }
}
