package com.androlua;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Environment;
import android.preference.PreferenceManager;
import android.support.multidex.MultiDexApplication;
import android.widget.Toast;
import com.luajava.LuaState;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes.dex */
public class LuaApplication extends MultiDexApplication implements LuaContext {
    private static HashMap<String, Object> data = new HashMap<>();
    private static LuaApplication mApp;
    private boolean isUpdata;
    protected String libDir;
    protected String localDir;
    protected String luaCpath;
    protected String luaExtDir;
    protected String luaLpath;
    protected String luaMdDir;
    private SharedPreferences mSharedPreferences;
    protected String odexDir;

    public static LuaApplication getInstance() {
        return mApp;
    }

    @Override // com.androlua.LuaContext
    public ArrayList<ClassLoader> getClassLoaders() {
        return null;
    }

    @Override // com.androlua.LuaContext
    public void regGc(LuaGcable obj) {
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath() {
        return null;
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath(String path) {
        return new File(getLuaDir(), path).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath(String dir, String name) {
        return new File(getLuaDir(dir), name).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtPath(String path) {
        return new File(getLuaExtDir(), path).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtPath(String dir, String name) {
        return new File(getLuaExtDir(dir), name).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public int getWidth() {
        return getResources().getDisplayMetrics().widthPixels;
    }

    @Override // com.androlua.LuaContext
    public int getHeight() {
        return getResources().getDisplayMetrics().heightPixels;
    }

    @Override // com.androlua.LuaContext
    public String getLuaDir(String dir) {
        return null;
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtDir(String dir) {
        return null;
    }

    public String getLibDir() {
        return this.libDir;
    }

    public String getOdexDir() {
        return this.odexDir;
    }

    @Override // android.app.Application
    public void onCreate() {
        super.onCreate();
        mApp = this;
        CrashHandler crashHandler = CrashHandler.getInstance();
        crashHandler.init(getApplicationContext());
        this.mSharedPreferences = PreferenceManager.getDefaultSharedPreferences(this);
        if (Environment.getExternalStorageState().equals("mounted")) {
            String sdDir = Environment.getExternalStorageDirectory().getAbsolutePath();
            this.luaExtDir = sdDir + "/AndroLua";
        } else {
            File[] fs = new File("/storage").listFiles();
            for (File f : fs) {
                String[] ls = f.list();
                if (ls != null && ls.length > 5) {
                    this.luaExtDir = f.getAbsolutePath() + "/AndroLua";
                }
            }
            if (this.luaExtDir == null) {
                this.luaExtDir = getDir("AndroLua", 0).getAbsolutePath();
            }
        }
        File destDir = new File(this.luaExtDir);
        if (!destDir.exists()) {
            destDir.mkdirs();
        }
        this.localDir = getFilesDir().getAbsolutePath();
        this.odexDir = getDir("odex", 0).getAbsolutePath();
        this.libDir = getDir("lib", 0).getAbsolutePath();
        this.luaMdDir = getDir("lua", 0).getAbsolutePath();
        this.luaCpath = getApplicationInfo().nativeLibraryDir + "/lib?.so;" + this.libDir + "/lib?.so";
        this.luaLpath = this.luaMdDir + "/?.lua;" + this.luaMdDir + "/lua/?.lua;" + this.luaMdDir + "/?/init.lua;";
    }

    @Override // com.androlua.LuaContext
    public String getLuaDir() {
        return this.localDir;
    }

    @Override // com.androlua.LuaContext
    public void call(String name, Object[] args) {
    }

    @Override // com.androlua.LuaContext
    public void set(String name, Object object) {
        data.put(name, object);
    }

    @Override // com.androlua.LuaContext
    public Map getGlobalData() {
        return data;
    }

    @Override // com.androlua.LuaContext
    public Object getSharedData(String key) {
        return this.mSharedPreferences.getAll().get(key);
    }

    @Override // com.androlua.LuaContext
    public Object getSharedData(String key, Object def) {
        Object ret = this.mSharedPreferences.getAll().get(key);
        return ret == null ? def : ret;
    }

    @Override // com.androlua.LuaContext
    public boolean setSharedData(String key, Object value) {
        SharedPreferences.Editor edit = this.mSharedPreferences.edit();
        if (value == null) {
            edit.remove(key);
        } else if (value instanceof String) {
            edit.putString(key, value.toString());
        } else if (value instanceof Long) {
            edit.putLong(key, ((Long) value).longValue());
        } else if (value instanceof Integer) {
            edit.putInt(key, ((Integer) value).intValue());
        } else if (value instanceof Float) {
            edit.putFloat(key, ((Float) value).floatValue());
        } else {
            return false;
        }
        edit.apply();
        return true;
    }

    public Object get(String name) {
        return data.get(name);
    }

    public String getLocalDir() {
        return this.localDir;
    }

    public String getMdDir() {
        return this.luaMdDir;
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtDir() {
        return this.luaExtDir;
    }

    @Override // com.androlua.LuaContext
    public String getLuaLpath() {
        return this.luaLpath;
    }

    @Override // com.androlua.LuaContext
    public String getLuaCpath() {
        return this.luaCpath;
    }

    @Override // com.androlua.LuaContext
    public Context getContext() {
        return this;
    }

    @Override // com.androlua.LuaContext
    public LuaState getLuaState() {
        return null;
    }

    @Override // com.androlua.LuaContext
    public Object doFile(String path, Object[] arg) {
        return null;
    }

    @Override // com.androlua.LuaContext
    public void sendMsg(String msg) {
        Toast.makeText(this, msg, 0).show();
    }

    @Override // com.androlua.LuaContext
    public void sendError(String title, Exception msg) {
    }
}
