package com.androlua;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.PorterDuff;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.widget.AbsListView;
import android.widget.ArrayListAdapter;
import android.widget.ImageView;
import android.widget.TextView;
import com.luajava.LuaException;
import com.luajava.LuaObject;
import com.luajava.LuaState;
import java.io.IOException;
import java.util.HashMap;
/* loaded from: classes.dex */
public class LuaArrayAdapter extends ArrayListAdapter {
    private LuaState L;
    private HashMap<String, Boolean> loaded;
    private LuaObject loadlayout;
    private Animation mAnimation;
    private LuaContext mContext;
    private Drawable mDraw;
    private Handler mHandler;
    private Resources mRes;
    private LuaObject mResource;

    public LuaArrayAdapter(LuaContext context, LuaObject resource) throws LuaException {
        this(context, resource, new String[0]);
    }

    public LuaArrayAdapter(LuaContext context, LuaObject resource, Object[] objects) throws LuaException {
        super(context.getContext(), 0, objects);
        this.mHandler = new Handler() { // from class: com.androlua.LuaArrayAdapter.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                LuaArrayAdapter.this.notifyDataSetChanged();
            }
        };
        this.loaded = new HashMap<>();
        this.mContext = context;
        this.mResource = resource;
        this.mRes = this.mContext.getContext().getResources();
        this.mDraw = new BitmapDrawable(this.mRes, getClass().getResourceAsStream("/res/drawable/icon.png"));
        this.mDraw.setColorFilter(-1996488705, PorterDuff.Mode.SRC_ATOP);
        this.L = context.getLuaState();
        this.loadlayout = this.L.getLuaObject("loadlayout");
        this.L.newTable();
        this.loadlayout.call(this.mResource, this.L.getLuaObject(-1), AbsListView.class);
        this.L.pop(1);
    }

    @Override // android.widget.ArrayListAdapter, android.widget.BaseAdapter, android.widget.SpinnerAdapter
    public View getDropDownView(int position, View convertView, ViewGroup parent) {
        return getView(position, convertView, parent);
    }

    @Override // android.widget.ArrayListAdapter, android.widget.Adapter
    public View getView(int position, View convertView, ViewGroup parent) {
        View view;
        if (convertView == null) {
            this.L.newTable();
            LuaObject holder = this.L.getLuaObject(-1);
            this.L.pop(1);
            try {
                view = (View) this.loadlayout.call(this.mResource, holder, AbsListView.class);
            } catch (LuaException e) {
                return new View(this.mContext.getContext());
            }
        } else {
            view = convertView;
        }
        setHelper(view, getItem(position));
        if (this.mAnimation != null) {
            view.startAnimation(this.mAnimation);
        }
        return view;
    }

    public void setAnimation(Animation animation) {
        this.mAnimation = animation;
    }

    public Animation getAnimation() {
        return this.mAnimation;
    }

    private void setHelper(View view, Object value) {
        if (view instanceof TextView) {
            if (value instanceof CharSequence) {
                ((TextView) view).setText((CharSequence) value);
            } else {
                ((TextView) view).setText(value.toString());
            }
        } else if (view instanceof ImageView) {
            try {
                ImageView img = (ImageView) view;
                Drawable drawable = null;
                if (value instanceof Bitmap) {
                    drawable = new BitmapDrawable(this.mRes, (Bitmap) value);
                } else if (value instanceof String) {
                    drawable = new AsyncLoader().getBitmap(this.mContext, (String) value);
                } else if (value instanceof Drawable) {
                    drawable = (Drawable) value;
                } else if (value instanceof Number) {
                    drawable = this.mRes.getDrawable(((Number) value).intValue());
                }
                img.setImageDrawable(drawable);
                if (drawable instanceof BitmapDrawable) {
                    Bitmap bmp = ((BitmapDrawable) drawable).getBitmap();
                    int w = bmp.getWidth();
                    int h = bmp.getHeight();
                    if (img.getScaleType() == ImageView.ScaleType.FIT_XY) {
                        int h2 = (int) ((this.mContext.getWidth() * h) / w);
                        int w2 = this.mContext.getWidth();
                        img.setLayoutParams(new ViewGroup.LayoutParams(w2, h2));
                    }
                }
            } catch (Exception e) {
                Log.d("lua", e.getMessage());
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class AsyncLoader extends Thread {
        private LuaContext mContext;
        private String mPath;

        private AsyncLoader() {
        }

        public Drawable getBitmap(LuaContext context, String path) throws IOException {
            this.mContext = context;
            this.mPath = path;
            if (!path.startsWith("http://")) {
                return new BitmapDrawable(LuaArrayAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
            }
            if (!LuaBitmap.checkCache(context, path)) {
                if (!LuaArrayAdapter.this.loaded.containsKey(this.mPath)) {
                    start();
                    LuaArrayAdapter.this.loaded.put(this.mPath, true);
                }
                return LuaArrayAdapter.this.mDraw;
            }
            return new BitmapDrawable(LuaArrayAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            try {
                LuaBitmap.getBitmap(this.mContext, this.mPath);
                LuaArrayAdapter.this.mHandler.sendEmptyMessage(0);
            } catch (IOException e) {
                this.mContext.sendError("AsyncLoader", e);
            }
        }
    }
}
