package com.androlua;

import android.os.AsyncTask;
import com.luajava.JavaFunction;
import com.luajava.LuaException;
import com.luajava.LuaObject;
import com.luajava.LuaState;
import com.luajava.LuaStateFactory;
/* loaded from: classes.dex */
public class LuaAsyncTask extends AsyncTask implements LuaGcable {
    private LuaState L;
    private Object[] loadeds;
    private byte[] mBuffer;
    private LuaObject mCallback;
    private long mDelay;
    private LuaContext mLuaContext;
    private LuaObject mUpdate;

    @Override // com.androlua.LuaGcable
    public void gc() {
        if (getStatus() == AsyncTask.Status.RUNNING) {
            cancel(true);
        }
    }

    public LuaAsyncTask(LuaContext luaContext, long delay, LuaObject callback) throws LuaException {
        this.mDelay = 0L;
        luaContext.regGc(this);
        this.mLuaContext = luaContext;
        this.mDelay = delay;
        this.mCallback = callback;
    }

    public LuaAsyncTask(LuaContext luaContext, String src, LuaObject callback) throws LuaException {
        this.mDelay = 0L;
        luaContext.regGc(this);
        this.mLuaContext = luaContext;
        this.mBuffer = src.getBytes();
        this.mCallback = callback;
    }

    public LuaAsyncTask(LuaContext luaContext, LuaObject func, LuaObject callback) throws LuaException {
        this.mDelay = 0L;
        luaContext.regGc(this);
        this.mLuaContext = luaContext;
        this.mBuffer = func.dump();
        this.mCallback = callback;
        LuaState l = func.getLuaState();
        LuaObject g = l.getLuaObject("luajava");
        LuaObject loaded = g.getField("imported");
        if (!loaded.isNil()) {
            this.loadeds = loaded.asArray();
        }
    }

    public LuaAsyncTask(LuaContext luaContext, LuaObject func, LuaObject update, LuaObject callback) throws LuaException {
        this.mDelay = 0L;
        luaContext.regGc(this);
        this.mLuaContext = luaContext;
        this.mBuffer = func.dump();
        this.mUpdate = update;
        this.mCallback = callback;
    }

    public void execute() throws IllegalArgumentException, ArrayIndexOutOfBoundsException, LuaException {
        super.execute(new Object[0]);
    }

    public void update(Object msg) {
        publishProgress(msg);
    }

    public void update(String msg) {
        publishProgress(msg);
    }

    public void update(int msg) {
        publishProgress(Integer.valueOf(msg));
    }

    @Override // android.os.AsyncTask
    protected Object doInBackground(Object[] args) {
        Object[] objArr;
        if (this.mDelay != 0) {
            try {
                Thread.sleep(this.mDelay);
                return args;
            } catch (InterruptedException e) {
                return args;
            }
        }
        this.L = LuaStateFactory.newLuaState();
        this.L.openLibs();
        this.L.pushJavaObject(this.mLuaContext);
        if (this.mLuaContext instanceof LuaActivity) {
            this.L.setGlobal("activity");
        } else if (this.mLuaContext instanceof LuaService) {
            this.L.setGlobal("service");
        }
        this.L.pushJavaObject(this);
        this.L.setGlobal("this");
        this.L.pushContext(this.mLuaContext);
        this.L.getGlobal("luajava");
        this.L.pushString(this.mLuaContext.getLuaDir());
        this.L.setField(-2, "luadir");
        this.L.pop(1);
        try {
            JavaFunction print = new LuaPrint(this.mLuaContext, this.L);
            print.register("print");
            JavaFunction update = new JavaFunction(this.L) { // from class: com.androlua.LuaAsyncTask.1
                @Override // com.luajava.JavaFunction
                public int execute() throws LuaException {
                    LuaAsyncTask.this.update(this.L.toJavaObject(2));
                    return 0;
                }
            };
            update.register("update");
            this.L.getGlobal("package");
            this.L.pushString(this.mLuaContext.getLuaLpath());
            this.L.setField(-2, "path");
            this.L.pushString(this.mLuaContext.getLuaCpath());
            this.L.setField(-2, "cpath");
            this.L.pop(1);
        } catch (LuaException e2) {
            this.mLuaContext.sendError("AsyncTask", e2);
        }
        if (this.loadeds != null) {
            LuaObject require = this.L.getLuaObject("require");
            try {
                require.call("import");
                LuaObject _import = this.L.getLuaObject("import");
                for (Object s : this.loadeds) {
                    _import.call(s.toString());
                }
            } catch (LuaException e3) {
            }
        }
        try {
            this.L.setTop(0);
            int ok = this.L.LloadBuffer(this.mBuffer, "LuaAsyncTask");
            if (ok == 0) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = args.length;
                for (Object obj : args) {
                    this.L.pushObjectValue(obj);
                }
                ok = this.L.pcall(l, -1, (-2) - l);
                if (ok == 0) {
                    int n = this.L.getTop() - 1;
                    Object[] ret = new Object[n];
                    for (int i = 0; i < n; i++) {
                        ret[i] = this.L.toJavaObject(i + 2);
                    }
                    return ret;
                }
            }
            throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
        } catch (LuaException e4) {
            this.mLuaContext.sendError("doInBackground", e4);
            return null;
        }
    }

    @Override // android.os.AsyncTask
    protected void onPostExecute(Object result) {
        if (!isCancelled()) {
            try {
                if (this.mCallback != null) {
                    this.mCallback.call((Object[]) result);
                }
            } catch (LuaException e) {
                this.mLuaContext.sendError("onPostExecute", e);
            }
            super.onPostExecute(result);
            if (this.L != null) {
                this.L.gc(2, 1);
            }
            System.gc();
        }
    }

    @Override // android.os.AsyncTask
    protected void onProgressUpdate(Object[] values) {
        try {
            if (this.mUpdate != null) {
                this.mUpdate.call(values);
            }
        } catch (LuaException e) {
            this.mLuaContext.sendError("onProgressUpdate", e);
        }
        super.onProgressUpdate(values);
    }

    private String errorReason(int error) {
        switch (error) {
            case 1:
                return "Yield error";
            case 2:
                return "Runtime error";
            case 3:
                return "Syntax error";
            case 4:
                return "Out of memory";
            case 5:
                return "GC error";
            case 6:
                return "error error";
            default:
                return "Unknown error " + error;
        }
    }
}
