package com.androlua;

import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.view.View;
import com.pixplicity.sharp.Sharp;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.ref.WeakReference;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.WeakHashMap;
/* loaded from: classes.dex */
public class LuaBitmap {
    static WeakHashMap<String, WeakReference<Bitmap>> cache = new WeakHashMap<>();
    private static int l;

    public static Bitmap createTintedBitmap(Bitmap bitmap, int tintColor) {
        Bitmap tempBitmap = Bitmap.createBitmap(bitmap.getWidth(), bitmap.getHeight(), Bitmap.Config.ARGB_8888);
        Canvas tempCanvas = new Canvas(tempBitmap);
        tempCanvas.drawColor(tintColor);
        Paint paint = new Paint(1);
        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.DST_OUT));
        tempCanvas.drawBitmap(bitmap, 0.0f, 0.0f, paint);
        Bitmap resultBitmap = Bitmap.createBitmap(tempBitmap.getWidth(), tempBitmap.getHeight(), Bitmap.Config.ARGB_8888);
        Canvas resultCanvas = new Canvas(resultBitmap);
        resultCanvas.drawColor(tintColor);
        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.DST_OUT));
        resultCanvas.drawBitmap(tempBitmap, 0.0f, 0.0f, paint);
        tempBitmap.recycle();
        return resultBitmap;
    }

    public static Bitmap getBitmapFromView(View v) {
        if (v == null) {
            return null;
        }
        Bitmap screenshot = Bitmap.createBitmap(v.getWidth(), v.getHeight(), Bitmap.Config.ARGB_4444);
        Canvas canvas = new Canvas(screenshot);
        canvas.translate(-v.getScrollX(), -v.getScrollY());
        v.draw(canvas);
        return screenshot;
    }

    public static Bitmap svg2bitmap(String svgPath, int size) {
        try {
            FileInputStream input = new FileInputStream(svgPath);
            Sharp sharp = Sharp.loadInputStream(input);
            Bitmap bitmap = Bitmap.createBitmap(size, size, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(bitmap);
            canvas.drawPicture(sharp.getSharpPicture().getPicture(), new Rect(0, 0, size, size));
            return bitmap;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        }
    }

    public static Bitmap svg2bitmap(String svgPath, int size, int color) {
        try {
            FileInputStream input = new FileInputStream(svgPath);
            Sharp sharp = Sharp.loadInputStream(input);
            Bitmap bitmap = Bitmap.createBitmap(size, size, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(bitmap);
            canvas.drawPicture(sharp.getSharpPicture().getPicture(), new Rect(0, 0, size, size));
            Bitmap lbitmap = createTintedBitmap(bitmap, color);
            bitmap.recycle();
            return lbitmap;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        }
    }

    public static boolean checkCache(LuaContext context, String url) {
        String path = context.getLuaExtDir("cache") + "/" + url.hashCode();
        File f = new File(path);
        return f.exists();
    }

    public static Bitmap getLoacalBitmap(String url) throws FileNotFoundException, IOException {
        FileInputStream fis = new FileInputStream(url);
        Bitmap bitmap = BitmapFactory.decodeStream(fis);
        fis.close();
        return bitmap;
    }

    public static Bitmap getLoacalBitmap(LuaContext context, String url) {
        return decodeScale(context.getWidth(), new File(url));
    }

    public static Bitmap getHttpBitmap(String url) throws IOException {
        URL myFileUrl = new URL(url);
        HttpURLConnection conn = (HttpURLConnection) myFileUrl.openConnection();
        conn.setDoInput(true);
        conn.connect();
        InputStream is = conn.getInputStream();
        Bitmap bitmap = BitmapFactory.decodeStream(is);
        is.close();
        return bitmap;
    }

    public static Bitmap getHttpBitmap(LuaContext context, String url) throws IOException {
        String path = context.getLuaExtDir("cache") + "/" + url.hashCode();
        File f = new File(path);
        if (f.exists()) {
            return decodeScale(context.getWidth(), new File(path));
        }
        URL myFileUrl = new URL(url);
        HttpURLConnection conn = (HttpURLConnection) myFileUrl.openConnection();
        conn.setConnectTimeout(120000);
        conn.setDoInput(true);
        conn.connect();
        InputStream is = conn.getInputStream();
        FileOutputStream out = new FileOutputStream(path);
        if (!LuaUtil.copyFile(is, out)) {
            out.close();
            is.close();
            new File(path).delete();
            throw new RuntimeException("LoadHttpBitmap Error.");
        }
        out.close();
        is.close();
        return decodeScale(context.getWidth(), new File(path));
    }

    public static Bitmap getAssetBitmap(Context context, String name) throws IOException {
        AssetManager am = context.getAssets();
        InputStream is = am.open(name);
        Bitmap bitmap = BitmapFactory.decodeStream(is);
        is.close();
        return bitmap;
    }

    public static Bitmap getBitmap(LuaContext context, String path) throws IOException {
        Bitmap bitmap;
        Bitmap bt;
        WeakReference<Bitmap> wRef = cache.get(path);
        if (wRef == null || (bt = wRef.get()) == null) {
            if (path.indexOf("http://") == 0) {
                bitmap = getHttpBitmap(context, path);
            } else if (path.charAt(0) != '/') {
                bitmap = getLoacalBitmap(context, context.getLuaDir() + "/" + path);
            } else {
                bitmap = getLoacalBitmap(context, path);
            }
            cache.put(path, new WeakReference<>(bitmap));
            return bitmap;
        }
        return bt;
    }

    public static Bitmap decodeScale(int IMAGE_MAX_SIZE, File fis) {
        BitmapFactory.Options o = new BitmapFactory.Options();
        o.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(fis.getAbsolutePath(), o);
        int scale = 1;
        if (o.outHeight > IMAGE_MAX_SIZE || o.outWidth > IMAGE_MAX_SIZE) {
            scale = (int) Math.pow(2.0d, (int) Math.round(Math.log(IMAGE_MAX_SIZE / Math.max(o.outHeight, o.outWidth)) / Math.log(0.5d)));
        }
        BitmapFactory.Options o2 = new BitmapFactory.Options();
        o2.inSampleSize = scale;
        Bitmap b = BitmapFactory.decodeFile(fis.getAbsolutePath(), o2);
        return b;
    }

    public static Bitmap getImageFromPath(String filePath) {
        BitmapFactory.Options opts = new BitmapFactory.Options();
        opts.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(filePath, opts);
        opts.inSampleSize = computeSampleSize(opts, -1, 62500);
        opts.inJustDecodeBounds = false;
        try {
            Bitmap bitmap = BitmapFactory.decodeFile(filePath, opts);
            return bitmap;
        } catch (Exception e) {
            return null;
        }
    }

    private static int computeSampleSize(BitmapFactory.Options options, int minSideLength, int maxNumOfPixels) {
        int initialSize = computeInitialSampleSize(options, minSideLength, maxNumOfPixels);
        if (initialSize <= 8) {
            int roundedSize = 1;
            while (roundedSize < initialSize) {
                roundedSize <<= 1;
            }
            return roundedSize;
        }
        int roundedSize2 = ((initialSize + 7) / 8) * 8;
        return roundedSize2;
    }

    private static int computeInitialSampleSize(BitmapFactory.Options options, int minSideLength, int maxNumOfPixels) {
        double w = options.outWidth;
        double h = options.outHeight;
        int lowerBound = maxNumOfPixels == -1 ? 1 : (int) Math.ceil(Math.sqrt((w * h) / maxNumOfPixels));
        int upperBound = minSideLength == -1 ? 128 : (int) Math.min(Math.floor(w / minSideLength), Math.floor(h / minSideLength));
        if (upperBound >= lowerBound) {
            if (maxNumOfPixels == -1 && minSideLength == -1) {
                return 1;
            }
            if (minSideLength != -1) {
                return upperBound;
            }
            return lowerBound;
        }
        return lowerBound;
    }

    public static Bitmap getBitmapFromFile(File file, int width, int height) {
        BitmapFactory.Options opts = null;
        if (file != null && file.exists()) {
            if (width > 0 && height > 0) {
                opts = new BitmapFactory.Options();
                opts.inJustDecodeBounds = true;
                BitmapFactory.decodeFile(file.getPath(), opts);
                int minSideLength = Math.min(width, height);
                opts.inSampleSize = computeSampleSize(opts, minSideLength, width * height);
                opts.inJustDecodeBounds = false;
                opts.inInputShareable = true;
                opts.inPurgeable = true;
            }
            try {
                return BitmapFactory.decodeFile(file.getPath(), opts);
            } catch (OutOfMemoryError e) {
                e.printStackTrace();
            }
        }
        return null;
    }
}
