package com.androlua;

import android.content.res.AssetManager;
import android.content.res.Resources;
import com.luajava.LuaException;
import dalvik.system.DexClassLoader;
import java.io.File;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
/* loaded from: classes.dex */
public class LuaDexLoader {
    private static HashMap<String, LuaDexClassLoader> dexCache = new HashMap<>();
    private ArrayList<ClassLoader> dexList = new ArrayList<>();
    private HashMap<String, String> libCache = new HashMap<>();
    private String luaDir;
    private AssetManager mAssetManager;
    private LuaContext mContext;
    private Resources mResources;
    private Resources.Theme mTheme;
    private String odexDir;

    public LuaDexLoader(LuaContext context) {
        this.mContext = context;
        this.luaDir = context.getLuaDir();
        LuaApplication app = LuaApplication.getInstance();
        this.odexDir = app.getOdexDir();
    }

    public Resources.Theme getTheme() {
        return this.mTheme;
    }

    public ArrayList<ClassLoader> getClassLoaders() {
        return this.dexList;
    }

    public void loadLibs() throws LuaException {
        File[] libs = new File(this.mContext.getLuaDir() + "/libs").listFiles();
        if (libs != null) {
            for (File f : libs) {
                if (f.getAbsolutePath().endsWith(".so")) {
                    loadLib(f.getName());
                } else {
                    loadDex(f.getAbsolutePath());
                }
            }
        }
    }

    public void loadLib(String name) throws LuaException {
        String fn = name;
        int i = name.indexOf(".");
        if (i > 0) {
            fn = name.substring(0, i);
        }
        if (fn.startsWith("lib")) {
            fn = fn.substring(3);
        }
        String libDir = this.mContext.getContext().getDir(fn, 0).getAbsolutePath();
        String libPath = libDir + "/lib" + fn + ".so";
        File f = new File(libPath);
        if (!f.exists()) {
            File f2 = new File(this.luaDir + "/libs/lib" + fn + ".so");
            if (!f2.exists()) {
                throw new LuaException("can not find lib " + name);
            }
            LuaUtil.copyFile(this.luaDir + "/libs/lib" + fn + ".so", libPath);
        }
        this.libCache.put(fn, libPath);
    }

    public HashMap<String, String> getLibrarys() {
        return this.libCache;
    }

    public DexClassLoader loadDex(String path) throws LuaException {
        LuaDexClassLoader dex = dexCache.get(path);
        if (dex == null) {
            if (path.charAt(0) != '/') {
                path = this.luaDir + "/" + path;
            }
            if (!new File(path).exists()) {
                if (new File(path + ".dex").exists()) {
                    path = path + ".dex";
                } else if (new File(path + ".jar").exists()) {
                    path = path + ".jar";
                } else {
                    throw new LuaException(path + " not found");
                }
            }
            dex = new LuaDexClassLoader(path, this.odexDir, LuaApplication.getInstance().getApplicationInfo().nativeLibraryDir, this.mContext.getContext().getClassLoader());
            dexCache.put(path, dex);
        }
        if (!this.dexList.contains(dex)) {
            this.dexList.add(dex);
            String path2 = dex.getDexPath();
            if (path2.endsWith(".jar")) {
                loadResources(path2);
            }
        }
        return dex;
    }

    public void loadResources(String path) {
        try {
            AssetManager assetManager = (AssetManager) AssetManager.class.newInstance();
            Method addAssetPath = assetManager.getClass().getMethod("addAssetPath", String.class);
            int ok = ((Integer) addAssetPath.invoke(assetManager, path)).intValue();
            if (ok != 0) {
                this.mAssetManager = assetManager;
                Resources superRes = this.mContext.getContext().getResources();
                this.mResources = new LuaResources(this.mAssetManager, superRes.getDisplayMetrics(), superRes.getConfiguration());
                this.mTheme = this.mResources.newTheme();
                this.mTheme.setTo(this.mContext.getContext().getTheme());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public AssetManager getAssets() {
        return this.mAssetManager;
    }

    public Resources getResources() {
        return this.mResources;
    }
}
