package com.androlua;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.drawable.Drawable;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayListAdapter;
import android.widget.ListAdapter;
import android.widget.ListView;
import java.util.ArrayList;
import java.util.Arrays;
/* loaded from: classes.dex */
public class LuaDialog extends AlertDialog {
    private Context mContext;
    private ListView mListView;
    private String mMessage;
    private String mTitle;
    private View mView;

    public LuaDialog(Context context) {
        super(context);
        this.mContext = context;
        this.mListView = new ListView(this.mContext);
    }

    public LuaDialog(Context context, int theme) {
        super(context, theme);
        this.mContext = context;
        this.mListView = new ListView(this.mContext);
    }

    public void setPositiveButton(CharSequence text, DialogInterface.OnClickListener listener) {
        setButton(-1, text, listener);
    }

    public void setNegativeButton(CharSequence text, DialogInterface.OnClickListener listener) {
        setButton(-2, text, listener);
    }

    public void setNeutralButton(CharSequence text, DialogInterface.OnClickListener listener) {
        setButton(-3, text, listener);
    }

    public String getTitle() {
        return this.mTitle;
    }

    @Override // android.app.AlertDialog, android.app.Dialog
    public void setTitle(CharSequence title) {
        this.mTitle = title.toString();
        super.setTitle(title);
    }

    public String getMessage() {
        return this.mMessage;
    }

    @Override // android.app.AlertDialog
    public void setMessage(CharSequence message) {
        this.mMessage = message.toString();
        super.setMessage(message);
    }

    @Override // android.app.AlertDialog
    public void setIcon(Drawable icon) {
        super.setIcon(icon);
    }

    public View getView() {
        return this.mView;
    }

    @Override // android.app.AlertDialog
    public void setView(View view) {
        this.mView = view;
        super.setView(view);
    }

    public void setItems(String[] items) {
        ArrayList<String> alist = new ArrayList<>(Arrays.asList(items));
        ArrayListAdapter adp = new ArrayListAdapter(this.mContext, 17367043, alist);
        setAdapter(adp);
        this.mListView.setChoiceMode(0);
    }

    public void setAdapter(ListAdapter adp) {
        if (!this.mListView.equals(this.mView)) {
            setView(this.mListView);
        }
        this.mListView.setAdapter(adp);
    }

    public void setSingleChoiceItems(CharSequence[] items) {
        setSingleChoiceItems(items, 0);
    }

    public void setSingleChoiceItems(CharSequence[] items, int checkedItem) {
        ArrayList<CharSequence> alist = new ArrayList<>(Arrays.asList(items));
        ArrayListAdapter adp = new ArrayListAdapter(this.mContext, 17367055, alist);
        setAdapter(adp);
        this.mListView.setChoiceMode(1);
        this.mListView.setItemChecked(checkedItem, true);
    }

    public void setMultiChoiceItems(CharSequence[] items) {
        setMultiChoiceItems(items, new int[0]);
    }

    public void setMultiChoiceItems(CharSequence[] items, int[] checkedItems) {
        ArrayList<CharSequence> alist = new ArrayList<>(Arrays.asList(items));
        ArrayListAdapter adp = new ArrayListAdapter(this.mContext, 17367056, alist);
        setAdapter(adp);
        this.mListView.setChoiceMode(2);
        for (int i : checkedItems) {
            this.mListView.setItemChecked(checkedItems[i], true);
        }
    }

    @Override // android.app.AlertDialog
    public ListView getListView() {
        return this.mListView;
    }

    public void setOnItemClickListener(AdapterView.OnItemClickListener listener) {
        this.mListView.setOnItemClickListener(listener);
    }

    @Override // android.app.Dialog
    public void setOnCancelListener(DialogInterface.OnCancelListener listener) {
        super.setOnCancelListener(listener);
    }

    @Override // android.app.Dialog
    public void setOnDismissListener(DialogInterface.OnDismissListener listener) {
        super.setOnDismissListener(listener);
    }

    @Override // android.app.Dialog
    public void show() {
        super.create();
        getWindow().setWindowAnimations(R.style.dialog_anim);
        super.show();
    }

    @Override // android.app.Dialog
    public void hide() {
        super.hide();
    }

    @Override // android.app.Dialog
    public boolean isShowing() {
        return super.isShowing();
    }
}
