package com.androlua;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Typeface;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.ActionMode;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;
import com.myopicmobile.textwarrior.android.FreeScrollingTextField;
import com.myopicmobile.textwarrior.android.TrackpadNavigationMethod;
import com.myopicmobile.textwarrior.android.YoyoNavigationMethod;
import com.myopicmobile.textwarrior.common.ColorScheme;
import com.myopicmobile.textwarrior.common.ColorSchemeDark;
import com.myopicmobile.textwarrior.common.ColorSchemeLight;
import com.myopicmobile.textwarrior.common.Document;
import com.myopicmobile.textwarrior.common.DocumentProvider;
import com.myopicmobile.textwarrior.common.LanguageLua;
import com.myopicmobile.textwarrior.common.Lexer;
import com.myopicmobile.textwarrior.common.LinearSearchStrategy;
import com.myopicmobile.textwarrior.common.ReadTask;
import com.tencent.smtt.sdk.TbsListener;
import java.io.File;
/* loaded from: classes.dex */
public class LuaEditor extends FreeScrollingTextField {
    private int _index;
    private Document _inputingDoc;
    private boolean _isWordWrap;
    private String _lastSelectedFile;
    private LinearSearchStrategy finder;
    private String fontDir;
    private int idx;
    private Context mContext;
    private String mKeyword;

    public LuaEditor(Context context) {
        super(context);
        this.fontDir = "/sdcard/androlua/fonts/";
        this.mContext = context;
        setTypeface(Typeface.MONOSPACE);
        File df = new File(this.fontDir + "default.ttf");
        if (df.exists()) {
            setTypeface(Typeface.createFromFile(df));
        }
        File bf = new File(this.fontDir + "bold.ttf");
        if (bf.exists()) {
            setBoldTypeface(Typeface.createFromFile(bf));
        }
        File tf = new File(this.fontDir + "italic.ttf");
        if (tf.exists()) {
            setItalicTypeface(Typeface.createFromFile(tf));
        }
        DisplayMetrics dm = context.getResources().getDisplayMetrics();
        float size = TypedValue.applyDimension(2, BASE_TEXT_SIZE_PIXELS, dm);
        setTextSize((int) size);
        setShowLineNumbers(true);
        setHighlightCurrentRow(true);
        setWordWrap(false);
        setAutoIndentWidth(2);
        Lexer.setLanguage(LanguageLua.getInstance());
        if (isAccessibilityEnabled()) {
            setNavigationMethod(new TrackpadNavigationMethod(this));
        } else {
            setNavigationMethod(new YoyoNavigationMethod(this));
        }
        TypedArray array = this.mContext.getTheme().obtainStyledAttributes(new int[]{16842801, 16842806, 16842905});
        array.getColor(0, 16711935);
        int textColor = array.getColor(1, 16711935);
        int textColorHighlight = array.getColor(2, 16711935);
        array.recycle();
        setTextColor(textColor);
        setTextHighlightColor(textColorHighlight);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.myopicmobile.textwarrior.android.FreeScrollingTextField, android.view.View
    public void onLayout(boolean changed, int left, int top, int right, int bottom) {
        super.onLayout(changed, left, top, right, bottom);
        if (this._index != 0 && right > 0) {
            moveCaret(this._index);
            this._index = 0;
        }
    }

    public void setDark(boolean isDark) {
        if (isDark) {
            setColorScheme(new ColorSchemeDark());
        } else {
            setColorScheme(new ColorSchemeLight());
        }
    }

    public void addNames(String[] names) {
        LanguageLua lang = (LanguageLua) Lexer.getLanguage();
        String[] old = lang.getNames();
        String[] news = new String[old.length + names.length];
        System.arraycopy(old, 0, news, 0, old.length);
        System.arraycopy(names, 0, news, old.length, names.length);
        lang.setNames(news);
        Lexer.setLanguage(lang);
        respan();
        invalidate();
    }

    public void setPanelBackgroundColor(int color) {
        this._autoCompletePanel.setBackgroundColor(color);
    }

    public void setPanelTextColor(int color) {
        this._autoCompletePanel.setTextColor(color);
    }

    public void setKeywordColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.KEYWORD, color);
    }

    public void setUserwordColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.LITERAL, color);
    }

    public void setBasewordColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.NAME, color);
    }

    public void setStringColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.STRING, color);
    }

    public void setCommentColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.COMMENT, color);
    }

    public void setBackgoudColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.BACKGROUND, color);
    }

    public void setTextColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.FOREGROUND, color);
    }

    public void setTextHighlightColor(int color) {
        getColorScheme().setColor(ColorScheme.Colorable.SELECTION_BACKGROUND, color);
    }

    public String getSelectedText() {
        return this._hDoc.subSequence(getSelectionStart(), getSelectionEnd() - getSelectionStart()).toString();
    }

    @Override // android.view.View
    public boolean onKeyShortcut(int keyCode, KeyEvent event) {
        int filteredMetaState = event.getMetaState() & (-28673);
        if (KeyEvent.metaStateHasNoModifiers(filteredMetaState)) {
            switch (keyCode) {
                case 29:
                    selectAll();
                    return true;
                case 31:
                    copy();
                    return true;
                case Lexer.SINGLE_SYMBOL_DELIMITED_A /* 50 */:
                    paste();
                    return true;
                case 52:
                    cut();
                    return true;
            }
        }
        return super.onKeyShortcut(keyCode, event);
    }

    public void gotoLine() {
        startGotoMode();
    }

    public void search() {
        startFindMode();
    }

    public void startGotoMode() {
        startActionMode(new ActionMode.Callback() { // from class: com.androlua.LuaEditor.1
            private EditText edit;
            private int idx;

            @Override // android.view.ActionMode.Callback
            public boolean onCreateActionMode(ActionMode mode, Menu menu) {
                mode.setTitle("转到");
                mode.setSubtitle((CharSequence) null);
                this.edit = new EditText(LuaEditor.this.mContext) { // from class: com.androlua.LuaEditor.1.1
                    @Override // android.widget.TextView
                    public void onTextChanged(CharSequence s, int start, int before, int count) {
                        if (s.length() > 0) {
                            AnonymousClass1.this.idx = 0;
                            _gotoLine();
                        }
                    }
                };
                this.edit.setSingleLine(true);
                this.edit.setInputType(2);
                this.edit.setImeOptions(2);
                this.edit.setOnEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.androlua.LuaEditor.1.2
                    @Override // android.widget.TextView.OnEditorActionListener
                    public boolean onEditorAction(TextView p1, int p2, KeyEvent p3) {
                        _gotoLine();
                        return true;
                    }
                });
                this.edit.setLayoutParams(new RadioGroup.LayoutParams(LuaEditor.this.getWidth() / 3, -1));
                menu.add(0, 1, 0, "").setActionView(this.edit);
                menu.add(0, 2, 0, LuaEditor.this.mContext.getString(17039370));
                this.edit.requestFocus();
                return true;
            }

            /* JADX INFO: Access modifiers changed from: private */
            public void _gotoLine() {
                String s = this.edit.getText().toString();
                if (!s.isEmpty()) {
                    int l = Integer.valueOf(s).intValue();
                    if (l > LuaEditor.this._hDoc.getRowCount()) {
                        l = LuaEditor.this._hDoc.getRowCount();
                    }
                    LuaEditor.this.gotoLine(l);
                }
            }

            @Override // android.view.ActionMode.Callback
            public boolean onPrepareActionMode(ActionMode mode, Menu menu) {
                return false;
            }

            @Override // android.view.ActionMode.Callback
            public boolean onActionItemClicked(ActionMode mode, MenuItem item) {
                switch (item.getItemId()) {
                    case 1:
                    default:
                        return false;
                    case 2:
                        _gotoLine();
                        return false;
                }
            }

            @Override // android.view.ActionMode.Callback
            public void onDestroyActionMode(ActionMode p1) {
            }
        });
    }

    public void startFindMode() {
        startActionMode(new ActionMode.Callback() { // from class: com.androlua.LuaEditor.2
            private EditText edit;
            private LinearSearchStrategy finder;
            private int idx;

            @Override // android.view.ActionMode.Callback
            public boolean onCreateActionMode(ActionMode mode, Menu menu) {
                mode.setTitle("搜索");
                mode.setSubtitle((CharSequence) null);
                this.edit = new EditText(LuaEditor.this.mContext) { // from class: com.androlua.LuaEditor.2.1
                    @Override // android.widget.TextView
                    public void onTextChanged(CharSequence s, int start, int before, int count) {
                        if (s.length() > 0) {
                            AnonymousClass2.this.idx = 0;
                            findNext();
                        }
                    }
                };
                this.edit.setSingleLine(true);
                this.edit.setImeOptions(3);
                this.edit.setOnEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.androlua.LuaEditor.2.2
                    @Override // android.widget.TextView.OnEditorActionListener
                    public boolean onEditorAction(TextView p1, int p2, KeyEvent p3) {
                        findNext();
                        return true;
                    }
                });
                this.edit.setLayoutParams(new RadioGroup.LayoutParams(LuaEditor.this.getWidth() / 3, -1));
                menu.add(0, 1, 0, "").setActionView(this.edit);
                menu.add(0, 2, 0, LuaEditor.this.mContext.getString(17039372));
                this.edit.requestFocus();
                return true;
            }

            @Override // android.view.ActionMode.Callback
            public boolean onPrepareActionMode(ActionMode mode, Menu menu) {
                return false;
            }

            @Override // android.view.ActionMode.Callback
            public boolean onActionItemClicked(ActionMode mode, MenuItem item) {
                switch (item.getItemId()) {
                    case 1:
                    default:
                        return false;
                    case 2:
                        findNext();
                        return false;
                }
            }

            /* JADX INFO: Access modifiers changed from: private */
            public void findNext() {
                this.finder = new LinearSearchStrategy();
                String kw = this.edit.getText().toString();
                if (kw.isEmpty()) {
                    LuaEditor.this.selectText(false);
                    return;
                }
                this.idx = this.finder.find(LuaEditor.this.getText(), kw, this.idx, LuaEditor.this.getText().length(), false, false);
                if (this.idx == -1) {
                    LuaEditor.this.selectText(false);
                    Toast.makeText(LuaEditor.this.mContext, "未找到", (int) TbsListener.ErrorCode.INFO_CODE_MINIQB).show();
                    this.idx = 0;
                    return;
                }
                LuaEditor.this.setSelection(this.idx, this.edit.getText().length());
                this.idx += this.edit.getText().length();
                LuaEditor.this.moveCaret(this.idx);
            }

            @Override // android.view.ActionMode.Callback
            public void onDestroyActionMode(ActionMode p1) {
            }
        });
    }

    @Override // com.myopicmobile.textwarrior.android.FreeScrollingTextField
    public void setWordWrap(boolean enable) {
        this._isWordWrap = enable;
        super.setWordWrap(enable);
    }

    public DocumentProvider getText() {
        return createDocumentProvider();
    }

    public void setText(CharSequence c) {
        Document doc = new Document(this);
        doc.setWordWrap(this._isWordWrap);
        doc.setText(c);
        setDocumentProvider(new DocumentProvider(doc));
    }

    public void insert(int idx, String text) {
        selectText(false);
        moveCaret(idx);
        paste(text);
    }

    public void setText(CharSequence c, boolean isRep) {
        replaceText(0, getLength() - 1, c.toString());
    }

    public void setSelection(int index) {
        selectText(false);
        if (!hasLayout()) {
            moveCaret(index);
        } else {
            this._index = index;
        }
    }

    public void gotoLine(int line) {
        if (line > this._hDoc.getRowCount()) {
            line = this._hDoc.getRowCount();
        }
        int i = getText().getLineOffset(line - 1);
        setSelection(i);
    }

    public void undo() {
        DocumentProvider doc = createDocumentProvider();
        int newPosition = doc.undo();
        if (newPosition >= 0) {
            setEdited(true);
            respan();
            selectText(false);
            moveCaret(newPosition);
            invalidate();
        }
    }

    public void redo() {
        DocumentProvider doc = createDocumentProvider();
        int newPosition = doc.redo();
        if (newPosition >= 0) {
            setEdited(true);
            respan();
            selectText(false);
            moveCaret(newPosition);
            invalidate();
        }
    }

    public void open(String filename) {
        this._lastSelectedFile = filename;
        File inputFile = new File(filename);
        this._inputingDoc = new Document(this);
        this._inputingDoc.setWordWrap(isWordWrap());
        ReadTask _taskRead = new ReadTask(this, inputFile);
        _taskRead.start();
    }

    public void save(String filename, boolean overwrite) {
        File outputFile = new File(filename);
        if (!outputFile.exists() || !outputFile.canWrite()) {
        }
    }

    public boolean findNext(String keyword) {
        if (!keyword.equals(this.mKeyword)) {
            this.mKeyword = keyword;
            this.idx = 0;
        }
        this.finder = new LinearSearchStrategy();
        String kw = this.mKeyword;
        if (kw.isEmpty()) {
            selectText(false);
            return false;
        }
        this.idx = this.finder.find(getText(), kw, this.idx, getText().length(), false, false);
        if (this.idx == -1) {
            selectText(false);
            Toast.makeText(this.mContext, "未找到", (int) TbsListener.ErrorCode.INFO_CODE_MINIQB).show();
            this.idx = 0;
            return false;
        }
        setSelection(this.idx, this.mKeyword.length());
        this.idx += this.mKeyword.length();
        moveCaret(this.idx);
        return true;
    }
}
