package com.androlua;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.PorterDuff;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.widget.AbsListView;
import android.widget.BaseExpandableListAdapter;
import android.widget.ImageView;
import android.widget.TextView;
import com.luajava.LuaException;
import com.luajava.LuaFunction;
import com.luajava.LuaJavaAPI;
import com.luajava.LuaState;
import com.luajava.LuaTable;
import java.io.IOException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
/* loaded from: classes.dex */
public class LuaExpandableListAdapter extends BaseExpandableListAdapter {
    private LuaState L;
    private LuaFunction<?> insert;
    private HashMap<String, Boolean> loaded;
    private LuaFunction<View> loadlayout;
    private HashMap<View, Animation> mAnimCache;
    private LuaFunction<Animation> mAnimationUtil;
    private LuaTable<Integer, LuaTable<Integer, LuaTable<String, Object>>> mChildData;
    private LuaTable mChildLayout;
    private LuaContext mContext;
    private BitmapDrawable mDraw;
    private LuaTable<Integer, LuaTable<String, Object>> mGroupData;
    private LuaTable mGroupLayout;
    private Handler mHandler;
    private boolean mNotifyOnChange;
    private Resources mRes;
    private LuaFunction<?> remove;
    private boolean updateing;

    public LuaExpandableListAdapter(LuaContext context, LuaTable groupLayout, LuaTable childLayout) throws LuaException {
        this(context, null, null, groupLayout, childLayout);
    }

    public LuaExpandableListAdapter(LuaContext context, LuaTable<Integer, LuaTable<String, Object>> groupData, LuaTable<Integer, LuaTable<Integer, LuaTable<String, Object>>> childData, LuaTable groupLayout, LuaTable childLayout) throws LuaException {
        this.mAnimCache = new HashMap<>();
        this.mHandler = new Handler() { // from class: com.androlua.LuaExpandableListAdapter.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                LuaExpandableListAdapter.this.notifyDataSetChanged();
            }
        };
        this.loaded = new HashMap<>();
        this.mContext = context;
        this.L = context.getLuaState();
        this.mRes = this.mContext.getContext().getResources();
        this.mDraw = new BitmapDrawable(this.mRes, getClass().getResourceAsStream("/res/drawable/icon.png"));
        this.mDraw.setColorFilter(-1996488705, PorterDuff.Mode.SRC_ATOP);
        this.mGroupLayout = groupLayout;
        this.mChildLayout = childLayout;
        groupData = groupData == null ? new LuaTable<>(this.L) : groupData;
        childData = childData == null ? new LuaTable<>(this.L) : childData;
        this.mGroupData = groupData;
        this.mChildData = childData;
        this.loadlayout = this.L.getLuaObject("loadlayout").getFunction();
        this.insert = this.L.getLuaObject("table").getField("insert").getFunction();
        this.remove = this.L.getLuaObject("table").getField("remove").getFunction();
        this.L.newTable();
        this.loadlayout.call(this.mGroupLayout, this.L.getLuaObject(-1), AbsListView.class);
        this.loadlayout.call(this.mChildLayout, this.L.getLuaObject(-1), AbsListView.class);
        this.L.pop(1);
    }

    public void setAnimationUtil(LuaFunction<Animation> animation) {
        this.mAnimCache.clear();
        this.mAnimationUtil = animation;
    }

    @Override // android.widget.ExpandableListAdapter
    public int getGroupCount() {
        return this.mGroupData.length();
    }

    @Override // android.widget.ExpandableListAdapter
    public int getChildrenCount(int groupPosition) {
        return this.mChildData.get(Integer.valueOf(groupPosition + 1)).length();
    }

    @Override // android.widget.ExpandableListAdapter
    public Object getGroup(int groupPosition) {
        return this.mGroupData.get(Integer.valueOf(groupPosition + 1));
    }

    @Override // android.widget.ExpandableListAdapter
    public Object getChild(int groupPosition, int childPosition) {
        return this.mChildData.get(Integer.valueOf(groupPosition + 1)).get(Integer.valueOf(childPosition + 1));
    }

    @Override // android.widget.ExpandableListAdapter
    public long getGroupId(int groupPosition) {
        return groupPosition + 1;
    }

    @Override // android.widget.ExpandableListAdapter
    public long getChildId(int groupPosition, int childPosition) {
        return childPosition + 1;
    }

    @Override // android.widget.ExpandableListAdapter
    public boolean hasStableIds() {
        return false;
    }

    public GroupItem getGroupItem(int groupPosition) {
        return new GroupItem(this.mChildData.get(Integer.valueOf(groupPosition + 1)));
    }

    public LuaTable<Integer, LuaTable<String, Object>> getGroupData() {
        return this.mGroupData;
    }

    public LuaTable<Integer, LuaTable<Integer, LuaTable<String, Object>>> getChildData() {
        return this.mChildData;
    }

    public GroupItem add(LuaTable<String, Object> groupItem) throws Exception {
        this.mGroupData.put(Integer.valueOf(this.mGroupData.length() + 1), groupItem);
        LuaTable<Integer, LuaTable<String, Object>> childItem = new LuaTable<>(this.L);
        this.mChildData.put(Integer.valueOf(this.mGroupData.length()), childItem);
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
        return new GroupItem(childItem);
    }

    public GroupItem add(LuaTable<String, Object> groupItem, LuaTable<Integer, LuaTable<String, Object>> childItem) throws Exception {
        this.mGroupData.put(Integer.valueOf(this.mGroupData.length() + 1), groupItem);
        this.mChildData.put(Integer.valueOf(this.mGroupData.length()), childItem);
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
        return new GroupItem(childItem);
    }

    public GroupItem insert(int position, LuaTable<String, Object> groupItem, LuaTable<Integer, LuaTable<String, Object>> childItem) throws Exception {
        this.insert.call(this.mGroupData, Integer.valueOf(position + 1), groupItem);
        this.insert.call(this.mChildData, Integer.valueOf(position + 1), childItem);
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
        return new GroupItem(childItem);
    }

    public void remove(int idx) throws Exception {
        this.remove.call(this.mGroupData, Integer.valueOf(idx + 1));
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void clear() {
        this.mGroupData.clear();
        this.mChildData.clear();
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void setNotifyOnChange(boolean notifyOnChange) {
        this.mNotifyOnChange = notifyOnChange;
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    @Override // android.widget.ExpandableListAdapter
    public View getGroupView(int groupPosition, boolean isExpanded, View convertView, ViewGroup parent) {
        LuaTable<String, View> holder;
        View view;
        LuaTable<String, View> holder2;
        if (convertView == null) {
            try {
                holder = new LuaTable<>(this.L);
            } catch (LuaException e) {
            }
            try {
                view = this.loadlayout.call(this.mGroupLayout, holder, AbsListView.class);
                view.setTag(holder);
                holder2 = holder;
            } catch (LuaException e2) {
                return new View(this.mContext.getContext());
            }
        } else {
            view = convertView;
            holder2 = (LuaTable) view.getTag();
        }
        LuaTable<String, Object> hm = this.mGroupData.get(Integer.valueOf(groupPosition + 1));
        if (hm == null) {
            Log.d("lua", groupPosition + " is null");
            return view;
        }
        Set<Map.Entry<String, Object>> sets = hm.entrySet();
        for (Map.Entry<String, Object> entry : sets) {
            try {
                String key = entry.getKey();
                Object value = entry.getValue();
                View obj = holder2.get(key);
                if (obj != null) {
                    setHelper(obj, value);
                }
            } catch (Exception e3) {
                Log.d("lua", e3.getMessage());
            }
        }
        if (this.updateing) {
            return view;
        }
        if (this.mAnimationUtil != null && convertView != null) {
            Animation anim = this.mAnimCache.get(convertView);
            if (anim == null) {
                try {
                    anim = this.mAnimationUtil.call(new Object[0]);
                    this.mAnimCache.put(convertView, anim);
                } catch (Exception e4) {
                    Log.d("lua", e4.getMessage());
                }
            }
            if (anim != null) {
                view.clearAnimation();
                view.startAnimation(anim);
            }
        }
        return view;
    }

    @Override // android.widget.ExpandableListAdapter
    public View getChildView(int groupPosition, int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
        LuaTable<String, View> holder;
        View view;
        LuaTable<String, View> holder2;
        if (convertView == null) {
            try {
                holder = new LuaTable<>(this.L);
            } catch (LuaException e) {
            }
            try {
                view = this.loadlayout.call(this.mChildLayout, holder, AbsListView.class);
                view.setTag(holder);
                holder2 = holder;
            } catch (LuaException e2) {
                return new View(this.mContext.getContext());
            }
        } else {
            view = convertView;
            holder2 = (LuaTable) view.getTag();
        }
        LuaTable<String, Object> hm = this.mChildData.get(Integer.valueOf(groupPosition + 1)).get(Integer.valueOf(childPosition + 1));
        if (hm == null) {
            Log.d("lua", childPosition + " is null");
            return view;
        }
        Set<Map.Entry<String, Object>> sets = hm.entrySet();
        for (Map.Entry<String, Object> entry : sets) {
            try {
                String key = entry.getKey();
                Object value = entry.getValue();
                View obj = holder2.get(key);
                if (obj != null) {
                    setHelper(obj, value);
                }
            } catch (Exception e3) {
                Log.d("lua", e3.getMessage());
            }
        }
        if (this.updateing) {
            return view;
        }
        if (this.mAnimationUtil != null && convertView != null) {
            Animation anim = this.mAnimCache.get(convertView);
            if (anim == null) {
                try {
                    anim = this.mAnimationUtil.call(new Object[0]);
                    this.mAnimCache.put(convertView, anim);
                } catch (Exception e4) {
                    Log.d("lua", e4.getMessage());
                }
            }
            if (anim != null) {
                view.clearAnimation();
                view.startAnimation(anim);
            }
        }
        return view;
    }

    @Override // android.widget.ExpandableListAdapter
    public boolean isChildSelectable(int groupPosition, int childPosition) {
        return false;
    }

    private void setFields(View view, LuaTable<String, Object> fields) {
        Set<Map.Entry<String, Object>> sets = fields.entrySet();
        for (Map.Entry<String, Object> entry2 : sets) {
            try {
                String key2 = entry2.getKey();
                Object value2 = entry2.getValue();
                if (key2.toLowerCase().equals("src")) {
                    setHelper(view, value2);
                } else {
                    javaSetter(view, key2, value2);
                }
            } catch (Exception e2) {
                Log.d("lua", e2.getMessage());
            }
        }
    }

    private void setHelper(View view, Object value) {
        if (value instanceof LuaTable) {
            setFields(view, (LuaTable) value);
        } else if (view instanceof TextView) {
            if (value instanceof CharSequence) {
                ((TextView) view).setText((CharSequence) value);
            } else {
                ((TextView) view).setText(value.toString());
            }
        } else if (view instanceof ImageView) {
            try {
                if (value instanceof Bitmap) {
                    ((ImageView) view).setImageBitmap((Bitmap) value);
                } else if (value instanceof String) {
                    ((ImageView) view).setImageDrawable(new AsyncLoader().getBitmap(this.mContext, (String) value));
                } else if (value instanceof Drawable) {
                    ((ImageView) view).setImageDrawable((Drawable) value);
                } else if (value instanceof Number) {
                    ((ImageView) view).setImageResource(((Number) value).intValue());
                }
            } catch (Exception e) {
                Log.d("lua", e.getMessage());
            }
        }
    }

    private int javaSetter(Object obj, String methodName, Object value) throws LuaException {
        return (methodName.length() > 2 && methodName.substring(0, 2).equals("on") && (value instanceof LuaFunction)) ? javaSetListener(obj, methodName, value) : javaSetMethod(obj, methodName, value);
    }

    private int javaSetListener(Object obj, String methodName, Object value) throws LuaException {
        String name = "setOn" + methodName.substring(2) + "Listener";
        ArrayList<Method> methods = LuaJavaAPI.getMethod(obj.getClass(), name, false);
        Iterator<Method> it = methods.iterator();
        while (it.hasNext()) {
            Method m = it.next();
            Class<?>[] tp = m.getParameterTypes();
            if (tp.length == 1 && tp[0].isInterface()) {
                this.L.newTable();
                this.L.pushObjectValue(value);
                this.L.setField(-2, methodName);
                try {
                    Object listener = this.L.getLuaObject(-1).createProxy(tp[0]);
                    m.invoke(obj, listener);
                    return 1;
                } catch (Exception e) {
                    throw new LuaException(e);
                }
            }
        }
        return 0;
    }

    private int javaSetMethod(Object obj, String methodName, Object value) throws LuaException {
        if (Character.isLowerCase(methodName.charAt(0))) {
            methodName = Character.toUpperCase(methodName.charAt(0)) + methodName.substring(1);
        }
        String name = "set" + methodName;
        Class<?> type = value.getClass();
        StringBuilder buf = new StringBuilder();
        ArrayList<Method> methods = LuaJavaAPI.getMethod(obj.getClass(), name, false);
        Iterator<Method> it = methods.iterator();
        while (it.hasNext()) {
            Method m = it.next();
            Class<?>[] tp = m.getParameterTypes();
            if (tp.length == 1) {
                if (tp[0].isPrimitive()) {
                    try {
                        if ((value instanceof Double) || (value instanceof Float)) {
                            m.invoke(obj, LuaState.convertLuaNumber(Double.valueOf(((Number) value).doubleValue()), tp[0]));
                        } else if ((value instanceof Long) || (value instanceof Integer)) {
                            m.invoke(obj, LuaState.convertLuaNumber(Long.valueOf(((Number) value).longValue()), tp[0]));
                        } else if (value instanceof Boolean) {
                            m.invoke(obj, (Boolean) value);
                        }
                        return 1;
                    } catch (Exception e) {
                        buf.append(e.getMessage());
                        buf.append("\n");
                    }
                } else if (tp[0].isAssignableFrom(type)) {
                    try {
                        m.invoke(obj, value);
                        return 1;
                    } catch (Exception e2) {
                        buf.append(e2.getMessage());
                        buf.append("\n");
                    }
                } else {
                    continue;
                }
            }
        }
        if (buf.length() > 0) {
            throw new LuaException("Invalid setter " + methodName + ". Invalid Parameters.\n" + buf.toString() + type.toString());
        }
        throw new LuaException("Invalid setter " + methodName + " is not a method.\n");
    }

    /* loaded from: classes.dex */
    private class GroupItem {
        private LuaTable<Integer, LuaTable<String, Object>> mData;

        public GroupItem(LuaTable<Integer, LuaTable<String, Object>> item) {
            this.mData = item;
        }

        public LuaTable<Integer, LuaTable<String, Object>> getData() {
            return this.mData;
        }

        public void add(LuaTable<String, Object> item) throws Exception {
            this.mData.put(Integer.valueOf(this.mData.length() + 1), item);
            if (LuaExpandableListAdapter.this.mNotifyOnChange) {
                LuaExpandableListAdapter.this.notifyDataSetChanged();
            }
        }

        public void insert(int position, LuaTable<String, Object> item) throws Exception {
            LuaExpandableListAdapter.this.insert.call(this.mData, Integer.valueOf(position + 1), item);
            if (LuaExpandableListAdapter.this.mNotifyOnChange) {
                LuaExpandableListAdapter.this.notifyDataSetChanged();
            }
        }

        public void remove(int position) throws Exception {
            LuaExpandableListAdapter.this.remove.call(this.mData, Integer.valueOf(position + 1));
            if (LuaExpandableListAdapter.this.mNotifyOnChange) {
                LuaExpandableListAdapter.this.notifyDataSetChanged();
            }
        }

        public void clear() {
            this.mData.clear();
            if (LuaExpandableListAdapter.this.mNotifyOnChange) {
                LuaExpandableListAdapter.this.notifyDataSetChanged();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class AsyncLoader extends Thread {
        private LuaContext mContext;
        private String mPath;

        private AsyncLoader() {
        }

        public Drawable getBitmap(LuaContext context, String path) throws IOException {
            this.mContext = context;
            this.mPath = path;
            if (!path.startsWith("http://")) {
                return new BitmapDrawable(LuaExpandableListAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
            }
            if (!LuaBitmap.checkCache(context, path)) {
                if (!LuaExpandableListAdapter.this.loaded.containsKey(this.mPath)) {
                    start();
                    LuaExpandableListAdapter.this.loaded.put(this.mPath, true);
                }
                return LuaExpandableListAdapter.this.mDraw;
            }
            return new BitmapDrawable(LuaExpandableListAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            try {
                LuaBitmap.getBitmap(this.mContext, this.mPath);
                LuaExpandableListAdapter.this.mHandler.sendEmptyMessage(0);
            } catch (IOException e) {
                this.mContext.sendError("AsyncLoader", e);
            }
        }
    }
}
