package com.androlua;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.PorterDuff;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.widget.AbsListView;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;
import com.luajava.LuaException;
import com.luajava.LuaFunction;
import com.luajava.LuaJavaAPI;
import com.luajava.LuaObject;
import com.luajava.LuaState;
import com.luajava.LuaTable;
import java.io.IOException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
/* loaded from: classes.dex */
public class LuaMultiAdapter extends BaseAdapter {
    private LuaState L;
    private LuaFunction insert;
    private LuaFunction<View> loadLayout;
    private HashMap<String, Boolean> loaded;
    private HashMap<View, Animation> mAnimCache;
    private LuaTable<Integer, LuaFunction<Animation>> mAnimationUtil;
    private LuaContext mContext;
    private LuaTable<Integer, LuaTable<String, Object>> mData;
    private BitmapDrawable mDraw;
    private Handler mHandler;
    private LuaTable<Integer, LuaTable> mLayout;
    private boolean mNotifyOnChange;
    private Resources mRes;
    private HashMap<View, Boolean> mStyleCache;
    private LuaTable<String, Object> mTheme;
    private LuaFunction remove;
    private boolean updateing;

    public LuaMultiAdapter(LuaContext context, LuaTable layout) throws LuaException {
        this(context, null, layout);
    }

    public LuaMultiAdapter(LuaContext context, LuaTable<Integer, LuaTable<String, Object>> data, LuaTable<Integer, LuaTable> layout) throws LuaException {
        this.mAnimCache = new HashMap<>();
        this.mStyleCache = new HashMap<>();
        this.mNotifyOnChange = true;
        this.mHandler = new Handler() { // from class: com.androlua.LuaMultiAdapter.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                LuaMultiAdapter.this.notifyDataSetChanged();
            }
        };
        this.loaded = new HashMap<>();
        this.mContext = context;
        this.mLayout = layout;
        this.mRes = this.mContext.getContext().getResources();
        this.mDraw = new BitmapDrawable(this.mRes, getClass().getResourceAsStream("/res/drawable/icon.png"));
        this.mDraw.setColorFilter(-1996488705, PorterDuff.Mode.SRC_ATOP);
        this.L = context.getLuaState();
        this.mData = data == null ? new LuaTable<>(this.L) : data;
        this.loadLayout = this.L.getLuaObject("loadlayout").getFunction();
        this.insert = this.L.getLuaObject("table").getField("insert").getFunction();
        this.remove = this.L.getLuaObject("table").getField("remove").getFunction();
        int len = this.mLayout.length();
        for (int i = 1; i <= len; i++) {
            this.L.newTable();
            this.loadLayout.call(this.mLayout.get(Integer.valueOf(i)), this.L.getLuaObject(-1), AbsListView.class);
            this.L.pop(1);
        }
    }

    @Override // android.widget.BaseAdapter, android.widget.Adapter
    public int getViewTypeCount() {
        return this.mLayout.length();
    }

    @Override // android.widget.BaseAdapter, android.widget.Adapter
    public int getItemViewType(int position) {
        int t = ((Long) this.mData.get(Integer.valueOf(position + 1)).get("__type")).intValue() - 1;
        if (t < 0) {
            return 0;
        }
        return t;
    }

    public void setAnimation(LuaTable<Integer, LuaFunction<Animation>> animation) {
        setAnimationUtil(animation);
    }

    public void setAnimationUtil(LuaTable<Integer, LuaFunction<Animation>> animation) {
        this.mAnimCache.clear();
        this.mAnimationUtil = animation;
    }

    @Override // android.widget.Adapter
    public int getCount() {
        return this.mData.length();
    }

    @Override // android.widget.Adapter
    public Object getItem(int position) {
        return this.mData.get(Integer.valueOf(position + 1));
    }

    @Override // android.widget.Adapter
    public long getItemId(int position) {
        return position + 1;
    }

    public LuaTable<Integer, LuaTable<String, Object>> getData() {
        return this.mData;
    }

    public void add(LuaTable<String, Object> item) throws Exception {
        this.mData.put(Integer.valueOf(this.mData.length() + 1), item);
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void insert(int position, LuaTable<String, Object> item) throws Exception {
        this.insert.call(this.mData, Integer.valueOf(position + 1), item);
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void remove(int position) throws Exception {
        this.remove.call(this.mData, Integer.valueOf(position + 1));
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void clear() {
        this.mData.clear();
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    public void setNotifyOnChange(boolean notifyOnChange) {
        this.mNotifyOnChange = notifyOnChange;
        if (this.mNotifyOnChange) {
            notifyDataSetChanged();
        }
    }

    @Override // android.widget.BaseAdapter
    public void notifyDataSetChanged() {
        super.notifyDataSetChanged();
        if (!this.updateing) {
            this.updateing = true;
            new Handler().postDelayed(new Runnable() { // from class: com.androlua.LuaMultiAdapter.2
                @Override // java.lang.Runnable
                public void run() {
                    LuaMultiAdapter.this.updateing = false;
                }
            }, 500L);
        }
    }

    @Override // android.widget.BaseAdapter, android.widget.SpinnerAdapter
    public View getDropDownView(int position, View convertView, ViewGroup parent) {
        return getView(position, convertView, parent);
    }

    public void setStyle(LuaTable<String, Object> theme) {
        this.mStyleCache.clear();
        this.mTheme = theme;
    }

    @Override // android.widget.Adapter
    public View getView(int position, View convertView, ViewGroup parent) {
        LuaObject holder;
        View view;
        int t = ((Long) this.mData.get(Integer.valueOf(position + 1)).get("__type")).intValue();
        if (t < 1) {
            t = 1;
        }
        if (convertView == null) {
            try {
                LuaTable layout = this.mLayout.get(Integer.valueOf(t));
                this.L.newTable();
                holder = this.L.getLuaObject(-1);
                this.L.pop(1);
                view = this.loadLayout.call(layout, holder, AbsListView.class);
                view.setTag(holder);
            } catch (LuaException e) {
                return new View(this.mContext.getContext());
            }
        } else {
            view = convertView;
            holder = (LuaObject) view.getTag();
        }
        LuaTable<String, Object> hm = this.mData.get(Integer.valueOf(position + 1));
        if (hm == null) {
            Log.d("lua", position + " is null");
            return view;
        }
        boolean bool = this.mStyleCache.get(view) == null;
        if (bool) {
            this.mStyleCache.put(view, true);
        }
        Set<Map.Entry<String, Object>> sets = hm.entrySet();
        for (Map.Entry<String, Object> entry : sets) {
            try {
                String key = entry.getKey();
                if (!key.equals("type")) {
                    Object value = entry.getValue();
                    LuaObject obj = holder.getField(key);
                    if (obj.isJavaObject()) {
                        if (this.mTheme != null && bool) {
                            setHelper((View) obj.getObject(), this.mTheme.get(key));
                        }
                        setHelper((View) obj.getObject(), value);
                    }
                }
            } catch (Exception e2) {
                Log.d("lua", e2.getMessage());
            }
        }
        if (this.updateing) {
            return view;
        }
        if (this.mAnimationUtil != null && convertView != null) {
            Animation anim = this.mAnimCache.get(convertView);
            if (anim == null) {
                try {
                    anim = this.mAnimationUtil.get(Integer.valueOf(t)).call(new Object[0]);
                    this.mAnimCache.put(convertView, anim);
                } catch (Exception e3) {
                    this.mContext.sendError("setAnimation", e3);
                }
            }
            if (anim != null) {
                view.clearAnimation();
                view.startAnimation(anim);
            }
        }
        return view;
    }

    private void setFields(View view, LuaTable<String, Object> fields) throws LuaException {
        Set<Map.Entry<String, Object>> sets = fields.entrySet();
        for (Map.Entry<String, Object> entry2 : sets) {
            String key2 = entry2.getKey();
            Object value2 = entry2.getValue();
            if (key2.toLowerCase().equals("src")) {
                setHelper(view, value2);
            } else {
                javaSetter(view, key2, value2);
            }
        }
    }

    private void setHelper(View view, Object value) {
        try {
            if (value instanceof LuaTable) {
                setFields(view, (LuaTable) value);
            } else if (view instanceof TextView) {
                if (value instanceof CharSequence) {
                    ((TextView) view).setText((CharSequence) value);
                } else {
                    ((TextView) view).setText(value.toString());
                }
            } else if (view instanceof ImageView) {
                if (value instanceof Bitmap) {
                    ((ImageView) view).setImageBitmap((Bitmap) value);
                } else if (value instanceof String) {
                    ((ImageView) view).setImageDrawable(new AsyncLoader().getBitmap(this.mContext, (String) value));
                } else if (value instanceof Drawable) {
                    ((ImageView) view).setImageDrawable((Drawable) value);
                } else if (value instanceof Number) {
                    ((ImageView) view).setImageResource(((Number) value).intValue());
                }
            }
        } catch (Exception e) {
            this.mContext.sendError("setHelper", e);
        }
    }

    private int javaSetter(Object obj, String methodName, Object value) throws LuaException {
        return (methodName.length() > 2 && methodName.substring(0, 2).equals("on") && (value instanceof LuaFunction)) ? javaSetListener(obj, methodName, value) : javaSetMethod(obj, methodName, value);
    }

    private int javaSetListener(Object obj, String methodName, Object value) throws LuaException {
        String name = "setOn" + methodName.substring(2) + "Listener";
        ArrayList<Method> methods = LuaJavaAPI.getMethod(obj.getClass(), name, false);
        Iterator<Method> it = methods.iterator();
        while (it.hasNext()) {
            Method m = it.next();
            Class<?>[] tp = m.getParameterTypes();
            if (tp.length == 1 && tp[0].isInterface()) {
                this.L.newTable();
                this.L.pushObjectValue(value);
                this.L.setField(-2, methodName);
                try {
                    Object listener = this.L.getLuaObject(-1).createProxy(tp[0]);
                    m.invoke(obj, listener);
                    return 1;
                } catch (Exception e) {
                    throw new LuaException(e);
                }
            }
        }
        return 0;
    }

    private int javaSetMethod(Object obj, String methodName, Object value) throws LuaException {
        if (Character.isLowerCase(methodName.charAt(0))) {
            methodName = Character.toUpperCase(methodName.charAt(0)) + methodName.substring(1);
        }
        String name = "set" + methodName;
        Class<?> type = value.getClass();
        StringBuilder buf = new StringBuilder();
        ArrayList<Method> methods = LuaJavaAPI.getMethod(obj.getClass(), name, false);
        Iterator<Method> it = methods.iterator();
        while (it.hasNext()) {
            Method m = it.next();
            Class<?>[] tp = m.getParameterTypes();
            if (tp.length == 1) {
                if (tp[0].isPrimitive()) {
                    try {
                        if ((value instanceof Double) || (value instanceof Float)) {
                            m.invoke(obj, LuaState.convertLuaNumber(Double.valueOf(((Number) value).doubleValue()), tp[0]));
                        } else if ((value instanceof Long) || (value instanceof Integer)) {
                            m.invoke(obj, LuaState.convertLuaNumber(Long.valueOf(((Number) value).longValue()), tp[0]));
                        } else if (value instanceof Boolean) {
                            m.invoke(obj, (Boolean) value);
                        }
                        return 1;
                    } catch (Exception e) {
                        buf.append(e.getMessage());
                        buf.append("\n");
                    }
                } else if (tp[0].isAssignableFrom(type)) {
                    try {
                        m.invoke(obj, value);
                        return 1;
                    } catch (Exception e2) {
                        buf.append(e2.getMessage());
                        buf.append("\n");
                    }
                } else {
                    continue;
                }
            }
        }
        if (buf.length() > 0) {
            throw new LuaException("Invalid setter " + methodName + ". Invalid Parameters.\n" + buf.toString() + type.toString());
        }
        throw new LuaException("Invalid setter " + methodName + " is not a method.\n");
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class AsyncLoader extends Thread {
        private LuaContext mContext;
        private String mPath;

        private AsyncLoader() {
        }

        public Drawable getBitmap(LuaContext context, String path) throws IOException {
            this.mContext = context;
            this.mPath = path;
            if (!path.startsWith("http://")) {
                return new BitmapDrawable(LuaMultiAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
            }
            if (!LuaBitmap.checkCache(context, path)) {
                if (!LuaMultiAdapter.this.loaded.containsKey(this.mPath)) {
                    start();
                    LuaMultiAdapter.this.loaded.put(this.mPath, true);
                }
                return LuaMultiAdapter.this.mDraw;
            }
            return new BitmapDrawable(LuaMultiAdapter.this.mRes, LuaBitmap.getBitmap(context, path));
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            try {
                LuaBitmap.getBitmap(this.mContext, this.mPath);
                LuaMultiAdapter.this.mHandler.sendEmptyMessage(0);
            } catch (IOException e) {
                this.mContext.sendError("AsyncLoader", e);
            }
        }
    }
}
