package com.androlua;

import android.content.res.AssetManager;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.util.DisplayMetrics;
import android.util.SparseArray;
import android.util.SparseIntArray;
import com.luajava.LuaException;
import com.luajava.LuaMetaTable;
import java.util.HashMap;
/* loaded from: classes.dex */
public class LuaResources extends Resources implements LuaMetaTable {
    private static SparseArray<String> mTextMap = new SparseArray<>();
    private static SparseArray<Drawable> mDrawableMap = new SparseArray<>();
    private static SparseIntArray mColorMap = new SparseIntArray();
    private static int mId = R.xml.accessibility_service_config;
    private static HashMap<String, Integer> mIdMap = new HashMap<>();

    public LuaResources(AssetManager assets, DisplayMetrics metrics, Configuration config) {
        super(assets, metrics, config);
    }

    public static void setText(int id, String text) {
        if (text == null) {
            throw new NullPointerException();
        }
        mTextMap.put(id, text);
    }

    public static void setDrawable(int id, Drawable drawable) {
        if (drawable == null) {
            throw new NullPointerException();
        }
        mDrawableMap.put(id, drawable);
    }

    public static void setColor(int id, int color) {
        mColorMap.put(id, color);
    }

    @Override // android.content.res.Resources
    public CharSequence getText(int id) throws Resources.NotFoundException {
        String text = mTextMap.get(id);
        return text != null ? text : super.getText(id);
    }

    @Override // android.content.res.Resources
    public CharSequence getText(int id, CharSequence def) {
        String text = mTextMap.get(id);
        return text != null ? text : super.getText(id, def);
    }

    @Override // android.content.res.Resources
    public Drawable getDrawable(int id) throws Resources.NotFoundException {
        Drawable drawable = mDrawableMap.get(id);
        return drawable != null ? drawable : super.getDrawable(id);
    }

    @Override // android.content.res.Resources
    public Drawable getDrawable(int id, Resources.Theme theme) throws Resources.NotFoundException {
        Drawable drawable = mDrawableMap.get(id);
        return drawable != null ? drawable : super.getDrawable(id, theme);
    }

    @Override // android.content.res.Resources
    public int getColor(int id) throws Resources.NotFoundException {
        int color = mColorMap.get(id);
        return color != 0 ? color : super.getColor(id);
    }

    @Override // com.luajava.LuaMetaTable
    public Object __call(Object... arg) throws LuaException {
        return null;
    }

    public static int put(String key, Object value) {
        if (value == null) {
            throw new NullPointerException();
        }
        int id = mId;
        mId = id + 1;
        if (value instanceof Drawable) {
            setDrawable(id, (Drawable) value);
        } else if (value instanceof String) {
            setText(id, (String) value);
        } else if (value instanceof Number) {
            setColor(id, ((Number) value).intValue());
        } else {
            throw new IllegalArgumentException();
        }
        mIdMap.put(key, Integer.valueOf(id));
        return id;
    }

    public static Object get(String key) {
        return mIdMap.get(key);
    }

    @Override // com.luajava.LuaMetaTable
    public Object __index(String key) {
        return get(key);
    }

    @Override // com.luajava.LuaMetaTable
    public void __newIndex(String key, Object value) {
        put(key, value);
    }
}
