package com.androlua;

import android.app.Notification;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.res.AssetManager;
import android.content.res.Resources;
import android.net.Uri;
import android.os.Binder;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.util.Log;
import android.widget.Toast;
import com.androlua.LuaBroadcastReceiver;
import com.luajava.JavaFunction;
import com.luajava.LuaException;
import com.luajava.LuaObject;
import com.luajava.LuaState;
import com.luajava.LuaStateFactory;
import dalvik.system.DexClassLoader;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes.dex */
public class LuaService extends Service implements LuaContext, LuaBroadcastReceiver.OnReceiveListerer {
    private static LuaService _this;
    private LuaState L;
    private MainHandler handler;
    private long lastShow;
    private String libDir;
    private String localDir;
    public String luaCpath;
    public String luaDir;
    private String luaExtDir;
    private String luaLpath;
    private String luaMdDir;
    private String luaPath;
    private LuaDexLoader mLuaDexLoader;
    private BroadcastReceiver mReceiver;
    private LuaResources mResources;
    private String odexDir;
    private Toast toast;
    LuaBinder mBinder = new LuaBinder();
    private ArrayList<LuaGcable> gclist = new ArrayList<>();
    private StringBuilder output = new StringBuilder();
    private StringBuilder toastbuilder = new StringBuilder();

    private static byte[] readAll(InputStream input) throws IOException {
        ByteArrayOutputStream output = new ByteArrayOutputStream(4096);
        byte[] buffer = new byte[4096];
        while (true) {
            int n = input.read(buffer);
            if (-1 != n) {
                output.write(buffer, 0, n);
            } else {
                byte[] ret = output.toByteArray();
                output.close();
                return ret;
            }
        }
    }

    public static LuaService getService() {
        return _this;
    }

    @Override // com.androlua.LuaContext
    public ArrayList<ClassLoader> getClassLoaders() {
        return this.mLuaDexLoader.getClassLoaders();
    }

    public DexClassLoader loadDex(String path) throws LuaException {
        return this.mLuaDexLoader.loadDex(path);
    }

    public HashMap<String, String> getLibrarys() {
        return this.mLuaDexLoader.getLibrarys();
    }

    public void loadResources(String path) {
        this.mLuaDexLoader.loadResources(path);
    }

    @Override // android.content.ContextWrapper, android.content.Context
    public AssetManager getAssets() {
        return (this.mLuaDexLoader == null || this.mLuaDexLoader.getAssets() == null) ? super.getAssets() : this.mLuaDexLoader.getAssets();
    }

    @Override // android.content.ContextWrapper, android.content.Context
    public Resources getResources() {
        if (this.mLuaDexLoader != null && this.mLuaDexLoader.getResources() != null) {
            return this.mLuaDexLoader.getResources();
        }
        if (this.mResources != null) {
            return this.mResources;
        }
        return super.getResources();
    }

    public Intent registerReceiver(LuaBroadcastReceiver receiver, IntentFilter filter) {
        return super.registerReceiver((BroadcastReceiver) receiver, filter);
    }

    public Intent registerReceiver(LuaBroadcastReceiver.OnReceiveListerer ltr, IntentFilter filter) {
        LuaBroadcastReceiver receiver = new LuaBroadcastReceiver(ltr);
        return super.registerReceiver((BroadcastReceiver) receiver, filter);
    }

    public Intent registerReceiver(IntentFilter filter) {
        if (this.mReceiver != null) {
            unregisterReceiver(this.mReceiver);
        }
        this.mReceiver = new LuaBroadcastReceiver(this);
        return super.registerReceiver(this.mReceiver, filter);
    }

    @Override // com.androlua.LuaBroadcastReceiver.OnReceiveListerer
    public void onReceive(Context context, Intent intent) {
        runFunc("onReceive", context, intent);
    }

    @Override // com.androlua.LuaContext
    public void regGc(LuaGcable obj) {
        this.gclist.add(obj);
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath() {
        return this.luaPath;
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath(String path) {
        return new File(getLuaDir(), path).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaPath(String dir, String name) {
        return new File(getLuaDir(dir), name).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtPath(String path) {
        return new File(getLuaExtDir(), path).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtPath(String dir, String name) {
        return new File(getLuaExtDir(dir), name).getAbsolutePath();
    }

    @Override // com.androlua.LuaContext
    public String getLuaDir(String name) {
        File dir = new File(this.luaDir + "/" + name);
        if (dir.exists() || dir.mkdirs()) {
            return dir.getAbsolutePath();
        }
        return null;
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtDir(String name) {
        File dir = new File(this.luaExtDir + "/" + name);
        if (dir.exists() || dir.mkdirs()) {
            return dir.getAbsolutePath();
        }
        return null;
    }

    @Override // com.androlua.LuaContext
    public String getLuaDir() {
        return this.luaDir;
    }

    @Override // com.androlua.LuaContext
    public String getLuaExtDir() {
        return this.luaExtDir;
    }

    @Override // com.androlua.LuaContext
    public String getLuaLpath() {
        return this.luaLpath;
    }

    @Override // com.androlua.LuaContext
    public String getLuaCpath() {
        return this.luaCpath;
    }

    @Override // com.androlua.LuaContext
    public Context getContext() {
        return this;
    }

    @Override // com.androlua.LuaContext
    public LuaState getLuaState() {
        return this.L;
    }

    public LuaBinder getBinder() {
        return this.mBinder;
    }

    public void setBinder(LuaBinder mBinder) {
        this.mBinder = mBinder;
    }

    @Override // android.app.Service
    public IBinder onBind(Intent p1) {
        startForeground(1, new Notification());
        return new LuaBinder();
    }

    @Override // android.app.Service
    public void onCreate() {
        super.onCreate();
        Resources superRes = super.getResources();
        this.mResources = new LuaResources(getAssets(), superRes.getDisplayMetrics(), superRes.getConfiguration());
        _this = this;
        LuaApplication app = (LuaApplication) getApplication();
        this.localDir = app.getLocalDir();
        this.odexDir = app.getOdexDir();
        this.libDir = app.getLibDir();
        this.luaMdDir = app.getMdDir();
        this.luaCpath = app.getLuaCpath();
        this.luaDir = this.localDir;
        this.luaLpath = app.getLuaLpath();
        this.luaExtDir = app.getLuaExtDir();
        this.handler = new MainHandler();
    }

    @Override // android.app.Service
    public int onStartCommand(Intent intent, int flags, int startId) {
        _this = this;
        if (this.L == null) {
            startForeground(1, new Notification());
            this.luaPath = intent.getStringExtra("luaPath");
            this.luaDir = intent.getStringExtra("luaDir");
            this.luaLpath = this.luaDir + "/?.lua;" + this.luaDir + "/lua/?.lua;" + this.luaDir + "/?/init.lua;" + this.luaLpath;
            Uri uri = intent.getData();
            try {
                initLua();
                this.mLuaDexLoader = new LuaDexLoader(this);
                this.mLuaDexLoader.loadLibs();
                if (uri != null) {
                    doFile(uri.getPath());
                } else {
                    doFile("service.lua");
                }
            } catch (Exception e) {
                sendMsg(e.getMessage());
            }
        }
        runFunc("onStartCommand", intent, Integer.valueOf(flags), Integer.valueOf(startId));
        runFunc("onStart", (Object[]) intent.getSerializableExtra("arg"));
        return super.onStartCommand(intent, flags, startId);
    }

    @Override // android.app.Service
    public boolean onUnbind(Intent intent) {
        return super.onUnbind(intent);
    }

    @Override // android.app.Service
    public void onDestroy() {
        unregisterReceiver(this.mReceiver);
        super.onDestroy();
    }

    @Override // com.androlua.LuaContext
    public int getWidth() {
        return getResources().getDisplayMetrics().widthPixels;
    }

    @Override // com.androlua.LuaContext
    public int getHeight() {
        return getResources().getDisplayMetrics().heightPixels;
    }

    @Override // com.androlua.LuaContext
    public Map getGlobalData() {
        return LuaApplication.getInstance().getGlobalData();
    }

    @Override // com.androlua.LuaContext
    public Object getSharedData(String key) {
        return LuaApplication.getInstance().getSharedData(key);
    }

    @Override // com.androlua.LuaContext
    public Object getSharedData(String key, Object def) {
        return LuaApplication.getInstance().getSharedData(key, def);
    }

    @Override // com.androlua.LuaContext
    public boolean setSharedData(String key, Object value) {
        return LuaApplication.getInstance().setSharedData(key, value);
    }

    private void initLua() throws Exception {
        this.L = LuaStateFactory.newLuaState();
        this.L.openLibs();
        this.L.pushJavaObject(this);
        this.L.setGlobal("service");
        this.L.getGlobal("service");
        this.L.setGlobal("this");
        this.L.pushContext(this);
        this.L.getGlobal("luajava");
        this.L.pushString(this.luaExtDir);
        this.L.setField(-2, "luaextdir");
        this.L.pushString(this.luaDir);
        this.L.setField(-2, "luadir");
        this.L.pushString(this.luaPath);
        this.L.setField(-2, "luapath");
        this.L.pop(1);
        new LuaAssetLoader(this, this.L);
        this.L.getGlobal("package");
        this.L.pushString(this.luaLpath);
        this.L.setField(-2, "path");
        this.L.pushString(this.luaCpath);
        this.L.setField(-2, "cpath");
        this.L.pop(1);
        JavaFunction print = new JavaFunction(this.L) { // from class: com.androlua.LuaService.1
            @Override // com.luajava.JavaFunction
            public int execute() throws LuaException {
                if (this.L.getTop() < 2) {
                    LuaService.this.sendMsg("");
                } else {
                    for (int i = 2; i <= this.L.getTop(); i++) {
                        int type = this.L.type(i);
                        String val = null;
                        String stype = this.L.typeName(type);
                        char c = 65535;
                        switch (stype.hashCode()) {
                            case -266011147:
                                if (stype.equals("userdata")) {
                                    c = 0;
                                    break;
                                }
                                break;
                            case 64711720:
                                if (stype.equals("boolean")) {
                                    c = 1;
                                    break;
                                }
                                break;
                        }
                        switch (c) {
                            case 0:
                                Object obj = this.L.toJavaObject(i);
                                if (obj != null) {
                                    val = obj.toString();
                                    break;
                                }
                                break;
                            case 1:
                                if (this.L.toBoolean(i)) {
                                    val = "true";
                                    break;
                                } else {
                                    val = "false";
                                    break;
                                }
                            default:
                                val = this.L.toString(i);
                                break;
                        }
                        if (val == null) {
                            val = stype;
                        }
                        LuaService.this.output.append("\t");
                        LuaService.this.output.append(val);
                        LuaService.this.output.append("\t");
                    }
                    LuaService.this.sendMsg(LuaService.this.output.toString().substring(1, LuaService.this.output.length() - 1));
                    LuaService.this.output.setLength(0);
                }
                return 0;
            }
        };
        print.register("print");
        JavaFunction set = new JavaFunction(this.L) { // from class: com.androlua.LuaService.2
            @Override // com.luajava.JavaFunction
            public int execute() throws LuaException {
                LuaThread thread = (LuaThread) this.L.toJavaObject(2);
                thread.set(this.L.toString(3), this.L.toJavaObject(4));
                return 0;
            }
        };
        set.register("set");
        JavaFunction call = new JavaFunction(this.L) { // from class: com.androlua.LuaService.3
            @Override // com.luajava.JavaFunction
            public int execute() throws LuaException {
                LuaThread thread = (LuaThread) this.L.toJavaObject(2);
                int top = this.L.getTop();
                if (top > 3) {
                    Object[] args = new Object[top - 3];
                    for (int i = 4; i <= top; i++) {
                        args[i - 4] = this.L.toJavaObject(i);
                    }
                    thread.call(this.L.toString(3), args);
                    return 0;
                } else if (top == 3) {
                    thread.call(this.L.toString(3));
                    return 0;
                } else {
                    return 0;
                }
            }
        };
        call.register("call");
    }

    public Object doFile(String filePath) {
        return doFile(filePath, new Object[0]);
    }

    @Override // com.androlua.LuaContext
    public Object doFile(String filePath, Object[] args) {
        try {
            if (filePath.charAt(0) != '/') {
                filePath = this.luaDir + "/" + filePath;
            }
            this.L.setTop(0);
            int ok = this.L.LloadFile(filePath);
            if (ok == 0) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = 0;
                if (args != null) {
                    l = args.length;
                }
                for (int i = 0; i < l; i++) {
                    this.L.pushObjectValue(args[i]);
                }
                ok = this.L.pcall(l, 1, (-2) - l);
                if (ok == 0) {
                    return this.L.toJavaObject(-1);
                }
            }
            throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
        } catch (LuaException e) {
            sendMsg(e.getMessage());
            return null;
        }
    }

    public Object doAsset(String name, Object... args) {
        try {
            byte[] bytes = readAsset(name);
            this.L.setTop(0);
            int ok = this.L.LloadBuffer(bytes, name);
            if (ok == 0) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = 0;
                if (args != null) {
                    l = args.length;
                }
                for (int i = 0; i < l; i++) {
                    this.L.pushObjectValue(args[i]);
                }
                ok = this.L.pcall(l, 0, (-2) - l);
                if (ok == 0) {
                    return this.L.toJavaObject(-1);
                }
            }
            throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
        } catch (Exception e) {
            sendMsg(e.getMessage());
            return null;
        }
    }

    public Object runFunc(String funcName, Object... args) {
        if (this.L != null) {
            try {
                this.L.setTop(0);
                this.L.getGlobal(funcName);
                if (this.L.isFunction(-1)) {
                    this.L.getGlobal(BuildConfig.BUILD_TYPE);
                    this.L.getField(-1, "traceback");
                    this.L.remove(-2);
                    this.L.insert(-2);
                    int l = 0;
                    if (args != null) {
                        l = args.length;
                    }
                    for (int i = 0; i < l; i++) {
                        this.L.pushObjectValue(args[i]);
                    }
                    int ok = this.L.pcall(l, 1, (-2) - l);
                    if (ok == 0) {
                        return this.L.toJavaObject(-1);
                    }
                    throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
                }
            } catch (LuaException e) {
                sendMsg(funcName + " " + e.getMessage());
            }
        }
        return null;
    }

    public Object doString(String funcSrc, Object... args) {
        try {
            this.L.setTop(0);
            int ok = this.L.LloadString(funcSrc);
            if (ok == 0) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = 0;
                if (args != null) {
                    l = args.length;
                }
                for (int i = 0; i < l; i++) {
                    this.L.pushObjectValue(args[i]);
                }
                ok = this.L.pcall(l, 1, (-2) - l);
                if (ok == 0) {
                    return this.L.toJavaObject(-1);
                }
            }
            throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
        } catch (LuaException e) {
            sendMsg(e.getMessage());
            return null;
        }
    }

    private String errorReason(int error) {
        switch (error) {
            case 1:
                return "Yield error";
            case 2:
                return "Runtime error";
            case 3:
                return "Syntax error";
            case 4:
                return "Out of memory";
            case 5:
                return "GC error";
            case 6:
                return "error error";
            default:
                return "Unknown error " + error;
        }
    }

    public byte[] readAsset(String name) throws IOException {
        AssetManager am = getAssets();
        InputStream is = am.open(name);
        byte[] ret = readAll(is);
        is.close();
        return ret;
    }

    @Override // com.androlua.LuaContext
    public void sendMsg(String msg) {
        Message message = new Message();
        Bundle bundle = new Bundle();
        bundle.putString("data", msg);
        message.setData(bundle);
        message.what = 0;
        this.handler.sendMessage(message);
        Log.d("lua", msg);
    }

    @Override // com.androlua.LuaContext
    public void sendError(String title, Exception msg) {
        runFunc("onError", title, msg);
    }

    public Object loadLib(String name) throws LuaException {
        int i = name.indexOf(".");
        String fn = name;
        if (i > 0) {
            fn = name.substring(0, i);
        }
        File f = new File(this.libDir + "/lib" + fn + ".so");
        if (!f.exists()) {
            File f2 = new File(this.luaDir + "/lib" + fn + ".so");
            if (!f2.exists()) {
                throw new LuaException("can not find lib " + name);
            }
            copyFile(this.luaDir + "/lib" + fn + ".so", this.libDir + "/lib" + fn + ".so");
        }
        LuaObject require = this.L.getLuaObject("require");
        return require.call(name);
    }

    private void copyFile(String oldPath, String newPath) {
        int bytesum = 0;
        try {
            File oldfile = new File(oldPath);
            if (oldfile.exists()) {
                InputStream inStream = new FileInputStream(oldPath);
                FileOutputStream fs = new FileOutputStream(newPath);
                byte[] buffer = new byte[4096];
                while (true) {
                    int byteread = inStream.read(buffer);
                    if (byteread != -1) {
                        bytesum += byteread;
                        System.out.println(bytesum);
                        fs.write(buffer, 0, byteread);
                    } else {
                        inStream.close();
                        return;
                    }
                }
            }
        } catch (Exception e) {
            System.out.println("复制文件操作出错");
            e.printStackTrace();
        }
    }

    public void showToast(String text) {
        long now = System.currentTimeMillis();
        if (this.toast == null || now - this.lastShow > 1000) {
            this.toastbuilder.setLength(0);
            this.toast = Toast.makeText(this, text, 1);
            this.toastbuilder.append(text);
        } else {
            this.toastbuilder.append("\n");
            this.toastbuilder.append(text);
            this.toast.setText(this.toastbuilder.toString());
            this.toast.setDuration(1);
        }
        this.lastShow = now;
        this.toast.show();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setField(String key, Object value) {
        try {
            this.L.pushObjectValue(value);
            this.L.setGlobal(key);
        } catch (LuaException e) {
            sendMsg(e.getMessage());
        }
    }

    public void call(String func) {
        push(2, func);
    }

    @Override // com.androlua.LuaContext
    public void call(String func, Object[] args) {
        if (args.length == 0) {
            push(2, func);
        } else {
            push(3, func, args);
        }
    }

    @Override // com.androlua.LuaContext
    public void set(String key, Object value) {
        push(1, key, new Object[]{value});
    }

    public Object get(String key) throws LuaException {
        this.L.getGlobal(key);
        return this.L.toJavaObject(-1);
    }

    public void push(int what, String s) {
        Message message = new Message();
        Bundle bundle = new Bundle();
        bundle.putString("data", s);
        message.setData(bundle);
        message.what = what;
        this.handler.sendMessage(message);
    }

    /* JADX WARN: Multi-variable type inference failed */
    public void push(int what, String s, Object[] args) {
        Message message = new Message();
        Bundle bundle = new Bundle();
        bundle.putString("data", s);
        bundle.putSerializable("args", args);
        message.setData(bundle);
        message.what = what;
        this.handler.sendMessage(message);
    }

    /* loaded from: classes.dex */
    public class LuaBinder extends Binder {
        public LuaBinder() {
        }

        public LuaService getService() {
            return LuaService.this;
        }
    }

    /* loaded from: classes.dex */
    public class MainHandler extends Handler {
        public MainHandler() {
        }

        @Override // android.os.Handler
        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            switch (msg.what) {
                case 0:
                    LuaService.this.showToast(msg.getData().getString("data"));
                    return;
                case 1:
                    Bundle data = msg.getData();
                    LuaService.this.setField(data.getString("data"), ((Object[]) data.getSerializable("args"))[0]);
                    return;
                case 2:
                    String src = msg.getData().getString("data");
                    LuaService.this.runFunc(src, new Object[0]);
                    return;
                case 3:
                    String src2 = msg.getData().getString("data");
                    Serializable args = msg.getData().getSerializable("args");
                    LuaService.this.runFunc(src2, (Object[]) args);
                    return;
                default:
                    return;
            }
        }
    }
}
