package com.androlua;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.luajava.JavaFunction;
import com.luajava.LuaException;
import com.luajava.LuaMetaTable;
import com.luajava.LuaObject;
import com.luajava.LuaState;
import com.luajava.LuaStateFactory;
import java.io.IOException;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public class LuaThread extends Thread implements Runnable, LuaMetaTable, LuaGcable {
    private LuaState L;
    public boolean isRun;
    private Object[] mArg;
    private byte[] mBuffer;
    private boolean mIsLoop;
    private LuaContext mLuaContext;
    private String mSrc;
    private Handler thandler;

    @Override // com.androlua.LuaGcable
    public void gc() {
        quit();
    }

    @Override // com.luajava.LuaMetaTable
    public Object __call(Object[] arg) {
        return null;
    }

    @Override // com.luajava.LuaMetaTable
    public Object __index(final String key) {
        return new LuaMetaTable() { // from class: com.androlua.LuaThread.1
            @Override // com.luajava.LuaMetaTable
            public Object __call(Object[] arg) {
                LuaThread.this.call(key, arg);
                return null;
            }

            @Override // com.luajava.LuaMetaTable
            public Object __index(String key2) {
                return null;
            }

            @Override // com.luajava.LuaMetaTable
            public void __newIndex(String key2, Object value) {
            }
        };
    }

    @Override // com.luajava.LuaMetaTable
    public void __newIndex(String key, Object value) {
        set(key, value);
    }

    public LuaThread(LuaContext luaContext, String src) throws LuaException {
        this(luaContext, src, false, (Object[]) null);
    }

    public LuaThread(LuaContext luaContext, String src, Object[] arg) throws LuaException {
        this(luaContext, src, false, arg);
    }

    public LuaThread(LuaContext luaContext, String src, boolean isLoop) throws LuaException {
        this(luaContext, src, isLoop, (Object[]) null);
    }

    public LuaThread(LuaContext luaContext, String src, boolean isLoop, Object[] arg) throws LuaException {
        this.isRun = false;
        this.mArg = new Object[0];
        luaContext.regGc(this);
        this.mLuaContext = luaContext;
        this.mSrc = src;
        this.mIsLoop = isLoop;
        if (arg != null) {
            this.mArg = arg;
        }
    }

    public LuaThread(LuaContext luaContext, LuaObject func) throws LuaException {
        this(luaContext, func, false, (Object[]) null);
    }

    public LuaThread(LuaContext luaContext, LuaObject func, Object[] arg) throws LuaException {
        this(luaContext, func, false, arg);
    }

    public LuaThread(LuaContext luaContext, LuaObject func, boolean isLoop) throws LuaException {
        this(luaContext, func, isLoop, (Object[]) null);
    }

    public LuaThread(LuaContext luaContext, LuaObject func, boolean isLoop, Object[] arg) throws LuaException {
        this.isRun = false;
        this.mArg = new Object[0];
        this.mLuaContext = luaContext;
        if (arg != null) {
            this.mArg = arg;
        }
        this.mIsLoop = isLoop;
        this.mBuffer = func.dump();
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        try {
            if (this.L == null) {
                initLua();
                if (this.mBuffer != null) {
                    newLuaThread(this.mBuffer, this.mArg);
                } else {
                    newLuaThread(this.mSrc, this.mArg);
                }
            }
            if (this.mIsLoop) {
                Looper.prepare();
                this.thandler = new ThreadHandler();
                this.isRun = true;
                this.L.getGlobal("run");
                if (!this.L.isNil(-1)) {
                    this.L.pop(1);
                    runFunc("run", new Object[0]);
                }
                Looper.loop();
            }
            this.isRun = false;
            this.L.gc(2, 1);
            System.gc();
        } catch (LuaException e) {
            this.mLuaContext.sendError(toString(), e);
        }
    }

    public void call(String func) {
        push(3, func);
    }

    public void call(String func, Object[] args) {
        if (args.length == 0) {
            push(3, func);
        } else {
            push(1, func, args);
        }
    }

    public void set(String key, Object value) {
        push(4, key, new Object[]{value});
    }

    public Object get(String key) throws LuaException {
        this.L.getGlobal(key);
        return this.L.toJavaObject(-1);
    }

    public void quit() {
        if (this.isRun) {
            this.isRun = false;
            this.thandler.getLooper().quit();
        }
    }

    public void push(int what, String s) {
        if (!this.isRun) {
            this.mLuaContext.sendMsg("thread is not running");
            return;
        }
        Message message = new Message();
        Bundle bundle = new Bundle();
        bundle.putString("data", s);
        message.setData(bundle);
        message.what = what;
        this.thandler.sendMessage(message);
    }

    /* JADX WARN: Multi-variable type inference failed */
    public void push(int what, String s, Object[] args) {
        if (!this.isRun) {
            this.mLuaContext.sendMsg("thread is not running");
            return;
        }
        Message message = new Message();
        Bundle bundle = new Bundle();
        bundle.putString("data", s);
        bundle.putSerializable("args", args);
        message.setData(bundle);
        message.what = what;
        this.thandler.sendMessage(message);
    }

    private String errorReason(int error) {
        switch (error) {
            case 1:
                return "Yield error";
            case 2:
                return "Runtime error";
            case 3:
                return "Syntax error";
            case 4:
                return "Out of memory";
            case 5:
                return "GC error";
            case 6:
                return "error error";
            default:
                return "Unknown error " + error;
        }
    }

    private void initLua() throws LuaException {
        this.L = LuaStateFactory.newLuaState();
        this.L.openLibs();
        this.L.pushJavaObject(this.mLuaContext.getContext());
        if (this.mLuaContext instanceof LuaActivity) {
            this.L.setGlobal("activity");
        } else if (this.mLuaContext instanceof LuaService) {
            this.L.setGlobal("service");
        }
        this.L.pushJavaObject(this);
        this.L.setGlobal("this");
        this.L.pushContext(this.mLuaContext);
        JavaFunction print = new LuaPrint(this.mLuaContext, this.L);
        print.register("print");
        this.L.getGlobal("package");
        this.L.pushString(this.mLuaContext.getLuaLpath());
        this.L.setField(-2, "path");
        this.L.pushString(this.mLuaContext.getLuaCpath());
        this.L.setField(-2, "cpath");
        this.L.pop(1);
        JavaFunction set = new JavaFunction(this.L) { // from class: com.androlua.LuaThread.2
            @Override // com.luajava.JavaFunction
            public int execute() throws LuaException {
                LuaThread.this.mLuaContext.set(this.L.toString(2), this.L.toJavaObject(3));
                return 0;
            }
        };
        set.register("set");
        JavaFunction call = new JavaFunction(this.L) { // from class: com.androlua.LuaThread.3
            @Override // com.luajava.JavaFunction
            public int execute() throws LuaException {
                int top = this.L.getTop();
                if (top > 2) {
                    Object[] args = new Object[top - 2];
                    for (int i = 3; i <= top; i++) {
                        args[i - 3] = this.L.toJavaObject(i);
                    }
                    LuaThread.this.mLuaContext.call(this.L.toString(2), args);
                } else if (top == 2) {
                    LuaThread.this.mLuaContext.call(this.L.toString(2), new Object[0]);
                }
                return 0;
            }
        };
        call.register("call");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void newLuaThread(String str, Object... args) {
        try {
            if (Pattern.matches("^\\w+$", str)) {
                doAsset(str + ".lua", args);
            } else if (Pattern.matches("^[\\w\\.\\_/]+$", str)) {
                this.L.getGlobal("luajava");
                this.L.pushString(this.mLuaContext.getLuaDir());
                this.L.setField(-2, "luadir");
                this.L.pushString(str);
                this.L.setField(-2, "luapath");
                this.L.pop(1);
                doFile(str, args);
            } else {
                doString(str, args);
            }
        } catch (Exception e) {
            this.mLuaContext.sendError(toString(), e);
            quit();
        }
    }

    private void newLuaThread(byte[] buf, Object... args) {
        try {
            this.L.setTop(0);
            int ok = this.L.LloadBuffer(buf, "TimerTask");
            if (ok == 0) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = args.length;
                for (Object obj : args) {
                    this.L.pushObjectValue(obj);
                }
                ok = this.L.pcall(l, 0, (-2) - l);
                if (ok == 0) {
                    return;
                }
            }
            throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
        } catch (Exception e) {
            this.mLuaContext.sendError(toString(), e);
            quit();
        }
    }

    private void doFile(String filePath, Object... args) throws LuaException {
        this.L.setTop(0);
        int ok = this.L.LloadFile(filePath);
        if (ok == 0) {
            this.L.getGlobal(BuildConfig.BUILD_TYPE);
            this.L.getField(-1, "traceback");
            this.L.remove(-2);
            this.L.insert(-2);
            int l = args.length;
            for (Object obj : args) {
                this.L.pushObjectValue(obj);
            }
            ok = this.L.pcall(l, 0, (-2) - l);
            if (ok == 0) {
                return;
            }
        }
        throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
    }

    public void doAsset(String name, Object... args) throws LuaException, IOException {
        byte[] bytes = LuaUtil.readAsset(this.mLuaContext.getContext(), name);
        this.L.setTop(0);
        int ok = this.L.LloadBuffer(bytes, name);
        if (ok == 0) {
            this.L.getGlobal(BuildConfig.BUILD_TYPE);
            this.L.getField(-1, "traceback");
            this.L.remove(-2);
            this.L.insert(-2);
            int l = args.length;
            for (Object obj : args) {
                this.L.pushObjectValue(obj);
            }
            ok = this.L.pcall(l, 0, (-2) - l);
            if (ok == 0) {
                return;
            }
        }
        throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
    }

    private void doString(String src, Object... args) throws LuaException {
        this.L.setTop(0);
        int ok = this.L.LloadString(src);
        if (ok == 0) {
            this.L.getGlobal(BuildConfig.BUILD_TYPE);
            this.L.getField(-1, "traceback");
            this.L.remove(-2);
            this.L.insert(-2);
            int l = args.length;
            for (Object obj : args) {
                this.L.pushObjectValue(obj);
            }
            ok = this.L.pcall(l, 0, (-2) - l);
            if (ok == 0) {
                return;
            }
        }
        throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void runFunc(String funcName, Object... args) {
        try {
            this.L.setTop(0);
            this.L.getGlobal(funcName);
            if (this.L.isFunction(-1)) {
                this.L.getGlobal(BuildConfig.BUILD_TYPE);
                this.L.getField(-1, "traceback");
                this.L.remove(-2);
                this.L.insert(-2);
                int l = args.length;
                for (Object obj : args) {
                    this.L.pushObjectValue(obj);
                }
                int ok = this.L.pcall(l, 1, (-2) - l);
                if (ok != 0) {
                    throw new LuaException(errorReason(ok) + ": " + this.L.toString(-1));
                }
            }
        } catch (LuaException e) {
            this.mLuaContext.sendError(toString() + " " + funcName, e);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setField(String key, Object value) {
        try {
            this.L.pushObjectValue(value);
            this.L.setGlobal(key);
        } catch (LuaException e) {
            this.mLuaContext.sendError(toString(), e);
        }
    }

    /* loaded from: classes.dex */
    private class ThreadHandler extends Handler {
        private ThreadHandler() {
        }

        @Override // android.os.Handler
        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            Bundle data = msg.getData();
            switch (msg.what) {
                case 0:
                    LuaThread.this.newLuaThread(data.getString("data"), (Object[]) data.getSerializable("args"));
                    return;
                case 1:
                    LuaThread.this.runFunc(data.getString("data"), (Object[]) data.getSerializable("args"));
                    return;
                case 2:
                    LuaThread.this.newLuaThread(data.getString("data"), new Object[0]);
                    return;
                case 3:
                    LuaThread.this.runFunc(data.getString("data"), new Object[0]);
                    return;
                case 4:
                    LuaThread.this.setField(data.getString("data"), ((Object[]) data.getSerializable("args"))[0]);
                    return;
                default:
                    return;
            }
        }
    }
}
