package com.androlua;

import android.app.Activity;
import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.PixelFormat;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.WindowManager;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.util.Enumeration;
import java.util.zip.Adler32;
import java.util.zip.CheckedOutputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;
/* loaded from: classes.dex */
public class LuaUtil {
    private static final byte[] BUFFER = new byte[1048576];

    public static Bitmap captureScreen(Activity activity) {
        DisplayMetrics metrics = new DisplayMetrics();
        WindowManager WM = (WindowManager) activity.getSystemService("window");
        Display display = WM.getDefaultDisplay();
        display.getMetrics(metrics);
        int height = metrics.heightPixels;
        int width = metrics.widthPixels;
        int pixelformat = display.getPixelFormat();
        PixelFormat localPixelFormat1 = new PixelFormat();
        PixelFormat.getPixelFormatInfo(pixelformat, localPixelFormat1);
        int deepth = localPixelFormat1.bytesPerPixel;
        byte[] piex = new byte[height * width * deepth];
        try {
            Runtime.getRuntime().exec(new String[]{"/system/bin/su", "-c", "chmod 777 /dev/graphics/fb0"});
        } catch (IOException e) {
            e.printStackTrace();
        }
        try {
            InputStream stream = new FileInputStream(new File("/dev/graphics/fb0"));
            DataInputStream dStream = new DataInputStream(stream);
            dStream.readFully(piex);
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        int[] colors = new int[height * width];
        for (int m = 0; m < colors.length; m++) {
            int r = piex[m * 4] & 255;
            int g = piex[(m * 4) + 1] & 255;
            int b = piex[(m * 4) + 2] & 255;
            int a = piex[(m * 4) + 3] & 255;
            colors[m] = (a << 24) + (r << 16) + (g << 8) + b;
        }
        Bitmap bitmap = Bitmap.createBitmap(colors, width, height, Bitmap.Config.ARGB_8888);
        return bitmap;
    }

    public static byte[] readAsset(Context context, String name) throws IOException {
        AssetManager am = context.getAssets();
        InputStream is = am.open(name);
        byte[] ret = readAll(is);
        is.close();
        return ret;
    }

    public static byte[] readAll(InputStream input) throws IOException {
        ByteArrayOutputStream output = new ByteArrayOutputStream(4096);
        byte[] buffer = new byte[34];
        while (true) {
            int n = input.read(buffer);
            if (-1 != n) {
                output.write(buffer, 0, n);
            } else {
                byte[] ret = output.toByteArray();
                output.close();
                return ret;
            }
        }
    }

    public static void assetsToSD(Context context, String InFileName, String OutFileName) throws IOException {
        OutputStream myOutput = new FileOutputStream(OutFileName);
        InputStream myInput = context.getAssets().open(InFileName);
        byte[] buffer = new byte[8192];
        for (int length = myInput.read(buffer); length > 0; length = myInput.read(buffer)) {
            myOutput.write(buffer, 0, length);
        }
        myOutput.flush();
        myInput.close();
        myOutput.close();
    }

    public static void copyFile(String from, String to) {
        try {
            copyFile(new FileInputStream(from), new FileOutputStream(to));
        } catch (IOException e) {
            Log.d("lua", e.getMessage());
        }
    }

    public static boolean copyFile(InputStream in, OutputStream out) {
        try {
            byte[] buffer = new byte[1048576];
            while (true) {
                int byteread = in.read(buffer);
                if (byteread == -1) {
                    return true;
                }
                out.write(buffer, 0, byteread);
            }
        } catch (Exception e) {
            Log.d("lua", e.getMessage());
            return false;
        }
    }

    public static boolean copyDir(String from, String to) {
        return copyDir(new File(from), new File(to));
    }

    public static boolean copyDir(File from, File to) {
        boolean ret = true;
        File p = to.getParentFile();
        if (!p.exists()) {
            p.mkdirs();
        }
        if (from.isDirectory()) {
            File[] fs = from.listFiles();
            if (fs == null || fs.length == 0) {
                if (to.exists()) {
                    return true;
                } else {
                    boolean ret2 = to.mkdirs();
                    return ret2;
                }
            }
            for (File f : fs) {
                ret = copyDir(f, new File(to, f.getName()));
            }
            return ret;
        }
        try {
            if (!to.exists()) {
                to.createNewFile();
            }
            boolean ret3 = copyFile(new FileInputStream(from), new FileOutputStream(to));
            return ret3;
        } catch (IOException e) {
            Log.d("lua", e.getMessage());
            return false;
        }
    }

    public static boolean rmDir(File dir) {
        if (dir.isDirectory()) {
            File[] fs = dir.listFiles();
            for (File f : fs) {
                rmDir(f);
            }
        }
        return dir.delete();
    }

    public static boolean rmDir(String dir) {
        return rmDir(new File(dir));
    }

    public static void rmDir(File dir, String ext) {
        if (dir.isDirectory()) {
            File[] fs = dir.listFiles();
            for (File f : fs) {
                rmDir(f, ext);
            }
            dir.delete();
        }
        if (dir.getName().endsWith(ext)) {
            dir.delete();
        }
    }

    public static byte[] readZip(String zippath, String filepath) throws IOException {
        ZipFile zip = new ZipFile(zippath);
        ZipEntry entey = zip.getEntry(filepath);
        InputStream is = zip.getInputStream(entey);
        return readAll(is);
    }

    public static String getFileMD5(String file) {
        return getFileMD5(new File(file));
    }

    public static String getFileMD5(File file) {
        try {
            return getFileMD5(new FileInputStream(file));
        } catch (FileNotFoundException e) {
            return null;
        }
    }

    public static String getFileMD5(InputStream in) {
        String str;
        byte[] buffer = new byte[8192];
        try {
            try {
                MessageDigest digest = MessageDigest.getInstance("MD5");
                while (true) {
                    int len = in.read(buffer);
                    if (len == -1) {
                        break;
                    }
                    digest.update(buffer, 0, len);
                }
                BigInteger bigInt = new BigInteger(1, digest.digest());
                str = bigInt.toString(16);
            } catch (Exception e) {
                e.printStackTrace();
                str = null;
                try {
                    in.close();
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
            return str;
        } finally {
            try {
                in.close();
            } catch (Exception e3) {
                e3.printStackTrace();
            }
        }
    }

    public static String getFileSha1(String file) {
        return getFileMD5(new File(file));
    }

    public static String getFileSha1(File file) {
        try {
            return getFileSha1(new FileInputStream(file));
        } catch (FileNotFoundException e) {
            return null;
        }
    }

    public static String getFileSha1(InputStream in) {
        String str;
        byte[] buffer = new byte[8192];
        try {
            try {
                MessageDigest digest = MessageDigest.getInstance("SHA-1");
                while (true) {
                    int len = in.read(buffer);
                    if (len == -1) {
                        break;
                    }
                    digest.update(buffer, 0, len);
                }
                BigInteger bigInt = new BigInteger(1, digest.digest());
                str = bigInt.toString(16);
            } catch (Exception e) {
                e.printStackTrace();
                str = null;
                try {
                    in.close();
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
            return str;
        } finally {
            try {
                in.close();
            } catch (Exception e3) {
                e3.printStackTrace();
            }
        }
    }

    public static void unZip(String SourceDir) throws IOException {
        unZip(SourceDir, new File(SourceDir).getParent(), "");
    }

    public static void unZip(String SourceDir, String extDir) throws IOException {
        unZip(SourceDir, extDir, "");
    }

    public static void unZip(String SourceDir, String extDir, String fileExt) throws IOException {
        ZipFile zip = new ZipFile(SourceDir);
        Enumeration<? extends ZipEntry> entries = zip.entries();
        while (entries.hasMoreElements()) {
            ZipEntry entry = entries.nextElement();
            String name = entry.getName();
            if (name.startsWith(fileExt)) {
                if (!entry.isDirectory()) {
                    String fname = extDir + File.separator + name;
                    File temp = new File(fname).getParentFile();
                    if (!temp.exists() && !temp.mkdirs()) {
                        throw new RuntimeException("create file " + temp.getName() + " fail");
                    }
                    FileOutputStream out = new FileOutputStream(extDir + File.separator + name);
                    InputStream in = zip.getInputStream(entry);
                    byte[] buf = new byte[18];
                    while (true) {
                        int count = in.read(buf);
                        if (count == -1) {
                            break;
                        }
                        out.write(buf, 0, count);
                    }
                    out.close();
                    in.close();
                } else {
                    File f = new File(extDir + File.separator + name);
                    if (!f.exists()) {
                        f.mkdirs();
                    }
                }
            }
        }
        zip.close();
    }

    public static boolean zip(String sourceFilePath) {
        return zip(sourceFilePath, new File(sourceFilePath).getParent());
    }

    public static boolean zip(String sourceFilePath, String zipFilePath) {
        File f = new File(sourceFilePath);
        return zip(sourceFilePath, f.getParent(), f.getName() + ".zip");
    }

    public static boolean zip(String sourceFilePath, String zipFilePath, String zipFileName) {
        CheckedOutputStream checksum;
        ZipOutputStream out;
        boolean result = false;
        File source = new File(sourceFilePath);
        File zipFile = new File(zipFilePath, zipFileName);
        if (zipFile.getParentFile().exists() || zipFile.getParentFile().mkdirs()) {
            if (zipFile.exists()) {
                try {
                    zipFile.createNewFile();
                } catch (IOException e) {
                    return false;
                }
            }
            ZipOutputStream out2 = null;
            try {
                try {
                    FileOutputStream dest = new FileOutputStream(zipFile);
                    try {
                        checksum = new CheckedOutputStream(dest, new Adler32());
                        out = new ZipOutputStream(new BufferedOutputStream(checksum));
                    } catch (FileNotFoundException e2) {
                        e = e2;
                    } catch (Throwable th) {
                        th = th;
                    }
                } catch (Throwable th2) {
                    th = th2;
                }
            } catch (FileNotFoundException e3) {
                e = e3;
            }
            try {
                compress(source, out, "");
                checksum.getChecksum().getValue();
                result = true;
                if (out != null) {
                    try {
                        out.closeEntry();
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                    try {
                        out.close();
                        out2 = out;
                    } catch (IOException e5) {
                        e5.printStackTrace();
                        out2 = out;
                    }
                } else {
                    out2 = out;
                }
            } catch (FileNotFoundException e6) {
                e = e6;
                out2 = out;
                e.printStackTrace();
                if (out2 != null) {
                    try {
                        out2.closeEntry();
                    } catch (IOException e7) {
                        e7.printStackTrace();
                    }
                    try {
                        out2.close();
                    } catch (IOException e8) {
                        e8.printStackTrace();
                    }
                }
                return result;
            } catch (Throwable th3) {
                th = th3;
                out2 = out;
                if (out2 != null) {
                    try {
                        out2.closeEntry();
                    } catch (IOException e9) {
                        e9.printStackTrace();
                    }
                    try {
                        out2.close();
                    } catch (IOException e10) {
                        e10.printStackTrace();
                    }
                }
                throw th;
            }
            return result;
        }
        return false;
    }

    private static void compress(File file, ZipOutputStream out, String mainFileName) {
        File[] fs;
        if (!file.isFile()) {
            if (!file.isDirectory() || (fs = file.listFiles()) == null || fs.length <= 0) {
                return;
            }
            for (File f : fs) {
                if (f.isFile()) {
                    compress(f, out, mainFileName);
                } else {
                    compress(f, out, mainFileName + f.getName() + "/");
                }
            }
            return;
        }
        BufferedInputStream origin = null;
        try {
            try {
                FileInputStream fi = new FileInputStream(file);
                try {
                    BufferedInputStream origin2 = new BufferedInputStream(fi, BUFFER.length);
                    try {
                        String entryName = mainFileName + file.getName();
                        System.out.println(entryName);
                        ZipEntry entry = new ZipEntry(entryName);
                        out.putNextEntry(entry);
                        while (true) {
                            int count = origin2.read(BUFFER, 0, BUFFER.length);
                            if (count == -1) {
                                break;
                            }
                            out.write(BUFFER, 0, count);
                        }
                        if (origin2 != null) {
                            try {
                                origin2.close();
                                origin = origin2;
                            } catch (IOException e) {
                                e.printStackTrace();
                                origin = origin2;
                            }
                        } else {
                            origin = origin2;
                        }
                    } catch (FileNotFoundException e2) {
                        e = e2;
                        origin = origin2;
                        e.printStackTrace();
                        if (origin != null) {
                            try {
                                origin.close();
                            } catch (IOException e3) {
                                e3.printStackTrace();
                            }
                        }
                    } catch (IOException e4) {
                        e = e4;
                        origin = origin2;
                        e.printStackTrace();
                        if (origin != null) {
                            try {
                                origin.close();
                            } catch (IOException e5) {
                                e5.printStackTrace();
                            }
                        }
                    } catch (Throwable th) {
                        th = th;
                        origin = origin2;
                        if (origin != null) {
                            try {
                                origin.close();
                            } catch (IOException e6) {
                                e6.printStackTrace();
                            }
                        }
                        throw th;
                    }
                } catch (FileNotFoundException e7) {
                    e = e7;
                } catch (IOException e8) {
                    e = e8;
                } catch (Throwable th2) {
                    th = th2;
                }
            } catch (Throwable th3) {
                th = th3;
            }
        } catch (FileNotFoundException e9) {
            e = e9;
        } catch (IOException e10) {
            e = e10;
        }
    }
}
