package com.androlua;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import java.io.IOException;
/* loaded from: classes.dex */
public class NineBitmapDrawable extends Drawable {
    private Bitmap mBitmap;
    private Paint mPaint;
    private Rect mRect1;
    private Rect mRect2;
    private Rect mRect3;
    private Rect mRect4;
    private Rect mRect5;
    private Rect mRect6;
    private Rect mRect7;
    private Rect mRect8;
    private Rect mRect9;
    private int mX1;
    private int mX2;
    private int mY1;
    private int mY2;

    public NineBitmapDrawable(String path) throws IOException {
        this(LuaBitmap.getLoacalBitmap(path));
    }

    public NineBitmapDrawable(Bitmap bitmap) {
        this.mPaint = new Paint();
        int w = bitmap.getWidth();
        int h = bitmap.getHeight();
        int x1 = 0;
        int x2 = 0;
        int i = 0;
        while (true) {
            if (i >= w) {
                break;
            } else if (bitmap.getPixel(i, 0) != -16777216) {
                i++;
            } else {
                x1 = i;
                break;
            }
        }
        if (x1 == 0 || x1 == w - 1) {
            throw new IllegalArgumentException("not found x1");
        }
        int i2 = x1;
        while (true) {
            if (i2 >= w) {
                break;
            } else if (bitmap.getPixel(i2, 0) == -16777216) {
                i2++;
            } else {
                x2 = w - i2;
                break;
            }
        }
        if (x2 == 0 || x2 == 1) {
            throw new IllegalArgumentException("not found x2");
        }
        int y1 = 0;
        int y2 = 0;
        int i3 = 0;
        while (true) {
            if (i3 >= h) {
                break;
            } else if (bitmap.getPixel(0, i3) != -16777216) {
                i3++;
            } else {
                y1 = i3;
                break;
            }
        }
        if (y1 == 0 || y1 == h - 1) {
            throw new IllegalArgumentException("not found y1");
        }
        int i4 = y1;
        while (true) {
            if (i4 >= h) {
                break;
            } else if (bitmap.getPixel(0, i4) == -16777216) {
                i4++;
            } else {
                y2 = h - i4;
                break;
            }
        }
        if (y2 == 0 || y2 == 1) {
            throw new IllegalArgumentException("not found y2");
        }
        init(bitmap, x1, y1, x2, y2);
    }

    public NineBitmapDrawable(Bitmap bitmap, int x1, int y1, int x2, int y2) {
        this.mPaint = new Paint();
        init(bitmap, x1, y1, x2, y2);
    }

    private void init(Bitmap bitmap, int x1, int y1, int x2, int y2) {
        this.mBitmap = bitmap;
        int w = bitmap.getWidth();
        int h = bitmap.getHeight();
        this.mX1 = x1;
        this.mY1 = y1;
        this.mX2 = x2;
        this.mY2 = y2;
        int x22 = w - x2;
        int y22 = h - y2;
        this.mRect1 = new Rect(1, 1, x1, y1);
        this.mRect2 = new Rect(x1, 1, x22, y1);
        this.mRect3 = new Rect(x22, 1, w - 1, y1);
        this.mRect4 = new Rect(1, y1, x1, y22);
        this.mRect5 = new Rect(x1, y1, x22, y22);
        this.mRect6 = new Rect(x22, y1, w - 1, y22);
        this.mRect7 = new Rect(1, y22, x1, h - 1);
        this.mRect8 = new Rect(x1, y22, x22, h - 1);
        this.mRect9 = new Rect(x22, y22, w - 1, h - 1);
    }

    @Override // android.graphics.drawable.Drawable
    public void draw(Canvas canvas) {
        Rect rect = getBounds();
        int w = rect.right;
        int h = rect.bottom;
        Rect rect1 = new Rect(0, 0, this.mX1, this.mY1);
        Rect rect2 = new Rect(this.mX1, 0, w - this.mX2, this.mY1);
        Rect rect3 = new Rect(w - this.mX2, 0, w, this.mY1);
        Rect rect4 = new Rect(0, this.mY1, this.mX1, h - this.mY2);
        Rect rect5 = new Rect(this.mX1, this.mY1, w - this.mX2, h - this.mY2);
        Rect rect6 = new Rect(w - this.mX2, this.mY1, w, h - this.mY2);
        Rect rect7 = new Rect(0, h - this.mY2, this.mX1, h);
        Rect rect8 = new Rect(this.mX1, h - this.mY2, w - this.mX2, h);
        Rect rect9 = new Rect(w - this.mX2, h - this.mY2, w, h);
        canvas.drawBitmap(this.mBitmap, this.mRect1, rect1, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect2, rect2, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect3, rect3, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect4, rect4, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect5, rect5, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect6, rect6, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect7, rect7, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect8, rect8, this.mPaint);
        canvas.drawBitmap(this.mBitmap, this.mRect9, rect9, this.mPaint);
    }

    @Override // android.graphics.drawable.Drawable
    public void setAlpha(int p1) {
        this.mPaint.setAlpha(p1);
    }

    @Override // android.graphics.drawable.Drawable
    public void setColorFilter(ColorFilter p1) {
        this.mPaint.setColorFilter(p1);
    }

    @Override // android.graphics.drawable.Drawable
    public int getOpacity() {
        return 0;
    }
}
