package com.androlua;

import android.os.Handler;
import android.os.Message;
/* loaded from: classes.dex */
public class Ticker {
    private Handler mHandler;
    private long mLast;
    private long mOffset;
    private OnTickListener mOnTickListener;
    private Thread mThread;
    private long mPeriod = 1000;
    private boolean mEnabled = true;
    private boolean isRun = false;

    /* loaded from: classes.dex */
    public interface OnTickListener {
        void onTick();
    }

    public Ticker() {
        init();
    }

    private void init() {
        this.mHandler = new Handler() { // from class: com.androlua.Ticker.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                if (Ticker.this.mOnTickListener != null) {
                    Ticker.this.mOnTickListener.onTick();
                }
            }
        };
        this.mThread = new Thread() { // from class: com.androlua.Ticker.2
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                Ticker.this.isRun = true;
                while (Ticker.this.isRun) {
                    long now = System.currentTimeMillis();
                    if (!Ticker.this.mEnabled) {
                        Ticker.this.mLast = now - Ticker.this.mOffset;
                    }
                    if (now - Ticker.this.mLast >= Ticker.this.mPeriod) {
                        Ticker.this.mLast = now;
                        Ticker.this.mHandler.sendEmptyMessage(0);
                    }
                    try {
                        sleep(1L);
                    } catch (InterruptedException e) {
                    }
                }
            }
        };
    }

    public void setPeriod(long period) {
        this.mLast = System.currentTimeMillis();
        this.mPeriod = period;
    }

    public long getPeriod() {
        return this.mPeriod;
    }

    public void setInterval(long period) {
        this.mLast = System.currentTimeMillis();
        this.mPeriod = period;
    }

    public long getInterval() {
        return this.mPeriod;
    }

    public void setEnabled(boolean enabled) {
        this.mEnabled = enabled;
        if (!enabled) {
            this.mOffset = System.currentTimeMillis() - this.mLast;
        }
    }

    public boolean getEnabled() {
        return this.mEnabled;
    }

    public void setOnTickListener(OnTickListener ltr) {
        this.mOnTickListener = ltr;
    }

    public void start() {
        this.mThread.start();
    }

    public void stop() {
        this.isRun = false;
    }

    public boolean isRun() {
        return this.isRun;
    }
}
