package com.androlua;

import android.app.Activity;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.AsyncTask;
import android.os.Bundle;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
/* loaded from: classes.dex */
public class Welcome extends Activity {
    private LuaApplication app;
    private Dialog dlg;
    private boolean isUpdata;
    private boolean isVersionChanged;
    private String localDir;
    private String luaMdDir;
    private long mLastTime;
    private long mOldLastTime;
    private String mOldVersionName;
    private String mVersionName;
    private ProgressDialog pd;

    /* JADX WARN: Type inference failed for: r0v8, types: [com.androlua.Welcome$1] */
    @Override // android.app.Activity
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.welcome);
        this.app = (LuaApplication) getApplication();
        this.luaMdDir = this.app.luaMdDir;
        this.localDir = this.app.localDir;
        if (checkInfo()) {
            new UpdateTask().execute(new Object[0]);
        } else {
            new Thread() { // from class: com.androlua.Welcome.1
                @Override // java.lang.Thread, java.lang.Runnable
                public void run() {
                    super.run();
                    try {
                        Thread.sleep(500L);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                    Welcome.this.startActivity();
                }
            }.start();
        }
    }

    public void startActivity() {
        Intent intent = new Intent(this, Main.class);
        if (this.isVersionChanged) {
            intent.putExtra("isVersionChanged", this.isVersionChanged);
            intent.putExtra("newVersionName", this.mVersionName);
            intent.putExtra("oldVersionName", this.mOldVersionName);
        }
        startActivity(intent);
        finish();
    }

    public boolean checkInfo() {
        try {
            PackageInfo packageInfo = getPackageManager().getPackageInfo(getPackageName(), 0);
            long lastTime = packageInfo.lastUpdateTime;
            String versionName = packageInfo.versionName;
            SharedPreferences info = getSharedPreferences("appInfo", 0);
            String oldVersionName = info.getString("versionName", "");
            if (!versionName.equals(oldVersionName)) {
                SharedPreferences.Editor edit = info.edit();
                edit.putString("versionName", versionName);
                edit.commit();
                this.isVersionChanged = true;
                this.mVersionName = versionName;
                this.mOldVersionName = oldVersionName;
            }
            long oldLastTime = info.getLong("lastUpdateTime", 0L);
            if (oldLastTime != lastTime) {
                SharedPreferences.Editor edit2 = info.edit();
                edit2.putLong("lastUpdateTime", lastTime);
                edit2.commit();
                this.isUpdata = true;
                this.mLastTime = lastTime;
                this.mOldLastTime = oldLastTime;
                return true;
            }
        } catch (PackageManager.NameNotFoundException e) {
        }
        return false;
    }

    /* loaded from: classes.dex */
    class UpdateTask extends AsyncTask {
        UpdateTask() {
        }

        @Override // android.os.AsyncTask
        protected Object doInBackground(Object[] p1) {
            try {
                Thread.sleep(200L);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            onUpdata(Welcome.this.mLastTime, Welcome.this.mOldLastTime);
            return null;
        }

        @Override // android.os.AsyncTask
        protected void onPostExecute(Object result) {
            Welcome.this.startActivity();
        }

        private void onUpdata(long lastTime, long oldLastTime) {
            try {
                unApk("assets", Welcome.this.localDir);
                unApk("lua", Welcome.this.luaMdDir);
            } catch (IOException e) {
                sendMsg(e.getMessage());
            }
        }

        private void sendMsg(String message) {
        }

        private void unApk(String dir, String extDir) throws IOException {
            int i = dir.length() + 1;
            ZipFile zip = new ZipFile(Welcome.this.getApplicationInfo().publicSourceDir);
            Enumeration<? extends ZipEntry> entries = zip.entries();
            while (entries.hasMoreElements()) {
                ZipEntry entry = entries.nextElement();
                String name = entry.getName();
                if (name.indexOf(dir) == 0) {
                    String path = name.substring(i);
                    if (entry.isDirectory()) {
                        File f = new File(extDir + File.separator + path);
                        if (!f.exists()) {
                            f.mkdirs();
                        }
                    } else {
                        String fname = extDir + File.separator + path;
                        File ff = new File(fname);
                        File temp = new File(fname).getParentFile();
                        if (!temp.exists() && !temp.mkdirs()) {
                            throw new RuntimeException("create file " + temp.getName() + " fail");
                        }
                        if (!ff.exists() || entry.getSize() != ff.length() || !LuaUtil.getFileMD5(ff).equals(LuaUtil.getFileMD5(zip.getInputStream(entry)))) {
                            FileOutputStream out = new FileOutputStream(extDir + File.separator + path);
                            InputStream in = zip.getInputStream(entry);
                            byte[] buf = new byte[18];
                            while (true) {
                                int count = in.read(buf);
                                if (count == -1) {
                                    break;
                                }
                                out.write(buf, 0, count);
                            }
                            out.close();
                            in.close();
                        }
                    }
                }
            }
            zip.close();
        }
    }
}
