package com.androlua.util;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.media.MediaScannerConnection;
import android.os.Environment;
import com.androlua.LuaActivity;
import com.androlua.LuaBitmap;
import com.pixplicity.sharp.Sharp;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
/* loaded from: classes.dex */
public class ImageUtils {
    public String saveImageByUrl(String url, Context context, String filename) {
        try {
            Bitmap bitmap = LuaBitmap.getHttpBitmap(url);
            return saveBitmap(bitmap, filename, context);
        } catch (IOException e) {
            return null;
        }
    }

    public static String svg2png(LuaActivity context, String svgPath, int size, String exportPath) {
        try {
            FileInputStream input = new FileInputStream(svgPath);
            Sharp sharp = Sharp.loadInputStream(input);
            Bitmap bitmap = Bitmap.createBitmap(size, size, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(bitmap);
            canvas.drawPicture(sharp.getSharpPicture().getPicture(), new Rect(0, 0, size, size));
            saveBitmap(exportPath, bitmap, context);
            bitmap.recycle();
            return exportPath;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        }
    }

    public static String svg2png(LuaActivity context, String svgPath, int size, int color, String exportPath) {
        try {
            FileInputStream input = new FileInputStream(svgPath);
            Sharp sharp = Sharp.loadInputStream(input);
            Bitmap bitmap = Bitmap.createBitmap(size, size, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(bitmap);
            canvas.drawPicture(sharp.getSharpPicture().getPicture(), new Rect(0, 0, size, size));
            Bitmap bit2 = LuaBitmap.createTintedBitmap(bitmap, color);
            saveBitmap(exportPath, bit2, context);
            bitmap.recycle();
            bit2.recycle();
            return exportPath;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        }
    }

    public String saveImageByUrl(String url, Context context) {
        try {
            Bitmap bitmap = LuaBitmap.getHttpBitmap(url);
            new TieUtils();
            return saveBitmap(bitmap, TieUtils.getUrlFileName(url), context);
        } catch (IOException e) {
            return null;
        }
    }

    public String saveImageByUrl(String url, String path, Context context) {
        try {
            Bitmap bitmap = LuaBitmap.getHttpBitmap(url);
            return saveBitmap(path, bitmap, context);
        } catch (IOException e) {
            return null;
        }
    }

    public String saveBitmap(Bitmap bitmap, String bitName, Context context) {
        File file = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/" + Environment.DIRECTORY_PICTURES + "/" + new TieUtils().getApplicationName(context) + "/" + bitName);
        if (file.exists()) {
            file.delete();
        }
        if (!file.getParentFile().exists()) {
            file.getParentFile().mkdirs();
        }
        try {
            FileOutputStream out = new FileOutputStream(file);
            if (bitmap.compress(Bitmap.CompressFormat.PNG, 100, out)) {
                out.flush();
                out.close();
                bitmap.recycle();
                return file.getAbsolutePath();
            }
            return null;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        } catch (IOException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static String saveBitmap(String path, Bitmap bitmap, Context context, boolean update) {
        File file = new File(path);
        if (file.exists()) {
            file.delete();
        }
        if (!file.getParentFile().exists()) {
            file.getParentFile().mkdirs();
        }
        try {
            FileOutputStream out = new FileOutputStream(file);
            if (bitmap.compress(Bitmap.CompressFormat.PNG, 100, out)) {
                out.flush();
                out.close();
                if (update) {
                    MediaScannerConnection.scanFile(context, new String[]{path}, null, null);
                }
                return file.getAbsolutePath();
            }
            return null;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        } catch (IOException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static String saveBitmap(Context context, String path, Bitmap bitmap) {
        return saveBitmap(path, bitmap, context);
    }

    public static String saveBitmap(String path, Bitmap bitmap, Context context) {
        File file = new File(path);
        if (file.exists()) {
            file.delete();
        }
        if (!file.getParentFile().exists()) {
            file.getParentFile().mkdirs();
        }
        try {
            FileOutputStream out = new FileOutputStream(file);
            if (bitmap.compress(Bitmap.CompressFormat.PNG, 100, out)) {
                out.flush();
                out.close();
                return file.getAbsolutePath();
            }
            return null;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return null;
        } catch (IOException e2) {
            e2.printStackTrace();
            return null;
        }
    }
}
