package com.androlua.util;

import android.annotation.TargetApi;
import android.app.Activity;
import android.graphics.Color;
import android.os.Build;
import android.support.v4.widget.ExploreByTouchHelper;
import android.view.Window;
import android.view.WindowManager;
import com.androlua.LuaActivity;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
/* loaded from: classes.dex */
public class StatusBarUtil {
    private LuaActivity mActivity;
    private int type;

    public StatusBarUtil(LuaActivity activity) {
        this.mActivity = activity;
    }

    @TargetApi(19)
    public static void transparencyBar(Activity activity) {
        if (Build.VERSION.SDK_INT >= 21) {
            Window window = activity.getWindow();
            window.clearFlags(67108864);
            window.getDecorView().setSystemUiVisibility(1280);
            window.addFlags(ExploreByTouchHelper.INVALID_ID);
            window.setStatusBarColor(0);
        } else if (Build.VERSION.SDK_INT >= 19) {
            activity.getWindow().setFlags(67108864, 67108864);
        }
    }

    public static void setStatusBarColor(LuaActivity activity, String color) {
        if (Build.VERSION.SDK_INT >= 21) {
            activity.getWindow().setStatusBarColor(activity.getResources().getColor(Color.parseColor(color)));
        } else if (Build.VERSION.SDK_INT >= 19) {
            transparencyBar(activity);
            Window window = activity.getWindow();
            window.addFlags(ExploreByTouchHelper.INVALID_ID);
            window.setStatusBarColor(Color.parseColor(color));
        }
    }

    public void lightMode() {
        if (this.type != 0) {
            setStatusBarLightMode();
        } else if (MIUISetStatusBarLightMode(true)) {
            this.type = 1;
        } else if (FlymeSetStatusBarLightMode(true)) {
            this.type = 2;
        } else if (Build.VERSION.SDK_INT >= 23) {
            this.mActivity.getWindow().getDecorView().setSystemUiVisibility(9216);
            this.type = 3;
        }
    }

    public void setStatusBarLightMode() {
        if (this.type == 1) {
            MIUISetStatusBarLightMode(true);
        } else if (this.type == 2) {
            FlymeSetStatusBarLightMode(true);
        } else if (this.type == 3) {
            this.mActivity.getWindow().getDecorView().setSystemUiVisibility(9216);
        }
    }

    public void darkMode() {
        if (this.type != 0) {
            setStatusBarDarkMode();
        } else if (MIUISetStatusBarLightMode(false)) {
            this.type = 1;
        } else if (FlymeSetStatusBarLightMode(false)) {
            this.type = 2;
        } else if (Build.VERSION.SDK_INT >= 23) {
            this.mActivity.getWindow().getDecorView().setSystemUiVisibility(0);
            this.type = 3;
        }
    }

    public void setStatusBarDarkMode() {
        if (this.type == 1) {
            MIUISetStatusBarLightMode(false);
        } else if (this.type == 2) {
            FlymeSetStatusBarLightMode(false);
        } else if (this.type == 3) {
            this.mActivity.getWindow().getDecorView().setSystemUiVisibility(0);
        }
    }

    public void setStatusBarDarkMode(Activity activity) {
        if (MIUISetStatusBarLightMode(false)) {
            this.type = 1;
        } else if (FlymeSetStatusBarLightMode(false)) {
            this.type = 2;
        } else if (Build.VERSION.SDK_INT >= 23) {
            activity.getWindow().getDecorView().setSystemUiVisibility(0);
            this.type = 3;
        }
    }

    public void hide() {
        this.mActivity.getWindow().setFlags(1024, 1024);
    }

    public boolean FlymeSetStatusBarLightMode(boolean dark) {
        int value;
        Window window = this.mActivity.getWindow();
        if (window == null) {
            return false;
        }
        try {
            WindowManager.LayoutParams lp = window.getAttributes();
            Field darkFlag = WindowManager.LayoutParams.class.getDeclaredField("MEIZU_FLAG_DARK_STATUS_BAR_ICON");
            Field meizuFlags = WindowManager.LayoutParams.class.getDeclaredField("meizuFlags");
            darkFlag.setAccessible(true);
            meizuFlags.setAccessible(true);
            int bit = darkFlag.getInt(null);
            int value2 = meizuFlags.getInt(lp);
            if (dark) {
                value = value2 | bit;
            } else {
                value = value2 & (bit ^ (-1));
            }
            meizuFlags.setInt(lp, value);
            window.setAttributes(lp);
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public boolean MIUISetStatusBarLightMode(boolean dark) {
        boolean result = false;
        Window window = this.mActivity.getWindow();
        if (window != null) {
            Class clazz = window.getClass();
            try {
                Class layoutParams = Class.forName("android.view.MiuiWindowManager$LayoutParams");
                Field field = layoutParams.getField("EXTRA_FLAG_STATUS_BAR_DARK_MODE");
                int darkModeFlag = field.getInt(layoutParams);
                Method extraFlagField = clazz.getMethod("setExtraFlags", Integer.TYPE, Integer.TYPE);
                if (dark) {
                    extraFlagField.invoke(window, Integer.valueOf(darkModeFlag), Integer.valueOf(darkModeFlag));
                } else {
                    extraFlagField.invoke(window, 0, Integer.valueOf(darkModeFlag));
                }
                result = true;
                if (Build.VERSION.SDK_INT >= 23) {
                    if (dark) {
                        this.mActivity.getWindow().getDecorView().setSystemUiVisibility(8192);
                    } else {
                        this.mActivity.getWindow().getDecorView().setSystemUiVisibility(0);
                    }
                }
            } catch (Exception e) {
            }
        }
        return result;
    }
}
