package com.androlua.util;

import android.app.DownloadManager;
import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.ContentUris;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Environment;
import android.provider.DocumentsContract;
import android.provider.MediaStore;
import android.util.DisplayMetrics;
import android.view.View;
import com.androlua.LuaActivity;
import com.androlua.constants.Path;
import java.io.File;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public class TieUtils {
    public static int getSysBarHeight(Context context) {
        return context.getResources().getDimensionPixelSize(context.getResources().getIdentifier("status_bar_height", "dimen", "android"));
    }

    public static boolean isContainChinese(String str) {
        Pattern p = Pattern.compile("[一-龥]");
        Matcher m = p.matcher(str);
        return m.find();
    }

    public static int px2dp(Context context, int px) {
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        int dp = Math.round(px / (displayMetrics.xdpi / 160.0f));
        return dp;
    }

    public static int dip2px(Context context, float dpValue) {
        float scale = context.getResources().getDisplayMetrics().density;
        return (int) ((dpValue * scale) + 0.5f);
    }

    public static int dp2px(Context context, float dpValue) {
        return dip2px(context, dpValue);
    }

    public String getApplicationName(Context mContext) {
        ApplicationInfo applicationInfo;
        PackageManager packageManager = null;
        try {
            packageManager = mContext.getApplicationContext().getPackageManager();
            applicationInfo = packageManager.getApplicationInfo(mContext.getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            applicationInfo = null;
        }
        String applicationName = (String) packageManager.getApplicationLabel(applicationInfo);
        return applicationName;
    }

    public String redirectPath(String str, String userAgent) throws MalformedURLException {
        URL url;
        String realURL = null;
        HttpURLConnection conn = null;
        try {
            try {
                url = new URL(str);
            } catch (Throwable th) {
                th = th;
            }
        } catch (MalformedURLException e) {
            throw e;
        } catch (IOException e2) {
            e = e2;
        }
        try {
            conn = (HttpURLConnection) url.openConnection();
            conn.setConnectTimeout(30000);
            conn.setReadTimeout(30000);
            conn.setRequestProperty("User-Agent", userAgent);
            conn.setInstanceFollowRedirects(true);
            conn.getResponseCode();
            realURL = conn.getURL().toString();
            if (conn != null) {
                conn.disconnect();
            }
        } catch (MalformedURLException e3) {
            throw e3;
        } catch (IOException e4) {
            e = e4;
            e.printStackTrace();
            if (conn != null) {
                conn.disconnect();
            }
            return realURL;
        } catch (Throwable th2) {
            th = th2;
            if (conn != null) {
                conn.disconnect();
            }
            throw th;
        }
        return realURL;
    }

    public static String getUrlFileName(String url) {
        String filename = "";
        HttpURLConnection conn = null;
        if (url != null) {
            try {
                if (url.length() >= 1) {
                    try {
                        URL myURL = new URL(url);
                        conn = (HttpURLConnection) myURL.openConnection();
                        conn.connect();
                        conn.getResponseCode();
                        URL absUrl = conn.getURL();
                        filename = Uri.parse(absUrl.toString()).getLastPathSegment();
                        if (filename == null || filename.length() < 1) {
                            filename = absUrl.getFile();
                        }
                    } catch (MalformedURLException e) {
                        e.printStackTrace();
                        if (conn != null) {
                            conn.disconnect();
                        }
                    } catch (IOException e2) {
                        e2.printStackTrace();
                        if (conn != null) {
                            conn.disconnect();
                        }
                    }
                    return filename;
                }
            } finally {
                if (conn != null) {
                    conn.disconnect();
                }
            }
        }
        return null;
    }

    public static boolean isInstalled(Context context, String packageName) {
        PackageManager mPackageManager = context.getPackageManager();
        try {
            mPackageManager.getPackageInfo(packageName, 0);
            return true;
        } catch (PackageManager.NameNotFoundException e) {
            return false;
        }
    }

    public static Bitmap getBitmapFromView(View v) {
        v.clearFocus();
        v.setPressed(false);
        boolean willNotCache = v.willNotCacheDrawing();
        v.setWillNotCacheDrawing(false);
        int color = v.getDrawingCacheBackgroundColor();
        v.setDrawingCacheBackgroundColor(0);
        if (color != 0) {
            v.destroyDrawingCache();
        }
        v.buildDrawingCache();
        Bitmap cacheBitmap = v.getDrawingCache();
        if (cacheBitmap == null) {
            return null;
        }
        Bitmap createBitmap = Bitmap.createBitmap(cacheBitmap);
        v.destroyDrawingCache();
        v.setWillNotCacheDrawing(willNotCache);
        v.setDrawingCacheBackgroundColor(color);
        return createBitmap;
    }

    public static void shareText(Context context, String text) {
        Intent sendIntent = new Intent();
        sendIntent.setAction("android.intent.action.SEND");
        sendIntent.putExtra("android.intent.extra.TEXT", text);
        sendIntent.setType("text/plain");
        context.startActivity(sendIntent);
    }

    public static void shareBitmap(final Context context, Bitmap bitmap) {
        AsyncTask<Bitmap, Integer, String> asyncTask = new AsyncTask<Bitmap, Integer, String>() { // from class: com.androlua.util.TieUtils.1
            /* JADX INFO: Access modifiers changed from: protected */
            @Override // android.os.AsyncTask
            public String doInBackground(Bitmap... params) {
                ImageUtils.saveBitmap(MyFile.getTmpDir("icon.png"), params[0], context);
                return Path.TMP_DIR + "icon.png";
            }

            /* JADX INFO: Access modifiers changed from: protected */
            @Override // android.os.AsyncTask
            public void onPostExecute(String s) {
                Intent sendIntent = new Intent();
                sendIntent.setAction("android.intent.action.SEND");
                sendIntent.putExtra("android.intent.extra.STREAM", Uri.fromFile(new File(s)));
                sendIntent.setFlags(268435456);
                sendIntent.setType("image/png");
                context.startActivity(sendIntent);
                super.onPostExecute((AnonymousClass1) s);
            }
        };
        asyncTask.execute(bitmap);
    }

    public static void copyText(LuaActivity context, String text, boolean toast) {
        ClipboardManager mClipboardManager = (ClipboardManager) context.getSystemService("clipboard");
        mClipboardManager.setPrimaryClip(ClipData.newPlainText("Label", text));
        if (toast) {
            context.toast("复制完成");
        }
    }

    public static void copyText(LuaActivity context, String text) {
        ClipboardManager mClipboardManager = (ClipboardManager) context.getSystemService("clipboard");
        mClipboardManager.setPrimaryClip(ClipData.newPlainText("Label", text));
    }

    public boolean isNetworkConnected(Context context) {
        if (context != null) {
            ConnectivityManager mConnectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
            NetworkInfo mNetworkInfo = mConnectivityManager.getActiveNetworkInfo();
            if (mNetworkInfo != null) {
                return mNetworkInfo.isAvailable();
            }
        }
        return false;
    }

    public static void downloadFile(Context context, String url) {
        if (isInstalled(context, "com.dv.adm.pay")) {
            Intent intent = new Intent().setAction("android.intent.action.SEND").setType("text/*").putExtra("android.intent.extra.TEXT", url).setClassName("com.dv.adm.pay", "com.dv.adm.pay.AEditor");
            context.startActivity(intent);
            return;
        }
        DownloadManager downloadManager = (DownloadManager) context.getSystemService("download");
        Uri mUri = Uri.parse(url);
        String mFileName = getUrlFileName(url);
        DownloadManager.Request request = new DownloadManager.Request(mUri);
        request.setAllowedNetworkTypes(3);
        request.setDestinationInExternalPublicDir("Download", mFileName);
        request.setTitle(mFileName);
        request.setNotificationVisibility(1);
        downloadManager.enqueue(request);
    }

    public static String getUriPath(Context context, Uri uri) {
        boolean isKitKat = Build.VERSION.SDK_INT >= 19;
        if (isKitKat && DocumentsContract.isDocumentUri(context, uri)) {
            if (isExternalStorageDocument(uri)) {
                String docId = DocumentsContract.getDocumentId(uri);
                String[] split = docId.split(":");
                if ("primary".equalsIgnoreCase(split[0])) {
                    return Environment.getExternalStorageDirectory() + "/" + split[1];
                }
                return null;
            } else if (isDownloadsDocument(uri)) {
                String id = DocumentsContract.getDocumentId(uri);
                Uri contentUri = ContentUris.withAppendedId(Uri.parse("content://downloads/public_downloads"), Long.valueOf(id).longValue());
                return getDataColumn(context, contentUri, null, null);
            } else if (isMediaDocument(uri)) {
                String docId2 = DocumentsContract.getDocumentId(uri);
                String[] split2 = docId2.split(":");
                String type = split2[0];
                Uri contentUri2 = null;
                if ("image".equals(type)) {
                    contentUri2 = MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
                } else if ("video".equals(type)) {
                    contentUri2 = MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
                } else if ("audio".equals(type)) {
                    contentUri2 = MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
                }
                String[] selectionArgs = {split2[1]};
                return getDataColumn(context, contentUri2, "_id=?", selectionArgs);
            } else {
                return null;
            }
        } else if ("content".equalsIgnoreCase(uri.getScheme())) {
            return getDataColumn(context, uri, null, null);
        } else {
            if ("file".equalsIgnoreCase(uri.getScheme())) {
                return uri.getPath();
            }
            return null;
        }
    }

    public static String getDataColumn(Context context, Uri uri, String selection, String[] selectionArgs) {
        Cursor cursor = null;
        String[] projection = {"_data"};
        try {
            cursor = context.getContentResolver().query(uri, projection, selection, selectionArgs, null);
            if (cursor != null && cursor.moveToFirst()) {
                int column_index = cursor.getColumnIndexOrThrow("_data");
                String string = cursor.getString(column_index);
            }
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } finally {
            if (cursor != null) {
                cursor.close();
            }
        }
    }

    public static boolean isExternalStorageDocument(Uri uri) {
        return "com.android.externalstorage.documents".equals(uri.getAuthority());
    }

    public static boolean isDownloadsDocument(Uri uri) {
        return "com.android.providers.downloads.documents".equals(uri.getAuthority());
    }

    public static boolean isMediaDocument(Uri uri) {
        return "com.android.providers.media.documents".equals(uri.getAuthority());
    }
}
