package com.androlua.util;

import java.util.Date;
/* loaded from: classes.dex */
public class TimerX {
    private static long timerId;
    private final FinalizerHelper finalizer;
    private final TimerImpl impl;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class TimerImpl extends Thread {
        private boolean cancelled;
        private boolean finished;
        private TimerHeap tasks = new TimerHeap();

        /* JADX INFO: Access modifiers changed from: private */
        /* loaded from: classes.dex */
        public static final class TimerHeap {
            private int DEFAULT_HEAP_SIZE;
            private int deletedCancelledNumber;
            private int size;
            private TimerTaskX[] timers;

            private TimerHeap() {
                this.DEFAULT_HEAP_SIZE = 256;
                this.timers = new TimerTaskX[this.DEFAULT_HEAP_SIZE];
                this.size = 0;
                this.deletedCancelledNumber = 0;
            }

            public TimerTaskX minimum() {
                return this.timers[0];
            }

            public boolean isEmpty() {
                return this.size == 0;
            }

            public void insert(TimerTaskX task) {
                if (this.timers.length == this.size) {
                    TimerTaskX[] appendedTimers = new TimerTaskX[this.size * 2];
                    System.arraycopy(this.timers, 0, appendedTimers, 0, this.size);
                    this.timers = appendedTimers;
                }
                TimerTaskX[] timerTaskXArr = this.timers;
                int i = this.size;
                this.size = i + 1;
                timerTaskXArr[i] = task;
                upHeap();
            }

            public void delete(int pos) {
                if (pos >= 0 && pos < this.size) {
                    TimerTaskX[] timerTaskXArr = this.timers;
                    TimerTaskX[] timerTaskXArr2 = this.timers;
                    int i = this.size - 1;
                    this.size = i;
                    timerTaskXArr[pos] = timerTaskXArr2[i];
                    this.timers[this.size] = null;
                    downHeap(pos);
                }
            }

            private void upHeap() {
                int current = this.size - 1;
                while (true) {
                    int parent = (current - 1) / 2;
                    if (this.timers[current].when < this.timers[parent].when) {
                        TimerTaskX tmp = this.timers[current];
                        this.timers[current] = this.timers[parent];
                        this.timers[parent] = tmp;
                        current = parent;
                    } else {
                        return;
                    }
                }
            }

            private void downHeap(int pos) {
                int current = pos;
                while (true) {
                    int child = (current * 2) + 1;
                    if (child < this.size && this.size > 0) {
                        if (child + 1 < this.size && this.timers[child + 1].when < this.timers[child].when) {
                            child++;
                        }
                        if (this.timers[current].when >= this.timers[child].when) {
                            TimerTaskX tmp = this.timers[current];
                            this.timers[current] = this.timers[child];
                            this.timers[child] = tmp;
                            current = child;
                        } else {
                            return;
                        }
                    } else {
                        return;
                    }
                }
            }

            public void reset() {
                this.timers = new TimerTaskX[this.DEFAULT_HEAP_SIZE];
                this.size = 0;
            }

            public void adjustMinimum() {
                downHeap(0);
            }

            public void deleteIfCancelled() {
                int i = 0;
                while (i < this.size) {
                    if (this.timers[i].cancelled) {
                        this.deletedCancelledNumber++;
                        delete(i);
                        i--;
                    }
                    i++;
                }
            }

            /* JADX INFO: Access modifiers changed from: private */
            public int getTask(TimerTaskX task) {
                for (int i = 0; i < this.timers.length; i++) {
                    if (this.timers[i] == task) {
                        return i;
                    }
                }
                return -1;
            }
        }

        TimerImpl(String name, boolean isDaemon) {
            setName(name);
            setDaemon(isDaemon);
            start();
        }

        /* JADX WARN: Code restructure failed: missing block: B:115:0x0000, code lost:
            continue;
         */
        /* JADX WARN: Code restructure failed: missing block: B:59:0x009b, code lost:
            if (r3.isEnabled() == false) goto L47;
         */
        /* JADX WARN: Code restructure failed: missing block: B:60:0x009d, code lost:
            r3.run();
         */
        /* JADX WARN: Code restructure failed: missing block: B:62:0x00a1, code lost:
            if (1 != 0) goto L62;
         */
        /* JADX WARN: Code restructure failed: missing block: B:63:0x00a3, code lost:
            monitor-enter(r14);
         */
        /* JADX WARN: Code restructure failed: missing block: B:65:0x00a5, code lost:
            r14.cancelled = true;
         */
        /* JADX WARN: Code restructure failed: missing block: B:66:0x00a7, code lost:
            monitor-exit(r14);
         */
        /* JADX WARN: Code restructure failed: missing block: B:78:0x00bf, code lost:
            r5 = move-exception;
         */
        /* JADX WARN: Code restructure failed: missing block: B:79:0x00c0, code lost:
            if (0 == 0) goto L66;
         */
        /* JADX WARN: Code restructure failed: missing block: B:80:0x00c2, code lost:
            monitor-enter(r14);
         */
        /* JADX WARN: Code restructure failed: missing block: B:82:0x00c4, code lost:
            r14.cancelled = true;
         */
        /* JADX WARN: Code restructure failed: missing block: B:84:0x00c7, code lost:
            throw r5;
         */
        @Override // java.lang.Thread, java.lang.Runnable
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public void run() {
            while (true) {
                synchronized (this) {
                    if (!this.cancelled) {
                        if (this.tasks.isEmpty()) {
                            if (this.finished) {
                                return;
                            }
                            try {
                                wait();
                            } catch (InterruptedException e) {
                            }
                        } else {
                            long currentTime = System.currentTimeMillis();
                            TimerTaskX task = this.tasks.minimum();
                            synchronized (task.lock) {
                                if (task.cancelled) {
                                    this.tasks.delete(0);
                                } else {
                                    long timeToSleep = task.when - currentTime;
                                    if (timeToSleep > 0) {
                                        try {
                                            wait(timeToSleep);
                                        } catch (InterruptedException e2) {
                                        }
                                    } else {
                                        synchronized (task.lock) {
                                            int pos = 0;
                                            if (this.tasks.minimum().when != task.when) {
                                                pos = this.tasks.getTask(task);
                                            }
                                            if (task.cancelled) {
                                                this.tasks.delete(this.tasks.getTask(task));
                                            } else {
                                                task.setScheduledTime(task.when);
                                                this.tasks.delete(pos);
                                                if (task.period >= 0) {
                                                    if (task.fixedRate) {
                                                        task.when += task.period;
                                                    } else {
                                                        task.when = System.currentTimeMillis() + task.period;
                                                    }
                                                    insertTask(task);
                                                } else {
                                                    task.when = 0L;
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    } else {
                        return;
                    }
                }
            }
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void insertTask(TimerTaskX newTask) {
            this.tasks.insert(newTask);
            notify();
        }

        public synchronized void cancel() {
            this.cancelled = true;
            this.tasks.reset();
            notify();
        }

        public int purge() {
            if (this.tasks.isEmpty()) {
                return 0;
            }
            this.tasks.deletedCancelledNumber = 0;
            this.tasks.deleteIfCancelled();
            return this.tasks.deletedCancelledNumber;
        }
    }

    /* loaded from: classes.dex */
    private static final class FinalizerHelper {
        private final TimerImpl impl;

        FinalizerHelper(TimerImpl impl) {
            this.impl = impl;
        }

        protected void finalize() throws Throwable {
            try {
                synchronized (this.impl) {
                    this.impl.finished = true;
                    this.impl.notify();
                }
            } finally {
                super.finalize();
            }
        }
    }

    private static synchronized long nextId() {
        long j;
        synchronized (TimerX.class) {
            j = timerId;
            timerId = 1 + j;
        }
        return j;
    }

    public TimerX(String name, boolean isDaemon) {
        if (name == null) {
            throw new NullPointerException("name is null");
        }
        this.impl = new TimerImpl(name, isDaemon);
        this.finalizer = new FinalizerHelper(this.impl);
    }

    public TimerX(String name) {
        this(name, false);
    }

    public TimerX(boolean isDaemon) {
        this("Timer-" + nextId(), isDaemon);
    }

    public TimerX() {
        this(false);
    }

    public void cancel() {
        this.impl.cancel();
    }

    public int purge() {
        int purge;
        synchronized (this.impl) {
            purge = this.impl.purge();
        }
        return purge;
    }

    public void schedule(TimerTaskX task, Date when) {
        if (when.getTime() < 0) {
            throw new IllegalArgumentException();
        }
        long delay = when.getTime() - System.currentTimeMillis();
        scheduleImpl(task, delay >= 0 ? delay : 0L, -1L, false);
    }

    public void schedule(TimerTaskX task, long delay) {
        if (delay < 0) {
            throw new IllegalArgumentException();
        }
        scheduleImpl(task, delay, -1L, false);
    }

    public void schedule(TimerTaskX task, long delay, long period) {
        if (delay < 0 || period <= 0) {
            throw new IllegalArgumentException();
        }
        scheduleImpl(task, delay, period, false);
    }

    public void schedule(TimerTaskX task, Date when, long period) {
        if (period <= 0 || when.getTime() < 0) {
            throw new IllegalArgumentException();
        }
        long delay = when.getTime() - System.currentTimeMillis();
        scheduleImpl(task, delay >= 0 ? delay : 0L, period, false);
    }

    public void scheduleAtFixedRate(TimerTaskX task, long delay, long period) {
        if (delay < 0 || period <= 0) {
            throw new IllegalArgumentException();
        }
        scheduleImpl(task, delay, period, true);
    }

    public void scheduleAtFixedRate(TimerTaskX task, Date when, long period) {
        if (period <= 0 || when.getTime() < 0) {
            throw new IllegalArgumentException();
        }
        long delay = when.getTime() - System.currentTimeMillis();
        scheduleImpl(task, delay, period, true);
    }

    private void scheduleImpl(TimerTaskX task, long delay, long period, boolean fixed) {
        synchronized (this.impl) {
            if (this.impl.cancelled) {
                throw new IllegalStateException("Timer was canceled");
            }
            long when = delay + System.currentTimeMillis();
            if (when < 0) {
                throw new IllegalArgumentException("Illegal delay to start the TimerTask: " + when);
            }
            synchronized (task.lock) {
                if (task.isScheduled()) {
                    throw new IllegalStateException("TimerTask is scheduled already");
                }
                if (task.cancelled) {
                    throw new IllegalStateException("TimerTask is canceled");
                }
                task.when = when;
                task.period = period;
                task.fixedRate = fixed;
            }
            this.impl.insertTask(task);
        }
    }
}
