package com.flask.colorpicker;

import android.content.Context;
import android.content.DialogInterface;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.preference.Preference;
import android.support.annotation.NonNull;
import android.util.AttributeSet;
import android.util.TypedValue;
import android.view.View;
import android.widget.ImageView;
import com.androlua.R;
import com.flask.colorpicker.ColorPickerView;
import com.flask.colorpicker.builder.ColorPickerClickListener;
import com.flask.colorpicker.builder.ColorPickerDialogBuilder;
/* loaded from: classes.dex */
public class ColorPickerPreference extends Preference {
    protected boolean alphaSlider;
    protected ImageView colorIndicator;
    protected int density;
    protected boolean lightSlider;
    private String pickerButtonCancel;
    private String pickerButtonOk;
    private String pickerTitle;
    protected int selectedColor;
    protected ColorPickerView.WHEEL_TYPE wheelType;

    public ColorPickerPreference(Context context) {
        super(context);
        this.selectedColor = 0;
    }

    public ColorPickerPreference(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.selectedColor = 0;
        initWith(context, attrs);
    }

    public ColorPickerPreference(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.selectedColor = 0;
        initWith(context, attrs);
    }

    private void initWith(Context context, AttributeSet attrs) {
        TypedArray typedArray = context.obtainStyledAttributes(attrs, R.styleable.ColorPickerPreference);
        try {
            this.alphaSlider = typedArray.getBoolean(0, false);
            this.lightSlider = typedArray.getBoolean(1, false);
            this.density = typedArray.getInt(2, 10);
            this.wheelType = ColorPickerView.WHEEL_TYPE.indexOf(typedArray.getInt(4, 0));
            this.selectedColor = typedArray.getInt(3, -1);
            this.pickerTitle = typedArray.getString(8);
            if (this.pickerTitle == null) {
                this.pickerTitle = "Choose color";
            }
            this.pickerButtonCancel = typedArray.getString(10);
            if (this.pickerButtonCancel == null) {
                this.pickerButtonCancel = "cancel";
            }
            this.pickerButtonOk = typedArray.getString(9);
            if (this.pickerButtonOk == null) {
                this.pickerButtonOk = "ok";
            }
            typedArray.recycle();
            setWidgetLayoutResource(R.layout.color_widget);
        } catch (Throwable th) {
            typedArray.recycle();
            throw th;
        }
    }

    @Override // android.preference.Preference
    protected void onBindView(@NonNull View view) {
        super.onBindView(view);
        Resources res = view.getContext().getResources();
        GradientDrawable colorChoiceDrawable = null;
        this.colorIndicator = (ImageView) view.findViewById(R.id.color_indicator);
        Drawable currentDrawable = this.colorIndicator.getDrawable();
        if (currentDrawable != null && (currentDrawable instanceof GradientDrawable)) {
            colorChoiceDrawable = (GradientDrawable) currentDrawable;
        }
        if (colorChoiceDrawable == null) {
            colorChoiceDrawable = new GradientDrawable();
            colorChoiceDrawable.setShape(1);
        }
        int tmpColor = isEnabled() ? this.selectedColor : darken(this.selectedColor, 0.5f);
        colorChoiceDrawable.setColor(tmpColor);
        colorChoiceDrawable.setStroke((int) TypedValue.applyDimension(1, 1.0f, res.getDisplayMetrics()), darken(tmpColor, 0.8f));
        this.colorIndicator.setImageDrawable(colorChoiceDrawable);
    }

    public void setValue(int value) {
        if (callChangeListener(Integer.valueOf(value))) {
            this.selectedColor = value;
            persistInt(value);
            notifyChanged();
        }
    }

    @Override // android.preference.Preference
    protected void onSetInitialValue(boolean restoreValue, Object defaultValue) {
        setValue(restoreValue ? getPersistedInt(0) : ((Integer) defaultValue).intValue());
    }

    @Override // android.preference.Preference
    protected void onClick() {
        ColorPickerDialogBuilder builder = ColorPickerDialogBuilder.with(getContext()).setTitle(this.pickerTitle).initialColor(this.selectedColor).wheelType(this.wheelType).density(this.density).setPositiveButton(this.pickerButtonOk, new ColorPickerClickListener() { // from class: com.flask.colorpicker.ColorPickerPreference.1
            @Override // com.flask.colorpicker.builder.ColorPickerClickListener
            public void onClick(DialogInterface dialog, int selectedColorFromPicker, Integer[] allColors) {
                ColorPickerPreference.this.setValue(selectedColorFromPicker);
            }
        }).setNegativeButton(this.pickerButtonCancel, (DialogInterface.OnClickListener) null);
        if (!this.alphaSlider && !this.lightSlider) {
            builder.noSliders();
        } else if (!this.alphaSlider) {
            builder.lightnessSliderOnly();
        } else if (!this.lightSlider) {
            builder.alphaSliderOnly();
        }
        builder.build().show();
    }

    public static int darken(int color, float factor) {
        int a = Color.alpha(color);
        int r = Color.red(color);
        int g = Color.green(color);
        int b = Color.blue(color);
        return Color.argb(a, Math.max((int) (r * factor), 0), Math.max((int) (g * factor), 0), Math.max((int) (b * factor), 0));
    }
}
