package com.flask.colorpicker;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.androlua.R;
import com.flask.colorpicker.builder.ColorWheelRendererBuilder;
import com.flask.colorpicker.builder.PaintBuilder;
import com.flask.colorpicker.renderer.ColorWheelRenderOption;
import com.flask.colorpicker.renderer.ColorWheelRenderer;
import com.flask.colorpicker.slider.AlphaSlider;
import com.flask.colorpicker.slider.LightnessSlider;
import java.util.ArrayList;
import java.util.Iterator;
/* loaded from: classes.dex */
public class ColorPickerView extends View {
    private static final float STROKE_RATIO = 2.0f;
    private float alpha;
    private Paint alphaPatternPaint;
    private AlphaSlider alphaSlider;
    private int alphaSliderViewId;
    private int backgroundColor;
    private ArrayList<OnColorChangedListener> colorChangedListeners;
    private EditText colorEdit;
    private LinearLayout colorPreview;
    private int colorSelection;
    private TextWatcher colorTextChange;
    private Bitmap colorWheel;
    private Canvas colorWheelCanvas;
    private Paint colorWheelFill;
    private ColorCircle currentColorCircle;
    private int density;
    private Integer initialColor;
    private Integer[] initialColors;
    private float lightness;
    private LightnessSlider lightnessSlider;
    private int lightnessSliderViewId;
    private ArrayList<OnColorSelectedListener> listeners;
    private Integer pickerTextColor;
    private ColorWheelRenderer renderer;
    private Paint selectorStroke1;
    private Paint selectorStroke2;

    public ColorPickerView(Context context) {
        super(context);
        this.density = 10;
        this.lightness = 1.0f;
        this.alpha = 1.0f;
        this.backgroundColor = 0;
        this.initialColors = new Integer[]{null, null, null, null, null};
        this.colorSelection = 0;
        this.colorWheelFill = PaintBuilder.newPaint().color(0).build();
        this.selectorStroke1 = PaintBuilder.newPaint().color(-1).build();
        this.selectorStroke2 = PaintBuilder.newPaint().color(-16777216).build();
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.colorChangedListeners = new ArrayList<>();
        this.listeners = new ArrayList<>();
        this.colorTextChange = new TextWatcher() { // from class: com.flask.colorpicker.ColorPickerView.1
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                try {
                    int color = Color.parseColor(s.toString());
                    ColorPickerView.this.setColor(color, false);
                } catch (Exception e) {
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
            }
        };
        initWith(context, null);
    }

    public ColorPickerView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.density = 10;
        this.lightness = 1.0f;
        this.alpha = 1.0f;
        this.backgroundColor = 0;
        this.initialColors = new Integer[]{null, null, null, null, null};
        this.colorSelection = 0;
        this.colorWheelFill = PaintBuilder.newPaint().color(0).build();
        this.selectorStroke1 = PaintBuilder.newPaint().color(-1).build();
        this.selectorStroke2 = PaintBuilder.newPaint().color(-16777216).build();
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.colorChangedListeners = new ArrayList<>();
        this.listeners = new ArrayList<>();
        this.colorTextChange = new TextWatcher() { // from class: com.flask.colorpicker.ColorPickerView.1
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                try {
                    int color = Color.parseColor(s.toString());
                    ColorPickerView.this.setColor(color, false);
                } catch (Exception e) {
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
            }
        };
        initWith(context, attrs);
    }

    public ColorPickerView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.density = 10;
        this.lightness = 1.0f;
        this.alpha = 1.0f;
        this.backgroundColor = 0;
        this.initialColors = new Integer[]{null, null, null, null, null};
        this.colorSelection = 0;
        this.colorWheelFill = PaintBuilder.newPaint().color(0).build();
        this.selectorStroke1 = PaintBuilder.newPaint().color(-1).build();
        this.selectorStroke2 = PaintBuilder.newPaint().color(-16777216).build();
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.colorChangedListeners = new ArrayList<>();
        this.listeners = new ArrayList<>();
        this.colorTextChange = new TextWatcher() { // from class: com.flask.colorpicker.ColorPickerView.1
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                try {
                    int color = Color.parseColor(s.toString());
                    ColorPickerView.this.setColor(color, false);
                } catch (Exception e) {
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
            }
        };
        initWith(context, attrs);
    }

    @TargetApi(21)
    public ColorPickerView(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.density = 10;
        this.lightness = 1.0f;
        this.alpha = 1.0f;
        this.backgroundColor = 0;
        this.initialColors = new Integer[]{null, null, null, null, null};
        this.colorSelection = 0;
        this.colorWheelFill = PaintBuilder.newPaint().color(0).build();
        this.selectorStroke1 = PaintBuilder.newPaint().color(-1).build();
        this.selectorStroke2 = PaintBuilder.newPaint().color(-16777216).build();
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.colorChangedListeners = new ArrayList<>();
        this.listeners = new ArrayList<>();
        this.colorTextChange = new TextWatcher() { // from class: com.flask.colorpicker.ColorPickerView.1
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                try {
                    int color = Color.parseColor(s.toString());
                    ColorPickerView.this.setColor(color, false);
                } catch (Exception e) {
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
            }
        };
        initWith(context, attrs);
    }

    private void initWith(Context context, AttributeSet attrs) {
        TypedArray typedArray = context.obtainStyledAttributes(attrs, R.styleable.ColorPickerPreference);
        this.density = typedArray.getInt(2, 10);
        this.initialColor = Integer.valueOf(typedArray.getInt(3, -1));
        this.pickerTextColor = Integer.valueOf(typedArray.getInt(7, -4342339));
        WHEEL_TYPE wheelType = WHEEL_TYPE.indexOf(typedArray.getInt(4, 0));
        ColorWheelRenderer renderer = ColorWheelRendererBuilder.getRenderer(wheelType);
        this.alphaSliderViewId = typedArray.getResourceId(6, 0);
        this.lightnessSliderViewId = typedArray.getResourceId(5, 0);
        setRenderer(renderer);
        setDensity(this.density);
        setInitialColor(this.initialColor.intValue(), true);
        typedArray.recycle();
    }

    @Override // android.view.View
    public void onWindowFocusChanged(boolean hasWindowFocus) {
        super.onWindowFocusChanged(hasWindowFocus);
        updateColorWheel();
        this.currentColorCircle = findNearestByColor(this.initialColor.intValue());
    }

    @Override // android.view.View
    protected void onLayout(boolean changed, int left, int top, int right, int bottom) {
        super.onLayout(changed, left, top, right, bottom);
        if (this.alphaSliderViewId != 0) {
            setAlphaSlider((AlphaSlider) getRootView().findViewById(this.alphaSliderViewId));
        }
        if (this.lightnessSliderViewId != 0) {
            setLightnessSlider((LightnessSlider) getRootView().findViewById(this.lightnessSliderViewId));
        }
        updateColorWheel();
        this.currentColorCircle = findNearestByColor(this.initialColor.intValue());
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        updateColorWheel();
    }

    private void updateColorWheel() {
        int width = getMeasuredWidth();
        int height = getMeasuredHeight();
        if (height < width) {
            width = height;
        }
        if (width > 0) {
            if (this.colorWheel == null) {
                this.colorWheel = Bitmap.createBitmap(width, width, Bitmap.Config.ARGB_8888);
                this.colorWheelCanvas = new Canvas(this.colorWheel);
                this.alphaPatternPaint.setShader(PaintBuilder.createAlphaPatternShader(8));
            }
            drawColorWheel();
            invalidate();
        }
    }

    private void drawColorWheel() {
        this.colorWheelCanvas.drawColor(0, PorterDuff.Mode.CLEAR);
        if (this.renderer != null) {
            float half = this.colorWheelCanvas.getWidth() / STROKE_RATIO;
            float maxRadius = (half - 2.05f) - (half / this.density);
            float cSize = (maxRadius / (this.density - 1)) / STROKE_RATIO;
            ColorWheelRenderOption colorWheelRenderOption = this.renderer.getRenderOption();
            colorWheelRenderOption.density = this.density;
            colorWheelRenderOption.maxRadius = maxRadius;
            colorWheelRenderOption.cSize = cSize;
            colorWheelRenderOption.strokeWidth = 2.05f;
            colorWheelRenderOption.alpha = this.alpha;
            colorWheelRenderOption.lightness = this.lightness;
            colorWheelRenderOption.targetCanvas = this.colorWheelCanvas;
            this.renderer.initWith(colorWheelRenderOption);
            this.renderer.draw();
        }
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        int widthMode = View.MeasureSpec.getMode(widthMeasureSpec);
        int width = 0;
        if (widthMode == 0) {
            width = widthMeasureSpec;
        } else if (widthMode == Integer.MIN_VALUE) {
            width = View.MeasureSpec.getSize(widthMeasureSpec);
        } else if (widthMode == 1073741824) {
            width = View.MeasureSpec.getSize(widthMeasureSpec);
        }
        int heightMode = View.MeasureSpec.getMode(heightMeasureSpec);
        int height = 0;
        if (heightMode == 0) {
            height = widthMeasureSpec;
        } else if (heightMode == Integer.MIN_VALUE) {
            height = View.MeasureSpec.getSize(heightMeasureSpec);
        } else if (widthMode == 1073741824) {
            height = View.MeasureSpec.getSize(heightMeasureSpec);
        }
        int squareDimen = width;
        if (height < width) {
            squareDimen = height;
        }
        setMeasuredDimension(squareDimen, squareDimen);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        switch (event.getAction()) {
            case 0:
            case 2:
                int lastSelectedColor = getSelectedColor();
                this.currentColorCircle = findNearestByPosition(event.getX(), event.getY());
                int selectedColor = getSelectedColor();
                callOnColorChangedListeners(lastSelectedColor, selectedColor);
                this.initialColor = Integer.valueOf(selectedColor);
                setColorToSliders(selectedColor);
                invalidate();
                return true;
            case 1:
                int selectedColor2 = getSelectedColor();
                if (this.listeners != null) {
                    Iterator<OnColorSelectedListener> it = this.listeners.iterator();
                    while (it.hasNext()) {
                        OnColorSelectedListener listener = it.next();
                        try {
                            listener.onColorSelected(selectedColor2);
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                }
                setColorToSliders(selectedColor2);
                setColorText(selectedColor2);
                setColorPreviewColor(selectedColor2);
                invalidate();
                return true;
            default:
                return true;
        }
    }

    protected void callOnColorChangedListeners(int oldColor, int newColor) {
        if (this.colorChangedListeners != null && oldColor != newColor) {
            Iterator<OnColorChangedListener> it = this.colorChangedListeners.iterator();
            while (it.hasNext()) {
                OnColorChangedListener listener = it.next();
                try {
                    listener.onColorChanged(newColor);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        canvas.drawColor(this.backgroundColor);
        if (this.colorWheel != null) {
            canvas.drawBitmap(this.colorWheel, 0.0f, 0.0f, (Paint) null);
        }
        if (this.currentColorCircle != null) {
            float maxRadius = (canvas.getWidth() / STROKE_RATIO) - 2.05f;
            float size = (maxRadius / this.density) / STROKE_RATIO;
            this.colorWheelFill.setColor(Color.HSVToColor(this.currentColorCircle.getHsvWithLightness(this.lightness)));
            this.colorWheelFill.setAlpha((int) (this.alpha * 255.0f));
            canvas.drawCircle(this.currentColorCircle.getX(), this.currentColorCircle.getY(), size * STROKE_RATIO, this.selectorStroke1);
            canvas.drawCircle(this.currentColorCircle.getX(), this.currentColorCircle.getY(), 1.5f * size, this.selectorStroke2);
            canvas.drawCircle(this.currentColorCircle.getX(), this.currentColorCircle.getY(), size, this.alphaPatternPaint);
            canvas.drawCircle(this.currentColorCircle.getX(), this.currentColorCircle.getY(), size, this.colorWheelFill);
        }
    }

    private ColorCircle findNearestByPosition(float x, float y) {
        ColorCircle near = null;
        double minDist = Double.MAX_VALUE;
        for (ColorCircle colorCircle : this.renderer.getColorCircleList()) {
            double dist = colorCircle.sqDist(x, y);
            if (minDist > dist) {
                minDist = dist;
                near = colorCircle;
            }
        }
        return near;
    }

    private ColorCircle findNearestByColor(int color) {
        float[] hsv = new float[3];
        Color.colorToHSV(color, hsv);
        ColorCircle near = null;
        double minDiff = Double.MAX_VALUE;
        double x = hsv[1] * Math.cos((hsv[0] * 3.141592653589793d) / 180.0d);
        double y = hsv[1] * Math.sin((hsv[0] * 3.141592653589793d) / 180.0d);
        for (ColorCircle colorCircle : this.renderer.getColorCircleList()) {
            float[] hsv1 = colorCircle.getHsv();
            double x1 = hsv1[1] * Math.cos((hsv1[0] * 3.141592653589793d) / 180.0d);
            double y1 = hsv1[1] * Math.sin((hsv1[0] * 3.141592653589793d) / 180.0d);
            double dx = x - x1;
            double dy = y - y1;
            double dist = (dx * dx) + (dy * dy);
            if (dist < minDiff) {
                minDiff = dist;
                near = colorCircle;
            }
        }
        return near;
    }

    public int getSelectedColor() {
        int color = 0;
        if (this.currentColorCircle != null) {
            color = Utils.colorAtLightness(this.currentColorCircle.getColor(), this.lightness);
        }
        return Utils.adjustAlpha(this.alpha, color);
    }

    public Integer[] getAllColors() {
        return this.initialColors;
    }

    public void setInitialColors(Integer[] colors, int selectedColor) {
        this.initialColors = colors;
        this.colorSelection = selectedColor;
        Integer initialColor = this.initialColors[this.colorSelection];
        if (initialColor == null) {
            initialColor = -1;
        }
        setInitialColor(initialColor.intValue(), true);
    }

    public void setInitialColor(int color, boolean updateText) {
        float[] hsv = new float[3];
        Color.colorToHSV(color, hsv);
        this.alpha = Utils.getAlphaPercent(color);
        this.lightness = hsv[2];
        this.initialColors[this.colorSelection] = Integer.valueOf(color);
        this.initialColor = Integer.valueOf(color);
        setColorPreviewColor(color);
        setColorToSliders(color);
        if (this.colorEdit != null && updateText) {
            setColorText(color);
        }
        this.currentColorCircle = findNearestByColor(color);
    }

    public void setLightness(float lightness) {
        int lastSelectedColor = getSelectedColor();
        this.lightness = lightness;
        this.initialColor = Integer.valueOf(Color.HSVToColor(Utils.alphaValueAsInt(this.alpha), this.currentColorCircle.getHsvWithLightness(lightness)));
        if (this.colorEdit != null) {
            this.colorEdit.setText(Utils.getHexString(this.initialColor.intValue(), this.alphaSlider != null));
        }
        if (this.alphaSlider != null && this.initialColor != null) {
            this.alphaSlider.setColor(this.initialColor.intValue());
        }
        callOnColorChangedListeners(lastSelectedColor, this.initialColor.intValue());
        updateColorWheel();
        invalidate();
    }

    public void setColor(int color, boolean updateText) {
        setInitialColor(color, updateText);
        updateColorWheel();
        invalidate();
    }

    public void setAlphaValue(float alpha) {
        int lastSelectedColor = getSelectedColor();
        this.alpha = alpha;
        this.initialColor = Integer.valueOf(Color.HSVToColor(Utils.alphaValueAsInt(this.alpha), this.currentColorCircle.getHsvWithLightness(this.lightness)));
        if (this.colorEdit != null) {
            this.colorEdit.setText(Utils.getHexString(this.initialColor.intValue(), this.alphaSlider != null));
        }
        if (this.lightnessSlider != null && this.initialColor != null) {
            this.lightnessSlider.setColor(this.initialColor.intValue());
        }
        callOnColorChangedListeners(lastSelectedColor, this.initialColor.intValue());
        updateColorWheel();
        invalidate();
    }

    public void addOnColorChangedListener(OnColorChangedListener listener) {
        this.colorChangedListeners.add(listener);
    }

    public void addOnColorSelectedListener(OnColorSelectedListener listener) {
        this.listeners.add(listener);
    }

    public void setLightnessSlider(LightnessSlider lightnessSlider) {
        this.lightnessSlider = lightnessSlider;
        if (lightnessSlider != null) {
            this.lightnessSlider.setColorPicker(this);
            this.lightnessSlider.setColor(getSelectedColor());
        }
    }

    public void setAlphaSlider(AlphaSlider alphaSlider) {
        this.alphaSlider = alphaSlider;
        if (alphaSlider != null) {
            this.alphaSlider.setColorPicker(this);
            this.alphaSlider.setColor(getSelectedColor());
        }
    }

    public void setColorEdit(EditText colorEdit) {
        this.colorEdit = colorEdit;
        if (this.colorEdit != null) {
            this.colorEdit.setVisibility(0);
            this.colorEdit.addTextChangedListener(this.colorTextChange);
            setColorEditTextColor(this.pickerTextColor.intValue());
        }
    }

    public void setColorEditTextColor(int argb) {
        this.pickerTextColor = Integer.valueOf(argb);
        if (this.colorEdit != null) {
            this.colorEdit.setTextColor(argb);
        }
    }

    public void setDensity(int density) {
        this.density = Math.max(2, density);
        invalidate();
    }

    public void setRenderer(ColorWheelRenderer renderer) {
        this.renderer = renderer;
        invalidate();
    }

    public void setColorPreview(LinearLayout colorPreview, Integer selectedColor) {
        if (colorPreview != null) {
            this.colorPreview = colorPreview;
            if (selectedColor == null) {
                selectedColor = 0;
            }
            int children = colorPreview.getChildCount();
            if (children != 0 && colorPreview.getVisibility() == 0) {
                for (int i = 0; i < children; i++) {
                    View childView = colorPreview.getChildAt(i);
                    if (childView instanceof LinearLayout) {
                        LinearLayout childLayout = (LinearLayout) childView;
                        if (i == selectedColor.intValue()) {
                            childLayout.setBackgroundColor(-1);
                        }
                        ImageView childImage = (ImageView) childLayout.findViewById(R.id.image_preview);
                        childImage.setClickable(true);
                        childImage.setTag(Integer.valueOf(i));
                        childImage.setOnClickListener(new View.OnClickListener() { // from class: com.flask.colorpicker.ColorPickerView.2
                            @Override // android.view.View.OnClickListener
                            public void onClick(View v) {
                                Object tag;
                                if (v != null && (tag = v.getTag()) != null && (tag instanceof Integer)) {
                                    ColorPickerView.this.setSelectedColor(((Integer) tag).intValue());
                                }
                            }
                        });
                    }
                }
            }
        }
    }

    public void setSelectedColor(int previewNumber) {
        if (this.initialColors != null && this.initialColors.length >= previewNumber) {
            this.colorSelection = previewNumber;
            setHighlightedColor(previewNumber);
            Integer color = this.initialColors[previewNumber];
            if (color != null) {
                setColor(color.intValue(), true);
            }
        }
    }

    private void setHighlightedColor(int previewNumber) {
        int children = this.colorPreview.getChildCount();
        if (children != 0 && this.colorPreview.getVisibility() == 0) {
            for (int i = 0; i < children; i++) {
                View childView = this.colorPreview.getChildAt(i);
                if (childView instanceof LinearLayout) {
                    LinearLayout childLayout = (LinearLayout) childView;
                    if (i == previewNumber) {
                        childLayout.setBackgroundColor(-1);
                    } else {
                        childLayout.setBackgroundColor(0);
                    }
                }
            }
        }
    }

    private void setColorPreviewColor(int newColor) {
        if (this.colorPreview != null && this.initialColors != null && this.colorSelection <= this.initialColors.length && this.initialColors[this.colorSelection] != null) {
            int children = this.colorPreview.getChildCount();
            if (children != 0 && this.colorPreview.getVisibility() == 0) {
                View childView = this.colorPreview.getChildAt(this.colorSelection);
                if (childView instanceof LinearLayout) {
                    LinearLayout childLayout = (LinearLayout) childView;
                    ImageView childImage = (ImageView) childLayout.findViewById(R.id.image_preview);
                    childImage.setImageDrawable(new CircleColorDrawable(newColor));
                }
            }
        }
    }

    private void setColorText(int argb) {
        if (this.colorEdit != null) {
            this.colorEdit.setText(Utils.getHexString(argb, this.alphaSlider != null));
        }
    }

    private void setColorToSliders(int selectedColor) {
        if (this.lightnessSlider != null) {
            this.lightnessSlider.setColor(selectedColor);
        }
        if (this.alphaSlider != null) {
            this.alphaSlider.setColor(selectedColor);
        }
    }

    /* loaded from: classes.dex */
    public enum WHEEL_TYPE {
        FLOWER,
        CIRCLE;

        public static WHEEL_TYPE indexOf(int index) {
            switch (index) {
                case 0:
                    return FLOWER;
                case 1:
                    return CIRCLE;
                default:
                    return FLOWER;
            }
        }
    }
}
