package com.flask.colorpicker.slider;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.support.annotation.DimenRes;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import com.androlua.R;
/* loaded from: classes.dex */
public abstract class AbsCustomSlider extends View {
    protected Bitmap bar;
    protected Canvas barCanvas;
    protected int barHeight;
    protected int barOffsetX;
    protected Bitmap bitmap;
    protected Canvas bitmapCanvas;
    protected int handleRadius;
    protected OnValueChangedListener onValueChangedListener;
    protected float value;

    protected abstract void drawBar(Canvas canvas);

    protected abstract void drawHandle(Canvas canvas, float f, float f2);

    protected abstract void onValueChanged(float f);

    public AbsCustomSlider(Context context) {
        super(context);
        this.handleRadius = 20;
        this.barHeight = 5;
        this.value = 1.0f;
    }

    public AbsCustomSlider(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.handleRadius = 20;
        this.barHeight = 5;
        this.value = 1.0f;
    }

    public AbsCustomSlider(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.handleRadius = 20;
        this.barHeight = 5;
        this.value = 1.0f;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void updateBar() {
        this.handleRadius = getDimension(R.dimen.default_slider_handler_radius);
        this.barHeight = getDimension(R.dimen.default_slider_bar_height);
        this.barOffsetX = this.handleRadius;
        if (this.bar == null) {
            createBitmaps();
        }
        drawBar(this.barCanvas);
        invalidate();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void createBitmaps() {
        int width = getWidth();
        int height = getHeight();
        this.bar = Bitmap.createBitmap(width - (this.barOffsetX * 2), this.barHeight, Bitmap.Config.ARGB_8888);
        this.barCanvas = new Canvas(this.bar);
        if (this.bitmap == null || this.bitmap.getWidth() != width || this.bitmap.getHeight() != height) {
            if (this.bitmap != null) {
                this.bitmap.recycle();
            }
            this.bitmap = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
            this.bitmapCanvas = new Canvas(this.bitmap);
        }
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (this.bar != null && this.bitmapCanvas != null) {
            this.bitmapCanvas.drawColor(0, PorterDuff.Mode.CLEAR);
            this.bitmapCanvas.drawBitmap(this.bar, this.barOffsetX, (getHeight() - this.bar.getHeight()) / 2, (Paint) null);
            float x = this.handleRadius + (this.value * (getWidth() - (this.handleRadius * 2)));
            float y = getHeight() / 2.0f;
            drawHandle(this.bitmapCanvas, x, y);
            canvas.drawBitmap(this.bitmap, 0.0f, 0.0f, (Paint) null);
        }
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        updateBar();
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        int widthMode = View.MeasureSpec.getMode(widthMeasureSpec);
        int width = 0;
        if (widthMode == 0) {
            width = widthMeasureSpec;
        } else if (widthMode == Integer.MIN_VALUE) {
            width = View.MeasureSpec.getSize(widthMeasureSpec);
        } else if (widthMode == 1073741824) {
            width = View.MeasureSpec.getSize(widthMeasureSpec);
        }
        int heightMode = View.MeasureSpec.getMode(heightMeasureSpec);
        int height = 0;
        if (heightMode == 0) {
            height = heightMeasureSpec;
        } else if (heightMode == Integer.MIN_VALUE) {
            height = View.MeasureSpec.getSize(heightMeasureSpec);
        } else if (heightMode == 1073741824) {
            height = View.MeasureSpec.getSize(heightMeasureSpec);
        }
        setMeasuredDimension(width, height);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        switch (event.getAction()) {
            case 0:
            case 2:
                if (this.bar != null) {
                    this.value = (event.getX() - this.barOffsetX) / this.bar.getWidth();
                    this.value = Math.max(0.0f, Math.min(this.value, 1.0f));
                    onValueChanged(this.value);
                    invalidate();
                    return true;
                }
                return true;
            case 1:
                onValueChanged(this.value);
                if (this.onValueChangedListener != null) {
                    this.onValueChangedListener.onValueChanged(this.value);
                }
                invalidate();
                return true;
            default:
                return true;
        }
    }

    protected int getDimension(@DimenRes int id) {
        return getResources().getDimensionPixelSize(id);
    }

    public void setOnValueChangedListener(OnValueChangedListener onValueChangedListener) {
        this.onValueChangedListener = onValueChangedListener;
    }
}
