package com.flask.colorpicker.slider;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.util.AttributeSet;
import com.flask.colorpicker.ColorPickerView;
import com.flask.colorpicker.Utils;
import com.flask.colorpicker.builder.PaintBuilder;
/* loaded from: classes.dex */
public class AlphaSlider extends AbsCustomSlider {
    private Paint alphaPatternPaint;
    private Paint barPaint;
    private Paint clearingStroke;
    public int color;
    private ColorPickerView colorPicker;
    private Paint solid;

    public AlphaSlider(Context context) {
        super(context);
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    public AlphaSlider(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    public AlphaSlider(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.alphaPatternPaint = PaintBuilder.newPaint().build();
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    public void createBitmaps() {
        super.createBitmaps();
        this.alphaPatternPaint.setShader(PaintBuilder.createAlphaPatternShader(this.barHeight / 2));
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void drawBar(Canvas barCanvas) {
        int width = barCanvas.getWidth();
        int height = barCanvas.getHeight();
        barCanvas.drawRect(0.0f, 0.0f, width, height, this.alphaPatternPaint);
        int l = Math.max(2, width / 256);
        for (int x = 0; x <= width; x += l) {
            float alpha = x / (width - 1);
            this.barPaint.setColor(this.color);
            this.barPaint.setAlpha(Math.round(255.0f * alpha));
            barCanvas.drawRect(x, 0.0f, x + l, height, this.barPaint);
        }
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void onValueChanged(float value) {
        if (this.colorPicker != null) {
            this.colorPicker.setAlphaValue(value);
        }
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void drawHandle(Canvas canvas, float x, float y) {
        this.solid.setColor(this.color);
        this.solid.setAlpha(Math.round(this.value * 255.0f));
        canvas.drawCircle(x, y, this.handleRadius, this.clearingStroke);
        if (this.value < 1.0f) {
            canvas.drawCircle(x, y, this.handleRadius * 0.75f, this.alphaPatternPaint);
        }
        canvas.drawCircle(x, y, this.handleRadius * 0.75f, this.solid);
    }

    public void setColorPicker(ColorPickerView colorPicker) {
        this.colorPicker = colorPicker;
    }

    public void setColor(int color) {
        this.color = color;
        this.value = Utils.getAlphaPercent(color);
        if (this.bar != null) {
            updateBar();
            invalidate();
        }
    }
}
