package com.flask.colorpicker.slider;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.util.AttributeSet;
import com.flask.colorpicker.ColorPickerView;
import com.flask.colorpicker.Utils;
import com.flask.colorpicker.builder.PaintBuilder;
/* loaded from: classes.dex */
public class LightnessSlider extends AbsCustomSlider {
    private Paint barPaint;
    private Paint clearingStroke;
    private int color;
    private ColorPickerView colorPicker;
    private Paint solid;

    public LightnessSlider(Context context) {
        super(context);
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    public LightnessSlider(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    public LightnessSlider(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.barPaint = PaintBuilder.newPaint().build();
        this.solid = PaintBuilder.newPaint().build();
        this.clearingStroke = PaintBuilder.newPaint().color(-1).xPerMode(PorterDuff.Mode.CLEAR).build();
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void drawBar(Canvas barCanvas) {
        int width = barCanvas.getWidth();
        int height = barCanvas.getHeight();
        float[] hsv = new float[3];
        Color.colorToHSV(this.color, hsv);
        int l = Math.max(2, width / 256);
        for (int x = 0; x <= width; x += l) {
            hsv[2] = x / (width - 1);
            this.barPaint.setColor(Color.HSVToColor(hsv));
            barCanvas.drawRect(x, 0.0f, x + l, height, this.barPaint);
        }
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void onValueChanged(float value) {
        if (this.colorPicker != null) {
            this.colorPicker.setLightness(value);
        }
    }

    @Override // com.flask.colorpicker.slider.AbsCustomSlider
    protected void drawHandle(Canvas canvas, float x, float y) {
        this.solid.setColor(Utils.colorAtLightness(this.color, this.value));
        canvas.drawCircle(x, y, this.handleRadius, this.clearingStroke);
        canvas.drawCircle(x, y, this.handleRadius * 0.75f, this.solid);
    }

    public void setColorPicker(ColorPickerView colorPicker) {
        this.colorPicker = colorPicker;
    }

    public void setColor(int color) {
        this.color = color;
        this.value = Utils.lightnessOfColor(color);
        if (this.bar != null) {
            updateBar();
            invalidate();
        }
    }
}
