package com.luajava;

import com.androlua.LuaContext;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
/* loaded from: classes.dex */
public class LuaInvocationHandler implements InvocationHandler {
    private final LuaContext mContext;
    private LuaObject obj;

    public LuaInvocationHandler(LuaObject obj) {
        this.obj = obj;
        this.mContext = obj.getLuaState().getContext();
    }

    @Override // java.lang.reflect.InvocationHandler
    public Object invoke(Object proxy, Method method, Object[] args) throws LuaException {
        LuaObject func;
        Object obj;
        Object ret;
        synchronized (this.obj.L) {
            String methodName = method.getName();
            if (this.obj.isFunction()) {
                func = this.obj;
            } else {
                func = this.obj.getField(methodName);
            }
            Class<?> retType = method.getReturnType();
            if (func.isNil()) {
                if (retType.equals(Boolean.TYPE) || retType.equals(Boolean.class)) {
                    obj = false;
                } else if (retType.isPrimitive() || Number.class.isAssignableFrom(retType)) {
                    obj = 0;
                } else {
                    obj = null;
                }
            } else {
                try {
                    if (retType.equals(Void.class) || retType.equals(Void.TYPE)) {
                        func.call(args);
                        ret = null;
                    } else {
                        ret = func.call(args);
                        if (ret != null && (ret instanceof Double)) {
                            ret = LuaState.convertLuaNumber((Double) ret, retType);
                        }
                    }
                    obj = ret;
                } catch (LuaException e) {
                    this.mContext.sendError(methodName, e);
                    obj = null;
                }
                if (obj == null) {
                    if (retType.equals(Boolean.TYPE) || retType.equals(Boolean.class)) {
                        obj = false;
                    } else if (retType.isPrimitive() || Number.class.isAssignableFrom(retType)) {
                        obj = 0;
                    }
                }
            }
        }
        return obj;
    }
}
