package com.luajava;

import android.content.Context;
import android.view.View;
import java.lang.reflect.Array;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public final class LuaJavaAPI {
    public static HashMap<Class<?>, Method[]> methodsMap = new HashMap<>();
    public static HashMap<String, Method[]> methodCache = new HashMap<>();
    private static Class<?> LuaState_class = LuaState.class;
    private static Class<?> String_class = String.class;
    private static Class<?> List_class = List.class;
    private static Class<?> ArrayList_class = ArrayList.class;
    private static Class<?> HashMap_class = HashMap.class;
    private static Class<?> Map_class = Map.class;
    private static Class<?> LuaFunction_class = LuaFunction.class;
    private static Class<?> LuaObject_class = LuaObject.class;
    private static Class<?> LuaTable_class = LuaTable.class;
    private static Class<?> Number_class = Number.class;
    private static Class<?> Character_class = Character.class;
    private static HashMap<Class<?>, HashMap<String, ArrayList<Method>>> methodCache3 = new HashMap<>();

    private LuaJavaAPI() {
    }

    public static int objectIndex(long luaState, Object obj, String searchName, int type) throws LuaException {
        int ret;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (type == 0) {
                if (checkMethod(L, obj, searchName) != 0) {
                }
            }
            if ((type == 0 || type == 1 || type == 5) && (ret = checkField(L, obj, searchName)) != 0) {
                return ret;
            }
            if ((type == 0 || type == 4) && javaGetter(L, obj, searchName) != 0) {
                return 4;
            }
            if ((type == 0 || type == 3) && checkClass(L, obj, searchName) != 0) {
                return 3;
            }
            if ((type == 0 || type == 6) && (obj instanceof LuaMetaTable)) {
                Object res = ((LuaMetaTable) obj).__index(searchName);
                L.pushObjectValue(res);
                return 6;
            }
            return 0;
        }
        return 2;
    }

    public static int callMethod(long luaState, Object obj, String cacheName) throws LuaException {
        int i;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            Method[] methods = methodCache.get(cacheName);
            int top = L.getTop();
            Object[] objs = new Object[top];
            Method method = null;
            int length = methods.length;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                Method m = methods[i2];
                Class[] parameters = m.getParameterTypes();
                if (parameters.length == top) {
                    boolean okMethod = true;
                    for (int j = 0; j < parameters.length; j++) {
                        try {
                            objs[j] = compareTypes(L, parameters[j], j + 1);
                        } catch (Exception e) {
                            okMethod = false;
                        }
                    }
                    if (okMethod) {
                        method = m;
                        break;
                    }
                }
                i2++;
            }
            if (method == null) {
                StringBuilder msgbuilder = new StringBuilder();
                for (Method m2 : methods) {
                    msgbuilder.append(m2.toString());
                    msgbuilder.append("\n");
                }
                throw new LuaException("Invalid method call. Invalid Parameters.\n" + msgbuilder.toString());
            }
            try {
                if (!Modifier.isPublic(method.getModifiers())) {
                    method.setAccessible(true);
                }
                Object ret = method.invoke(obj, objs);
                if (ret == null && method.getReturnType().equals(Void.TYPE)) {
                    i = 0;
                } else {
                    L.pushObjectValue(ret);
                    i = 1;
                }
                return i;
            } catch (Exception e2) {
                throw new LuaException(e2);
            }
        }
    }

    public static int objectNewIndex(long luaState, Object obj, String searchName) throws LuaException {
        int i = 1;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            int res = setFieldValue(L, obj, searchName);
            if (res == 0) {
                int res2 = javaSetter(L, obj, searchName);
                if (res2 == 0) {
                    if (obj instanceof LuaMetaTable) {
                        ((LuaMetaTable) obj).__newIndex(searchName, L.toJavaObject(3));
                    } else {
                        i = 0;
                    }
                }
            }
        }
        return i;
    }

    public static int setFieldValue(LuaState L, Object obj, String fieldName) throws LuaException {
        Class objClass;
        synchronized (L) {
            boolean isClass = false;
            if (obj == null) {
                return 0;
            }
            if (obj instanceof Class) {
                objClass = (Class) obj;
                isClass = true;
            } else {
                objClass = obj.getClass();
            }
            try {
                Field field = objClass.getField(fieldName);
                if (field == null) {
                    return 0;
                }
                if (!isClass || Modifier.isStatic(field.getModifiers())) {
                    Class type = field.getType();
                    try {
                        if (!Modifier.isPublic(field.getModifiers())) {
                            field.setAccessible(true);
                        }
                        field.set(obj, compareTypes(L, type, 3));
                    } catch (LuaException e) {
                        argError(L, fieldName, 3, type);
                    } catch (Exception e2) {
                        throw new LuaException(e2);
                    }
                    return 1;
                }
                return 0;
            } catch (NoSuchFieldException e3) {
                return 0;
            }
        }
    }

    private static String argError(LuaState L, String name, int idx, Class type) throws LuaException {
        throw new LuaException("bad argument to '" + name + "' (" + type.getName() + " expected, got " + typeName(L, 3) + " value)");
    }

    private static String typeName(LuaState L, int idx) throws LuaException {
        if (L.isObject(idx)) {
            return L.getObjectFromUserdata(idx).getClass().getName();
        }
        switch (L.type(idx)) {
            case 1:
                return "boolean";
            case 2:
            case 7:
                return "userdata";
            case 3:
                return "number";
            case 4:
                return "string";
            case 5:
                return "table";
            case 6:
                return "function";
            case 8:
                return "thread";
            default:
                return "unkown";
        }
    }

    public static int setArrayValue(long luaState, Object obj, int index) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (obj.getClass().isArray()) {
                Class<?> type = obj.getClass().getComponentType();
                try {
                    Object value = compareTypes(L, type, 3);
                    Array.set(obj, index, value);
                } catch (LuaException e) {
                    argError(L, obj.getClass().getName() + " [" + index + "]", 3, type);
                }
            } else if (obj instanceof List) {
                ((List) obj).set(index, L.toJavaObject(3));
            } else if (obj instanceof Map) {
                ((Map) obj).put(Long.valueOf(index), L.toJavaObject(3));
            } else {
                throw new LuaException("can not set " + obj.getClass().getName() + " value: " + L.toJavaObject(3) + " in " + index);
            }
        }
        return 0;
    }

    public static int getArrayValue(long luaState, Object obj, int index) throws LuaException {
        Object ret;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (obj.getClass().isArray()) {
                ret = Array.get(obj, index);
            } else if (obj instanceof List) {
                ret = ((List) obj).get(index);
            } else if (obj instanceof Map) {
                ret = ((Map) obj).get(Long.valueOf(index));
            } else {
                throw new LuaException("can not get " + obj.getClass().getName() + " value in " + index);
            }
            L.pushObjectValue(ret);
        }
        return 1;
    }

    public static int asTable(long luaState, Object obj) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            try {
                L.newTable();
                if (obj.getClass().isArray()) {
                    int n = Array.getLength(obj);
                    for (int i = 0; i <= n - 1; i++) {
                        L.pushObjectValue(Array.get(obj, i));
                        L.rawSetI(-2, i + 1);
                    }
                } else if (obj instanceof Collection) {
                    Collection list = (Collection) obj;
                    int i2 = 1;
                    for (Object v : list) {
                        L.pushObjectValue(v);
                        L.rawSetI(-2, i2);
                        i2++;
                    }
                } else if (obj instanceof Map) {
                    Map map = (Map) obj;
                    for (Object o : map.entrySet()) {
                        Map.Entry entry = (Map.Entry) o;
                        L.pushObjectValue(entry.getKey());
                        L.pushObjectValue(entry.getValue());
                        L.setTable(-3);
                    }
                }
                L.pushValue(-1);
            } catch (Exception e) {
                throw new LuaException("can not astable: " + e.getMessage());
            }
        }
        return 1;
    }

    public static int newArray(long luaState, Class<?> clazz, int size) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            try {
                Object obj = Array.newInstance(clazz, size);
                L.pushJavaObject(obj);
            } catch (Exception e) {
                throw new LuaException("can not create a array: " + e.getMessage());
            }
        }
        return 1;
    }

    public static int newArray(long luaState, Class<?> clazz) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            try {
                int top = L.getTop();
                int[] dimensions = new int[top - 1];
                for (int i = 0; i < top - 1; i++) {
                    dimensions[i] = (int) L.toInteger(i + 2);
                }
                Object obj = Array.newInstance(clazz, dimensions);
                L.pushJavaObject(obj);
            } catch (Exception e) {
                throw new LuaException("can not create a array: " + e.getMessage());
            }
        }
        return 1;
    }

    public static Class javaBindClass(String className) throws LuaException {
        try {
            Class clazz = Class.forName(className);
            return clazz;
        } catch (Exception e) {
            char c = 65535;
            switch (className.hashCode()) {
                case -1325958191:
                    if (className.equals("double")) {
                        c = 7;
                        break;
                    }
                    break;
                case 104431:
                    if (className.equals("int")) {
                        c = 4;
                        break;
                    }
                    break;
                case 3039496:
                    if (className.equals("byte")) {
                        c = 1;
                        break;
                    }
                    break;
                case 3052374:
                    if (className.equals("char")) {
                        c = 2;
                        break;
                    }
                    break;
                case 3327612:
                    if (className.equals("long")) {
                        c = 5;
                        break;
                    }
                    break;
                case 64711720:
                    if (className.equals("boolean")) {
                        c = 0;
                        break;
                    }
                    break;
                case 97526364:
                    if (className.equals("float")) {
                        c = 6;
                        break;
                    }
                    break;
                case 109413500:
                    if (className.equals("short")) {
                        c = 3;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    Class clazz2 = Boolean.TYPE;
                    return clazz2;
                case 1:
                    Class clazz3 = Byte.TYPE;
                    return clazz3;
                case 2:
                    Class clazz4 = Character.TYPE;
                    return clazz4;
                case 3:
                    Class clazz5 = Short.TYPE;
                    return clazz5;
                case 4:
                    Class clazz6 = Integer.TYPE;
                    return clazz6;
                case 5:
                    Class clazz7 = Long.TYPE;
                    return clazz7;
                case 6:
                    Class clazz8 = Float.TYPE;
                    return clazz8;
                case 7:
                    Class clazz9 = Double.TYPE;
                    return clazz9;
                default:
                    throw new LuaException("Class not found: " + className);
            }
        }
    }

    public static int javaNewInstance(long luaState, String className) throws LuaException {
        int primitive;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            Class clazz = javaBindClass(className);
            primitive = clazz.isPrimitive() ? toPrimitive(L, clazz, -1) : getObjInstance(L, clazz);
        }
        return primitive;
    }

    public static int javaNew(long luaState, Class<?> clazz) throws LuaException {
        int primitive;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            primitive = clazz.isPrimitive() ? toPrimitive(L, clazz, -1) : getObjInstance(L, clazz);
        }
        return primitive;
    }

    public static int javaCreate(long luaState, Class<?> clazz) throws LuaException {
        int objInstance;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (clazz.isInterface()) {
                objInstance = createProxyObject(L, clazz);
            } else if (clazz.isPrimitive()) {
                objInstance = createArray(L, clazz);
            } else if (List_class.isAssignableFrom(clazz)) {
                objInstance = createList(L, clazz);
            } else if (Map_class.isAssignableFrom(clazz)) {
                objInstance = createMap(L, clazz);
            } else if (L.objLen(-1) == 0) {
                objInstance = createArray(L, clazz);
            } else if (clazz.isAssignableFrom(new LuaTable(L, -1).get(1).getClass())) {
                objInstance = createArray(L, clazz);
            } else {
                objInstance = getObjInstance(L, clazz);
            }
        }
        return objInstance;
    }

    public static int objectCall(long luaState, Object obj) throws LuaException {
        int i;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (obj instanceof LuaMetaTable) {
                int n = L.getTop();
                Object[] args = new Object[n - 1];
                for (int i2 = 2; i2 <= n; i2++) {
                    args[i2 - 2] = L.toJavaObject(i2);
                }
                Object ret = ((LuaMetaTable) obj).__call(args);
                L.pushObjectValue(ret);
                i = 1;
            } else {
                i = 0;
            }
        }
        return i;
    }

    public static int createProxy(long luaState, String implem) throws LuaException {
        int createProxyObject;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            createProxyObject = createProxyObject(L, implem);
        }
        return createProxyObject;
    }

    public static int createArray(long luaState, String className) throws LuaException {
        int createArray;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            Class type = javaBindClass(className);
            createArray = createArray(L, type);
        }
        return createArray;
    }

    public static int javaLoadLib(long luaState, String className, String methodName) throws LuaException {
        int i = 0;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            try {
                Class<?> clazz = Class.forName(className);
                try {
                    Method mt = clazz.getMethod(methodName, LuaState_class);
                    Object obj = mt.invoke(null, L);
                    if (obj != null && (obj instanceof Integer)) {
                        i = ((Integer) obj).intValue();
                    }
                } catch (Exception e) {
                    throw new LuaException("Error on calling method. Library could not be loaded. " + e.getMessage());
                }
            } catch (ClassNotFoundException e2) {
                throw new LuaException(e2);
            }
        }
        return i;
    }

    public static int javaToString(long luaState, Object obj) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            if (obj == null) {
                L.pushString("null");
            } else {
                L.pushString(obj.toString());
            }
        }
        return 1;
    }

    public static int javaEquals(long luaState, Object obj, Object obj2) throws LuaException {
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            boolean eq = obj.equals(obj2);
            L.pushBoolean(eq);
        }
        return 1;
    }

    public static int javaObjectLength(long luaState, Object obj) throws LuaException {
        int ret;
        LuaState L = LuaStateFactory.getExistingState(luaState);
        synchronized (L) {
            try {
                if (obj instanceof CharSequence) {
                    ret = ((CharSequence) obj).length();
                } else if (obj instanceof Collection) {
                    ret = ((Collection) obj).size();
                } else if (obj instanceof Map) {
                    ret = ((Map) obj).size();
                } else {
                    ret = Array.getLength(obj);
                }
                L.pushInteger(ret);
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return 1;
    }

    private static int getObjInstance(LuaState L, Class<?> clazz) throws LuaException {
        int i;
        synchronized (L) {
            int top = L.getTop();
            if (top == 1) {
                try {
                    Object ret = clazz.newInstance();
                    L.pushJavaObject(ret);
                    i = 1;
                } catch (Exception e) {
                    if (View.class.isAssignableFrom(clazz)) {
                        try {
                            Constructor<?> ctr = clazz.getConstructor(Context.class);
                            Object ret2 = ctr.newInstance(L.getContext().getContext());
                            L.pushJavaObject(ret2);
                            i = 1;
                        } catch (Exception e2) {
                        }
                    }
                }
                return i;
            }
            Object[] objs = new Object[top - 1];
            Constructor[] constructors = clazz.getConstructors();
            Constructor constructor = null;
            int length = constructors.length;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                Constructor c = constructors[i2];
                Class<?>[] parameters = c.getParameterTypes();
                if (parameters.length == top - 1) {
                    boolean okConstructor = true;
                    for (int j = 0; j < parameters.length; j++) {
                        try {
                            objs[j] = compareTypes(L, parameters[j], j + 2);
                        } catch (Exception e3) {
                            okConstructor = false;
                        }
                    }
                    if (okConstructor) {
                        constructor = c;
                        break;
                    }
                }
                i2++;
            }
            if (constructor == null) {
                StringBuilder msgBuilder = new StringBuilder();
                for (Constructor c2 : constructors) {
                    msgBuilder.append(c2.toString());
                    msgBuilder.append("\n");
                }
                throw new LuaException("Invalid constructor method call. Invalid Parameters.\n" + msgBuilder.toString());
            }
            try {
                Object ret3 = constructor.newInstance(objs);
                if (ret3 == null) {
                    throw new LuaException("Couldn't instantiate java Object");
                }
                L.pushJavaObject(ret3);
                i = 1;
                return i;
            } catch (Exception e4) {
                throw new LuaException(e4);
            }
        }
    }

    public static ArrayList<Method> getMethod(Class<?> clazz, String methodName, boolean isClass) {
        HashMap<String, ArrayList<Method>> cList = methodCache3.get(clazz);
        if (cList == null) {
            cList = new HashMap<>();
            methodCache3.put(clazz, cList);
        }
        ArrayList<Method> mlist = cList.get(methodName);
        if (mlist == null) {
            Method[] methods = methodsMap.get(clazz);
            if (methods == null) {
                methods = clazz.getMethods();
                methodsMap.put(clazz, methods);
            }
            for (Method method : methods) {
                String name = method.getName();
                ArrayList<Method> list = cList.get(name);
                if (list == null) {
                    list = new ArrayList<>();
                    cList.put(name, list);
                }
                list.add(method);
            }
            mlist = cList.get(methodName);
        }
        if (mlist == null) {
            mlist = new ArrayList<>();
        }
        if (isClass) {
            ArrayList<Method> slist = new ArrayList<>();
            Iterator<Method> it = mlist.iterator();
            while (it.hasNext()) {
                Method m = it.next();
                if (Modifier.isStatic(m.getModifiers())) {
                    slist.add(m);
                }
            }
            if (slist.isEmpty()) {
                return getMethod(Class.class, methodName, false);
            }
            return slist;
        }
        return mlist;
    }

    public static int checkField(LuaState L, Object obj, String fieldName) throws LuaException {
        Class objClass;
        synchronized (L) {
            boolean isClass = false;
            if (obj instanceof Class) {
                objClass = (Class) obj;
                isClass = true;
            } else {
                objClass = obj.getClass();
            }
            try {
                Field field = objClass.getField(fieldName);
                if (field == null) {
                    return 0;
                }
                if (!isClass || Modifier.isStatic(field.getModifiers())) {
                    try {
                        if (!Modifier.isPublic(field.getModifiers())) {
                            field.setAccessible(true);
                        }
                        Object ret = field.get(obj);
                        L.pushObjectValue(ret);
                        return Modifier.isFinal(field.getModifiers()) ? 5 : 1;
                    } catch (Exception e) {
                        throw new LuaException(e);
                    }
                }
                return 0;
            } catch (NoSuchFieldException e2) {
                return 0;
            }
        }
    }

    public static int checkMethod(LuaState L, Object obj, String methodName) throws LuaException {
        Class<?> clazz;
        int i;
        synchronized (L) {
            boolean isClass = false;
            if (obj instanceof Class) {
                clazz = (Class) obj;
                isClass = true;
            } else {
                clazz = obj.getClass();
            }
            String cacheName = L.toString(-1);
            Method[] mlist = methodCache.get(cacheName);
            if (mlist == null) {
                ArrayList<Method> list = getMethod(clazz, methodName, isClass);
                mlist = new Method[list.size()];
                list.toArray(mlist);
                methodCache.put(cacheName, mlist);
            }
            if (mlist.length == 0) {
                i = 0;
            } else {
                i = 2;
            }
        }
        return i;
    }

    public static int checkClass(LuaState L, Object obj, String className) throws LuaException {
        int i = 0;
        synchronized (L) {
            if (obj instanceof Class) {
                Class clazz = (Class) obj;
                Class[] clazzes = clazz.getClasses();
                int length = clazzes.length;
                int i2 = 0;
                while (true) {
                    if (i2 >= length) {
                        break;
                    }
                    Class c = clazzes[i2];
                    if (!c.getSimpleName().equals(className)) {
                        i2++;
                    } else {
                        L.pushJavaObject(c);
                        i = 3;
                        break;
                    }
                }
            }
        }
        return i;
    }

    public static int javaGetter(LuaState L, Object obj, String methodName) throws LuaException {
        Class<?> clazz;
        Method method;
        synchronized (L) {
            boolean isClass = false;
            if (obj instanceof Map) {
                Map map = (Map) obj;
                L.pushObjectValue(map.get(methodName));
                return 1;
            }
            if (obj instanceof Class) {
                clazz = (Class) obj;
                isClass = true;
            } else {
                clazz = obj.getClass();
            }
            char c = methodName.charAt(0);
            if (Character.isLowerCase(c)) {
                methodName = Character.toUpperCase(c) + methodName.substring(1);
            }
            try {
                method = clazz.getMethod("get" + methodName, new Class[0]);
            } catch (NoSuchMethodException e) {
                try {
                    method = clazz.getMethod("is" + methodName, new Class[0]);
                } catch (NoSuchMethodException e2) {
                    return 0;
                }
            }
            if (!isClass || Modifier.isStatic(method.getModifiers())) {
                try {
                    Object ret = method.invoke(obj, new Object[0]);
                    if (ret instanceof CharSequence) {
                        L.pushString(ret.toString());
                    } else {
                        L.pushObjectValue(ret);
                    }
                    return 1;
                } catch (Exception e3) {
                    throw new LuaException(e3);
                }
            }
            return 0;
        }
    }

    public static int javaSetter(LuaState L, Object obj, String methodName) throws LuaException {
        int ret;
        synchronized (L) {
            boolean isClass = false;
            if (obj instanceof Map) {
                Map map = (Map) obj;
                map.put(methodName, L.toJavaObject(3));
                ret = 1;
            } else {
                if (obj instanceof Class) {
                    Class cls = (Class) obj;
                    isClass = true;
                } else {
                    obj.getClass();
                }
                if (methodName.length() > 2 && methodName.substring(0, 2).equals("on") && L.type(-1) == 6) {
                    ret = javaSetListener(L, obj, methodName, isClass);
                } else {
                    ret = javaSetMethod(L, obj, methodName, isClass);
                    if (ret == 0) {
                        ret = setDeclaredFieldValue(L, obj, methodName);
                    }
                }
            }
        }
        return ret;
    }

    private static int setDeclaredFieldValue(LuaState L, Object obj, String fieldName) throws LuaException {
        Class objClass;
        synchronized (L) {
            Field field = null;
            boolean isClass = false;
            if (obj == null) {
                return 0;
            }
            if (obj instanceof Class) {
                objClass = (Class) obj;
                isClass = true;
            } else {
                objClass = obj.getClass();
            }
            String name = null;
            if (!fieldName.startsWith("m")) {
                char c = fieldName.charAt(0);
                if (Character.isLowerCase(c)) {
                    name = Character.toUpperCase(c) + fieldName.substring(1);
                }
                name = "m" + name;
            }
            while (objClass != null) {
                try {
                    field = objClass.getDeclaredField(fieldName);
                } catch (NoSuchFieldException e) {
                    if (name != null) {
                        try {
                            field = objClass.getDeclaredField(name);
                        } catch (NoSuchFieldException e2) {
                        }
                    }
                }
                if (field != null) {
                    break;
                }
                objClass = objClass.getSuperclass();
            }
            if (field == null) {
                return 0;
            }
            if (!isClass || Modifier.isStatic(field.getModifiers())) {
                Class type = field.getType();
                try {
                    if (!Modifier.isPublic(field.getModifiers())) {
                        field.setAccessible(true);
                    }
                    field.set(obj, compareTypes(L, type, 3));
                } catch (LuaException e3) {
                    argError(L, fieldName, 3, type);
                } catch (Exception e4) {
                    throw new LuaException(e4);
                }
                return 1;
            }
            return 0;
        }
    }

    private static int javaSetListener(LuaState L, Object obj, String methodName, boolean isClass) throws LuaException {
        synchronized (L) {
            String name = "setOn" + methodName.substring(2) + "Listener";
            ArrayList<Method> methods = getMethod(obj.getClass(), name, isClass);
            Iterator<Method> it = methods.iterator();
            while (it.hasNext()) {
                Method m = it.next();
                if (!isClass || Modifier.isStatic(m.getModifiers())) {
                    Class<?>[] tp = m.getParameterTypes();
                    if (tp.length == 1 && tp[0].isInterface()) {
                        L.newTable();
                        L.pushValue(-2);
                        L.setField(-2, methodName);
                        try {
                            Object listener = L.getLuaObject(-1).createProxy(tp[0]);
                            m.invoke(obj, listener);
                            return 1;
                        } catch (Exception e) {
                            throw new LuaException(e);
                        }
                    }
                }
            }
            return 0;
        }
    }

    private static int javaSetMethod(LuaState L, Object obj, String methodName, boolean isClass) throws LuaException {
        synchronized (L) {
            char c = methodName.charAt(0);
            if (Character.isLowerCase(c)) {
                methodName = Character.toUpperCase(c) + methodName.substring(1);
            }
            String name = "set" + methodName;
            ArrayList<Method> methods = getMethod(obj.getClass(), name, isClass);
            StringBuilder buf = new StringBuilder();
            Iterator<Method> it = methods.iterator();
            while (it.hasNext()) {
                Method m = it.next();
                if (!isClass || Modifier.isStatic(m.getModifiers())) {
                    Class<?>[] tp = m.getParameterTypes();
                    if (tp.length == 1) {
                        try {
                            Object arg = compareTypes(L, tp[0], -1);
                            try {
                                m.invoke(obj, arg);
                                return 1;
                            } catch (Exception e) {
                                throw new LuaException(e);
                            }
                        } catch (LuaException e2) {
                            buf.append(tp[0]);
                            buf.append("\n");
                        }
                    } else {
                        continue;
                    }
                }
            }
            if (buf.length() > 0) {
                throw new LuaException("Invalid setter " + methodName + ". Invalid Parameters.\n" + buf.toString() + L.typeName(-1));
            }
            return 0;
        }
    }

    private static int createProxyObject(LuaState L, String implem) throws LuaException {
        synchronized (L) {
            try {
                LuaObject luaObj = L.getLuaObject(2);
                Object proxy = luaObj.createProxy(implem);
                L.pushJavaObject(proxy);
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return 1;
    }

    private static int createProxyObject(LuaState L, Class implem) throws LuaException {
        synchronized (L) {
            L.pushJavaObject(createProxyObject(L, implem, 2));
        }
        return 1;
    }

    private static Object createProxyObject(LuaState L, Class implem, int idx) throws LuaException {
        Object createProxy;
        synchronized (L) {
            try {
                LuaObject luaObj = L.getLuaObject(idx);
                createProxy = luaObj.createProxy(implem);
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return createProxy;
    }

    private static int createArray(LuaState L, Class<?> type) throws LuaException {
        synchronized (L) {
            L.pushJavaObject(createArray(L, type, 2));
        }
        return 1;
    }

    private static Object createArray(LuaState L, Class<?> type, int idx) throws LuaException {
        Object array;
        synchronized (L) {
            try {
                int n = L.objLen(idx);
                array = Array.newInstance(type, n);
                if (type == String_class) {
                    for (int i = 1; i <= n; i++) {
                        L.pushNumber(i);
                        L.getTable(idx);
                        Array.set(array, i - 1, L.toString(-1));
                        L.pop(1);
                    }
                } else if (type == Double.TYPE) {
                    for (int i2 = 1; i2 <= n; i2++) {
                        L.pushNumber(i2);
                        L.getTable(idx);
                        Array.set(array, i2 - 1, Double.valueOf(L.toNumber(-1)));
                        L.pop(1);
                    }
                } else if (type == Float.TYPE) {
                    for (int i3 = 1; i3 <= n; i3++) {
                        L.pushNumber(i3);
                        L.getTable(idx);
                        Array.set(array, i3 - 1, Float.valueOf((float) L.toNumber(-1)));
                        L.pop(1);
                    }
                } else if (type == Long.TYPE) {
                    for (int i4 = 1; i4 <= n; i4++) {
                        L.pushNumber(i4);
                        L.getTable(idx);
                        Array.set(array, i4 - 1, Long.valueOf(L.toInteger(-1)));
                        L.pop(1);
                    }
                } else if (type == Integer.TYPE) {
                    for (int i5 = 1; i5 <= n; i5++) {
                        L.pushNumber(i5);
                        L.getTable(idx);
                        Array.set(array, i5 - 1, Integer.valueOf((int) L.toInteger(-1)));
                        L.pop(1);
                    }
                } else if (type == Short.TYPE) {
                    for (int i6 = 1; i6 <= n; i6++) {
                        L.pushNumber(i6);
                        L.getTable(idx);
                        Array.set(array, i6 - 1, Short.valueOf((short) L.toInteger(-1)));
                        L.pop(1);
                    }
                } else if (type == Character.TYPE) {
                    for (int i7 = 1; i7 <= n; i7++) {
                        L.pushNumber(i7);
                        L.getTable(idx);
                        Array.set(array, i7 - 1, Character.valueOf((char) L.toInteger(-1)));
                        L.pop(1);
                    }
                } else if (type == Byte.TYPE) {
                    for (int i8 = 1; i8 <= n; i8++) {
                        L.pushNumber(i8);
                        L.getTable(idx);
                        Array.set(array, i8 - 1, Byte.valueOf((byte) L.toInteger(-1)));
                        L.pop(1);
                    }
                } else {
                    for (int i9 = 1; i9 <= n; i9++) {
                        L.pushNumber(i9);
                        L.getTable(idx);
                        Array.set(array, i9 - 1, compareTypes(L, type, -1));
                        L.pop(1);
                    }
                }
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return array;
    }

    private static int createList(LuaState L, Class<?> type) throws LuaException {
        synchronized (L) {
            L.pushJavaObject(createList(L, type, 2));
        }
        return 1;
    }

    private static Object createList(LuaState L, Class<?> type, int idx) throws LuaException {
        List<Object> list;
        synchronized (L) {
            int n = L.objLen(idx);
            try {
                if (type.equals(List_class)) {
                    type = ArrayList_class;
                }
                list = (List) type.newInstance();
                for (int i = 1; i <= n; i++) {
                    L.pushNumber(i);
                    L.getTable(idx);
                    list.add(L.toJavaObject(-1));
                    L.pop(1);
                }
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return list;
    }

    private static int createMap(LuaState L, Class<?> clazz) throws LuaException {
        synchronized (L) {
            L.pushJavaObject(createMap(L, clazz, 2));
        }
        return 1;
    }

    private static Object createMap(LuaState L, Class<?> clazz, int idx) throws LuaException {
        Map<Object, Object> map;
        synchronized (L) {
            try {
                if (clazz.equals(Map_class)) {
                    clazz = HashMap_class;
                }
                map = (Map) clazz.newInstance();
                L.pushNil();
                while (L.next(idx) != 0) {
                    map.put(L.toJavaObject(-2), L.toJavaObject(-1));
                    L.pop(1);
                }
            } catch (Exception e) {
                throw new LuaException(e);
            }
        }
        return map;
    }

    private static Object compareTypes(LuaState L, Class<?> parameter, int idx) throws LuaException {
        boolean okType = true;
        Object obj = null;
        int type = L.type(idx);
        switch (type) {
            case 0:
                obj = null;
                break;
            case 1:
                if (parameter.isPrimitive()) {
                    if (parameter != Boolean.TYPE) {
                        okType = false;
                    }
                } else if (!parameter.isAssignableFrom(Boolean.TYPE)) {
                    okType = false;
                }
                obj = Boolean.valueOf(L.toBoolean(idx));
                break;
            case 2:
            default:
                throw new LuaException("Invalid Parameters.");
            case 3:
                if (L.isInteger(idx)) {
                    Long lg = Long.valueOf(L.toInteger(idx));
                    obj = LuaState.convertLuaNumber(lg, parameter);
                } else {
                    Double db = Double.valueOf(L.toNumber(idx));
                    obj = LuaState.convertLuaNumber(db, parameter);
                }
                if (obj == null) {
                    okType = false;
                    break;
                }
                break;
            case 4:
                if (!parameter.isAssignableFrom(String_class)) {
                    okType = false;
                    break;
                } else {
                    obj = L.toString(idx);
                    break;
                }
            case 5:
                if (parameter.isAssignableFrom(LuaTable_class)) {
                    obj = L.getLuaObject(idx);
                    break;
                } else if (parameter.isArray()) {
                    obj = createArray(L, parameter.getComponentType(), idx);
                    break;
                } else if (parameter.isInterface()) {
                    obj = createProxyObject(L, parameter, idx);
                    break;
                } else if (parameter == Object.class) {
                    obj = new LuaTable(L, idx);
                    break;
                } else if (Map_class.isAssignableFrom(parameter)) {
                    obj = createMap(L, parameter, idx);
                    break;
                } else {
                    okType = false;
                    break;
                }
            case 6:
                if (parameter.isInterface()) {
                    obj = createProxyObject(L, parameter, idx);
                    break;
                } else if (!parameter.isAssignableFrom(LuaFunction_class)) {
                    okType = false;
                    break;
                } else {
                    obj = L.getLuaObject(idx);
                    break;
                }
            case 7:
                if (L.isObject(idx)) {
                    Object userObj = L.getObjectFromUserdata(idx);
                    if (userObj == null) {
                        obj = null;
                        break;
                    } else if (parameter.isPrimitive() && (Number_class.isAssignableFrom(userObj.getClass()) || Character_class.isAssignableFrom(userObj.getClass()))) {
                        obj = userObj;
                        break;
                    } else if (parameter.isAssignableFrom(userObj.getClass())) {
                        obj = userObj;
                        break;
                    } else {
                        okType = false;
                        break;
                    }
                } else if (!parameter.isAssignableFrom(LuaObject_class)) {
                    okType = false;
                    break;
                } else {
                    obj = L.getLuaObject(idx);
                    break;
                }
                break;
        }
        if (!okType) {
            throw new LuaException("Invalid Parameter.");
        }
        return obj;
    }

    private static int toPrimitive(LuaState L, Class type, int idx) throws LuaException {
        Object obj = null;
        if (type == Character.TYPE && L.type(idx) == 4) {
            String s = L.toString(idx);
            if (s.length() == 1) {
                obj = Character.valueOf(s.charAt(0));
            } else {
                obj = s.toCharArray();
            }
        } else if (!L.isNumber(idx)) {
            throw new LuaException(L.toString(idx) + " is not number");
        } else {
            if (type == Double.TYPE) {
                obj = Double.valueOf(L.toNumber(idx));
            } else if (type == Float.TYPE) {
                obj = Float.valueOf((float) L.toNumber(idx));
            } else if (type == Long.TYPE) {
                obj = Long.valueOf(L.toInteger(idx));
            } else if (type == Integer.TYPE) {
                obj = Integer.valueOf((int) L.toInteger(idx));
            } else if (type == Short.TYPE) {
                obj = Short.valueOf((short) L.toInteger(idx));
            } else if (type == Character.TYPE) {
                obj = Character.valueOf((char) L.toInteger(idx));
            } else if (type == Byte.TYPE) {
                obj = Byte.valueOf((byte) L.toInteger(idx));
            } else if (type == Boolean.TYPE) {
                obj = Boolean.valueOf(L.toBoolean(idx));
            }
        }
        L.pushJavaObject(obj);
        return 1;
    }
}
