package com.luajava;

import java.lang.reflect.Array;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Proxy;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
/* loaded from: classes.dex */
public class LuaObject {
    protected final LuaState L;
    protected int ref;

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaState L) {
        this.L = L;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaState L, String globalName) {
        synchronized (L) {
            this.L = L;
            L.getGlobal(globalName);
            registerValue(-1);
            L.pop(1);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaObject parent, String name) throws LuaException {
        synchronized (parent.getLuaState()) {
            this.L = parent.getLuaState();
            if (!parent.isTable() && !parent.isUserdata()) {
                throw new LuaException("Object parent should be a table or userdata .");
            }
            parent.push();
            this.L.pushString(name);
            this.L.getTable(-2);
            this.L.remove(-2);
            registerValue(-1);
            this.L.pop(1);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaObject parent, Number name) throws LuaException {
        synchronized (parent.getLuaState()) {
            this.L = parent.getLuaState();
            if (!parent.isTable() && !parent.isUserdata()) {
                throw new LuaException("Object parent should be a table or userdata .");
            }
            parent.push();
            this.L.pushNumber(name.doubleValue());
            this.L.getTable(-2);
            this.L.remove(-2);
            registerValue(-1);
            this.L.pop(1);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaObject parent, LuaObject name) throws LuaException {
        if (parent.getLuaState() != name.getLuaState()) {
            throw new LuaException("LuaStates must be the same!");
        }
        synchronized (parent.getLuaState()) {
            if (!parent.isTable() && !parent.isUserdata()) {
                throw new LuaException("Object parent should be a table or userdata .");
            }
            this.L = parent.getLuaState();
            parent.push();
            name.push();
            this.L.getTable(-2);
            this.L.remove(-2);
            registerValue(-1);
            this.L.pop(1);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LuaObject(LuaState L, int index) {
        synchronized (L) {
            this.L = L;
            registerValue(index);
        }
    }

    public LuaState getLuaState() {
        return this.L;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void registerValue(int index) {
        synchronized (this.L) {
            this.L.pushValue(index);
            this.ref = this.L.Lref(LuaState.LUA_REGISTRYINDEX);
        }
    }

    protected void finalize() {
        try {
            synchronized (this.L) {
                if (this.L.getPointer() != 0) {
                    this.L.LunRef(LuaState.LUA_REGISTRYINDEX, this.ref);
                }
            }
        } catch (Exception e) {
            System.err.println("Unable to release object " + this.ref);
        }
    }

    public void push() {
        this.L.rawGetI(LuaState.LUA_REGISTRYINDEX, this.ref);
    }

    public void pop() {
        this.L.pop(1);
    }

    public boolean isNil() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isNil(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isBoolean() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isBoolean(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isNumber() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isNumber(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isInteger() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isInteger(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isString() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isString(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isFunction() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isFunction(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isJavaObject() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isObject(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isJavaFunction() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isJavaFunction(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isTable() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isTable(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public boolean isUserdata() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.isUserdata(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public int type() {
        int type;
        synchronized (this.L) {
            push();
            type = this.L.type(-1);
            this.L.pop(1);
        }
        return type;
    }

    public boolean getBoolean() {
        boolean bool;
        synchronized (this.L) {
            push();
            bool = this.L.toBoolean(-1);
            this.L.pop(1);
        }
        return bool;
    }

    public double getNumber() {
        double db;
        synchronized (this.L) {
            push();
            db = this.L.toNumber(-1);
            this.L.pop(1);
        }
        return db;
    }

    public long getInteger() {
        long lg;
        synchronized (this.L) {
            push();
            lg = this.L.toInteger(-1);
            this.L.pop(1);
        }
        return lg;
    }

    public String getString() {
        String str;
        synchronized (this.L) {
            push();
            str = this.L.toString(-1);
            this.L.pop(1);
        }
        return str;
    }

    public LuaTable<?, ?> getTable() {
        LuaTable td;
        synchronized (this.L) {
            push();
            td = new LuaTable(this.L, -1);
            this.L.pop(1);
        }
        return td;
    }

    public LuaFunction<?> getFunction() {
        LuaFunction<?> ft;
        synchronized (this.L) {
            push();
            ft = new LuaFunction<>(this.L, -1);
            this.L.pop(1);
        }
        return ft;
    }

    public Object getObject() throws LuaException {
        Object obj;
        synchronized (this.L) {
            push();
            obj = this.L.getObjectFromUserdata(-1);
            this.L.pop(1);
        }
        return obj;
    }

    public LuaObject getField(String field) throws LuaException {
        return this.L.getLuaObject(this, field);
    }

    public void setField(String field, Object obj) {
        push();
        try {
            this.L.pushObjectValue(obj);
        } catch (LuaException e) {
            this.L.pushNil();
        }
        this.L.setField(-2, field);
        this.L.pop(1);
    }

    public LuaObject getI(long idx) throws LuaException {
        return this.L.getLuaObject(this, Long.valueOf(idx));
    }

    public void setI(long idx, Object obj) {
        push();
        try {
            this.L.pushObjectValue(obj);
        } catch (LuaException e) {
            this.L.pushNil();
        }
        this.L.setI(-2, idx);
        this.L.pop(1);
    }

    public Object[] callx(Object[] args, int nres) throws LuaException {
        int nargs;
        Object[] res;
        String str;
        String str2;
        synchronized (this.L) {
            if (!isFunction() && !isTable() && !isUserdata()) {
                throw new LuaException("Invalid object. Not a function, table or userdata .");
            }
            int top = this.L.getTop();
            push();
            if (args != null) {
                for (Object obj : args) {
                    this.L.pushObjectValue(obj);
                }
            } else {
                nargs = 0;
            }
            int err = this.L.pcall(nargs, nres, 0);
            if (err != 0) {
                if (this.L.isString(-1)) {
                    str = this.L.toString(-1);
                    this.L.pop(1);
                } else {
                    str = "";
                }
                if (err == 2) {
                    str2 = "Runtime error. " + str;
                } else if (err == 4) {
                    str2 = "Memory allocation error. " + str;
                } else if (err == 6) {
                    str2 = "Error while running the error handler function. " + str;
                } else {
                    str2 = "Lua Error code " + err + ". " + str;
                }
                throw new LuaException(str2);
            }
            if (nres == -1) {
                nres = this.L.getTop() - top;
            }
            if (this.L.getTop() - top < nres) {
                throw new LuaException("Invalid Number of Results .");
            }
            res = new Object[nres];
            for (int i = nres; i > 0; i--) {
                res[i - 1] = this.L.toJavaObject(-1);
                this.L.pop(1);
            }
        }
        return res;
    }

    public Object call(Object... args) throws LuaException {
        return callx(args, 1)[0];
    }

    public byte[] dump() throws LuaException {
        byte[] buf;
        synchronized (this.L) {
            if (!isFunction()) {
                throw new LuaException("Invalid object. Not a function .");
            }
            push();
            buf = this.L.dump(-1);
            this.L.pop(1);
        }
        return buf;
    }

    public Object[] asArray() throws IllegalArgumentException, ArrayIndexOutOfBoundsException, LuaException {
        Object[] objArr;
        synchronized (this.L) {
            if (!isTable()) {
                throw new LuaException("Invalid object. Not a table .");
            }
            push();
            int n = this.L.objLen(-1);
            Object array = Array.newInstance(Object.class, n);
            for (int i = 1; i <= n; i++) {
                this.L.pushInteger(i);
                this.L.getTable(-2);
                try {
                    Array.set(array, i - 1, this.L.toJavaObject(-1));
                } catch (LuaException e) {
                }
                this.L.pop(1);
            }
            this.L.pop(1);
            objArr = (Object[]) array;
        }
        return objArr;
    }

    public Map asMap(LuaState L, Class<?> clazz, int idx) throws LuaException {
        HashMap<Object, Object> map;
        synchronized (L) {
            if (!isTable()) {
                throw new LuaException("Invalid object. Not a table .");
            }
            map = new HashMap<>();
            push();
            L.pushNil();
            while (L.next(idx) != 0) {
                try {
                    map.put(L.toJavaObject(-2), L.toJavaObject(-1));
                } catch (LuaException e) {
                }
                L.pop(1);
            }
            L.pop(1);
        }
        return map;
    }

    public String toString() {
        String str = null;
        synchronized (this.L) {
            try {
                if (isNil()) {
                    str = "nil";
                } else if (isBoolean()) {
                    str = String.valueOf(getBoolean());
                } else if (isNumber()) {
                    str = String.valueOf(getNumber());
                } else if (isString()) {
                    str = getString();
                } else if (isFunction()) {
                    str = "Lua Function";
                } else if (isJavaObject()) {
                    str = getObject().toString();
                } else if (isUserdata()) {
                    str = "Userdata";
                } else if (isTable()) {
                    str = "Lua Table";
                } else if (isJavaFunction()) {
                    str = "Java Function";
                }
            } catch (LuaException e) {
            }
        }
        return str;
    }

    public Object createProxy(String implem) throws ClassNotFoundException, LuaException {
        Object newProxyInstance;
        synchronized (this.L) {
            if (!isTable()) {
                throw new LuaException("Invalid Object. Must be Table.");
            }
            StringTokenizer st = new StringTokenizer(implem, ",");
            Class[] interfaces = new Class[st.countTokens()];
            int i = 0;
            while (st.hasMoreTokens()) {
                interfaces[i] = Class.forName(st.nextToken());
                i++;
            }
            InvocationHandler handler = new LuaInvocationHandler(this);
            newProxyInstance = Proxy.newProxyInstance(getClass().getClassLoader(), interfaces, handler);
        }
        return newProxyInstance;
    }

    public Object createProxy(Class implem) throws LuaException {
        Object newProxyInstance;
        synchronized (this.L) {
            if (!isTable() && !isFunction()) {
                throw new LuaException("Invalid Object. Must be Table or Function.");
            }
            if (isFunction() && implem.getMethods().length != 1) {
                throw new LuaException("Invalid Object. Must be a interface Method of Function.");
            }
            Class[] interfaces = {implem};
            InvocationHandler handler = new LuaInvocationHandler(this);
            newProxyInstance = Proxy.newProxyInstance(implem.getClassLoader(), interfaces, handler);
        }
        return newProxyInstance;
    }
}
