package com.myopicmobile.textwarrior.android;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.ListPopupWindow;
import android.widget.TextView;
import com.myopicmobile.textwarrior.common.Flag;
import com.myopicmobile.textwarrior.common.Language;
import com.myopicmobile.textwarrior.common.LanguageNonProg;
import com.tencent.smtt.sdk.TbsListener;
import java.util.ArrayList;
/* loaded from: classes.dex */
public class AutoCompletePanel {
    private static Language _globalLanguage = LanguageNonProg.getInstance();
    private MyAdapter _adapter;
    private ListPopupWindow _autoCompletePanel;
    private int _backgroundColor;
    private CharSequence _constraint;
    private Context _context;
    private Filter _filter;
    private int _height;
    private int _horizontal;
    private int _textColor;
    private FreeScrollingTextField _textField;
    private int _verticalOffset;
    private GradientDrawable gd;

    public AutoCompletePanel(FreeScrollingTextField textField) {
        this._textField = textField;
        this._context = textField.getContext();
        initAutoCompletePanel();
    }

    public void setTextColor(int color) {
        this._textColor = color;
        this.gd.setStroke(1, color);
        this._autoCompletePanel.setBackgroundDrawable(this.gd);
    }

    public void setBackgroundColor(int color) {
        this._backgroundColor = color;
        this.gd.setColor(color);
        this._autoCompletePanel.setBackgroundDrawable(this.gd);
    }

    public void setBackground(Drawable color) {
        this._autoCompletePanel.setBackgroundDrawable(color);
    }

    private void initAutoCompletePanel() {
        this._autoCompletePanel = new ListPopupWindow(this._context);
        this._autoCompletePanel.setAnchorView(this._textField);
        this._adapter = new MyAdapter(this._context, 17367043);
        this._autoCompletePanel.setAdapter(this._adapter);
        this._filter = this._adapter.getFilter();
        setHeight(TbsListener.ErrorCode.ERROR_CODE_LOAD_BASE);
        TypedArray array = this._context.getTheme().obtainStyledAttributes(new int[]{16842801, 16842806});
        int backgroundColor = array.getColor(0, 16711935);
        int textColor = array.getColor(1, 16711935);
        array.recycle();
        this.gd = new GradientDrawable();
        this.gd.setColor(backgroundColor);
        this.gd.setCornerRadius(4.0f);
        this.gd.setStroke(1, textColor);
        setTextColor(textColor);
        this._autoCompletePanel.setBackgroundDrawable(this.gd);
        this._autoCompletePanel.setOnItemClickListener(new AdapterView.OnItemClickListener() { // from class: com.myopicmobile.textwarrior.android.AutoCompletePanel.1
            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> p1, View p2, int p3, long p4) {
                AutoCompletePanel.this._textField.replaceText(AutoCompletePanel.this._textField.getCaretPosition() - AutoCompletePanel.this._constraint.length(), AutoCompletePanel.this._constraint.length(), ((TextView) p2).getText().toString());
                AutoCompletePanel.this._adapter.abort();
                AutoCompletePanel.this.dismiss();
            }
        });
    }

    public void setWidth(int width) {
        this._autoCompletePanel.setWidth(width);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setHeight(int height) {
        if (this._height != height) {
            this._height = height;
            this._autoCompletePanel.setHeight(height);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setHorizontalOffset(int horizontal) {
        int horizontal2 = Math.min(horizontal, this._textField.getWidth() / 2);
        if (this._horizontal != horizontal2) {
            this._horizontal = horizontal2;
            this._autoCompletePanel.setHorizontalOffset(horizontal2);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setVerticalOffset(int verticalOffset) {
        int max = 0 - this._autoCompletePanel.getHeight();
        if (verticalOffset > max) {
            this._textField.scrollBy(0, verticalOffset - max);
            verticalOffset = max;
        }
        if (this._verticalOffset != verticalOffset) {
            this._verticalOffset = verticalOffset;
            this._autoCompletePanel.setVerticalOffset(verticalOffset);
        }
    }

    public void update(CharSequence constraint) {
        this._adapter.restart();
        this._filter.filter(constraint);
    }

    public void show() {
        if (!this._autoCompletePanel.isShowing()) {
            this._autoCompletePanel.show();
        }
        this._autoCompletePanel.getListView().setFadingEdgeLength(0);
    }

    public void dismiss() {
        if (this._autoCompletePanel.isShowing()) {
            this._autoCompletePanel.dismiss();
        }
    }

    public synchronized void setLanguage(Language lang) {
        _globalLanguage = lang;
    }

    public static synchronized Language getLanguage() {
        Language language;
        synchronized (AutoCompletePanel.class) {
            language = _globalLanguage;
        }
        return language;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public class MyAdapter extends ArrayAdapter<String> implements Filterable {
        private Flag _abort;
        private int _h;
        private DisplayMetrics dm;

        public MyAdapter(Context context, int resource) {
            super(context, resource);
            this._abort = new Flag();
            setNotifyOnChange(false);
            this.dm = context.getResources().getDisplayMetrics();
        }

        public void abort() {
            this._abort.set();
        }

        private int dp(float n) {
            return (int) TypedValue.applyDimension(1, n, this.dm);
        }

        @Override // android.widget.ArrayAdapter, android.widget.Adapter
        public View getView(int position, View convertView, ViewGroup parent) {
            TextView view = (TextView) super.getView(position, convertView, parent);
            view.setTextColor(AutoCompletePanel.this._textColor);
            return view;
        }

        public void restart() {
            this._abort.clear();
        }

        public int getItemHeight() {
            if (this._h != 0) {
                return this._h;
            }
            LayoutInflater inflater = (LayoutInflater) getContext().getSystemService("layout_inflater");
            TextView item = (TextView) inflater.inflate(17367043, (ViewGroup) null);
            item.measure(0, 0);
            this._h = item.getMeasuredHeight();
            return this._h;
        }

        @Override // android.widget.ArrayAdapter, android.widget.Filterable
        public Filter getFilter() {
            Filter filter = new Filter() { // from class: com.myopicmobile.textwarrior.android.AutoCompletePanel.MyAdapter.1
                @Override // android.widget.Filter
                protected Filter.FilterResults performFiltering(CharSequence constraint) {
                    int i = 0;
                    ArrayList<String> buf = new ArrayList<>();
                    String keyword = String.valueOf(constraint).toLowerCase();
                    String[] ss = keyword.split("\\.");
                    if (ss.length == 2) {
                        String pkg = ss[0];
                        keyword = ss[1];
                        if (AutoCompletePanel._globalLanguage.isBasePackage(pkg)) {
                            String[] keywords = AutoCompletePanel._globalLanguage.getBasePackage(pkg);
                            int length = keywords.length;
                            while (i < length) {
                                String k = keywords[i];
                                if (k.toLowerCase().startsWith(keyword)) {
                                    buf.add(k);
                                }
                                i++;
                            }
                        }
                    } else if (ss.length == 1) {
                        if (keyword.charAt(keyword.length() - 1) != '.') {
                            String[] keywords2 = AutoCompletePanel._globalLanguage.getUserWord();
                            for (String k2 : keywords2) {
                                if (k2.toLowerCase().startsWith(keyword)) {
                                    buf.add(k2);
                                }
                            }
                            String[] keywords3 = AutoCompletePanel._globalLanguage.getKeywords();
                            for (String k3 : keywords3) {
                                if (k3.indexOf(keyword) == 0) {
                                    buf.add(k3);
                                }
                            }
                            String[] keywords4 = AutoCompletePanel._globalLanguage.getNames();
                            int length2 = keywords4.length;
                            while (i < length2) {
                                String k4 = keywords4[i];
                                if (k4.toLowerCase().startsWith(keyword)) {
                                    buf.add(k4);
                                }
                                i++;
                            }
                        } else {
                            String pkg2 = keyword.substring(0, keyword.length() - 1);
                            keyword = "";
                            if (AutoCompletePanel._globalLanguage.isBasePackage(pkg2)) {
                                String[] keywords5 = AutoCompletePanel._globalLanguage.getBasePackage(pkg2);
                                int length3 = keywords5.length;
                                while (i < length3) {
                                    buf.add(keywords5[i]);
                                    i++;
                                }
                            }
                        }
                    }
                    AutoCompletePanel.this._constraint = keyword;
                    Filter.FilterResults filterResults = new Filter.FilterResults();
                    filterResults.values = buf;
                    filterResults.count = buf.size();
                    return filterResults;
                }

                @Override // android.widget.Filter
                protected void publishResults(CharSequence constraint, Filter.FilterResults results) {
                    if (results != null && results.count > 0 && !MyAdapter.this._abort.isSet()) {
                        MyAdapter.this.clear();
                        MyAdapter.this.addAll((ArrayList) results.values);
                        int y = (AutoCompletePanel.this._textField.getCaretY() + (AutoCompletePanel.this._textField.rowHeight() / 2)) - AutoCompletePanel.this._textField.getScrollY();
                        AutoCompletePanel.this.setHeight(MyAdapter.this.getItemHeight() * Math.min(2, results.count));
                        AutoCompletePanel.this.setHorizontalOffset(AutoCompletePanel.this._textField.getCaretX() - AutoCompletePanel.this._textField.getScrollX());
                        AutoCompletePanel.this.setVerticalOffset(y - AutoCompletePanel.this._textField.getHeight());
                        MyAdapter.this.notifyDataSetChanged();
                        AutoCompletePanel.this.show();
                        return;
                    }
                    MyAdapter.this.notifyDataSetInvalidated();
                }
            };
            return filter;
        }
    }
}
