package com.myopicmobile.textwarrior.android;

import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.support.v4.internal.view.SupportMenu;
import android.support.v4.view.MotionEventCompat;
import android.support.v4.view.accessibility.AccessibilityNodeInfoCompat;
import android.text.ClipboardManager;
import android.text.Selection;
import android.text.SpannableStringBuilder;
import android.text.method.CharacterPickerDialog;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.accessibility.AccessibilityRecord;
import android.view.animation.AnimationUtils;
import android.view.inputmethod.BaseInputConnection;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import android.view.inputmethod.InputMethodManager;
import android.widget.Scroller;
import com.myopicmobile.textwarrior.common.AutoIndent;
import com.myopicmobile.textwarrior.common.ColorScheme;
import com.myopicmobile.textwarrior.common.ColorSchemeLight;
import com.myopicmobile.textwarrior.common.Document;
import com.myopicmobile.textwarrior.common.DocumentProvider;
import com.myopicmobile.textwarrior.common.Language;
import com.myopicmobile.textwarrior.common.LanguageLua;
import com.myopicmobile.textwarrior.common.Lexer;
import com.myopicmobile.textwarrior.common.Pair;
import com.myopicmobile.textwarrior.common.RowListener;
import com.myopicmobile.textwarrior.common.TextWarriorException;
import com.tencent.smtt.sdk.TbsListener;
import java.util.List;
/* loaded from: classes.dex */
public class FreeScrollingTextField extends View implements Document.TextFieldMetrics {
    public static final int SCROLL_DOWN = 1;
    public static final int SCROLL_LEFT = 2;
    public static final int SCROLL_RIGHT = 3;
    public static final int SCROLL_UP = 0;
    private int _alphaWidth;
    protected AutoCompletePanel _autoCompletePanel;
    protected int _autoIndentWidth;
    private Typeface _boldTypeface;
    private Paint _brush;
    private Paint _brushLine;
    protected int _caretPosition;
    private int _caretRow;
    private int _caretX;
    private int _caretY;
    private ClipboardManager _clipboardManager;
    private ClipboardPanel _clipboardPanel;
    protected ColorScheme _colorScheme;
    private Typeface _defTypeface;
    private char _emoji;
    private TextFieldController _fieldController;
    protected DocumentProvider _hDoc;
    private TextFieldInputConnection _inputConnection;
    protected boolean _isAutoComplete;
    protected boolean _isAutoIndent;
    protected boolean _isEdited;
    protected boolean _isHighlightRow;
    private boolean _isLayout;
    protected boolean _isLongPressCaps;
    private Typeface _italicTypeface;
    private int _leftOffset;
    protected TouchNavigationMethod _navMethod;
    private RowListener _rowLis;
    private final Runnable _scrollCaretDownTask;
    private final Runnable _scrollCaretLeftTask;
    private final Runnable _scrollCaretRightTask;
    private final Runnable _scrollCaretUpTask;
    private final Scroller _scroller;
    private OnSelectionChangedListener _selModeLis;
    protected int _selectionAnchor;
    protected int _selectionEdge;
    private boolean _showLineNumbers;
    protected boolean _showNonPrinting;
    private int _spaceWidth;
    protected int _tabLength;
    private TextChangeListener _textLis;
    private int _topOffset;
    private int _xExtent;
    private float _zoomFactor;
    private boolean isAccessibilityEnabled;
    private long mLastScroll;
    private MotionEvent mMotionEvent;
    private float mX;
    private float mY;
    protected static float EMPTY_CARET_WIDTH_SCALE = 0.75f;
    protected static float SEL_CARET_HEIGHT_SCALE = 0.5f;
    protected static int DEFAULT_TAB_LENGTH_SPACES = 4;
    protected static int BASE_TEXT_SIZE_PIXELS = 16;
    protected static long SCROLL_PERIOD = 250;
    private static SparseArray<String> PICKER_SETS = new SparseArray<>();

    static /* synthetic */ int access$304(FreeScrollingTextField x0) {
        int i = x0._caretRow + 1;
        x0._caretRow = i;
        return i;
    }

    static /* synthetic */ int access$306(FreeScrollingTextField x0) {
        int i = x0._caretRow - 1;
        x0._caretRow = i;
        return i;
    }

    static {
        PICKER_SETS.put(65, "ÀÁÂÄÆÃÅĄĀ");
        PICKER_SETS.put(67, "ÇĆČ");
        PICKER_SETS.put(68, "Ď");
        PICKER_SETS.put(69, "ÈÉÊËĘĚĒ");
        PICKER_SETS.put(71, "Ğ");
        PICKER_SETS.put(76, "Ł");
        PICKER_SETS.put(73, "ÌÍÎÏĪİ");
        PICKER_SETS.put(78, "ÑŃŇ");
        PICKER_SETS.put(79, "ØŒÕÒÓÔÖŌ");
        PICKER_SETS.put(82, "Ř");
        PICKER_SETS.put(83, "ŚŠŞ");
        PICKER_SETS.put(84, "Ť");
        PICKER_SETS.put(85, "ÙÚÛÜŮŪ");
        PICKER_SETS.put(89, "ÝŸ");
        PICKER_SETS.put(90, "ŹŻŽ");
        PICKER_SETS.put(97, "àáâäæãåąā");
        PICKER_SETS.put(99, "çćč");
        PICKER_SETS.put(100, "ď");
        PICKER_SETS.put(101, "èéêëęěē");
        PICKER_SETS.put(103, "ğ");
        PICKER_SETS.put(TbsListener.ErrorCode.DISK_FULL, "ìíîïīı");
        PICKER_SETS.put(TbsListener.ErrorCode.VERIFY_ERROR, "ł");
        PICKER_SETS.put(TbsListener.ErrorCode.NONEEDTODOWN_ERROR, "ñńň");
        PICKER_SETS.put(TbsListener.ErrorCode.NETWORK_NOT_WIFI_ERROR, "øœõòóôöō");
        PICKER_SETS.put(114, "ř");
        PICKER_SETS.put(115, "§ßśšş");
        PICKER_SETS.put(116, "ť");
        PICKER_SETS.put(117, "ùúûüůū");
        PICKER_SETS.put(TbsListener.ErrorCode.THREAD_INIT_ERROR, "ýÿ");
        PICKER_SETS.put(TbsListener.ErrorCode.DOWNLOAD_HAS_COPY_TBS_ERROR, "źżž");
        PICKER_SETS.put(61185, "…¥•®©±[]{}\\|");
        PICKER_SETS.put(47, "\\");
        PICKER_SETS.put(49, "¹½⅓¼⅛");
        PICKER_SETS.put(50, "²⅔");
        PICKER_SETS.put(51, "³¾⅜");
        PICKER_SETS.put(52, "⁴");
        PICKER_SETS.put(53, "⅝");
        PICKER_SETS.put(55, "⅞");
        PICKER_SETS.put(48, "ⁿ∅");
        PICKER_SETS.put(36, "¢£€¥₣₤₱");
        PICKER_SETS.put(37, "‰");
        PICKER_SETS.put(42, "†‡");
        PICKER_SETS.put(45, "–—");
        PICKER_SETS.put(43, "±");
        PICKER_SETS.put(40, "[{<");
        PICKER_SETS.put(41, "]}>");
        PICKER_SETS.put(33, "¡");
        PICKER_SETS.put(34, "“”«»˝");
        PICKER_SETS.put(63, "¿");
        PICKER_SETS.put(44, "‚„");
        PICKER_SETS.put(61, "≠≈∞");
        PICKER_SETS.put(60, "≤«‹");
        PICKER_SETS.put(62, "≥»›");
    }

    public FreeScrollingTextField(Context context) {
        super(context);
        this._isEdited = false;
        this._caretPosition = 0;
        this._selectionAnchor = -1;
        this._selectionEdge = -1;
        this._tabLength = DEFAULT_TAB_LENGTH_SPACES;
        this._colorScheme = new ColorSchemeLight();
        this._isHighlightRow = false;
        this._showNonPrinting = false;
        this._isAutoIndent = true;
        this._autoIndentWidth = 4;
        this._isLongPressCaps = false;
        this._isAutoComplete = true;
        this._caretRow = 0;
        this._xExtent = 0;
        this._leftOffset = 0;
        this._showLineNumbers = false;
        this._zoomFactor = 1.0f;
        this._defTypeface = Typeface.DEFAULT;
        this._boldTypeface = Typeface.DEFAULT_BOLD;
        this._italicTypeface = Typeface.create(Typeface.DEFAULT, 2);
        this._scrollCaretDownTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.1
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretDown();
                if (!FreeScrollingTextField.this.caretOnLastRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretDownTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretUpTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.2
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretUp();
                if (!FreeScrollingTextField.this.caretOnFirstRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretUpTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretLeftTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.3
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretLeft(false);
                if (FreeScrollingTextField.this._caretPosition > 0 && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition - 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretLeftTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretRightTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.4
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretRight(false);
                if (!FreeScrollingTextField.this.caretOnEOF() && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition + 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretRightTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this.isAccessibilityEnabled = false;
        this._hDoc = new DocumentProvider(this);
        this._navMethod = new TouchNavigationMethod(this);
        this._scroller = new Scroller(context);
        initView();
    }

    public FreeScrollingTextField(Context context, AttributeSet attrs) {
        super(context, attrs);
        this._isEdited = false;
        this._caretPosition = 0;
        this._selectionAnchor = -1;
        this._selectionEdge = -1;
        this._tabLength = DEFAULT_TAB_LENGTH_SPACES;
        this._colorScheme = new ColorSchemeLight();
        this._isHighlightRow = false;
        this._showNonPrinting = false;
        this._isAutoIndent = true;
        this._autoIndentWidth = 4;
        this._isLongPressCaps = false;
        this._isAutoComplete = true;
        this._caretRow = 0;
        this._xExtent = 0;
        this._leftOffset = 0;
        this._showLineNumbers = false;
        this._zoomFactor = 1.0f;
        this._defTypeface = Typeface.DEFAULT;
        this._boldTypeface = Typeface.DEFAULT_BOLD;
        this._italicTypeface = Typeface.create(Typeface.DEFAULT, 2);
        this._scrollCaretDownTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.1
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretDown();
                if (!FreeScrollingTextField.this.caretOnLastRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretDownTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretUpTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.2
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretUp();
                if (!FreeScrollingTextField.this.caretOnFirstRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretUpTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretLeftTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.3
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretLeft(false);
                if (FreeScrollingTextField.this._caretPosition > 0 && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition - 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretLeftTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretRightTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.4
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretRight(false);
                if (!FreeScrollingTextField.this.caretOnEOF() && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition + 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretRightTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this.isAccessibilityEnabled = false;
        this._hDoc = new DocumentProvider(this);
        this._navMethod = new TouchNavigationMethod(this);
        this._scroller = new Scroller(context);
        initView();
    }

    public FreeScrollingTextField(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        this._isEdited = false;
        this._caretPosition = 0;
        this._selectionAnchor = -1;
        this._selectionEdge = -1;
        this._tabLength = DEFAULT_TAB_LENGTH_SPACES;
        this._colorScheme = new ColorSchemeLight();
        this._isHighlightRow = false;
        this._showNonPrinting = false;
        this._isAutoIndent = true;
        this._autoIndentWidth = 4;
        this._isLongPressCaps = false;
        this._isAutoComplete = true;
        this._caretRow = 0;
        this._xExtent = 0;
        this._leftOffset = 0;
        this._showLineNumbers = false;
        this._zoomFactor = 1.0f;
        this._defTypeface = Typeface.DEFAULT;
        this._boldTypeface = Typeface.DEFAULT_BOLD;
        this._italicTypeface = Typeface.create(Typeface.DEFAULT, 2);
        this._scrollCaretDownTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.1
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretDown();
                if (!FreeScrollingTextField.this.caretOnLastRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretDownTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretUpTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.2
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretUp();
                if (!FreeScrollingTextField.this.caretOnFirstRowOfFile()) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretUpTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretLeftTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.3
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretLeft(false);
                if (FreeScrollingTextField.this._caretPosition > 0 && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition - 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretLeftTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this._scrollCaretRightTask = new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.4
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this._fieldController.moveCaretRight(false);
                if (!FreeScrollingTextField.this.caretOnEOF() && FreeScrollingTextField.this._caretRow == FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition + 1)) {
                    FreeScrollingTextField.this.postDelayed(FreeScrollingTextField.this._scrollCaretRightTask, FreeScrollingTextField.SCROLL_PERIOD);
                }
            }
        };
        this.isAccessibilityEnabled = false;
        this._hDoc = new DocumentProvider(this);
        this._navMethod = new TouchNavigationMethod(this);
        this._scroller = new Scroller(context);
        initView();
    }

    public int getTopOffset() {
        return this._topOffset;
    }

    public int getAutoIndentWidth() {
        return this._autoIndentWidth;
    }

    public void setAutoIndentWidth(int autoIndentWidth) {
        this._autoIndentWidth = autoIndentWidth;
    }

    public int getCaretY() {
        return this._caretY;
    }

    public int getCaretX() {
        return this._caretX;
    }

    public boolean isShowLineNumbers() {
        return this._showLineNumbers;
    }

    public void setShowLineNumbers(boolean showLineNumbers) {
        this._showLineNumbers = showLineNumbers;
    }

    public int getLeftOffset() {
        return this._leftOffset;
    }

    public float getTextSize() {
        return this._brush.getTextSize();
    }

    public void setTextSize(int pix) {
        if (pix > 8 && pix < 80 && pix != this._brush.getTextSize()) {
            double oldHeight = rowHeight();
            double oldWidth = getAdvance('a');
            this._zoomFactor = pix / BASE_TEXT_SIZE_PIXELS;
            this._brush.setTextSize(pix);
            this._brushLine.setTextSize(pix);
            if (this._hDoc.isWordWrap()) {
                this._hDoc.analyzeWordWrap();
            }
            this._fieldController.updateCaretRow();
            double x = getScrollX() * (getAdvance('a') / oldWidth);
            double y = getScrollY() * (rowHeight() / oldHeight);
            scrollTo((int) x, (int) y);
            this._alphaWidth = (int) this._brush.measureText("a");
            this._spaceWidth = (int) this._brush.measureText(" ");
            invalidate();
        }
    }

    public void replaceText(int from, int charCount, String text) {
        this._hDoc.beginBatchEdit();
        this._fieldController.replaceText(from, charCount, text);
        this._fieldController.stopTextComposing();
        this._hDoc.endBatchEdit();
    }

    public void format() {
        selectText(false);
        CharSequence text = AutoIndent.format(new DocumentProvider(this._hDoc), this._autoIndentWidth);
        this._hDoc.beginBatchEdit();
        this._hDoc.deleteAt(0, this._hDoc.docLength() - 1, System.nanoTime());
        this._hDoc.insertBefore(text.toString().toCharArray(), 0, System.nanoTime());
        this._hDoc.endBatchEdit();
        this._hDoc.clearSpans();
        respan();
        invalidate();
    }

    public int getLength() {
        return this._hDoc.docLength();
    }

    private void initView() {
        AccessibilityManager accessibilityManager = (AccessibilityManager) getContext().getSystemService("accessibility");
        this.isAccessibilityEnabled = accessibilityManager.isEnabled();
        this._fieldController = new TextFieldController();
        this._clipboardManager = (ClipboardManager) getContext().getSystemService("clipboard");
        this._brush = new Paint();
        this._brush.setAntiAlias(true);
        this._brush.setTextSize(BASE_TEXT_SIZE_PIXELS);
        this._brushLine = new Paint();
        this._brushLine.setAntiAlias(true);
        this._brushLine.setTextSize(BASE_TEXT_SIZE_PIXELS);
        setLongClickable(true);
        setFocusableInTouchMode(true);
        setHapticFeedbackEnabled(true);
        this._rowLis = new RowListener() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.5
            @Override // com.myopicmobile.textwarrior.common.RowListener
            public void onRowChange(int newRowIndex) {
            }
        };
        this._selModeLis = new OnSelectionChangedListener() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.6
            @Override // com.myopicmobile.textwarrior.android.OnSelectionChangedListener
            public void onSelectionChanged(boolean active, int selStart, int selEnd) {
                if (active) {
                    FreeScrollingTextField.this._clipboardPanel.show();
                } else {
                    FreeScrollingTextField.this._clipboardPanel.hide();
                }
            }
        };
        this._textLis = new TextChangeListener() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.7
            @Override // com.myopicmobile.textwarrior.android.TextChangeListener
            public void onNewLine(String c, int _caretPosition, int p2) {
                if (FreeScrollingTextField.this.isAccessibilityEnabled) {
                    AccessibilityEvent event = AccessibilityEvent.obtain(16);
                    event.setFromIndex(_caretPosition - 1);
                    event.setAddedCount(1);
                    FreeScrollingTextField.this.sendAccessibilityEventUnchecked(event);
                }
                FreeScrollingTextField.this._autoCompletePanel.dismiss();
            }

            @Override // com.myopicmobile.textwarrior.android.TextChangeListener
            public void onDel(CharSequence text, int caretPosition, int delCount) {
                if (FreeScrollingTextField.this.isAccessibilityEnabled) {
                    AccessibilityEvent event = AccessibilityEvent.obtain(16);
                    event.setFromIndex(caretPosition - delCount);
                    event.setRemovedCount(delCount);
                    event.setBeforeText(FreeScrollingTextField.this._hDoc);
                    FreeScrollingTextField.this.sendAccessibilityEventUnchecked(event);
                }
                FreeScrollingTextField.this._autoCompletePanel.dismiss();
            }

            @Override // com.myopicmobile.textwarrior.android.TextChangeListener
            public void onAdd(CharSequence text, int caretPosition, int addCount) {
                if (FreeScrollingTextField.this.isAccessibilityEnabled) {
                    AccessibilityEvent event = AccessibilityEvent.obtain(16);
                    event.setFromIndex(caretPosition - addCount);
                    event.setAddedCount(addCount);
                    FreeScrollingTextField.this.sendAccessibilityEventUnchecked(event);
                }
                if (FreeScrollingTextField.this._isAutoComplete) {
                    int curr = FreeScrollingTextField.this._caretPosition;
                    while (curr >= 0) {
                        char c = FreeScrollingTextField.this._hDoc.charAt(curr - 1);
                        if (!Character.isLetterOrDigit(c) && c != '_' && c != '.') {
                            break;
                        }
                        curr--;
                    }
                    if (FreeScrollingTextField.this._caretPosition - curr > 0) {
                        FreeScrollingTextField.this._autoCompletePanel.update(FreeScrollingTextField.this._hDoc.subSequence(curr, FreeScrollingTextField.this._caretPosition - curr));
                    } else {
                        FreeScrollingTextField.this._autoCompletePanel.dismiss();
                    }
                }
            }
        };
        resetView();
        this._clipboardPanel = new ClipboardPanel(this);
        this._autoCompletePanel = new AutoCompletePanel(this);
        this._autoCompletePanel.setLanguage(LanguageLua.getInstance());
        invalidate();
    }

    @Override // android.view.View
    public AccessibilityNodeInfo createAccessibilityNodeInfo() {
        AccessibilityNodeInfo node = super.createAccessibilityNodeInfo();
        if (Build.VERSION.SDK_INT > 20) {
            node.addAction(AccessibilityNodeInfo.AccessibilityAction.ACTION_SCROLL_FORWARD);
            node.addAction(AccessibilityNodeInfo.AccessibilityAction.ACTION_SCROLL_BACKWARD);
            node.addAction(AccessibilityNodeInfo.AccessibilityAction.ACTION_NEXT_AT_MOVEMENT_GRANULARITY);
            node.addAction(AccessibilityNodeInfo.AccessibilityAction.ACTION_PREVIOUS_AT_MOVEMENT_GRANULARITY);
        } else if (Build.VERSION.SDK_INT > 15) {
            node.addAction(4096);
            node.addAction(8192);
            node.addAction(256);
            node.addAction(512);
        }
        node.setFocusable(true);
        if (Build.VERSION.SDK_INT >= 18) {
            node.setEditable(true);
        }
        if (Build.VERSION.SDK_INT >= 19) {
            node.setMultiLine(true);
        }
        return node;
    }

    @Override // android.view.View
    public boolean performAccessibilityAction(int action, Bundle arguments) {
        if (Build.VERSION.SDK_INT < 16) {
            return super.performAccessibilityAction(action, arguments);
        }
        switch (action) {
            case 256:
                switch (arguments.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_MOVEMENT_GRANULARITY_INT)) {
                    case 1:
                        moveCaretRight();
                        return true;
                    case 2:
                    case 3:
                    default:
                        return true;
                    case 4:
                        moveCaretDown();
                        return true;
                }
            case 512:
                switch (arguments.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_MOVEMENT_GRANULARITY_INT)) {
                    case 1:
                        moveCaretLeft();
                        return true;
                    case 2:
                    case 3:
                    default:
                        return true;
                    case 4:
                        moveCaretUp();
                        return true;
                }
            default:
                return super.performAccessibilityAction(action, arguments);
        }
    }

    private void resetView() {
        this._caretPosition = 0;
        this._caretRow = 0;
        this._xExtent = 0;
        this._fieldController.setSelectText(false);
        this._fieldController.stopTextComposing();
        this._hDoc.clearSpans();
        if (getContentWidth() > 0 || !this._hDoc.isWordWrap()) {
            this._hDoc.analyzeWordWrap();
        }
        this._rowLis.onRowChange(0);
        scrollTo(0, 0);
    }

    public void setDocumentProvider(DocumentProvider hDoc) {
        this._hDoc = hDoc;
        resetView();
        this._fieldController.cancelSpanning();
        this._fieldController.determineSpans();
        invalidate();
        if (this.isAccessibilityEnabled) {
            setContentDescription(this._hDoc);
        }
    }

    public DocumentProvider createDocumentProvider() {
        return new DocumentProvider(this._hDoc);
    }

    public void setRowListener(RowListener rLis) {
        this._rowLis = rLis;
    }

    public void setOnSelectionChangedListener(OnSelectionChangedListener sLis) {
        this._selModeLis = sLis;
    }

    public void setNavigationMethod(TouchNavigationMethod navMethod) {
        this._navMethod = navMethod;
    }

    public void setChirality(boolean isRightHanded) {
        this._navMethod.onChiralityChanged(isRightHanded);
    }

    public boolean isEdited() {
        return this._isEdited;
    }

    public void setEdited(boolean set) {
        this._isEdited = set;
    }

    @Override // android.view.View
    public InputConnection onCreateInputConnection(EditorInfo outAttrs) {
        outAttrs.inputType = 131073;
        outAttrs.imeOptions = 1342177286;
        if (this._inputConnection == null) {
            this._inputConnection = new TextFieldInputConnection(this);
        } else {
            this._inputConnection.resetComposingState();
        }
        return this._inputConnection;
    }

    @Override // android.view.View
    public boolean onCheckIsTextEditor() {
        return true;
    }

    @Override // android.view.View
    public boolean isSaveEnabled() {
        return true;
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        setMeasuredDimension(useAllDimensions(widthMeasureSpec), useAllDimensions(heightMeasureSpec));
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // android.view.View
    public void onLayout(boolean changed, int left, int top, int right, int bottom) {
        if (changed) {
            Rect rect = new Rect();
            getWindowVisibleDisplayFrame(rect);
            this._topOffset = (rect.top + rect.height()) - getHeight();
            if (!this._isLayout) {
                respan();
            }
            this._isLayout = right > 0;
            invalidate();
            this._autoCompletePanel.setWidth(getWidth() / 2);
        }
        super.onLayout(changed, left, top, right, bottom);
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        if (this._hDoc.isWordWrap() && oldw != w) {
            this._hDoc.analyzeWordWrap();
        }
        this._fieldController.updateCaretRow();
        if (h < oldh) {
            makeCharVisible(this._caretPosition);
        }
    }

    private int useAllDimensions(int measureSpec) {
        int specMode = View.MeasureSpec.getMode(measureSpec);
        int result = View.MeasureSpec.getSize(measureSpec);
        if (specMode != 1073741824 && specMode != Integer.MIN_VALUE) {
            TextWarriorException.fail("MeasureSpec cannot be UNSPECIFIED. Setting dimensions to max.");
            return Integer.MAX_VALUE;
        }
        return result;
    }

    protected int getNumVisibleRows() {
        return (int) Math.ceil(getContentHeight() / rowHeight());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int rowHeight() {
        Paint.FontMetricsInt metrics = this._brush.getFontMetricsInt();
        return metrics.descent - metrics.ascent;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getContentHeight() {
        return (getHeight() - getPaddingTop()) - getPaddingBottom();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getContentWidth() {
        return (getWidth() - getPaddingLeft()) - getPaddingRight();
    }

    public boolean hasLayout() {
        return getWidth() == 0;
    }

    private int getBeginPaintRow(Canvas canvas) {
        Rect bounds = canvas.getClipBounds();
        return bounds.top / rowHeight();
    }

    private int getEndPaintRow(Canvas canvas) {
        Rect bounds = canvas.getClipBounds();
        return (bounds.bottom - 1) / rowHeight();
    }

    public int getPaintBaseline(int row) {
        Paint.FontMetricsInt metrics = this._brush.getFontMetricsInt();
        return ((row + 1) * rowHeight()) - metrics.descent;
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        canvas.save();
        canvas.clipRect(getScrollX() + getPaddingLeft(), getScrollY() + getPaddingTop(), (getScrollX() + getWidth()) - getPaddingRight(), (getScrollY() + getHeight()) - getPaddingBottom());
        canvas.translate(getPaddingLeft(), getPaddingTop());
        realDraw(canvas);
        canvas.restore();
        this._navMethod.onTextDrawComplete(canvas);
    }

    private void realDraw(Canvas canvas) {
        Pair currSpan;
        Typeface lastTypeface;
        int drawChar;
        Typeface currTypeface;
        int currRowNum = getBeginPaintRow(canvas);
        int currIndex = this._hDoc.getRowOffset(currRowNum);
        if (currIndex >= 0) {
            this._hDoc.length();
            int currLineNum = isWordWrap() ? this._hDoc.findLineNumber(currIndex) + 1 : currRowNum + 1;
            int lastLineNum = 0;
            if (this._showLineNumbers) {
                this._leftOffset = (int) this._brushLine.measureText(this._hDoc.getRowCount() + " ");
            }
            int endRowNum = getEndPaintRow(canvas);
            int paintY = getPaintBaseline(currRowNum);
            List<Pair> spans = this._hDoc.getSpans();
            TextWarriorException.assertVerbose(!spans.isEmpty(), "No spans to paint in TextWarrior.paint()");
            int spanIndex = 0 + 1;
            Pair nextSpan = spans.get(0);
            int spanOffset = 0;
            int spanSize = spans.size();
            int spanIndex2 = spanIndex;
            do {
                currSpan = nextSpan;
                spanOffset += currSpan.getFirst();
                if (spanIndex2 < spanSize) {
                    Pair nextSpan2 = spans.get(spanIndex2);
                    nextSpan = nextSpan2;
                    spanIndex2++;
                } else {
                    nextSpan = null;
                }
                if (nextSpan == null) {
                    break;
                }
            } while (spanOffset <= currIndex);
            int currType = currSpan.getSecond();
            switch (currSpan.getSecond()) {
                case 1:
                    this._brush.setTypeface(this._boldTypeface);
                    break;
                case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
                    this._brush.setTypeface(this._italicTypeface);
                    break;
                default:
                    this._brush.setTypeface(this._defTypeface);
                    break;
            }
            int spanColor = this._colorScheme.getTokenColor(currSpan.getSecond());
            this._brush.setColor(spanColor);
            int rowCount = this._hDoc.getRowCount();
            if (this._showLineNumbers) {
                this._brushLine.setColor(this._colorScheme.getColor(ColorScheme.Colorable.NON_PRINTING_GLYPH));
                canvas.drawLine(this._leftOffset - (this._spaceWidth / 2), getScrollY(), this._leftOffset - (this._spaceWidth / 2), getScrollY() + getHeight(), this._brushLine);
            }
            switch (currType) {
                case 1:
                    lastTypeface = this._boldTypeface;
                    break;
                case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
                    lastTypeface = this._italicTypeface;
                    break;
                default:
                    lastTypeface = this._defTypeface;
                    break;
            }
            this._brush.setTypeface(lastTypeface);
            while (currRowNum <= endRowNum) {
                int spanLen = spanOffset - currIndex;
                int rowLen = this._hDoc.getRowSize(currRowNum);
                if (currRowNum < rowCount) {
                    if (this._showLineNumbers && currLineNum != lastLineNum) {
                        lastLineNum = currLineNum;
                        String num = String.valueOf(currLineNum);
                        drawLineNum(canvas, num, 0, paintY);
                    }
                    int paintX = this._leftOffset;
                    int i = 0;
                    while (true) {
                        int spanIndex3 = spanIndex2;
                        if (i < rowLen) {
                            if (nextSpan == null || currIndex < spanOffset) {
                                spanIndex2 = spanIndex3;
                            } else {
                                Pair currSpan2 = nextSpan;
                                spanLen = currSpan2.getFirst();
                                spanOffset += spanLen;
                                int lastType = currType;
                                currType = currSpan2.getSecond();
                                if (lastType != currType) {
                                    switch (currType) {
                                        case 1:
                                            currTypeface = this._boldTypeface;
                                            break;
                                        case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
                                            currTypeface = this._italicTypeface;
                                            break;
                                        default:
                                            currTypeface = this._defTypeface;
                                            break;
                                    }
                                    if (lastTypeface != currTypeface) {
                                        this._brush.setTypeface(currTypeface);
                                        lastTypeface = currTypeface;
                                    }
                                    int spanColor2 = this._colorScheme.getTokenColor(currType);
                                    this._brush.setColor(spanColor2);
                                }
                                if (spanIndex3 < spanSize) {
                                    spanIndex2 = spanIndex3 + 1;
                                    Pair nextSpan3 = spans.get(spanIndex3);
                                    nextSpan = nextSpan3;
                                } else {
                                    nextSpan = null;
                                    spanIndex2 = spanIndex3;
                                }
                            }
                            if (currIndex == this._caretPosition) {
                                drawCaret(canvas, paintX, paintY);
                            }
                            char c = this._hDoc.charAt(currIndex);
                            if (this._fieldController.inSelectionRange(currIndex)) {
                                drawChar = drawSelectedText(canvas, c, paintX, paintY);
                            } else {
                                drawChar = drawChar(canvas, c, paintX, paintY);
                            }
                            paintX += drawChar;
                            currIndex++;
                            i++;
                            spanLen--;
                        } else {
                            if (this._hDoc.charAt(currIndex - 1) == '\n') {
                                currLineNum++;
                            }
                            paintY += rowHeight();
                            if (paintX > this._xExtent) {
                                this._xExtent = paintX;
                            }
                            currRowNum++;
                            spanIndex2 = spanIndex3;
                        }
                    }
                } else {
                    doOptionHighlightRow(canvas);
                }
            }
            doOptionHighlightRow(canvas);
        }
    }

    private void doOptionHighlightRow(Canvas canvas) {
        if (this._isHighlightRow) {
            int y = getPaintBaseline(this._caretRow);
            int originalColor = this._brush.getColor();
            this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.LINE_HIGHLIGHT));
            int lineLength = Math.max(this._xExtent, getContentWidth());
            drawTextBackground(canvas, 0, y, lineLength);
            this._brush.setColor(-2013265920);
            this._brush.setColor(originalColor);
        }
    }

    private int drawString(Canvas canvas, String s, int start, int end, int paintX, int paintY) {
        int len = s.length();
        if (end >= len) {
            end = len - 1;
        }
        int charWidth = (int) this._brush.measureText(s, start, end);
        if (paintX > getScrollX() || paintX < getScrollX() + getContentWidth()) {
            canvas.drawText(s, start, end, paintX, paintY, this._brush);
        }
        return charWidth;
    }

    private int drawSelectedString(Canvas canvas, String s, int paintX, int paintY) {
        int advance = (int) this._brush.measureText(s);
        int oldColor = this._brush.getColor();
        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.SELECTION_BACKGROUND));
        drawTextBackground(canvas, paintX, paintY, advance);
        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.SELECTION_FOREGROUND));
        canvas.drawText(s, paintX, paintY, this._brush);
        this._brush.setColor(oldColor);
        return advance;
    }

    private int drawChar(Canvas canvas, char c, int paintX, int paintY) {
        int originalColor = this._brush.getColor();
        int charWidth = getAdvance(c, paintX);
        if (paintX > getScrollX() || paintX < getScrollX() + getContentWidth()) {
            switch (c) {
                case '\t':
                    if (this._showNonPrinting) {
                        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.NON_PRINTING_GLYPH));
                        canvas.drawText(Language.GLYPH_TAB, 0, 1, paintX, paintY, this._brush);
                        this._brush.setColor(originalColor);
                        break;
                    }
                    break;
                case '\n':
                case SupportMenu.USER_MASK /* 65535 */:
                    if (this._showNonPrinting) {
                        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.NON_PRINTING_GLYPH));
                        canvas.drawText(Language.GLYPH_NEWLINE, 0, 1, paintX, paintY, this._brush);
                        this._brush.setColor(originalColor);
                        break;
                    }
                    break;
                case ' ':
                    if (this._showNonPrinting) {
                        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.NON_PRINTING_GLYPH));
                        canvas.drawText(Language.GLYPH_SPACE, 0, 1, paintX, paintY, this._brush);
                        this._brush.setColor(originalColor);
                        break;
                    } else {
                        canvas.drawText(" ", 0, 1, paintX, paintY, this._brush);
                        break;
                    }
                case 55356:
                case 55357:
                    this._emoji = c;
                    break;
                default:
                    if (this._emoji != 0) {
                        canvas.drawText(new char[]{this._emoji, c}, 0, 2, paintX, paintY, this._brush);
                        this._emoji = (char) 0;
                        break;
                    } else {
                        char[] ca = {c};
                        canvas.drawText(ca, 0, 1, paintX, paintY, this._brush);
                        break;
                    }
            }
        }
        return charWidth;
    }

    private void drawTextBackground(Canvas canvas, int paintX, int paintY, int advance) {
        Paint.FontMetricsInt metrics = this._brush.getFontMetricsInt();
        canvas.drawRect(paintX, metrics.ascent + paintY, paintX + advance, metrics.descent + paintY, this._brush);
    }

    private int drawSelectedText(Canvas canvas, char c, int paintX, int paintY) {
        int oldColor = this._brush.getColor();
        int advance = getAdvance(c);
        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.SELECTION_BACKGROUND));
        drawTextBackground(canvas, paintX, paintY, advance);
        this._brush.setColor(this._colorScheme.getColor(ColorScheme.Colorable.SELECTION_FOREGROUND));
        drawChar(canvas, c, paintX, paintY);
        this._brush.setColor(oldColor);
        return advance;
    }

    private void drawCaret(Canvas canvas, int paintX, int paintY) {
        int originalColor = this._brush.getColor();
        this._caretX = paintX;
        this._caretY = paintY;
        int caretColor = this._colorScheme.getColor(ColorScheme.Colorable.CARET_DISABLED);
        this._brush.setColor(caretColor);
        drawTextBackground(canvas, paintX - 1, paintY, 2);
        this._brush.setColor(originalColor);
    }

    private int drawLineNum(Canvas canvas, String s, int paintX, int paintY) {
        canvas.drawText(s, paintX, paintY, this._brushLine);
        return 0;
    }

    @Override // com.myopicmobile.textwarrior.common.Document.TextFieldMetrics
    public final int getRowWidth() {
        return getContentWidth() - this._leftOffset;
    }

    @Override // com.myopicmobile.textwarrior.common.Document.TextFieldMetrics
    public int getAdvance(char c) {
        switch (c) {
            case '\t':
                int advance = getTabAdvance();
                return advance;
            case '\n':
            case SupportMenu.USER_MASK /* 65535 */:
                int advance2 = getEOLAdvance();
                return advance2;
            case ' ':
                int advance3 = getSpaceAdvance();
                return advance3;
            case 55356:
            case 55357:
                return 0;
            default:
                if (this._emoji != 0) {
                    char[] ca = {this._emoji, c};
                    int advance4 = (int) this._brush.measureText(ca, 0, 2);
                    return advance4;
                }
                char[] ca2 = {c};
                int advance5 = (int) this._brush.measureText(ca2, 0, 1);
                return advance5;
        }
    }

    public int getAdvance(char c, int x) {
        switch (c) {
            case '\t':
                int advance = getTabAdvance(x);
                return advance;
            case '\n':
            case SupportMenu.USER_MASK /* 65535 */:
                int advance2 = getEOLAdvance();
                return advance2;
            case ' ':
                int advance3 = getSpaceAdvance();
                return advance3;
            case 55356:
            case 55357:
                return 0;
            default:
                if (this._emoji != 0) {
                    char[] ca = {this._emoji, c};
                    int advance4 = (int) this._brush.measureText(ca, 0, 2);
                    return advance4;
                }
                char[] ca2 = {c};
                int advance5 = (int) this._brush.measureText(ca2, 0, 1);
                return advance5;
        }
    }

    public int getCharAdvance(char c) {
        char[] ca = {c};
        int advance = (int) this._brush.measureText(ca, 0, 1);
        return advance;
    }

    protected int getSpaceAdvance() {
        return this._showNonPrinting ? (int) this._brush.measureText(Language.GLYPH_SPACE, 0, Language.GLYPH_SPACE.length()) : this._spaceWidth;
    }

    protected int getEOLAdvance() {
        return this._showNonPrinting ? (int) this._brush.measureText(Language.GLYPH_NEWLINE, 0, Language.GLYPH_NEWLINE.length()) : (int) (EMPTY_CARET_WIDTH_SCALE * this._brush.measureText(" ", 0, 1));
    }

    protected int getTabAdvance() {
        return this._showNonPrinting ? this._tabLength * ((int) this._brush.measureText(Language.GLYPH_SPACE, 0, Language.GLYPH_SPACE.length())) : this._tabLength * this._spaceWidth;
    }

    protected int getTabAdvance(int x) {
        if (this._showNonPrinting) {
            return this._tabLength * ((int) this._brush.measureText(Language.GLYPH_SPACE, 0, Language.GLYPH_SPACE.length()));
        }
        int i = ((x - this._leftOffset) / this._spaceWidth) % this._tabLength;
        return (this._tabLength - i) * this._spaceWidth;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invalidateRows(int startRow, int endRow) {
        TextWarriorException.assertVerbose(startRow <= endRow && startRow >= 0, "Invalid startRow and/or endRow");
        Rect caretSpill = this._navMethod.getCaretBloat();
        Paint.FontMetricsInt metrics = this._brush.getFontMetricsInt();
        int top = (rowHeight() * startRow) + getPaddingTop();
        super.invalidate(0, Math.max(0, top - Math.max(caretSpill.top, metrics.descent)), getScrollX() + getWidth(), (rowHeight() * endRow) + getPaddingTop() + caretSpill.bottom);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invalidateFromRow(int startRow) {
        TextWarriorException.assertVerbose(startRow >= 0, "Invalid startRow");
        Rect caretSpill = this._navMethod.getCaretBloat();
        Paint.FontMetricsInt metrics = this._brush.getFontMetricsInt();
        int top = (rowHeight() * startRow) + getPaddingTop();
        super.invalidate(0, Math.max(0, top - Math.max(caretSpill.top, metrics.descent)), getScrollX() + getWidth(), getScrollY() + getHeight());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invalidateCaretRow() {
        invalidateRows(this._caretRow, this._caretRow + 1);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invalidateSelectionRows() {
        int startRow = this._hDoc.findRowNumber(this._selectionAnchor);
        int endRow = this._hDoc.findRowNumber(this._selectionEdge);
        invalidateRows(startRow, endRow + 1);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean makeCharVisible(int charOffset) {
        TextWarriorException.assertVerbose(charOffset >= 0 && charOffset < this._hDoc.docLength(), "Invalid charOffset given");
        int scrollVerticalBy = makeCharRowVisible(charOffset);
        int scrollHorizontalBy = makeCharColumnVisible(charOffset);
        if (scrollVerticalBy == 0 && scrollHorizontalBy == 0) {
            return false;
        }
        scrollBy(scrollHorizontalBy, scrollVerticalBy);
        return true;
    }

    private int makeCharRowVisible(int charOffset) {
        int charTop = this._hDoc.findRowNumber(charOffset) * rowHeight();
        int charBottom = charTop + rowHeight();
        if (charTop < getScrollY()) {
            int scrollBy = charTop - getScrollY();
            return scrollBy;
        } else if (charBottom <= getScrollY() + getContentHeight()) {
            return 0;
        } else {
            int scrollBy2 = (charBottom - getScrollY()) - getContentHeight();
            return scrollBy2;
        }
    }

    private int makeCharColumnVisible(int charOffset) {
        int scrollBy = 0;
        Pair visibleRange = getCharExtent(charOffset);
        int charLeft = visibleRange.getFirst();
        int charRight = visibleRange.getSecond();
        if (charRight > getScrollX() + getContentWidth()) {
            scrollBy = (charRight - getScrollX()) - getContentWidth();
        }
        if (charLeft < getScrollX() + this._alphaWidth) {
            int scrollBy2 = (charLeft - getScrollX()) - this._alphaWidth;
            return scrollBy2;
        }
        return scrollBy;
    }

    protected Pair getCharExtent(int charOffset) {
        int row = this._hDoc.findRowNumber(charOffset);
        int rowOffset = this._hDoc.getRowOffset(row);
        int left = this._leftOffset;
        int right = this._leftOffset;
        boolean isEmoji = false;
        String rowText = this._hDoc.getRow(row);
        int len = rowText.length();
        for (int i = 0; rowOffset + i <= charOffset && i < len; i++) {
            char c = rowText.charAt(i);
            left = right;
            switch (c) {
                case '\t':
                    right += getTabAdvance(right);
                    break;
                case '\n':
                case SupportMenu.USER_MASK /* 65535 */:
                    right += getEOLAdvance();
                    break;
                case ' ':
                    right += getSpaceAdvance();
                    break;
                case 55356:
                case 55357:
                    isEmoji = true;
                    char[] ca = {c, rowText.charAt(i + 1)};
                    right += (int) this._brush.measureText(ca, 0, 2);
                    break;
                default:
                    if (isEmoji) {
                        isEmoji = false;
                        break;
                    } else {
                        right += getCharAdvance(c);
                        break;
                    }
            }
        }
        return new Pair(left, right);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Rect getBoundingBox(int charOffset) {
        if (charOffset < 0 || charOffset >= this._hDoc.docLength()) {
            return new Rect(-1, -1, -1, -1);
        }
        int row = this._hDoc.findRowNumber(charOffset);
        int top = row * rowHeight();
        int bottom = top + rowHeight();
        Pair xExtent = getCharExtent(charOffset);
        int left = xExtent.getFirst();
        int right = xExtent.getSecond();
        return new Rect(left, top, right, bottom);
    }

    public ColorScheme getColorScheme() {
        return this._colorScheme;
    }

    public void setColorScheme(ColorScheme colorScheme) {
        this._colorScheme = colorScheme;
        this._navMethod.onColorSchemeChanged(colorScheme);
        setBackgroundColor(colorScheme.getColor(ColorScheme.Colorable.BACKGROUND));
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* JADX WARN: Removed duplicated region for block: B:19:0x0047  */
    /* JADX WARN: Removed duplicated region for block: B:26:0x007b  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public int coordToCharIndex(int x, int y) {
        int row = y / rowHeight();
        if (row > this._hDoc.getRowCount()) {
            return this._hDoc.docLength() - 1;
        }
        int charIndex = this._hDoc.getRowOffset(row);
        if (charIndex < 0) {
            return -1;
        }
        if (x >= 0) {
            String rowText = this._hDoc.getRow(row);
            int extent = this._leftOffset;
            boolean isEmoji = false;
            int len = rowText.length();
            for (int i = 0; i < len; i++) {
                char c = rowText.charAt(i);
                switch (c) {
                    case '\t':
                        extent += getTabAdvance(extent);
                        break;
                    case '\n':
                    case SupportMenu.USER_MASK /* 65535 */:
                        extent += getEOLAdvance();
                        break;
                    case ' ':
                        extent += getSpaceAdvance();
                        break;
                    case 55356:
                    case 55357:
                        isEmoji = true;
                        char[] ca = {c, rowText.charAt(i + 1)};
                        extent += (int) this._brush.measureText(ca, 0, 2);
                        break;
                    default:
                        if (isEmoji) {
                            isEmoji = false;
                            break;
                        } else {
                            extent += getCharAdvance(c);
                            break;
                        }
                }
                if (extent >= x) {
                    if (i >= rowText.length()) {
                        return charIndex + i;
                    } else {
                        return (charIndex + i) - 1;
                    }
                }
            }
            if (i >= rowText.length()) {
            }
        } else {
            return charIndex;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* JADX WARN: Removed duplicated region for block: B:16:0x0033  */
    /* JADX WARN: Removed duplicated region for block: B:23:0x006c A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public int coordToCharIndexStrict(int x, int y) {
        int row = y / rowHeight();
        int charIndex = this._hDoc.getRowOffset(row);
        if (charIndex < 0 || x < 0) {
            return -1;
        }
        String rowText = this._hDoc.getRow(row);
        int extent = 0;
        boolean isEmoji = false;
        int len = rowText.length();
        for (int i = 0; i < len; i++) {
            char c = rowText.charAt(i);
            switch (c) {
                case '\t':
                    extent += getTabAdvance(extent);
                    break;
                case '\n':
                case SupportMenu.USER_MASK /* 65535 */:
                    extent += getEOLAdvance();
                    break;
                case ' ':
                    extent += getSpaceAdvance();
                    break;
                case 55356:
                case 55357:
                    isEmoji = true;
                    char[] ca = {c, rowText.charAt(i + 1)};
                    extent += (int) this._brush.measureText(ca, 0, 2);
                    break;
                default:
                    if (isEmoji) {
                        isEmoji = false;
                        break;
                    } else {
                        extent += getCharAdvance(c);
                        break;
                    }
            }
            if (extent >= x) {
                if (i >= rowText.length()) {
                    return charIndex + i;
                } else {
                    return -1;
                }
            }
        }
        if (i >= rowText.length()) {
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public int getMaxScrollX() {
        if (isWordWrap()) {
            return this._leftOffset;
        }
        return Math.max(0, (this._xExtent - getContentWidth()) + this._navMethod.getCaretBloat().right + this._alphaWidth);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public int getMaxScrollY() {
        return Math.max(0, ((this._hDoc.getRowCount() * rowHeight()) - (getContentHeight() / 2)) + this._navMethod.getCaretBloat().bottom);
    }

    @Override // android.view.View
    protected int computeVerticalScrollOffset() {
        return getScrollY();
    }

    @Override // android.view.View
    protected int computeVerticalScrollRange() {
        return (this._hDoc.getRowCount() * rowHeight()) + getPaddingTop() + getPaddingBottom();
    }

    @Override // android.view.View
    public void computeScroll() {
        if (this._scroller.computeScrollOffset()) {
            scrollTo(this._scroller.getCurrX(), this._scroller.getCurrY());
            postInvalidate();
        }
    }

    public final void smoothScrollBy(int dx, int dy) {
        if (getHeight() != 0) {
            long duration = AnimationUtils.currentAnimationTimeMillis() - this.mLastScroll;
            if (duration > 250) {
                int scrollY = getScrollY();
                int scrollX = getScrollX();
                this._scroller.startScroll(scrollX, scrollY, dx, dy);
                postInvalidate();
            } else {
                if (!this._scroller.isFinished()) {
                    this._scroller.abortAnimation();
                }
                scrollBy(dx, dy);
            }
            this.mLastScroll = AnimationUtils.currentAnimationTimeMillis();
        }
    }

    public final void smoothScrollTo(int x, int y) {
        smoothScrollBy(x - getScrollX(), y - getScrollY());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void flingScroll(int velocityX, int velocityY) {
        this._scroller.fling(getScrollX(), getScrollY(), velocityX, velocityY, 0, getMaxScrollX(), 0, getMaxScrollY());
        postInvalidate();
    }

    public boolean isFlingScrolling() {
        return !this._scroller.isFinished();
    }

    public void stopFlingScrolling() {
        this._scroller.forceFinished(true);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public boolean autoScrollCaret(int scrollDir) {
        switch (scrollDir) {
            case 0:
                removeCallbacks(this._scrollCaretUpTask);
                if (caretOnFirstRowOfFile()) {
                    return false;
                }
                post(this._scrollCaretUpTask);
                return true;
            case 1:
                removeCallbacks(this._scrollCaretDownTask);
                if (caretOnLastRowOfFile()) {
                    return false;
                }
                post(this._scrollCaretDownTask);
                return true;
            case 2:
                removeCallbacks(this._scrollCaretLeftTask);
                if (this._caretPosition <= 0 || this._caretRow != this._hDoc.findRowNumber(this._caretPosition - 1)) {
                    return false;
                }
                post(this._scrollCaretLeftTask);
                return true;
            case 3:
                removeCallbacks(this._scrollCaretRightTask);
                if (caretOnEOF() || this._caretRow != this._hDoc.findRowNumber(this._caretPosition + 1)) {
                    return false;
                }
                post(this._scrollCaretRightTask);
                return true;
            default:
                TextWarriorException.fail("Invalid scroll direction");
                return false;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void stopAutoScrollCaret() {
        removeCallbacks(this._scrollCaretDownTask);
        removeCallbacks(this._scrollCaretUpTask);
        removeCallbacks(this._scrollCaretLeftTask);
        removeCallbacks(this._scrollCaretRightTask);
    }

    void stopAutoScrollCaret(int scrollDir) {
        switch (scrollDir) {
            case 0:
                removeCallbacks(this._scrollCaretUpTask);
                return;
            case 1:
                removeCallbacks(this._scrollCaretDownTask);
                return;
            case 2:
                removeCallbacks(this._scrollCaretLeftTask);
                return;
            case 3:
                removeCallbacks(this._scrollCaretRightTask);
                return;
            default:
                TextWarriorException.fail("Invalid scroll direction");
                return;
        }
    }

    public int getCaretRow() {
        return this._caretRow;
    }

    public int getCaretPosition() {
        return this._caretPosition;
    }

    public void moveCaret(int i) {
        this._fieldController.moveCaret(i);
    }

    public void moveCaretLeft() {
        this._fieldController.moveCaretLeft(false);
    }

    public void moveCaretRight() {
        this._fieldController.moveCaretRight(false);
    }

    public void moveCaretDown() {
        this._fieldController.moveCaretDown();
    }

    public void moveCaretUp() {
        this._fieldController.moveCaretUp();
    }

    public void focusCaret() {
        makeCharVisible(this._caretPosition);
    }

    protected int getColumn(int charOffset) {
        int row = this._hDoc.findRowNumber(charOffset);
        TextWarriorException.assertVerbose(row >= 0, "Invalid char offset given to getColumn");
        int firstCharOfRow = this._hDoc.getRowOffset(row);
        return charOffset - firstCharOfRow;
    }

    protected boolean caretOnFirstRowOfFile() {
        return this._caretRow == 0;
    }

    protected boolean caretOnLastRowOfFile() {
        return this._caretRow == this._hDoc.getRowCount() + (-1);
    }

    protected boolean caretOnEOF() {
        return this._caretPosition == this._hDoc.docLength() + (-1);
    }

    public final boolean isSelectText() {
        return this._fieldController.isSelectText();
    }

    public final boolean isSelectText2() {
        return this._fieldController.isSelectText2();
    }

    public void selectText(boolean mode) {
        if (this._fieldController.isSelectText() && !mode) {
            invalidateSelectionRows();
            this._fieldController.setSelectText(false);
        } else if (!this._fieldController.isSelectText() && mode) {
            invalidateCaretRow();
            this._fieldController.setSelectText(true);
        }
    }

    public void selectAll() {
        this._fieldController.setSelectionRange(0, this._hDoc.docLength() - 1, false, true);
    }

    public void setSelection(int beginPosition, int numChars) {
        this._fieldController.setSelectionRange(beginPosition, numChars, true, false);
    }

    public void setSelectionRange(int beginPosition, int numChars) {
        this._fieldController.setSelectionRange(beginPosition, numChars, true, true);
    }

    public boolean inSelectionRange(int charOffset) {
        return this._fieldController.inSelectionRange(charOffset);
    }

    public int getSelectionStart() {
        return this._selectionAnchor < 0 ? this._caretPosition : this._selectionAnchor;
    }

    public int getSelectionEnd() {
        return this._selectionEdge < 0 ? this._caretPosition : this._selectionEdge;
    }

    public void focusSelectionStart() {
        this._fieldController.focusSelection(true);
    }

    public void focusSelectionEnd() {
        this._fieldController.focusSelection(false);
    }

    public void cut() {
        if (this._selectionAnchor != this._selectionEdge) {
            this._fieldController.cut(this._clipboardManager);
        }
    }

    public void copy() {
        if (this._selectionAnchor != this._selectionEdge) {
            this._fieldController.copy(this._clipboardManager);
        }
        selectText(false);
    }

    public void paste() {
        CharSequence text = this._clipboardManager.getText();
        if (text != null) {
            this._fieldController.paste(text.toString());
        }
    }

    public void cut(ClipboardManager cb) {
        this._fieldController.cut(cb);
    }

    public void copy(ClipboardManager cb) {
        this._fieldController.copy(cb);
    }

    public void paste(String text) {
        this._fieldController.paste(text);
    }

    private boolean reachedNextSpan(int charIndex, Pair span) {
        return span != null && charIndex == span.getFirst();
    }

    public void respan() {
        this._fieldController.determineSpans();
    }

    public void cancelSpanning() {
        this._fieldController.cancelSpanning();
    }

    public void setTypeface(Typeface typeface) {
        this._defTypeface = typeface;
        this._boldTypeface = Typeface.create(typeface, 1);
        this._italicTypeface = Typeface.create(typeface, 2);
        this._brush.setTypeface(typeface);
        this._brushLine.setTypeface(typeface);
        if (this._hDoc.isWordWrap()) {
            this._hDoc.analyzeWordWrap();
        }
        this._fieldController.updateCaretRow();
        if (!makeCharVisible(this._caretPosition)) {
            invalidate();
        }
    }

    public void setItalicTypeface(Typeface typeface) {
        this._italicTypeface = typeface;
    }

    public void setBoldTypeface(Typeface typeface) {
        this._boldTypeface = typeface;
    }

    public boolean isWordWrap() {
        return this._hDoc.isWordWrap();
    }

    public void setWordWrap(boolean enable) {
        this._hDoc.setWordWrap(enable);
        if (enable) {
            this._xExtent = 0;
            scrollTo(0, 0);
        }
        this._fieldController.updateCaretRow();
        if (!makeCharVisible(this._caretPosition)) {
            invalidate();
        }
    }

    public float getZoom() {
        return this._zoomFactor;
    }

    public void setZoom(float factor) {
        if (factor > 0.5d && factor < 5.0f && factor != this._zoomFactor) {
            this._zoomFactor = factor;
            int newSize = (int) (BASE_TEXT_SIZE_PIXELS * factor);
            this._brush.setTextSize(newSize);
            this._brushLine.setTextSize(newSize);
            if (this._hDoc.isWordWrap()) {
                this._hDoc.analyzeWordWrap();
            }
            this._fieldController.updateCaretRow();
            this._alphaWidth = (int) this._brush.measureText("a");
            invalidate();
        }
    }

    public void setTabSpaces(int spaceCount) {
        if (spaceCount >= 0) {
            this._tabLength = spaceCount;
            if (this._hDoc.isWordWrap()) {
                this._hDoc.analyzeWordWrap();
            }
            this._fieldController.updateCaretRow();
            if (!makeCharVisible(this._caretPosition)) {
                invalidate();
            }
        }
    }

    public void setAutoIndent(boolean enable) {
        this._isAutoIndent = enable;
    }

    public void setAutoComplete(boolean enable) {
        this._isAutoComplete = enable;
    }

    public void setLongPressCaps(boolean enable) {
        this._isLongPressCaps = enable;
    }

    public void setHighlightCurrentRow(boolean enable) {
        this._isHighlightRow = enable;
        invalidateCaretRow();
    }

    public void setNonPrintingCharVisibility(boolean enable) {
        if (this._showNonPrinting ^ enable) {
            this._showNonPrinting = enable;
            if (this._hDoc.isWordWrap()) {
                this._hDoc.analyzeWordWrap();
            }
            this._fieldController.updateCaretRow();
            if (!makeCharVisible(this._caretPosition)) {
                invalidate();
            }
        }
    }

    @Override // android.view.View
    public boolean onKeyPreIme(int keyCode, KeyEvent event) {
        if (this._isLongPressCaps && event.getRepeatCount() == 1 && event.getAction() == 0) {
            char c = KeysInterpreter.keyEventToPrintableChar(event);
            if (Character.isLowerCase(c) && c == Character.toLowerCase(this._hDoc.charAt(this._caretPosition - 1))) {
                this._fieldController.onPrintableChar('\b');
                this._fieldController.onPrintableChar(Character.toUpperCase(c));
                return true;
            }
        }
        return super.onKeyPreIme(keyCode, event);
    }

    @Override // android.view.View, android.view.KeyEvent.Callback
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (this._navMethod.onKeyDown(keyCode, event)) {
            return true;
        }
        if (KeysInterpreter.isNavigationKey(event)) {
            handleNavigationKey(keyCode, event);
            return true;
        } else if (keyCode == 63 || keyCode == 61185) {
            showCharacterPicker(PICKER_SETS.get(61185), false);
            return true;
        } else {
            char c = KeysInterpreter.keyEventToPrintableChar(event);
            if (c == 0) {
                return super.onKeyDown(keyCode, event);
            }
            int repeatCount = event.getRepeatCount();
            if (repeatCount == 1) {
                if (this._isLongPressCaps) {
                    handleLongPressCaps(c);
                } else {
                    handleLongPressDialogDisplay(c);
                }
            } else if (repeatCount == 0 || ((this._isLongPressCaps && !Character.isLowerCase(c)) || (!this._isLongPressCaps && PICKER_SETS.get(c) == null))) {
                this._fieldController.onPrintableChar(c);
            }
            return true;
        }
    }

    private void handleNavigationKey(int keyCode, KeyEvent event) {
        if (event.isShiftPressed() && !isSelectText()) {
            invalidateCaretRow();
            this._fieldController.setSelectText(true);
        } else if (!event.isShiftPressed() && isSelectText()) {
            invalidateSelectionRows();
            this._fieldController.setSelectText(false);
        }
        switch (keyCode) {
            case 19:
                this._fieldController.moveCaretUp();
                return;
            case 20:
                this._fieldController.moveCaretDown();
                return;
            case 21:
                this._fieldController.moveCaretLeft(false);
                return;
            case MotionEventCompat.AXIS_GAS /* 22 */:
                this._fieldController.moveCaretRight(false);
                return;
            default:
                return;
        }
    }

    private void handleLongPressCaps(char c) {
        if (Character.isLowerCase(c) && c == this._hDoc.charAt(this._caretPosition - 1)) {
            this._fieldController.onPrintableChar('\b');
            this._fieldController.onPrintableChar(Character.toUpperCase(c));
            return;
        }
        this._fieldController.onPrintableChar(c);
    }

    private void handleLongPressDialogDisplay(char c) {
        boolean isCaps = Character.isUpperCase(this._hDoc.charAt(this._caretPosition - 1));
        char base = isCaps ? Character.toUpperCase(c) : c;
        String candidates = PICKER_SETS.get(base);
        if (candidates != null) {
            this._fieldController.stopTextComposing();
            showCharacterPicker(candidates, true);
            return;
        }
        this._fieldController.onPrintableChar(c);
    }

    private void showCharacterPicker(String candidates, final boolean replace) {
        final SpannableStringBuilder dummyString = new SpannableStringBuilder();
        Selection.setSelection(dummyString, 0);
        CharacterPickerDialog dialog = new CharacterPickerDialog(getContext(), this, dummyString, candidates, true);
        dialog.setOnDismissListener(new DialogInterface.OnDismissListener() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.8
            @Override // android.content.DialogInterface.OnDismissListener
            public void onDismiss(DialogInterface dialog2) {
                if (dummyString.length() > 0) {
                    if (replace) {
                        FreeScrollingTextField.this._fieldController.onPrintableChar('\b');
                    }
                    FreeScrollingTextField.this._fieldController.onPrintableChar(dummyString.charAt(0));
                }
            }
        });
        dialog.show();
    }

    @Override // android.view.View, android.view.KeyEvent.Callback
    public boolean onKeyUp(int keyCode, KeyEvent event) {
        if (this._navMethod.onKeyUp(keyCode, event)) {
            return true;
        }
        return super.onKeyUp(keyCode, event);
    }

    @Override // android.view.View
    public boolean onTrackballEvent(MotionEvent event) {
        int deltaX = Math.round(event.getX());
        int deltaY = Math.round(event.getY());
        while (deltaX > 0) {
            this._fieldController.moveCaretRight(false);
            deltaX--;
        }
        while (deltaX < 0) {
            this._fieldController.moveCaretLeft(false);
            deltaX++;
        }
        while (deltaY > 0) {
            this._fieldController.moveCaretDown();
            deltaY--;
        }
        while (deltaY < 0) {
            this._fieldController.moveCaretUp();
            deltaY++;
        }
        return true;
    }

    public boolean isAccessibilityEnabled() {
        return this.isAccessibilityEnabled;
    }

    @Override // android.view.View
    public boolean onHoverEvent(MotionEvent event) {
        if (this.isAccessibilityEnabled) {
            float x = event.getX();
            float y = event.getY();
            switch (event.getAction()) {
                case 7:
                    this._navMethod.onScroll(this.mMotionEvent, event, this.mX - x, this.mY - y);
                    break;
                case 9:
                    this.mMotionEvent = event;
                    break;
                case 10:
                    this._navMethod.onUp(event);
                    break;
            }
            this.mX = x;
            this.mY = y;
        }
        return super.onHoverEvent(event);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        if (isFocused()) {
            this._navMethod.onTouchEvent(event);
        } else if ((event.getAction() & 255) == 1 && isPointInView((int) event.getX(), (int) event.getY())) {
            requestFocus();
        }
        return true;
    }

    private final boolean isPointInView(int x, int y) {
        return x >= 0 && x < getWidth() && y >= 0 && y < getHeight();
    }

    @Override // android.view.View
    protected void onFocusChanged(boolean gainFocus, int direction, Rect previouslyFocusedRect) {
        super.onFocusChanged(gainFocus, direction, previouslyFocusedRect);
        invalidateCaretRow();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void showIME(boolean show) {
        InputMethodManager im = (InputMethodManager) getContext().getSystemService("input_method");
        if (show) {
            im.showSoftInput(this, 0);
        } else {
            im.hideSoftInputFromWindow(getWindowToken(), 0);
        }
    }

    void onPause() {
        this._navMethod.onPause();
    }

    void onResume() {
        this._navMethod.onResume();
    }

    void onDestroy() {
        this._fieldController.cancelSpanning();
    }

    public Parcelable getUiState() {
        return new TextFieldUiState(this);
    }

    public void restoreUiState(Parcelable state) {
        TextFieldUiState uiState = (TextFieldUiState) state;
        final int caretPosition = uiState._caretPosition;
        if (uiState._selectMode) {
            final int selStart = uiState._selectBegin;
            final int selEnd = uiState._selectEnd;
            post(new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.9
                @Override // java.lang.Runnable
                public void run() {
                    FreeScrollingTextField.this.setSelectionRange(selStart, selEnd - selStart);
                    if (caretPosition < selEnd) {
                        FreeScrollingTextField.this.focusSelectionStart();
                    }
                }
            });
            return;
        }
        post(new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.10
            @Override // java.lang.Runnable
            public void run() {
                FreeScrollingTextField.this.moveCaret(caretPosition);
            }
        });
    }

    /* loaded from: classes.dex */
    public static class TextFieldUiState implements Parcelable {
        public static final Parcelable.Creator<TextFieldUiState> CREATOR = new Parcelable.Creator<TextFieldUiState>() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.TextFieldUiState.1
            /* JADX WARN: Can't rename method to resolve collision */
            @Override // android.os.Parcelable.Creator
            public TextFieldUiState createFromParcel(Parcel in) {
                return new TextFieldUiState(in);
            }

            /* JADX WARN: Can't rename method to resolve collision */
            @Override // android.os.Parcelable.Creator
            public TextFieldUiState[] newArray(int size) {
                return new TextFieldUiState[size];
            }
        };
        final int _caretPosition;
        final int _scrollX;
        final int _scrollY;
        final int _selectBegin;
        final int _selectEnd;
        final boolean _selectMode;

        public TextFieldUiState(FreeScrollingTextField textField) {
            this._caretPosition = textField.getCaretPosition();
            this._scrollX = textField.getScrollX();
            this._scrollY = textField.getScrollY();
            this._selectMode = textField.isSelectText();
            this._selectBegin = textField.getSelectionStart();
            this._selectEnd = textField.getSelectionEnd();
        }

        private TextFieldUiState(Parcel in) {
            this._caretPosition = in.readInt();
            this._scrollX = in.readInt();
            this._scrollY = in.readInt();
            this._selectMode = in.readInt() != 0;
            this._selectBegin = in.readInt();
            this._selectEnd = in.readInt();
        }

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel out, int flags) {
            out.writeInt(this._caretPosition);
            out.writeInt(this._scrollX);
            out.writeInt(this._scrollY);
            out.writeInt(this._selectMode ? 1 : 0);
            out.writeInt(this._selectBegin);
            out.writeInt(this._selectEnd);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class TextFieldController implements Lexer.LexCallback {
        private boolean _isInSelectionMode;
        private boolean _isInSelectionMode2;
        private final Lexer _lexer;

        private TextFieldController() {
            this._lexer = new Lexer(this);
            this._isInSelectionMode = false;
        }

        public void determineSpans() {
            this._lexer.tokenize(FreeScrollingTextField.this._hDoc);
        }

        public void cancelSpanning() {
            this._lexer.cancelTokenize();
        }

        @Override // com.myopicmobile.textwarrior.common.Lexer.LexCallback
        public void lexDone(final List<Pair> results) {
            FreeScrollingTextField.this.post(new Runnable() { // from class: com.myopicmobile.textwarrior.android.FreeScrollingTextField.TextFieldController.1
                @Override // java.lang.Runnable
                public void run() {
                    FreeScrollingTextField.this._hDoc.setSpans(results);
                    FreeScrollingTextField.this.invalidate();
                }
            });
        }

        public void onPrintableChar(char c) {
            boolean selectionDeleted = false;
            if (this._isInSelectionMode) {
                selectionDelete();
                selectionDeleted = true;
            }
            int originalRow = FreeScrollingTextField.this._caretRow;
            int originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(originalRow);
            switch (c) {
                case '\b':
                    if (!selectionDeleted && FreeScrollingTextField.this._caretPosition > 0) {
                        FreeScrollingTextField.this._textLis.onDel(c + "", FreeScrollingTextField.this._caretPosition, 1);
                        FreeScrollingTextField.this._hDoc.deleteAt(FreeScrollingTextField.this._caretPosition - 1, System.nanoTime());
                        if (FreeScrollingTextField.this._hDoc.charAt(FreeScrollingTextField.this._caretPosition - 2) == 55357 || FreeScrollingTextField.this._hDoc.charAt(FreeScrollingTextField.this._caretPosition - 2) == 55356) {
                            FreeScrollingTextField.this._hDoc.deleteAt(FreeScrollingTextField.this._caretPosition - 2, System.nanoTime());
                            moveCaretLeft(true);
                        }
                        moveCaretLeft(true);
                        if (FreeScrollingTextField.this._caretRow < originalRow) {
                            FreeScrollingTextField.this.invalidateFromRow(FreeScrollingTextField.this._caretRow);
                            break;
                        } else if (FreeScrollingTextField.this._hDoc.isWordWrap()) {
                            if (originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(originalRow)) {
                                originalRow--;
                            }
                            FreeScrollingTextField.this.invalidateFromRow(originalRow);
                            break;
                        }
                    }
                    break;
                case '\t':
                default:
                    FreeScrollingTextField.this._hDoc.insertBefore(c, FreeScrollingTextField.this._caretPosition, System.nanoTime());
                    moveCaretRight(true);
                    FreeScrollingTextField.this._textLis.onAdd(c + "", FreeScrollingTextField.this._caretPosition, 1);
                    if (FreeScrollingTextField.this._hDoc.isWordWrap()) {
                        if (originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(originalRow)) {
                            originalRow--;
                        }
                        FreeScrollingTextField.this.invalidateFromRow(originalRow);
                        break;
                    }
                    break;
                case '\n':
                    if (FreeScrollingTextField.this._isAutoIndent) {
                        char[] indent = createAutoIndent();
                        FreeScrollingTextField.this._hDoc.insertBefore(indent, FreeScrollingTextField.this._caretPosition, System.nanoTime());
                        moveCaret(FreeScrollingTextField.this._caretPosition + indent.length);
                    } else {
                        FreeScrollingTextField.this._hDoc.insertBefore(c, FreeScrollingTextField.this._caretPosition, System.nanoTime());
                        moveCaretRight(true);
                    }
                    if (FreeScrollingTextField.this._hDoc.isWordWrap() && originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(originalRow)) {
                        originalRow--;
                    }
                    FreeScrollingTextField.this._textLis.onNewLine(c + "", FreeScrollingTextField.this._caretPosition, 1);
                    FreeScrollingTextField.this.invalidateFromRow(originalRow);
                    break;
            }
            FreeScrollingTextField.this.setEdited(true);
            determineSpans();
        }

        private char[] createAutoIndent() {
            char c;
            int lineNum = FreeScrollingTextField.this._hDoc.findLineNumber(FreeScrollingTextField.this._caretPosition);
            int startOfLine = FreeScrollingTextField.this._hDoc.getLineOffset(lineNum);
            int whitespaceCount = 0;
            FreeScrollingTextField.this._hDoc.seekChar(startOfLine);
            while (FreeScrollingTextField.this._hDoc.hasNext() && (((c = FreeScrollingTextField.this._hDoc.next()) == ' ' || c == '\t') && startOfLine + whitespaceCount < FreeScrollingTextField.this._caretPosition)) {
                whitespaceCount++;
            }
            int whitespaceCount2 = whitespaceCount + (FreeScrollingTextField.this._autoIndentWidth * AutoIndent.createAutoIndent(FreeScrollingTextField.this._hDoc.subSequence(startOfLine, FreeScrollingTextField.this._caretPosition - startOfLine)));
            if (whitespaceCount2 < 0) {
                return new char[]{'\n'};
            }
            char[] indent = new char[whitespaceCount2 + 1];
            indent[0] = '\n';
            FreeScrollingTextField.this._hDoc.seekChar(startOfLine);
            for (int i = 0; i < whitespaceCount2; i++) {
                indent[i + 1] = ' ';
            }
            return indent;
        }

        public void moveCaretDown() {
            if (!FreeScrollingTextField.this.caretOnLastRowOfFile()) {
                int currCaret = FreeScrollingTextField.this._caretPosition;
                int currRow = FreeScrollingTextField.this._caretRow;
                int newRow = currRow + 1;
                int currColumn = FreeScrollingTextField.this.getColumn(currCaret);
                int currRowLength = FreeScrollingTextField.this._hDoc.getRowSize(currRow);
                int newRowLength = FreeScrollingTextField.this._hDoc.getRowSize(newRow);
                if (currColumn < newRowLength) {
                    FreeScrollingTextField.this._caretPosition += currRowLength;
                } else {
                    FreeScrollingTextField.this._caretPosition += ((currRowLength - currColumn) + newRowLength) - 1;
                }
                FreeScrollingTextField.access$304(FreeScrollingTextField.this);
                updateSelectionRange(currCaret, FreeScrollingTextField.this._caretPosition);
                if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                    FreeScrollingTextField.this.invalidateRows(currRow, newRow + 1);
                }
                FreeScrollingTextField.this._rowLis.onRowChange(newRow);
                stopTextComposing();
            }
        }

        public void moveCaretUp() {
            if (!FreeScrollingTextField.this.caretOnFirstRowOfFile()) {
                int currCaret = FreeScrollingTextField.this._caretPosition;
                int currRow = FreeScrollingTextField.this._caretRow;
                int newRow = currRow - 1;
                int currColumn = FreeScrollingTextField.this.getColumn(currCaret);
                int newRowLength = FreeScrollingTextField.this._hDoc.getRowSize(newRow);
                if (currColumn < newRowLength) {
                    FreeScrollingTextField.this._caretPosition -= newRowLength;
                } else {
                    FreeScrollingTextField.this._caretPosition -= currColumn + 1;
                }
                FreeScrollingTextField.access$306(FreeScrollingTextField.this);
                updateSelectionRange(currCaret, FreeScrollingTextField.this._caretPosition);
                if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                    FreeScrollingTextField.this.invalidateRows(newRow, currRow + 1);
                }
                FreeScrollingTextField.this._rowLis.onRowChange(newRow);
                stopTextComposing();
            }
        }

        public void moveCaretRight(boolean isTyping) {
            if (!FreeScrollingTextField.this.caretOnEOF()) {
                int originalRow = FreeScrollingTextField.this._caretRow;
                FreeScrollingTextField.this._caretPosition++;
                updateCaretRow();
                updateSelectionRange(FreeScrollingTextField.this._caretPosition - 1, FreeScrollingTextField.this._caretPosition);
                if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                    FreeScrollingTextField.this.invalidateRows(originalRow, FreeScrollingTextField.this._caretRow + 1);
                }
                if (!isTyping) {
                    stopTextComposing();
                }
            }
        }

        public void moveCaretLeft(boolean isTyping) {
            if (FreeScrollingTextField.this._caretPosition > 0) {
                int originalRow = FreeScrollingTextField.this._caretRow;
                FreeScrollingTextField freeScrollingTextField = FreeScrollingTextField.this;
                freeScrollingTextField._caretPosition--;
                updateCaretRow();
                updateSelectionRange(FreeScrollingTextField.this._caretPosition + 1, FreeScrollingTextField.this._caretPosition);
                if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                    FreeScrollingTextField.this.invalidateRows(FreeScrollingTextField.this._caretRow, originalRow + 1);
                }
                if (!isTyping) {
                    stopTextComposing();
                }
            }
        }

        public void moveCaret(int i) {
            if (i < 0 || i >= FreeScrollingTextField.this._hDoc.docLength()) {
                TextWarriorException.fail("Invalid caret position");
                return;
            }
            updateSelectionRange(FreeScrollingTextField.this._caretPosition, i);
            FreeScrollingTextField.this._caretPosition = i;
            updateAfterCaretJump();
        }

        private void updateAfterCaretJump() {
            int oldRow = FreeScrollingTextField.this._caretRow;
            updateCaretRow();
            if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                FreeScrollingTextField.this.invalidateRows(oldRow, oldRow + 1);
                FreeScrollingTextField.this.invalidateCaretRow();
            }
            stopTextComposing();
        }

        void updateCaretRow() {
            int newRow = FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._caretPosition);
            if (FreeScrollingTextField.this._caretRow != newRow) {
                FreeScrollingTextField.this._caretRow = newRow;
                FreeScrollingTextField.this._rowLis.onRowChange(newRow);
            }
        }

        public void stopTextComposing() {
            InputMethodManager im = (InputMethodManager) FreeScrollingTextField.this.getContext().getSystemService("input_method");
            im.restartInput(FreeScrollingTextField.this);
            if (FreeScrollingTextField.this._inputConnection != null && FreeScrollingTextField.this._inputConnection.isComposingStarted()) {
                FreeScrollingTextField.this._inputConnection.resetComposingState();
            }
        }

        public final boolean isSelectText() {
            return this._isInSelectionMode;
        }

        public void setSelectText(boolean mode) {
            if (this._isInSelectionMode ^ mode) {
                if (mode) {
                    FreeScrollingTextField.this._selectionAnchor = FreeScrollingTextField.this._caretPosition;
                    FreeScrollingTextField.this._selectionEdge = FreeScrollingTextField.this._caretPosition;
                } else {
                    FreeScrollingTextField.this._selectionAnchor = -1;
                    FreeScrollingTextField.this._selectionEdge = -1;
                }
                this._isInSelectionMode = mode;
                this._isInSelectionMode2 = mode;
                FreeScrollingTextField.this._selModeLis.onSelectionChanged(mode, FreeScrollingTextField.this.getSelectionStart(), FreeScrollingTextField.this.getSelectionEnd());
            }
        }

        public final boolean isSelectText2() {
            return this._isInSelectionMode2;
        }

        public boolean inSelectionRange(int charOffset) {
            return FreeScrollingTextField.this._selectionAnchor >= 0 && FreeScrollingTextField.this._selectionAnchor <= charOffset && charOffset < FreeScrollingTextField.this._selectionEdge;
        }

        public void setSelectionRange(int beginPosition, int numChars, boolean scrollToStart, boolean mode) {
            TextWarriorException.assertVerbose(beginPosition >= 0 && numChars <= FreeScrollingTextField.this._hDoc.docLength() + (-1) && numChars >= 0, "Invalid range to select");
            if (this._isInSelectionMode) {
                FreeScrollingTextField.this.invalidateSelectionRows();
            } else {
                FreeScrollingTextField.this.invalidateCaretRow();
                if (mode) {
                    setSelectText(true);
                } else {
                    this._isInSelectionMode = true;
                }
            }
            FreeScrollingTextField.this._selectionAnchor = beginPosition;
            FreeScrollingTextField.this._selectionEdge = FreeScrollingTextField.this._selectionAnchor + numChars;
            FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionEdge;
            stopTextComposing();
            updateCaretRow();
            if (mode) {
                FreeScrollingTextField.this._selModeLis.onSelectionChanged(isSelectText(), FreeScrollingTextField.this._selectionAnchor, FreeScrollingTextField.this._selectionEdge);
            }
            boolean scrolled = FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._selectionEdge);
            if (scrollToStart) {
                scrolled = FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._selectionAnchor);
            }
            if (!scrolled) {
                FreeScrollingTextField.this.invalidateSelectionRows();
            }
        }

        public void focusSelection(boolean start) {
            if (this._isInSelectionMode) {
                if (start && FreeScrollingTextField.this._caretPosition != FreeScrollingTextField.this._selectionAnchor) {
                    FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionAnchor;
                    updateAfterCaretJump();
                } else if (!start && FreeScrollingTextField.this._caretPosition != FreeScrollingTextField.this._selectionEdge) {
                    FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionEdge;
                    updateAfterCaretJump();
                }
            }
        }

        private void updateSelectionRange(int oldCaretPosition, int newCaretPosition) {
            if (FreeScrollingTextField.this.isAccessibilityEnabled && Build.VERSION.SDK_INT >= 16) {
                AccessibilityRecord.obtain();
                AccessibilityEvent event = AccessibilityEvent.obtain(131072);
                if ((oldCaretPosition - newCaretPosition) * (oldCaretPosition - newCaretPosition) == 1) {
                    event.setMovementGranularity(1);
                }
                if (oldCaretPosition > newCaretPosition) {
                    event.setAction(512);
                } else {
                    event.setAction(256);
                }
                event.setFromIndex(Math.min(oldCaretPosition, newCaretPosition));
                event.setToIndex(Math.max(oldCaretPosition, newCaretPosition));
                FreeScrollingTextField.this.sendAccessibilityEventUnchecked(event);
            }
            if (this._isInSelectionMode) {
                if (oldCaretPosition < FreeScrollingTextField.this._selectionEdge) {
                    if (newCaretPosition > FreeScrollingTextField.this._selectionEdge) {
                        FreeScrollingTextField.this._selectionAnchor = FreeScrollingTextField.this._selectionEdge;
                        FreeScrollingTextField.this._selectionEdge = newCaretPosition;
                        return;
                    }
                    FreeScrollingTextField.this._selectionAnchor = newCaretPosition;
                } else if (newCaretPosition < FreeScrollingTextField.this._selectionAnchor) {
                    FreeScrollingTextField.this._selectionEdge = FreeScrollingTextField.this._selectionAnchor;
                    FreeScrollingTextField.this._selectionAnchor = newCaretPosition;
                } else {
                    FreeScrollingTextField.this._selectionEdge = newCaretPosition;
                }
            }
        }

        public void cut(ClipboardManager cb) {
            copy(cb);
            selectionDelete();
        }

        public void copy(ClipboardManager cb) {
            if (this._isInSelectionMode && FreeScrollingTextField.this._selectionAnchor < FreeScrollingTextField.this._selectionEdge) {
                CharSequence contents = FreeScrollingTextField.this._hDoc.subSequence(FreeScrollingTextField.this._selectionAnchor, FreeScrollingTextField.this._selectionEdge - FreeScrollingTextField.this._selectionAnchor);
                cb.setText(contents);
            }
        }

        public void paste(String text) {
            if (text != null) {
                FreeScrollingTextField.this._hDoc.beginBatchEdit();
                selectionDelete();
                int originalRow = FreeScrollingTextField.this._caretRow;
                int originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(originalRow);
                FreeScrollingTextField.this._hDoc.insertBefore(text.toCharArray(), FreeScrollingTextField.this._caretPosition, System.nanoTime());
                FreeScrollingTextField.this._hDoc.endBatchEdit();
                FreeScrollingTextField.this._caretPosition += text.length();
                updateCaretRow();
                FreeScrollingTextField.this.setEdited(true);
                determineSpans();
                stopTextComposing();
                if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                    int invalidateStartRow = originalRow;
                    if (FreeScrollingTextField.this._hDoc.isWordWrap() && originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(originalRow)) {
                        invalidateStartRow--;
                    }
                    if (originalRow != FreeScrollingTextField.this._caretRow || FreeScrollingTextField.this._hDoc.isWordWrap()) {
                        FreeScrollingTextField.this.invalidateFromRow(invalidateStartRow);
                    } else {
                        FreeScrollingTextField.this.invalidateRows(invalidateStartRow, invalidateStartRow + 1);
                    }
                }
            }
        }

        public void selectionDelete() {
            if (this._isInSelectionMode) {
                int totalChars = FreeScrollingTextField.this._selectionEdge - FreeScrollingTextField.this._selectionAnchor;
                if (totalChars > 0) {
                    int originalRow = FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._selectionAnchor);
                    int originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(originalRow);
                    boolean isSingleRowSel = FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._selectionEdge) == originalRow;
                    FreeScrollingTextField.this._textLis.onDel("", FreeScrollingTextField.this._caretPosition, totalChars);
                    FreeScrollingTextField.this._hDoc.deleteAt(FreeScrollingTextField.this._selectionAnchor, totalChars, System.nanoTime());
                    FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionAnchor;
                    updateCaretRow();
                    FreeScrollingTextField.this.setEdited(true);
                    determineSpans();
                    setSelectText(false);
                    stopTextComposing();
                    if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                        int invalidateStartRow = originalRow;
                        if (FreeScrollingTextField.this._hDoc.isWordWrap() && originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(originalRow)) {
                            invalidateStartRow--;
                        }
                        if (!isSingleRowSel || FreeScrollingTextField.this._hDoc.isWordWrap()) {
                            FreeScrollingTextField.this.invalidateFromRow(invalidateStartRow);
                            return;
                        } else {
                            FreeScrollingTextField.this.invalidateRows(invalidateStartRow, invalidateStartRow + 1);
                            return;
                        }
                    }
                    return;
                }
                setSelectText(false);
                FreeScrollingTextField.this.invalidateCaretRow();
            }
        }

        void replaceText(int from, int charCount, String text) {
            int invalidateStartRow;
            int originalOffset;
            boolean isInvalidateSingleRow = true;
            boolean dirty = false;
            if (!this._isInSelectionMode) {
                invalidateStartRow = FreeScrollingTextField.this._caretRow;
                originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(FreeScrollingTextField.this._caretRow);
            } else {
                invalidateStartRow = FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._selectionAnchor);
                originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(invalidateStartRow);
                int totalChars = FreeScrollingTextField.this._selectionEdge - FreeScrollingTextField.this._selectionAnchor;
                if (totalChars > 0) {
                    FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionAnchor;
                    FreeScrollingTextField.this._hDoc.deleteAt(FreeScrollingTextField.this._selectionAnchor, totalChars, System.nanoTime());
                    if (invalidateStartRow != FreeScrollingTextField.this._caretRow) {
                        isInvalidateSingleRow = false;
                    }
                    dirty = true;
                }
                setSelectText(false);
            }
            if (charCount > 0) {
                int delFromRow = FreeScrollingTextField.this._hDoc.findRowNumber(from);
                if (delFromRow < invalidateStartRow) {
                    invalidateStartRow = delFromRow;
                    originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(delFromRow);
                }
                if (invalidateStartRow != FreeScrollingTextField.this._caretRow) {
                    isInvalidateSingleRow = false;
                }
                FreeScrollingTextField.this._caretPosition = from;
                FreeScrollingTextField.this._hDoc.deleteAt(from, charCount, System.nanoTime());
                dirty = true;
            }
            if (text != null && text.length() > 0) {
                int insFromRow = FreeScrollingTextField.this._hDoc.findRowNumber(from);
                if (insFromRow < invalidateStartRow) {
                    invalidateStartRow = insFromRow;
                    originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(insFromRow);
                }
                FreeScrollingTextField.this._hDoc.insertBefore(text.toCharArray(), FreeScrollingTextField.this._caretPosition, System.nanoTime());
                FreeScrollingTextField.this._caretPosition += text.length();
                dirty = true;
            }
            if (dirty) {
                FreeScrollingTextField.this.setEdited(true);
                determineSpans();
            }
            int originalRow = FreeScrollingTextField.this._caretRow;
            updateCaretRow();
            if (originalRow != FreeScrollingTextField.this._caretRow) {
                isInvalidateSingleRow = false;
            }
            if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                if (FreeScrollingTextField.this._hDoc.isWordWrap() && originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(invalidateStartRow)) {
                    invalidateStartRow--;
                }
                if (!isInvalidateSingleRow || FreeScrollingTextField.this._hDoc.isWordWrap()) {
                    FreeScrollingTextField.this.invalidateFromRow(invalidateStartRow);
                } else {
                    FreeScrollingTextField.this.invalidateRows(FreeScrollingTextField.this._caretRow, FreeScrollingTextField.this._caretRow + 1);
                }
            }
        }

        void replaceComposingText(int from, int charCount, String text) {
            int invalidateStartRow;
            int originalOffset;
            boolean isInvalidateSingleRow = true;
            boolean dirty = false;
            if (!this._isInSelectionMode) {
                invalidateStartRow = FreeScrollingTextField.this._caretRow;
                originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(FreeScrollingTextField.this._caretRow);
            } else {
                invalidateStartRow = FreeScrollingTextField.this._hDoc.findRowNumber(FreeScrollingTextField.this._selectionAnchor);
                originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(invalidateStartRow);
                int totalChars = FreeScrollingTextField.this._selectionEdge - FreeScrollingTextField.this._selectionAnchor;
                if (totalChars > 0) {
                    FreeScrollingTextField.this._caretPosition = FreeScrollingTextField.this._selectionAnchor;
                    FreeScrollingTextField.this._hDoc.deleteAt(FreeScrollingTextField.this._selectionAnchor, totalChars, System.nanoTime());
                    if (invalidateStartRow != FreeScrollingTextField.this._caretRow) {
                        isInvalidateSingleRow = false;
                    }
                    dirty = true;
                }
                setSelectText(false);
            }
            if (charCount > 0) {
                int delFromRow = FreeScrollingTextField.this._hDoc.findRowNumber(from);
                if (delFromRow < invalidateStartRow) {
                    invalidateStartRow = delFromRow;
                    originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(delFromRow);
                }
                if (invalidateStartRow != FreeScrollingTextField.this._caretRow) {
                    isInvalidateSingleRow = false;
                }
                FreeScrollingTextField.this._caretPosition = from;
                FreeScrollingTextField.this._hDoc.deleteAt(from, charCount, System.nanoTime());
                dirty = true;
            }
            if (text != null && text.length() > 0) {
                int insFromRow = FreeScrollingTextField.this._hDoc.findRowNumber(from);
                if (insFromRow < invalidateStartRow) {
                    invalidateStartRow = insFromRow;
                    originalOffset = FreeScrollingTextField.this._hDoc.getRowOffset(insFromRow);
                }
                FreeScrollingTextField.this._hDoc.insertBefore(text.toCharArray(), FreeScrollingTextField.this._caretPosition, System.nanoTime());
                FreeScrollingTextField.this._caretPosition += text.length();
                dirty = true;
            }
            FreeScrollingTextField.this._textLis.onAdd(text, FreeScrollingTextField.this._caretPosition, text.length() - charCount);
            if (dirty) {
                FreeScrollingTextField.this.setEdited(true);
                determineSpans();
            }
            int originalRow = FreeScrollingTextField.this._caretRow;
            updateCaretRow();
            if (originalRow != FreeScrollingTextField.this._caretRow) {
                isInvalidateSingleRow = false;
            }
            if (!FreeScrollingTextField.this.makeCharVisible(FreeScrollingTextField.this._caretPosition)) {
                if (FreeScrollingTextField.this._hDoc.isWordWrap() && originalOffset != FreeScrollingTextField.this._hDoc.getRowOffset(invalidateStartRow)) {
                    invalidateStartRow--;
                }
                if (!isInvalidateSingleRow || FreeScrollingTextField.this._hDoc.isWordWrap()) {
                    FreeScrollingTextField.this.invalidateFromRow(invalidateStartRow);
                } else {
                    FreeScrollingTextField.this.invalidateRows(FreeScrollingTextField.this._caretRow, FreeScrollingTextField.this._caretRow + 1);
                }
            }
        }

        void deleteAroundComposingText(int left, int right) {
            int start = FreeScrollingTextField.this._caretPosition - left;
            if (start < 0) {
                start = 0;
            }
            int end = FreeScrollingTextField.this._caretPosition + right;
            int docLength = FreeScrollingTextField.this._hDoc.docLength();
            if (end > docLength - 1) {
                end = docLength - 1;
            }
            replaceComposingText(start, end - start, "");
        }

        String getTextAfterCursor(int maxLen) {
            int docLength = FreeScrollingTextField.this._hDoc.docLength();
            return FreeScrollingTextField.this._caretPosition + maxLen > docLength + (-1) ? FreeScrollingTextField.this._hDoc.subSequence(FreeScrollingTextField.this._caretPosition, (docLength - FreeScrollingTextField.this._caretPosition) - 1).toString() : FreeScrollingTextField.this._hDoc.subSequence(FreeScrollingTextField.this._caretPosition, maxLen).toString();
        }

        String getTextBeforeCursor(int maxLen) {
            int start = FreeScrollingTextField.this._caretPosition - maxLen;
            if (start < 0) {
                start = 0;
            }
            return FreeScrollingTextField.this._hDoc.subSequence(start, FreeScrollingTextField.this._caretPosition - start).toString();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class TextFieldInputConnection extends BaseInputConnection {
        private int _composingCharCount;
        private boolean _isComposing;

        public TextFieldInputConnection(FreeScrollingTextField v) {
            super(v, true);
            this._isComposing = false;
            this._composingCharCount = 0;
        }

        public void resetComposingState() {
            this._composingCharCount = 0;
            this._isComposing = false;
            FreeScrollingTextField.this._hDoc.endBatchEdit();
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean performContextMenuAction(int id) {
            switch (id) {
                case 16908319:
                case 16908328:
                case 16908329:
                    FreeScrollingTextField.this.selectAll();
                    return false;
                case 16908320:
                    FreeScrollingTextField.this.cut();
                    return false;
                case 16908321:
                    FreeScrollingTextField.this.copy();
                    return false;
                case 16908322:
                    FreeScrollingTextField.this.paste();
                    return false;
                case 16908323:
                case 16908324:
                case 16908325:
                case 16908326:
                case 16908327:
                default:
                    return false;
            }
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean sendKeyEvent(KeyEvent event) {
            switch (event.getKeyCode()) {
                case 19:
                    FreeScrollingTextField.this.moveCaretUp();
                    return true;
                case 20:
                    FreeScrollingTextField.this.moveCaretDown();
                    return true;
                case 21:
                    FreeScrollingTextField.this.moveCaretLeft();
                    return true;
                case MotionEventCompat.AXIS_GAS /* 22 */:
                    FreeScrollingTextField.this.moveCaretRight();
                    return true;
                case 59:
                    if (FreeScrollingTextField.this.isSelectText()) {
                        FreeScrollingTextField.this.selectText(false);
                        return true;
                    }
                    FreeScrollingTextField.this.selectText(true);
                    return true;
                case TbsListener.ErrorCode.DOWNLOAD_HAS_COPY_TBS_ERROR /* 122 */:
                    FreeScrollingTextField.this.moveCaret(0);
                    return true;
                case TbsListener.ErrorCode.DOWNLOAD_RETRYTIMES302_EXCEED /* 123 */:
                    FreeScrollingTextField.this.moveCaret(FreeScrollingTextField.this._hDoc.length());
                    return true;
                default:
                    return super.sendKeyEvent(event);
            }
        }

        public boolean isComposingStarted() {
            return this._isComposing;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean setComposingText(CharSequence text, int newCursorPosition) {
            this._isComposing = true;
            if (!FreeScrollingTextField.this._hDoc.isBatchEdit()) {
                FreeScrollingTextField.this._hDoc.beginBatchEdit();
            }
            FreeScrollingTextField.this._fieldController.replaceComposingText(FreeScrollingTextField.this.getCaretPosition() - this._composingCharCount, this._composingCharCount, text.toString());
            this._composingCharCount = text.length();
            if (newCursorPosition > 1) {
                FreeScrollingTextField.this._fieldController.moveCaret((FreeScrollingTextField.this._caretPosition + newCursorPosition) - 1);
            } else if (newCursorPosition <= 0) {
                FreeScrollingTextField.this._fieldController.moveCaret((FreeScrollingTextField.this._caretPosition - text.length()) - newCursorPosition);
            }
            return true;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean commitText(CharSequence text, int newCursorPosition) {
            FreeScrollingTextField.this._fieldController.replaceComposingText(FreeScrollingTextField.this.getCaretPosition() - this._composingCharCount, this._composingCharCount, text.toString());
            this._composingCharCount = 0;
            FreeScrollingTextField.this._hDoc.endBatchEdit();
            if (newCursorPosition > 1) {
                FreeScrollingTextField.this._fieldController.moveCaret((FreeScrollingTextField.this._caretPosition + newCursorPosition) - 1);
            } else if (newCursorPosition <= 0) {
                FreeScrollingTextField.this._fieldController.moveCaret((FreeScrollingTextField.this._caretPosition - text.length()) - newCursorPosition);
            }
            this._isComposing = false;
            return true;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean deleteSurroundingText(int leftLength, int rightLength) {
            if (this._composingCharCount != 0) {
                Log.d("lua", "Warning: Implmentation of InputConnection.deleteSurroundingText will not skip composing text");
            }
            FreeScrollingTextField.this._fieldController.deleteAroundComposingText(leftLength, rightLength);
            return true;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean finishComposingText() {
            resetComposingState();
            return true;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public int getCursorCapsMode(int reqModes) {
            if ((reqModes & 8192) == 8192) {
                int prevChar = FreeScrollingTextField.this._caretPosition - 1;
                if (prevChar >= 0 && !Lexer.getLanguage().isWhitespace(FreeScrollingTextField.this._hDoc.charAt(prevChar))) {
                    return 0;
                }
                int capsMode = 0 | 8192;
                if ((reqModes & 16384) == 16384) {
                    return capsMode | 16384;
                }
                return capsMode;
            }
            Language lang = Lexer.getLanguage();
            int prevChar2 = FreeScrollingTextField.this._caretPosition - 1;
            int whitespaceCount = 0;
            boolean capsOn = true;
            while (true) {
                if (prevChar2 >= 0) {
                    char c = FreeScrollingTextField.this._hDoc.charAt(prevChar2);
                    if (c == '\n') {
                        break;
                    } else if (!lang.isWhitespace(c)) {
                        if (whitespaceCount == 0 || !lang.isSentenceTerminator(c)) {
                            capsOn = false;
                        }
                    } else {
                        whitespaceCount++;
                        prevChar2--;
                    }
                } else {
                    break;
                }
            }
            if (!capsOn) {
                return 0;
            }
            return 0 | 16384;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public CharSequence getTextAfterCursor(int maxLen, int flags) {
            return FreeScrollingTextField.this._fieldController.getTextAfterCursor(maxLen);
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public CharSequence getTextBeforeCursor(int maxLen, int flags) {
            return FreeScrollingTextField.this._fieldController.getTextBeforeCursor(maxLen);
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean setSelection(int start, int end) {
            if (start == end) {
                FreeScrollingTextField.this._fieldController.moveCaret(start);
            } else {
                FreeScrollingTextField.this._fieldController.setSelectionRange(start, end - start, false, true);
            }
            return true;
        }

        @Override // android.view.inputmethod.BaseInputConnection, android.view.inputmethod.InputConnection
        public boolean reportFullscreenMode(boolean enabled) {
            return false;
        }
    }
}
