package com.myopicmobile.textwarrior.android;

import android.graphics.Canvas;
import android.graphics.Rect;
import android.support.v4.view.MotionEventCompat;
import android.view.GestureDetector;
import android.view.KeyEvent;
import android.view.MotionEvent;
import com.myopicmobile.textwarrior.common.ColorScheme;
import com.myopicmobile.textwarrior.common.DocumentProvider;
/* loaded from: classes.dex */
public class TouchNavigationMethod extends GestureDetector.SimpleOnGestureListener {
    private GestureDetector _gestureDetector;
    protected boolean _isCaretTouched = false;
    protected FreeScrollingTextField _textField;
    private int fling;
    private float lastDist;
    private float lastSize;
    private float lastX;
    private float lastY;
    private static final Rect _caretBloat = new Rect(0, 0, 0, 0);
    protected static int SCROLL_EDGE_SLOP = 10;
    protected static int TOUCH_SLOP = 12;

    public TouchNavigationMethod(FreeScrollingTextField textField) {
        this._textField = textField;
        this._gestureDetector = new GestureDetector(textField.getContext(), this);
        this._gestureDetector.setIsLongpressEnabled(true);
    }

    private TouchNavigationMethod() {
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onDown(MotionEvent e) {
        int x = screenToViewX((int) e.getX());
        int y = screenToViewY((int) e.getY());
        this._isCaretTouched = isNearChar(x, y, this._textField.getCaretPosition());
        if (this._textField.isFlingScrolling()) {
            this._textField.stopFlingScrolling();
        } else if (this._textField.isSelectText()) {
            if (isNearChar(x, y, this._textField.getSelectionStart())) {
                this._textField.focusSelectionStart();
                this._textField.performHapticFeedback(0);
                this._isCaretTouched = true;
            } else if (isNearChar(x, y, this._textField.getSelectionEnd())) {
                this._textField.focusSelectionEnd();
                this._textField.performHapticFeedback(0);
                this._isCaretTouched = true;
            }
        }
        if (this._isCaretTouched) {
            this._textField.performHapticFeedback(0);
        }
        return true;
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public void onShowPress(MotionEvent e) {
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onSingleTapUp(MotionEvent e) {
        int x = screenToViewX((int) e.getX());
        int y = screenToViewY((int) e.getY());
        int charOffset = this._textField.coordToCharIndex(x, y);
        if (this._textField.isSelectText()) {
            int strictCharOffset = this._textField.coordToCharIndexStrict(x, y);
            if (!this._textField.inSelectionRange(strictCharOffset) && !isNearChar(x, y, this._textField.getSelectionStart()) && !isNearChar(x, y, this._textField.getSelectionEnd())) {
                this._textField.selectText(false);
                if (strictCharOffset >= 0) {
                    this._textField.moveCaret(charOffset);
                }
            }
        } else if (charOffset >= 0) {
            this._textField.moveCaret(charOffset);
        }
        if (1 != 0) {
            this._textField.showIME(true);
        }
        return true;
    }

    public boolean onUp(MotionEvent e) {
        this._textField.stopAutoScrollCaret();
        this._isCaretTouched = false;
        this.lastDist = 0.0f;
        this.fling = 0;
        return true;
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        if (this._isCaretTouched) {
            dragCaret(e2);
        } else if (e2.getPointerCount() == 1) {
            if (this.fling == 0) {
                if (Math.abs(distanceX) > Math.abs(distanceY)) {
                    this.fling = 1;
                } else {
                    this.fling = -1;
                }
            }
            if (this.fling == 1) {
                distanceY = 0.0f;
            } else if (this.fling == -1) {
                distanceX = 0.0f;
            }
            scrollView(distanceX, distanceY);
        }
        if ((e2.getAction() & 255) == 1) {
            onUp(e2);
        }
        return true;
    }

    private void dragCaret(MotionEvent e) {
        if (!this._textField.isSelectText() && isDragSelect()) {
            this._textField.selectText(true);
        }
        int x = ((int) e.getX()) - this._textField.getPaddingLeft();
        int y = ((int) e.getY()) - this._textField.getPaddingTop();
        boolean scrolled = false;
        if (x < SCROLL_EDGE_SLOP) {
            scrolled = this._textField.autoScrollCaret(2);
        } else if (x >= this._textField.getContentWidth() - SCROLL_EDGE_SLOP) {
            scrolled = this._textField.autoScrollCaret(3);
        } else if (y < SCROLL_EDGE_SLOP) {
            scrolled = this._textField.autoScrollCaret(0);
        } else if (y >= this._textField.getContentHeight() - SCROLL_EDGE_SLOP) {
            scrolled = this._textField.autoScrollCaret(1);
        }
        if (!scrolled) {
            this._textField.stopAutoScrollCaret();
            int newCaretIndex = this._textField.coordToCharIndex(screenToViewX((int) e.getX()), screenToViewY((int) e.getY()));
            if (newCaretIndex >= 0) {
                this._textField.moveCaret(newCaretIndex);
            }
        }
    }

    private void scrollView(float distanceX, float distanceY) {
        int newX = ((int) distanceX) + this._textField.getScrollX();
        int newY = ((int) distanceY) + this._textField.getScrollY();
        int maxWidth = Math.max(this._textField.getMaxScrollX(), this._textField.getScrollX());
        if (newX > maxWidth) {
            newX = maxWidth;
        } else if (newX < 0) {
            newX = 0;
        }
        int maxHeight = Math.max(this._textField.getMaxScrollY(), this._textField.getScrollY());
        if (newY > maxHeight) {
            newY = maxHeight;
        } else if (newY < 0) {
            newY = 0;
        }
        this._textField.smoothScrollTo(newX, newY);
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
        if (!this._isCaretTouched) {
            if (this.fling == 1) {
                velocityY = 0.0f;
            } else if (this.fling == -1) {
                velocityX = 0.0f;
            }
            this._textField.flingScroll(((int) (-velocityX)) * 2, ((int) (-velocityY)) * 2);
        }
        onUp(e2);
        return true;
    }

    private float spacing(MotionEvent event) {
        float x = event.getX(0) - event.getX(1);
        float y = event.getY(0) - event.getY(1);
        return (float) Math.sqrt((x * x) + (y * y));
    }

    private boolean onTouchZoom(MotionEvent e) {
        if (e.getAction() == 2 && e.getPointerCount() == 2) {
            if (this.lastDist == 0.0f) {
                float x = e.getX(0) - e.getX(1);
                float y = e.getY(0) - e.getY(1);
                this.lastDist = (float) Math.sqrt((x * x) + (y * y));
                this.lastX = (e.getX(0) + e.getX(1)) / 2.0f;
                this.lastY = (e.getY(0) + e.getY(1)) / 2.0f;
                this.lastSize = this._textField.getTextSize();
            }
            float dist = spacing(e);
            if (this.lastDist != 0.0f) {
                this._textField.setTextSize((int) (this.lastSize * (dist / this.lastDist)));
                return true;
            }
            return true;
        }
        this.lastDist = 0.0f;
        return false;
    }

    public boolean onTouchEvent(MotionEvent event) {
        onTouchZoom(event);
        boolean handled = this._gestureDetector.onTouchEvent(event);
        if (!handled && (event.getAction() & 255) == 1) {
            return onUp(event);
        }
        return handled;
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public void onLongPress(MotionEvent e) {
        onDoubleTap(e);
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnDoubleTapListener
    public boolean onDoubleTap(MotionEvent e) {
        this._isCaretTouched = true;
        int x = screenToViewX((int) e.getX());
        int y = screenToViewY((int) e.getY());
        int charOffset = this._textField.coordToCharIndex(x, y);
        if (this._textField.isSelectText() && this._textField.inSelectionRange(charOffset)) {
            DocumentProvider doc = this._textField.createDocumentProvider();
            int line = doc.findLineNumber(charOffset);
            int start = doc.getLineOffset(line);
            int end = doc.getLineOffset(line + 1) - 1;
            this._textField.setSelectionRange(start, end - start);
        } else if (charOffset >= 0) {
            this._textField.moveCaret(charOffset);
            DocumentProvider doc2 = this._textField.createDocumentProvider();
            int start2 = charOffset;
            while (start2 >= 0) {
                char c = doc2.charAt(start2);
                if (!Character.isJavaIdentifierPart(c)) {
                    break;
                }
                start2--;
            }
            if (start2 != charOffset) {
                start2++;
            }
            int end2 = charOffset;
            while (end2 >= 0) {
                char c2 = doc2.charAt(end2);
                if (!Character.isJavaIdentifierPart(c2)) {
                    break;
                }
                end2++;
            }
            this._textField.selectText(true);
            this._textField.setSelectionRange(start2, end2 - start2);
        }
        return true;
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
        return false;
    }

    public boolean onKeyUp(int keyCode, KeyEvent event) {
        return false;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onPause() {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onResume() {
    }

    public void onTextDrawComplete(Canvas canvas) {
    }

    public void onColorSchemeChanged(ColorScheme colorScheme) {
    }

    public void onChiralityChanged(boolean isRightHanded) {
    }

    public Rect getCaretBloat() {
        return _caretBloat;
    }

    protected final int getPointerId(MotionEvent e) {
        return (e.getAction() & MotionEventCompat.ACTION_POINTER_INDEX_MASK) >> 8;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final int screenToViewX(int x) {
        return (x - this._textField.getPaddingLeft()) + this._textField.getScrollX();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final int screenToViewY(int y) {
        return (y - this._textField.getPaddingTop()) + this._textField.getScrollY();
    }

    public final boolean isRightHanded() {
        return true;
    }

    private final boolean isDragSelect() {
        return false;
    }

    public boolean isNearChar(int x, int y, int charOffset) {
        Rect bounds = this._textField.getBoundingBox(charOffset);
        return y >= bounds.top - TOUCH_SLOP && y < bounds.bottom + TOUCH_SLOP && x >= bounds.left - TOUCH_SLOP && x < bounds.right + TOUCH_SLOP;
    }
}
