package com.myopicmobile.textwarrior.android;

import android.view.MotionEvent;
/* loaded from: classes.dex */
public class TrackpadNavigationMethod extends TouchNavigationMethod {
    private static final double MIN_ATAN = 0.322d;
    private static final int MOVEMENT_PIXELS = 16;
    private float _xAccum;
    private float _yAccum;

    public TrackpadNavigationMethod(FreeScrollingTextField textField) {
        super(textField);
        this._xAccum = 0.0f;
        this._yAccum = 0.0f;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onDown(MotionEvent e) {
        return true;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod
    public boolean onUp(MotionEvent e) {
        this._xAccum = 0.0f;
        this._yAccum = 0.0f;
        super.onUp(e);
        return true;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        moveCaretWithTrackpad(-distanceX, -distanceY);
        if ((e2.getAction() & 255) == 1) {
            onUp(e2);
        }
        return true;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
        onUp(e2);
        return true;
    }

    private void moveCaretWithTrackpad(float distanceX, float distanceY) {
        if ((this._xAccum < 0.0f && distanceX > 0.0f) || (this._xAccum > 0.0f && distanceX < 0.0f)) {
            this._xAccum = 0.0f;
        }
        if ((this._yAccum < 0.0f && distanceY > 0.0f) || (this._yAccum > 0.0f && distanceY < 0.0f)) {
            this._yAccum = 0.0f;
        }
        double angle = Math.atan2(Math.abs(distanceX), Math.abs(distanceY));
        if (angle >= MIN_ATAN) {
            float x = this._xAccum + distanceX;
            int xUnits = ((int) x) / 16;
            this._xAccum = x - (xUnits * 16);
            while (xUnits > 0) {
                this._textField.moveCaretRight();
                xUnits--;
            }
            while (xUnits < 0) {
                this._textField.moveCaretLeft();
                xUnits++;
            }
        }
        if (1.5707963267948966d - angle >= MIN_ATAN) {
            float y = this._yAccum + distanceY;
            int yUnits = ((int) y) / 16;
            this._yAccum = y - (yUnits * 16);
            for (int i = yUnits; i > 0; i--) {
                this._textField.moveCaretDown();
            }
            for (int i2 = yUnits; i2 < 0; i2++) {
                this._textField.moveCaretUp();
            }
        }
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnDoubleTapListener
    public boolean onSingleTapConfirmed(MotionEvent e) {
        return super.onSingleTapConfirmed(e);
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnDoubleTapListener
    public boolean onDoubleTap(MotionEvent e) {
        return super.onDoubleTap(e);
    }
}
