package com.myopicmobile.textwarrior.android;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.MotionEvent;
import com.myopicmobile.textwarrior.common.ColorScheme;
import com.myopicmobile.textwarrior.common.Pair;
/* loaded from: classes.dex */
public class YoyoNavigationMethod extends TouchNavigationMethod {
    private boolean _isCaretHandleTouched;
    private boolean _isEndHandleTouched;
    private boolean _isShowYoyoCaret;
    private boolean _isStartHandleTouched;
    private final Yoyo _yoyoCaret;
    private final Yoyo _yoyoEnd;
    private int _yoyoSize;
    private final Yoyo _yoyoStart;

    public YoyoNavigationMethod(FreeScrollingTextField textField) {
        super(textField);
        this._isStartHandleTouched = false;
        this._isEndHandleTouched = false;
        this._isCaretHandleTouched = false;
        this._isShowYoyoCaret = false;
        DisplayMetrics dm = textField.getContext().getResources().getDisplayMetrics();
        this._yoyoSize = (int) TypedValue.applyDimension(2, (float) (FreeScrollingTextField.BASE_TEXT_SIZE_PIXELS * 1.5d), dm);
        this._yoyoCaret = new Yoyo();
        this._yoyoStart = new Yoyo();
        this._yoyoEnd = new Yoyo();
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onDown(MotionEvent e) {
        super.onDown(e);
        if (!this._isCaretTouched) {
            int x = ((int) e.getX()) + this._textField.getScrollX();
            int y = ((int) e.getY()) + this._textField.getScrollY();
            this._isCaretHandleTouched = this._yoyoCaret.isInHandle(x, y);
            this._isStartHandleTouched = this._yoyoStart.isInHandle(x, y);
            this._isEndHandleTouched = this._yoyoEnd.isInHandle(x, y);
            if (this._isCaretHandleTouched) {
                this._isShowYoyoCaret = true;
                this._yoyoCaret.setInitialTouch(x, y);
                this._yoyoCaret.invalidateHandle();
            } else if (this._isStartHandleTouched) {
                this._yoyoStart.setInitialTouch(x, y);
                this._textField.focusSelectionStart();
                this._yoyoStart.invalidateHandle();
            } else if (this._isEndHandleTouched) {
                this._yoyoEnd.setInitialTouch(x, y);
                this._textField.focusSelectionEnd();
                this._yoyoEnd.invalidateHandle();
            }
        }
        return true;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod
    public boolean onUp(MotionEvent e) {
        this._isCaretHandleTouched = false;
        this._isStartHandleTouched = false;
        this._isEndHandleTouched = false;
        this._yoyoCaret.clearInitialTouch();
        this._yoyoStart.clearInitialTouch();
        this._yoyoEnd.clearInitialTouch();
        super.onUp(e);
        return true;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        if (this._isCaretHandleTouched) {
            if ((e2.getAction() & 255) == 1) {
                onUp(e2);
                return true;
            }
            this._isShowYoyoCaret = true;
            moveHandle(this._yoyoCaret, e2);
            return true;
        } else if (this._isStartHandleTouched) {
            if ((e2.getAction() & 255) == 1) {
                onUp(e2);
                return true;
            }
            moveHandle(this._yoyoStart, e2);
            return true;
        } else if (this._isEndHandleTouched) {
            if ((e2.getAction() & 255) == 1) {
                onUp(e2);
                return true;
            }
            moveHandle(this._yoyoEnd, e2);
            return true;
        } else {
            return super.onScroll(e1, e2, distanceX, distanceY);
        }
    }

    private void moveHandle(Yoyo _yoyo, MotionEvent e) {
        Pair foundIndex = _yoyo.findNearestChar((int) e.getX(), (int) e.getY());
        int newCaretIndex = foundIndex.getFirst();
        if (newCaretIndex >= 0) {
            this._textField.moveCaret(newCaretIndex);
            Rect newCaretBounds = this._textField.getBoundingBox(newCaretIndex);
            int newX = newCaretBounds.left + this._textField.getPaddingLeft();
            int newY = newCaretBounds.bottom + this._textField.getPaddingTop();
            _yoyo.attachYoyo(newX, newY);
        }
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onSingleTapUp(MotionEvent e) {
        int x = ((int) e.getX()) + this._textField.getScrollX();
        int y = ((int) e.getY()) + this._textField.getScrollY();
        if (this._yoyoCaret.isInHandle(x, y) || this._yoyoStart.isInHandle(x, y) || this._yoyoEnd.isInHandle(x, y)) {
            return true;
        }
        this._isShowYoyoCaret = true;
        return super.onSingleTapUp(e);
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnDoubleTapListener
    public boolean onDoubleTap(MotionEvent e) {
        int x = ((int) e.getX()) + this._textField.getScrollX();
        int y = ((int) e.getY()) + this._textField.getScrollY();
        if (this._yoyoCaret.isInHandle(x, y)) {
            this._textField.selectText(true);
            return true;
        } else if (this._yoyoStart.isInHandle(x, y)) {
            return true;
        } else {
            return super.onDoubleTap(e);
        }
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public void onLongPress(MotionEvent e) {
        onDoubleTap(e);
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod, android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
        if (this._isCaretHandleTouched || this._isStartHandleTouched || this._isEndHandleTouched) {
            onUp(e2);
            return true;
        }
        return super.onFling(e1, e2, velocityX, velocityY);
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod
    public void onTextDrawComplete(Canvas canvas) {
        if (!this._textField.isSelectText2()) {
            this._yoyoCaret.show();
            this._yoyoStart.hide();
            this._yoyoEnd.hide();
            if (!this._isCaretHandleTouched) {
                Rect caret = this._textField.getBoundingBox(this._textField.getCaretPosition());
                int x = caret.left + this._textField.getPaddingLeft();
                int y = caret.bottom + this._textField.getPaddingTop();
                this._yoyoCaret.setRestingCoord(x, y);
            }
            if (this._isShowYoyoCaret) {
                this._yoyoCaret.draw(canvas, this._isCaretHandleTouched);
            }
            this._isShowYoyoCaret = false;
            return;
        }
        this._yoyoCaret.hide();
        this._yoyoStart.show();
        this._yoyoEnd.show();
        if (!this._isStartHandleTouched || !this._isEndHandleTouched) {
            Rect caret2 = this._textField.getBoundingBox(this._textField.getSelectionStart());
            int x2 = caret2.left + this._textField.getPaddingLeft();
            int y2 = caret2.bottom + this._textField.getPaddingTop();
            this._yoyoStart.setRestingCoord(x2, y2);
            Rect caret22 = this._textField.getBoundingBox(this._textField.getSelectionEnd());
            int x22 = caret22.left + this._textField.getPaddingLeft();
            int y22 = caret22.bottom + this._textField.getPaddingTop();
            this._yoyoEnd.setRestingCoord(x22, y22);
        }
        this._yoyoStart.draw(canvas, this._isStartHandleTouched);
        this._yoyoEnd.draw(canvas, this._isStartHandleTouched);
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod
    public Rect getCaretBloat() {
        return this._yoyoCaret.HANDLE_BLOAT;
    }

    @Override // com.myopicmobile.textwarrior.android.TouchNavigationMethod
    public void onColorSchemeChanged(ColorScheme colorScheme) {
        this._yoyoCaret.setHandleColor(colorScheme.getColor(ColorScheme.Colorable.CARET_BACKGROUND));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class Yoyo {
        private static final int YOYO_HANDLE_ALPHA = 180;
        private static final int YOYO_HANDLE_COLOR = -16776961;
        public final Rect HANDLE_BLOAT;
        private final Rect HANDLE_RECT;
        private final int YOYO_STRING_RESTING_HEIGHT;
        private final Paint _brush;
        private boolean _isShow;
        private int _anchorX = 0;
        private int _anchorY = 0;
        private int _handleX = 0;
        private int _handleY = 0;
        private int _xOffset = 0;
        private int _yOffset = 0;

        public Yoyo() {
            this.YOYO_STRING_RESTING_HEIGHT = YoyoNavigationMethod.this._yoyoSize / 3;
            this.HANDLE_RECT = new Rect(0, 0, YoyoNavigationMethod.this._yoyoSize, YoyoNavigationMethod.this._yoyoSize);
            int radius = getRadius();
            this.HANDLE_BLOAT = new Rect(radius, 0, 0, this.HANDLE_RECT.bottom + this.YOYO_STRING_RESTING_HEIGHT);
            this._brush = new Paint();
            this._brush.setColor(YoyoNavigationMethod.this._textField.getColorScheme().getColor(ColorScheme.Colorable.CARET_BACKGROUND));
            this._brush.setAntiAlias(true);
        }

        public void setHandleColor(int color) {
            this._brush.setColor(color);
        }

        public void draw(Canvas canvas, boolean activated) {
            int radius = getRadius();
            canvas.drawLine(this._anchorX, this._anchorY, this._handleX + radius, this._handleY + radius, this._brush);
            canvas.drawArc(new RectF(this._anchorX - radius, (this._anchorY - (radius / 2)) - this.YOYO_STRING_RESTING_HEIGHT, this._handleX + (radius * 2), this._handleY + (radius / 2)), 60.0f, 60.0f, true, this._brush);
            canvas.drawOval(new RectF(this._handleX, this._handleY, this._handleX + this.HANDLE_RECT.right, this._handleY + this.HANDLE_RECT.bottom), this._brush);
        }

        public final int getRadius() {
            return this.HANDLE_RECT.right / 2;
        }

        public void attachYoyo(int x, int y) {
            invalidateYoyo();
            setRestingCoord(x, y);
            invalidateYoyo();
        }

        public void setRestingCoord(int x, int y) {
            this._anchorX = x;
            this._anchorY = y;
            this._handleX = x - getRadius();
            this._handleY = this.YOYO_STRING_RESTING_HEIGHT + y;
        }

        private void invalidateYoyo() {
            int x0;
            int x1;
            int y0;
            int y1;
            int handleCenter = this._handleX + getRadius();
            if (handleCenter >= this._anchorX) {
                x0 = this._anchorX;
                x1 = handleCenter + 1;
            } else {
                x0 = handleCenter;
                x1 = this._anchorX + 1;
            }
            if (this._handleY >= this._anchorY) {
                y0 = this._anchorY;
                y1 = this._handleY;
            } else {
                y0 = this._handleY;
                y1 = this._anchorY;
            }
            YoyoNavigationMethod.this._textField.invalidate(x0, y0, x1, y1);
            invalidateHandle();
        }

        public void invalidateHandle() {
            Rect handleExtent = new Rect(this._handleX, this._handleY, this._handleX + this.HANDLE_RECT.right, this._handleY + this.HANDLE_RECT.bottom);
            YoyoNavigationMethod.this._textField.invalidate(handleExtent);
        }

        public Pair findNearestChar(int handleX, int handleY) {
            int attachedLeft = (YoyoNavigationMethod.this.screenToViewX(handleX) - this._xOffset) + getRadius();
            int attachedBottom = ((YoyoNavigationMethod.this.screenToViewY(handleY) - this._yOffset) - this.YOYO_STRING_RESTING_HEIGHT) - 2;
            return new Pair(YoyoNavigationMethod.this._textField.coordToCharIndex(attachedLeft, attachedBottom), YoyoNavigationMethod.this._textField.coordToCharIndexStrict(attachedLeft, attachedBottom));
        }

        public void setInitialTouch(int x, int y) {
            this._xOffset = x - this._handleX;
            this._yOffset = y - this._handleY;
        }

        public void clearInitialTouch() {
            this._xOffset = 0;
            this._yOffset = 0;
        }

        public boolean isShow() {
            return this._isShow;
        }

        public void show() {
            this._isShow = true;
        }

        public void hide() {
            this._isShow = false;
        }

        public boolean isInHandle(int x, int y) {
            return this._isShow && x >= this._handleX && x < this._handleX + this.HANDLE_RECT.right && y >= this._handleY && y < this._handleY + this.HANDLE_RECT.bottom;
        }
    }
}
