package com.myopicmobile.textwarrior.common;

import java.util.HashMap;
/* loaded from: classes.dex */
public abstract class ColorScheme {
    private static final int BLACK = -16777216;
    private static final int BLUE = -16776961;
    private static final int DARK_BLUE = -3129123;
    private static final int DARK_RED = -7667712;
    private static final int GREEN = -7820664;
    private static final int GREY = -8355712;
    private static final int INDIGO = -14008065;
    private static final int LIGHT_BLUE = -10452737;
    private static final int LIGHT_BLUE2 = -12537601;
    private static final int LIGHT_GREY = -5592406;
    private static final int MAROON = -8388608;
    private static final int OLIVE_GREEN = -12615841;
    private static final int PURPLE = -2276216;
    private static final int PURPLE2 = -65281;
    private static final int RED = 1157562368;
    private static final int WHITE = -32;
    protected HashMap<Colorable, Integer> _colors = generateDefaultColors();

    /* loaded from: classes.dex */
    public enum Colorable {
        FOREGROUND,
        BACKGROUND,
        SELECTION_FOREGROUND,
        SELECTION_BACKGROUND,
        CARET_FOREGROUND,
        CARET_BACKGROUND,
        CARET_DISABLED,
        LINE_HIGHLIGHT,
        NON_PRINTING_GLYPH,
        COMMENT,
        KEYWORD,
        NAME,
        LITERAL,
        STRING,
        SECONDARY
    }

    public abstract boolean isDark();

    public void setColor(Colorable colorable, int color) {
        this._colors.put(colorable, Integer.valueOf(color));
    }

    public int getColor(Colorable colorable) {
        Integer color = this._colors.get(colorable);
        if (color == null) {
            TextWarriorException.fail("Color not specified for " + colorable);
            return 0;
        }
        return color.intValue();
    }

    public int getTokenColor(int tokenType) {
        Colorable element;
        switch (tokenType) {
            case 0:
                element = Colorable.FOREGROUND;
                break;
            case 1:
                element = Colorable.KEYWORD;
                break;
            case 2:
            case 10:
            case 20:
                element = Colorable.SECONDARY;
                break;
            case 3:
                element = Colorable.NAME;
                break;
            case 4:
                element = Colorable.LITERAL;
                break;
            case 21:
            case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
            case 40:
                element = Colorable.COMMENT;
                break;
            case Lexer.SINGLE_SYMBOL_DELIMITED_A /* 50 */:
            case Lexer.SINGLE_SYMBOL_DELIMITED_B /* 51 */:
                element = Colorable.STRING;
                break;
            default:
                TextWarriorException.fail("Invalid token type");
                element = Colorable.FOREGROUND;
                break;
        }
        return getColor(element);
    }

    private HashMap<Colorable, Integer> generateDefaultColors() {
        HashMap<Colorable, Integer> colors = new HashMap<>(Colorable.values().length);
        colors.put(Colorable.FOREGROUND, -16777216);
        colors.put(Colorable.BACKGROUND, Integer.valueOf((int) WHITE));
        colors.put(Colorable.SELECTION_FOREGROUND, Integer.valueOf((int) WHITE));
        colors.put(Colorable.SELECTION_BACKGROUND, -6832092);
        colors.put(Colorable.CARET_FOREGROUND, Integer.valueOf((int) WHITE));
        colors.put(Colorable.CARET_BACKGROUND, Integer.valueOf((int) LIGHT_BLUE2));
        colors.put(Colorable.CARET_DISABLED, Integer.valueOf((int) GREY));
        colors.put(Colorable.LINE_HIGHLIGHT, 545818760);
        colors.put(Colorable.NON_PRINTING_GLYPH, Integer.valueOf((int) LIGHT_GREY));
        colors.put(Colorable.COMMENT, Integer.valueOf((int) OLIVE_GREEN));
        colors.put(Colorable.KEYWORD, Integer.valueOf((int) DARK_BLUE));
        colors.put(Colorable.NAME, Integer.valueOf((int) INDIGO));
        colors.put(Colorable.LITERAL, Integer.valueOf((int) LIGHT_BLUE));
        colors.put(Colorable.STRING, Integer.valueOf((int) PURPLE));
        colors.put(Colorable.SECONDARY, Integer.valueOf((int) GREY));
        return colors;
    }
}
