package com.myopicmobile.textwarrior.common;

import com.myopicmobile.textwarrior.common.Document;
import java.util.List;
/* loaded from: classes.dex */
public class DocumentProvider implements CharSequence {
    private int _currIndex = 0;
    private final Document _theText;

    @Override // java.lang.CharSequence
    public int length() {
        return this._theText.length();
    }

    public DocumentProvider(Document.TextFieldMetrics metrics) {
        this._theText = new Document(metrics);
    }

    public DocumentProvider(Document doc) {
        this._theText = doc;
    }

    public DocumentProvider(DocumentProvider rhs) {
        this._theText = rhs._theText;
    }

    @Override // java.lang.CharSequence
    public CharSequence subSequence(int charOffset, int maxChars) {
        return this._theText.subSequence(charOffset, maxChars);
    }

    @Override // java.lang.CharSequence
    public char charAt(int charOffset) {
        if (this._theText.isValid(charOffset)) {
            return this._theText.charAt(charOffset);
        }
        return (char) 0;
    }

    public String getRow(int rowNumber) {
        return this._theText.getRow(rowNumber);
    }

    public int findRowNumber(int charOffset) {
        return this._theText.findRowNumber(charOffset);
    }

    public int findLineNumber(int charOffset) {
        return this._theText.findLineNumber(charOffset);
    }

    public int getRowOffset(int rowNumber) {
        return this._theText.getRowOffset(rowNumber);
    }

    public int getLineOffset(int lineNumber) {
        return this._theText.getLineOffset(lineNumber);
    }

    public int seekChar(int startingChar) {
        if (this._theText.isValid(startingChar)) {
            this._currIndex = startingChar;
        } else {
            this._currIndex = -1;
        }
        return this._currIndex;
    }

    public boolean hasNext() {
        return this._currIndex >= 0 && this._currIndex < this._theText.getTextLength();
    }

    public char next() {
        char nextChar = this._theText.charAt(this._currIndex);
        this._currIndex++;
        return nextChar;
    }

    public void insertBefore(char c, int insertionPoint, long timestamp) {
        if (this._theText.isValid(insertionPoint)) {
            char[] a = {c};
            this._theText.insert(a, insertionPoint, timestamp, true);
        }
    }

    public void insertBefore(char[] cArray, int insertionPoint, long timestamp) {
        if (this._theText.isValid(insertionPoint) && cArray.length != 0) {
            this._theText.insert(cArray, insertionPoint, timestamp, true);
        }
    }

    public void insert(int i, CharSequence s) {
        this._theText.insert(new char[]{s.charAt(0)}, i, System.nanoTime(), true);
    }

    public void deleteAt(int deletionPoint, long timestamp) {
        if (this._theText.isValid(deletionPoint)) {
            this._theText.delete(deletionPoint, 1, timestamp, true);
        }
    }

    public void deleteAt(int deletionPoint, int maxChars, long time) {
        if (this._theText.isValid(deletionPoint) && maxChars > 0) {
            int totalChars = Math.min(maxChars, this._theText.getTextLength() - deletionPoint);
            this._theText.delete(deletionPoint, totalChars, time, true);
        }
    }

    public boolean isBatchEdit() {
        return this._theText.isBatchEdit();
    }

    public void beginBatchEdit() {
        this._theText.beginBatchEdit();
    }

    public void endBatchEdit() {
        this._theText.endBatchEdit();
    }

    public int getRowCount() {
        return this._theText.getRowCount();
    }

    public int getRowSize(int rowNumber) {
        return this._theText.getRowSize(rowNumber);
    }

    public int docLength() {
        return this._theText.getTextLength();
    }

    public void clearSpans() {
        this._theText.clearSpans();
    }

    public List<Pair> getSpans() {
        return this._theText.getSpans();
    }

    public void setSpans(List<Pair> spans) {
        this._theText.setSpans(spans);
    }

    public void setMetrics(Document.TextFieldMetrics metrics) {
        this._theText.setMetrics(metrics);
    }

    public void setWordWrap(boolean enable) {
        this._theText.setWordWrap(enable);
    }

    public boolean isWordWrap() {
        return this._theText.isWordWrap();
    }

    public void analyzeWordWrap() {
        this._theText.analyzeWordWrap();
    }

    public boolean canUndo() {
        return this._theText.canUndo();
    }

    public boolean canRedo() {
        return this._theText.canRedo();
    }

    public int undo() {
        return this._theText.undo();
    }

    public int redo() {
        return this._theText.redo();
    }

    @Override // java.lang.CharSequence
    public String toString() {
        return this._theText.toString();
    }
}
