package com.myopicmobile.textwarrior.common;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
/* loaded from: classes.dex */
public abstract class Language {
    public static final char BACKSPACE = '\b';
    private static final char[] BASIC_C_OPERATORS = {'(', ')', '{', '}', '.', ',', ';', '=', '+', '-', '/', '*', '&', '!', '|', ':', '[', ']', '<', '>', '?', '~', '%', '^'};
    public static final char EOF = 65535;
    public static final String GLYPH_NEWLINE = "↵";
    public static final String GLYPH_SPACE = "·";
    public static final String GLYPH_TAB = "»";
    public static final char NEWLINE = '\n';
    public static final char NULL_CHAR = 0;
    public static final char TAB = '\t';
    private String[] _keyword;
    private String[] _name;
    protected HashMap<String, Integer> _keywords = new HashMap<>(0);
    protected HashMap<String, Integer> _names = new HashMap<>(0);
    protected HashMap<String, String[]> _bases = new HashMap<>(0);
    protected HashMap<String, Integer> _users = new HashMap<>(0);
    protected HashMap<Character, Integer> _operators = generateOperators(BASIC_C_OPERATORS);
    private ArrayList<String> _ueserCache = new ArrayList<>();
    private String[] _userWords = new String[0];

    public void updateUserWord() {
        String[] uw = new String[this._ueserCache.size()];
        this._userWords = (String[]) this._ueserCache.toArray(uw);
    }

    public String[] getUserWord() {
        return this._userWords;
    }

    public String[] getNames() {
        return this._name;
    }

    public String[] getBasePackage(String name) {
        return this._bases.get(name);
    }

    public String[] getKeywords() {
        return this._keyword;
    }

    public void setKeywords(String[] keywords) {
        this._keyword = keywords;
        this._keywords = new HashMap<>(keywords.length);
        for (String str : keywords) {
            this._keywords.put(str, 1);
        }
    }

    public void setNames(String[] names) {
        this._name = names;
        ArrayList<String> buf = new ArrayList<>();
        this._names = new HashMap<>(names.length);
        for (int i = 0; i < names.length; i++) {
            if (!buf.contains(names[i])) {
                buf.add(names[i]);
            }
            this._names.put(names[i], 3);
        }
        this._name = new String[buf.size()];
        buf.toArray(this._name);
    }

    public void addBasePackage(String name, String[] names) {
        this._bases.put(name, names);
    }

    public void clearUserWord() {
        this._ueserCache.clear();
        this._users.clear();
    }

    public void addUserWord(String name) {
        if (!this._ueserCache.contains(name) && !this._names.containsKey(name)) {
            this._ueserCache.add(name);
        }
        this._users.put(name, 3);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setOperators(char[] operators) {
        this._operators = generateOperators(operators);
    }

    private HashMap<Character, Integer> generateOperators(char[] operators) {
        HashMap<Character, Integer> operatorsMap = new HashMap<>(operators.length);
        for (char c : operators) {
            operatorsMap.put(Character.valueOf(c), 2);
        }
        return operatorsMap;
    }

    public final boolean isOperator(char c) {
        return this._operators.containsKey(Character.valueOf(c));
    }

    public final boolean isKeyword(String s) {
        return this._keywords.containsKey(s);
    }

    public final boolean isName(String s) {
        return this._names.containsKey(s);
    }

    public final boolean isBasePackage(String s) {
        return this._bases.containsKey(s);
    }

    public final boolean isBaseWord(String p, String s) {
        String[] pkg = this._bases.get(p);
        for (String n : pkg) {
            if (n.equals(s)) {
                return true;
            }
        }
        return false;
    }

    public final boolean isUserWord(String s) {
        return this._users.containsKey(s);
    }

    private boolean contains(String[] a, String s) {
        for (String n : a) {
            if (n.equals(s)) {
                return true;
            }
        }
        return false;
    }

    private boolean contains(ArrayList<String> a, String s) {
        Iterator<String> it = a.iterator();
        while (it.hasNext()) {
            String n = it.next();
            if (n.equals(s)) {
                return true;
            }
        }
        return false;
    }

    public boolean isWhitespace(char c) {
        return c == ' ' || c == '\n' || c == '\t' || c == '\r' || c == '\f' || c == 65535;
    }

    public boolean isSentenceTerminator(char c) {
        return c == '.';
    }

    public boolean isEscapeChar(char c) {
        return c == '\\';
    }

    public boolean isProgLang() {
        return true;
    }

    public boolean isWordStart(char c) {
        return false;
    }

    public boolean isDelimiterA(char c) {
        return c == '\"';
    }

    public boolean isDelimiterB(char c) {
        return c == '\'';
    }

    public boolean isLineAStart(char c) {
        return c == '#';
    }

    public boolean isLineBStart(char c) {
        return false;
    }

    public boolean isLineStart(char c0, char c1) {
        return c0 == '/' && c1 == '/';
    }

    public boolean isMultilineStartDelimiter(char c0, char c1) {
        return c0 == '/' && c1 == '*';
    }

    public boolean isMultilineEndDelimiter(char c0, char c1) {
        return c0 == '*' && c1 == '/';
    }
}
