package com.myopicmobile.textwarrior.common;

import android.support.v4.view.MotionEventCompat;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes.dex */
public class Lexer {
    public static final int DOUBLE_SYMBOL_DELIMITED_MULTILINE = 40;
    public static final int DOUBLE_SYMBOL_LINE = 30;
    public static final int KEYWORD = 1;
    public static final int LITERAL = 4;
    private static final int MAX_KEYWORD_LENGTH = 127;
    public static final int NAME = 3;
    public static final int NORMAL = 0;
    public static final int OPERATOR = 2;
    public static final int SINGLE_SYMBOL_DELIMITED_A = 50;
    public static final int SINGLE_SYMBOL_DELIMITED_B = 51;
    public static final int SINGLE_SYMBOL_LINE_A = 20;
    public static final int SINGLE_SYMBOL_LINE_B = 21;
    public static final int SINGLE_SYMBOL_WORD = 10;
    public static final int UNKNOWN = -1;
    private static Language _globalLanguage = LanguageNonProg.getInstance();
    LexCallback _callback;
    private DocumentProvider _hDoc;
    private LexThread _workerThread = null;

    /* loaded from: classes.dex */
    public interface LexCallback {
        void lexDone(List<Pair> list);
    }

    public Lexer(LexCallback callback) {
        this._callback = null;
        this._callback = callback;
    }

    public static synchronized Language getLanguage() {
        Language language;
        synchronized (Lexer.class) {
            language = _globalLanguage;
        }
        return language;
    }

    public static synchronized void setLanguage(Language lang) {
        synchronized (Lexer.class) {
            _globalLanguage = lang;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.myopicmobile.textwarrior.common.Lexer$1  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes = new int[LuaTokenTypes.values().length];

        static {
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.TRUE.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.FALSE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.DO.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.FUNCTION.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.NOT.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.AND.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.OR.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.WITH.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.IF.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.THEN.ordinal()] = 10;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.ELSEIF.ordinal()] = 11;
            } catch (NoSuchFieldError e11) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.ELSE.ordinal()] = 12;
            } catch (NoSuchFieldError e12) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.WHILE.ordinal()] = 13;
            } catch (NoSuchFieldError e13) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.FOR.ordinal()] = 14;
            } catch (NoSuchFieldError e14) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.IN.ordinal()] = 15;
            } catch (NoSuchFieldError e15) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.RETURN.ordinal()] = 16;
            } catch (NoSuchFieldError e16) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.BREAK.ordinal()] = 17;
            } catch (NoSuchFieldError e17) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.CONTINUE.ordinal()] = 18;
            } catch (NoSuchFieldError e18) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LOCAL.ordinal()] = 19;
            } catch (NoSuchFieldError e19) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.REPEAT.ordinal()] = 20;
            } catch (NoSuchFieldError e20) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.UNTIL.ordinal()] = 21;
            } catch (NoSuchFieldError e21) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.END.ordinal()] = 22;
            } catch (NoSuchFieldError e22) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.NIL.ordinal()] = 23;
            } catch (NoSuchFieldError e23) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LPAREN.ordinal()] = 24;
            } catch (NoSuchFieldError e24) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.RPAREN.ordinal()] = 25;
            } catch (NoSuchFieldError e25) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LBRACK.ordinal()] = 26;
            } catch (NoSuchFieldError e26) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.RBRACK.ordinal()] = 27;
            } catch (NoSuchFieldError e27) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LCURLY.ordinal()] = 28;
            } catch (NoSuchFieldError e28) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.RCURLY.ordinal()] = 29;
            } catch (NoSuchFieldError e29) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.COMMA.ordinal()] = 30;
            } catch (NoSuchFieldError e30) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.DOT.ordinal()] = 31;
            } catch (NoSuchFieldError e31) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.STRING.ordinal()] = 32;
            } catch (NoSuchFieldError e32) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGSTRING.ordinal()] = 33;
            } catch (NoSuchFieldError e33) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.NL_BEFORE_LONGSTRING.ordinal()] = 34;
            } catch (NoSuchFieldError e34) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGSTRING_BEGIN.ordinal()] = 35;
            } catch (NoSuchFieldError e35) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGSTRING_END.ordinal()] = 36;
            } catch (NoSuchFieldError e36) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.UNTERMINATED_STRING.ordinal()] = 37;
            } catch (NoSuchFieldError e37) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.NAME.ordinal()] = 38;
            } catch (NoSuchFieldError e38) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.SHORTCOMMENT.ordinal()] = 39;
            } catch (NoSuchFieldError e39) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGCOMMENT.ordinal()] = 40;
            } catch (NoSuchFieldError e40) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGCOMMENT_BEGIN.ordinal()] = 41;
            } catch (NoSuchFieldError e41) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.LONGCOMMENT_END.ordinal()] = 42;
            } catch (NoSuchFieldError e42) {
            }
            try {
                $SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[LuaTokenTypes.NUMBER.ordinal()] = 43;
            } catch (NoSuchFieldError e43) {
            }
        }
    }

    private static boolean isKeyword(LuaTokenTypes t) {
        switch (AnonymousClass1.$SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[t.ordinal()]) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 11:
            case 12:
            case MotionEventCompat.AXIS_RY /* 13 */:
            case MotionEventCompat.AXIS_RZ /* 14 */:
            case 15:
            case 16:
            case MotionEventCompat.AXIS_LTRIGGER /* 17 */:
            case MotionEventCompat.AXIS_RTRIGGER /* 18 */:
            case 19:
            case 20:
            case 21:
            case MotionEventCompat.AXIS_GAS /* 22 */:
            case MotionEventCompat.AXIS_BRAKE /* 23 */:
                return true;
            default:
                return false;
        }
    }

    public void tokenize(DocumentProvider hDoc) {
        if (getLanguage().isProgLang()) {
            setDocument(new DocumentProvider(hDoc));
            if (this._workerThread == null) {
                this._workerThread = new LexThread(this);
                this._workerThread.start();
                return;
            }
            this._workerThread.restart();
        }
    }

    void tokenizeDone(List<Pair> result) {
        if (this._callback != null) {
            this._callback.lexDone(result);
        }
        this._workerThread = null;
    }

    public void cancelTokenize() {
        if (this._workerThread != null) {
            this._workerThread.abort();
            this._workerThread = null;
        }
    }

    public synchronized DocumentProvider getDocument() {
        return this._hDoc;
    }

    public synchronized void setDocument(DocumentProvider hDoc) {
        this._hDoc = hDoc;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class LexThread extends Thread {
        private final Lexer _lexManager;
        private ArrayList<Pair> _tokens;
        private boolean rescan = false;
        private int max = 16;
        private final Flag _abort = new Flag();

        public LexThread(Lexer p) {
            this._lexManager = p;
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            do {
                this.rescan = false;
                this._abort.clear();
                if (Lexer.getLanguage() instanceof LanguageLua) {
                    tokenize();
                } else {
                    tokenize2();
                }
            } while (this.rescan);
            if (!this._abort.isSet()) {
                this._lexManager.tokenizeDone(this._tokens);
            }
        }

        public void restart() {
            this.rescan = true;
            this._abort.set();
        }

        public void abort() {
            this._abort.set();
        }

        /* JADX WARN: Removed duplicated region for block: B:10:0x004e  */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        private void tokenize() {
            String lastName;
            Pair lastPair;
            int lastLen;
            StringBuilder bul;
            boolean isModule;
            DocumentProvider hDoc = Lexer.this.getDocument();
            int rowCount = hDoc.getRowCount();
            ArrayList<Pair> tokens = new ArrayList<>(8196);
            LuaLexer lexer = new LuaLexer(hDoc);
            Language language = Lexer.getLanguage();
            language.clearUserWord();
            int idx = 0;
            LuaTokenTypes lastType = null;
            LuaTokenTypes lastType2 = null;
            try {
                lastName = "";
                lastPair = null;
                lastLen = 0;
                bul = new StringBuilder();
                isModule = false;
            } catch (IOException e) {
                e.printStackTrace();
            }
            while (!this._abort.isSet()) {
                Pair pair = null;
                LuaTokenTypes type = lexer.advance();
                if (type != null) {
                    int len = lexer.yylength();
                    if (isModule && lastType == LuaTokenTypes.STRING && type != LuaTokenTypes.STRING) {
                        String mod = bul.toString();
                        if (bul.length() > 2) {
                            language.addUserWord(mod.substring(1, mod.length() - 1));
                        }
                        bul = new StringBuilder();
                        isModule = false;
                    }
                    if (lastType2 == type && lastPair != null) {
                        lastLen += len;
                        lastPair.setFirst(lastLen);
                    } else {
                        lastLen = len;
                        lastType2 = type;
                        switch (AnonymousClass1.$SwitchMap$com$myopicmobile$textwarrior$common$LuaTokenTypes[type.ordinal()]) {
                            case 1:
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                            case 6:
                            case 7:
                            case 8:
                            case 9:
                            case 10:
                            case 11:
                            case 12:
                            case MotionEventCompat.AXIS_RY /* 13 */:
                            case MotionEventCompat.AXIS_RZ /* 14 */:
                            case 15:
                            case 16:
                            case MotionEventCompat.AXIS_LTRIGGER /* 17 */:
                            case MotionEventCompat.AXIS_RTRIGGER /* 18 */:
                            case 19:
                            case 20:
                            case 21:
                            case MotionEventCompat.AXIS_GAS /* 22 */:
                            case MotionEventCompat.AXIS_BRAKE /* 23 */:
                                tokens.add(new Pair(len, 1));
                                break;
                            case MotionEventCompat.AXIS_DISTANCE /* 24 */:
                            case 25:
                            case 26:
                            case MotionEventCompat.AXIS_RELATIVE_X /* 27 */:
                            case MotionEventCompat.AXIS_RELATIVE_Y /* 28 */:
                            case 29:
                            case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
                            case 31:
                                pair = new Pair(len, 2);
                                tokens.add(pair);
                                break;
                            case 32:
                            case MotionEventCompat.AXIS_GENERIC_2 /* 33 */:
                            case MotionEventCompat.AXIS_GENERIC_3 /* 34 */:
                            case MotionEventCompat.AXIS_GENERIC_4 /* 35 */:
                            case MotionEventCompat.AXIS_GENERIC_5 /* 36 */:
                            case MotionEventCompat.AXIS_GENERIC_6 /* 37 */:
                                pair = new Pair(len, 50);
                                tokens.add(pair);
                                if (rowCount <= 9999) {
                                    if (lastName.equals("require")) {
                                        isModule = true;
                                    }
                                    if (isModule) {
                                        bul.append(lexer.yytext());
                                        break;
                                    }
                                }
                                break;
                            case MotionEventCompat.AXIS_GENERIC_7 /* 38 */:
                                if (rowCount > 9999) {
                                    tokens.add(new Pair(len, 0));
                                    break;
                                } else {
                                    String name = lexer.yytext();
                                    if (lastType == LuaTokenTypes.FUNCTION) {
                                        tokens.add(new Pair(len, 4));
                                        language.addUserWord(name);
                                    } else if (language.isUserWord(name)) {
                                        tokens.add(new Pair(len, 4));
                                    } else if (language.isBasePackage(name)) {
                                        tokens.add(new Pair(len, 3));
                                    } else if (lastType == LuaTokenTypes.DOT && language.isBasePackage(lastName) && language.isBaseWord(lastName, name)) {
                                        tokens.add(new Pair(len, 3));
                                    } else if (language.isName(name)) {
                                        tokens.add(new Pair(len, 3));
                                    } else {
                                        tokens.add(new Pair(len, 0));
                                    }
                                    if (lastType == LuaTokenTypes.ASSIGN && name.equals("require")) {
                                        language.addUserWord(lastName);
                                        if (tokens.size() >= 3) {
                                            Pair p = tokens.get(tokens.size() - 3);
                                            p.setSecond(3);
                                        }
                                    }
                                    lastName = name;
                                    break;
                                }
                                break;
                            case MotionEventCompat.AXIS_GENERIC_8 /* 39 */:
                            case 40:
                            case MotionEventCompat.AXIS_GENERIC_10 /* 41 */:
                            case MotionEventCompat.AXIS_GENERIC_11 /* 42 */:
                                pair = new Pair(len, 30);
                                tokens.add(pair);
                                break;
                            case MotionEventCompat.AXIS_GENERIC_12 /* 43 */:
                                tokens.add(new Pair(len, 4));
                                break;
                            default:
                                pair = new Pair(len, 0);
                                tokens.add(pair);
                                break;
                        }
                        if (type != LuaTokenTypes.WS && type != LuaTokenTypes.NL_BEFORE_LONGSTRING) {
                            lastType = type;
                        }
                        if (pair != null) {
                            lastPair = pair;
                        }
                        idx += len;
                    }
                } else {
                    if (tokens.isEmpty()) {
                        tokens.add(new Pair(0, 0));
                    }
                    language.updateUserWord();
                    this._tokens = tokens;
                }
            }
            if (tokens.isEmpty()) {
            }
            language.updateUserWord();
            this._tokens = tokens;
        }

        public void tokenize2() {
            int spanStartPosition;
            DocumentProvider hDoc = Lexer.this.getDocument();
            Language language = Lexer.getLanguage();
            ArrayList<Pair> tokens = new ArrayList<>();
            if (!language.isProgLang()) {
                tokens.add(new Pair(0, 0));
                this._tokens = tokens;
                return;
            }
            char[] candidateWord = new char[127];
            int currentCharInWord = 0;
            int workingPosition = 0;
            int state = -1;
            char prevChar = 0;
            hDoc.seekChar(0);
            while (hDoc.hasNext() && !this._abort.isSet()) {
                char currentChar = hDoc.next();
                switch (state) {
                    case -1:
                    case 0:
                    case 1:
                    case 3:
                    case 10:
                        int pendingState = state;
                        boolean stateChanged = false;
                        if (language.isLineStart(prevChar, currentChar)) {
                            pendingState = 30;
                            stateChanged = true;
                        } else if (language.isMultilineStartDelimiter(prevChar, currentChar)) {
                            pendingState = 40;
                            stateChanged = true;
                        } else if (language.isDelimiterA(currentChar)) {
                            pendingState = 50;
                            stateChanged = true;
                        } else if (language.isDelimiterB(currentChar)) {
                            pendingState = 51;
                            stateChanged = true;
                        } else if (language.isLineAStart(currentChar)) {
                            pendingState = 20;
                            stateChanged = true;
                        } else if (language.isLineBStart(currentChar)) {
                            pendingState = 21;
                            stateChanged = true;
                        }
                        if (stateChanged) {
                            if (pendingState == 30 || pendingState == 40) {
                                spanStartPosition = workingPosition - 1;
                                if (tokens.get(tokens.size() - 1).getFirst() == spanStartPosition) {
                                    tokens.remove(tokens.size() - 1);
                                }
                            } else {
                                spanStartPosition = workingPosition;
                            }
                            if (currentCharInWord > 0 && state != 0) {
                                tokens.add(new Pair(workingPosition - currentCharInWord, 0));
                            }
                            state = pendingState;
                            tokens.add(new Pair(spanStartPosition, state));
                            currentCharInWord = 0;
                            break;
                        } else if (language.isWhitespace(currentChar) || language.isOperator(currentChar)) {
                            if (currentCharInWord > 0) {
                                if (language.isWordStart(candidateWord[0])) {
                                    int spanStartPosition2 = workingPosition - currentCharInWord;
                                    state = 10;
                                    tokens.add(new Pair(spanStartPosition2, 10));
                                } else if (language.isKeyword(new String(candidateWord, 0, currentCharInWord))) {
                                    int spanStartPosition3 = workingPosition - currentCharInWord;
                                    state = 1;
                                    tokens.add(new Pair(spanStartPosition3, 1));
                                } else if (language.isName(new String(candidateWord, 0, currentCharInWord))) {
                                    int spanStartPosition4 = workingPosition - currentCharInWord;
                                    state = 3;
                                    tokens.add(new Pair(spanStartPosition4, 3));
                                } else if (state != 0) {
                                    int spanStartPosition5 = workingPosition - currentCharInWord;
                                    state = 0;
                                    tokens.add(new Pair(spanStartPosition5, 0));
                                }
                                currentCharInWord = 0;
                            }
                            if (state != 0 && language.isOperator(currentChar)) {
                                state = 0;
                                tokens.add(new Pair(workingPosition, 0));
                                break;
                            }
                        } else if (currentCharInWord >= 127) {
                            break;
                        } else {
                            candidateWord[currentCharInWord] = currentChar;
                            currentCharInWord++;
                            break;
                        }
                        break;
                    case 20:
                    case 21:
                    case Lexer.DOUBLE_SYMBOL_LINE /* 30 */:
                        if (language.isMultilineStartDelimiter(prevChar, currentChar)) {
                            state = 40;
                            break;
                        } else if (currentChar != '\n') {
                            break;
                        } else {
                            state = -1;
                            break;
                        }
                    case 40:
                        if (!language.isMultilineEndDelimiter(prevChar, currentChar)) {
                            break;
                        } else {
                            state = -1;
                            break;
                        }
                    case Lexer.SINGLE_SYMBOL_DELIMITED_A /* 50 */:
                        if ((language.isDelimiterA(currentChar) || currentChar == '\n') && !language.isEscapeChar(prevChar)) {
                            state = -1;
                            break;
                        } else if (language.isEscapeChar(currentChar) && language.isEscapeChar(prevChar)) {
                            currentChar = ' ';
                            break;
                        }
                        break;
                    case Lexer.SINGLE_SYMBOL_DELIMITED_B /* 51 */:
                        if ((language.isDelimiterB(currentChar) || currentChar == '\n') && !language.isEscapeChar(prevChar)) {
                            state = -1;
                            break;
                        } else if (language.isEscapeChar(currentChar) && language.isEscapeChar(prevChar)) {
                            currentChar = ' ';
                            break;
                        }
                        break;
                    default:
                        TextWarriorException.fail("Invalid state in TokenScanner");
                        break;
                }
                workingPosition++;
                prevChar = currentChar;
            }
            if (tokens.isEmpty()) {
                tokens.add(new Pair(0, 0));
            }
            this._tokens = tokens;
        }
    }
}
