package com.myopicmobile.textwarrior.common;
/* loaded from: classes.dex */
public class LinearSearchStrategy implements SearchStrategy {
    private int _unitsDone = 0;

    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    public int getProgress() {
        return this._unitsDone;
    }

    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    public int wrappedFind(DocumentProvider src, String target, int start, boolean isCaseSensitive, boolean isWholeWord) {
        int foundOffset = find(src, target, start, src.docLength(), isCaseSensitive, isWholeWord);
        if (foundOffset < 0) {
            return find(src, target, 0, start, isCaseSensitive, isWholeWord);
        }
        return foundOffset;
    }

    /* JADX WARN: Code restructure failed: missing block: B:27:?, code lost:
        return -1;
     */
    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public int find(DocumentProvider src, String target, int start, int end, boolean isCaseSensitive, boolean isWholeWord) {
        if (target.length() == 0) {
            return -1;
        }
        if (start < 0) {
            TextWarriorException.fail("TextBuffer.find: Invalid start position");
            start = 0;
        }
        if (end > src.docLength()) {
            TextWarriorException.fail("TextBuffer.find: Invalid end position");
            end = src.docLength();
        }
        int end2 = Math.min(end, (src.docLength() - target.length()) + 1);
        int offset = start;
        while (offset < end2 && (!equals(src, target, offset, isCaseSensitive) || (isWholeWord && !isSandwichedByWhitespace(src, offset, target.length())))) {
            offset++;
            this._unitsDone++;
        }
        return offset;
    }

    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    public int wrappedFindBackwards(DocumentProvider src, String target, int start, boolean isCaseSensitive, boolean isWholeWord) {
        int foundOffset = findBackwards(src, target, start, -1, isCaseSensitive, isWholeWord);
        if (foundOffset < 0) {
            return findBackwards(src, target, src.docLength() - 1, start, isCaseSensitive, isWholeWord);
        }
        return foundOffset;
    }

    /* JADX WARN: Code restructure failed: missing block: B:27:?, code lost:
        return -1;
     */
    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public int findBackwards(DocumentProvider src, String target, int start, int end, boolean isCaseSensitive, boolean isWholeWord) {
        if (target.length() == 0) {
            return -1;
        }
        if (start >= src.docLength()) {
            TextWarriorException.fail("Invalid start position given to TextBuffer.find");
            start = src.docLength() - 1;
        }
        if (end < -1) {
            TextWarriorException.fail("Invalid end position given to TextBuffer.find");
            end = -1;
        }
        int offset = Math.min(start, src.docLength() - target.length());
        while (offset > end && (!equals(src, target, offset, isCaseSensitive) || (isWholeWord && !isSandwichedByWhitespace(src, offset, target.length())))) {
            offset--;
        }
        return offset;
    }

    @Override // com.myopicmobile.textwarrior.common.SearchStrategy
    public Pair replaceAll(DocumentProvider src, String searchText, String replacementText, int mark, boolean isCaseSensitive, boolean isWholeWord) {
        int replacementCount = 0;
        int anchor = mark;
        this._unitsDone = 0;
        char[] replacement = replacementText.toCharArray();
        int foundIndex = find(src, searchText, 0, src.docLength(), isCaseSensitive, isWholeWord);
        long timestamp = System.nanoTime();
        src.beginBatchEdit();
        while (foundIndex != -1) {
            src.deleteAt(foundIndex, searchText.length(), timestamp);
            src.insertBefore(replacement, foundIndex, timestamp);
            if (foundIndex < anchor) {
                anchor += replacementText.length() - searchText.length();
            }
            replacementCount++;
            this._unitsDone += searchText.length();
            foundIndex = find(src, searchText, foundIndex + replacementText.length(), src.docLength(), isCaseSensitive, isWholeWord);
        }
        src.endBatchEdit();
        return new Pair(replacementCount, Math.max(anchor, 0));
    }

    protected boolean equals(DocumentProvider src, String target, int srcOffset, boolean isCaseSensitive) {
        if (src.docLength() - srcOffset < target.length()) {
            return false;
        }
        for (int i = 0; i < target.length(); i++) {
            if (isCaseSensitive && target.charAt(i) != src.charAt(i + srcOffset)) {
                return false;
            }
            if (!isCaseSensitive && Character.toLowerCase(target.charAt(i)) != Character.toLowerCase(src.charAt(i + srcOffset))) {
                return false;
            }
        }
        return true;
    }

    protected boolean isSandwichedByWhitespace(DocumentProvider src, int start, int length) {
        Language charSet = Lexer.getLanguage();
        boolean startWithWhitespace = start == 0 ? true : charSet.isWhitespace(src.charAt(start - 1));
        int end = start + length;
        boolean endWithWhitespace = end == src.docLength() ? true : charSet.isWhitespace(src.charAt(end));
        return startWithWhitespace && endWithWhitespace;
    }
}
