package com.myopicmobile.textwarrior.common;
/* loaded from: classes.dex */
public class TextBufferCache {
    private static final int CACHE_SIZE = 4;
    private Pair[] _cache = new Pair[4];

    public TextBufferCache() {
        this._cache[0] = new Pair(0, 0);
        for (int i = 1; i < 4; i++) {
            this._cache[i] = new Pair(-1, -1);
        }
    }

    public Pair getNearestLine(int lineIndex) {
        int nearestMatch = 0;
        int nearestDistance = Integer.MAX_VALUE;
        for (int i = 0; i < 4; i++) {
            int distance = Math.abs(lineIndex - this._cache[i].getFirst());
            if (distance < nearestDistance) {
                nearestDistance = distance;
                nearestMatch = i;
            }
        }
        Pair nearestEntry = this._cache[nearestMatch];
        makeHead(nearestMatch);
        return nearestEntry;
    }

    public Pair getNearestCharOffset(int charOffset) {
        int nearestMatch = 0;
        int nearestDistance = Integer.MAX_VALUE;
        for (int i = 0; i < 4; i++) {
            int distance = Math.abs(charOffset - this._cache[i].getSecond());
            if (distance < nearestDistance) {
                nearestDistance = distance;
                nearestMatch = i;
            }
        }
        Pair nearestEntry = this._cache[nearestMatch];
        makeHead(nearestMatch);
        return nearestEntry;
    }

    private void makeHead(int newHead) {
        if (newHead != 0) {
            Pair temp = this._cache[newHead];
            for (int i = newHead; i > 1; i--) {
                this._cache[i] = this._cache[i - 1];
            }
            this._cache[1] = temp;
        }
    }

    public void updateEntry(int lineIndex, int charOffset) {
        if (lineIndex > 0 && !replaceEntry(lineIndex, charOffset)) {
            insertEntry(lineIndex, charOffset);
        }
    }

    private boolean replaceEntry(int lineIndex, int charOffset) {
        for (int i = 1; i < 4; i++) {
            if (this._cache[i].getFirst() == lineIndex) {
                this._cache[i].setSecond(charOffset);
                return true;
            }
        }
        return false;
    }

    private void insertEntry(int lineIndex, int charOffset) {
        makeHead(3);
        this._cache[1] = new Pair(lineIndex, charOffset);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void invalidateCache(int fromCharOffset) {
        for (int i = 1; i < 4; i++) {
            if (this._cache[i].getSecond() >= fromCharOffset) {
                this._cache[i] = new Pair(-1, -1);
            }
        }
    }
}
