package com.pixplicity.sharp;

import android.annotation.TargetApi;
import android.content.res.AssetManager;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Picture;
import android.graphics.RadialGradient;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.Typeface;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Looper;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v4.internal.view.SupportMenu;
import android.support.v4.view.MotionEventCompat;
import android.text.TextPaint;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import com.myopicmobile.textwarrior.common.Lexer;
import com.tencent.smtt.sdk.TbsListener;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Scanner;
import java.util.Stack;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.zip.GZIPInputStream;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
/* loaded from: classes.dex */
public abstract class Sharp {
    private static String sAssumedUnit;
    private AssetManager mAssetManager;
    private OnSvgElementListener mOnElementListener;
    private final SvgHandler mSvgHandler;
    static final String TAG = Sharp.class.getSimpleName();
    private static HashMap<String, String> sTextDynamic = null;
    private static final RectF arcRectf = new RectF();
    private static final Matrix arcMatrix = new Matrix();
    private static final Matrix arcMatrix2 = new Matrix();

    /* loaded from: classes.dex */
    public interface DrawableCallback {
        void onDrawableReady(SharpDrawable sharpDrawable);
    }

    /* loaded from: classes.dex */
    public interface PictureCallback {
        void onPictureReady(SharpPicture sharpPicture);
    }

    protected abstract void close(InputStream inputStream) throws IOException;

    protected abstract InputStream getInputStream() throws IOException;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public enum Unit {
        PERCENT("%"),
        PT("pt"),
        PX("px"),
        MM("mm", 100.0f);
        
        public final String mAbbreviation;
        public final float mScaleFactor;

        Unit(String abbreviation) {
            this(abbreviation, 1.0f);
        }

        Unit(String abbreviation, float scaleFactor) {
            this.mAbbreviation = abbreviation;
            this.mScaleFactor = scaleFactor;
        }

        public static Unit matches(String value) {
            Unit[] values;
            for (Unit unit : values()) {
                if (value.endsWith(unit.mAbbreviation)) {
                    return unit;
                }
            }
            return null;
        }
    }

    public static void prepareTexts(HashMap<String, String> texts) {
        sTextDynamic = texts;
    }

    public static Sharp loadInputStream(final InputStream svgData) {
        return new Sharp() { // from class: com.pixplicity.sharp.Sharp.1
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super();
            }

            @Override // com.pixplicity.sharp.Sharp
            protected InputStream getInputStream() {
                return svgData;
            }

            @Override // com.pixplicity.sharp.Sharp
            protected void close(InputStream inputStream) {
            }
        };
    }

    public static Sharp loadString(final String svgData) {
        return new Sharp() { // from class: com.pixplicity.sharp.Sharp.2
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super();
            }

            @Override // com.pixplicity.sharp.Sharp
            protected InputStream getInputStream() {
                return new ByteArrayInputStream(svgData.getBytes());
            }

            @Override // com.pixplicity.sharp.Sharp
            protected void close(InputStream inputStream) {
            }
        };
    }

    public static Sharp loadResource(final Resources resources, final int resId) {
        return new Sharp() { // from class: com.pixplicity.sharp.Sharp.3
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super();
            }

            @Override // com.pixplicity.sharp.Sharp
            protected InputStream getInputStream() {
                InputStream inputStream = resources.openRawResource(resId);
                if (Looper.myLooper() != Looper.getMainLooper()) {
                    return Sharp.readInputStream(inputStream);
                }
                return inputStream;
            }

            @Override // com.pixplicity.sharp.Sharp
            protected void close(InputStream inputStream) {
            }
        };
    }

    public static Sharp loadAsset(final AssetManager assetMngr, final String svgPath) {
        return new Sharp() { // from class: com.pixplicity.sharp.Sharp.4
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super();
            }

            @Override // com.pixplicity.sharp.Sharp
            protected InputStream getInputStream() throws IOException {
                InputStream inputStream = assetMngr.open(svgPath);
                if (Looper.myLooper() != Looper.getMainLooper()) {
                    return Sharp.readInputStream(inputStream);
                }
                return inputStream;
            }

            @Override // com.pixplicity.sharp.Sharp
            protected void close(InputStream inputStream) throws IOException {
                inputStream.close();
            }
        };
    }

    public static Sharp loadFile(final File imageFile) {
        return new Sharp() { // from class: com.pixplicity.sharp.Sharp.5
            private FileInputStream mFis;

            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super();
            }

            @Override // com.pixplicity.sharp.Sharp
            protected InputStream getInputStream() throws FileNotFoundException {
                this.mFis = new FileInputStream(imageFile);
                return this.mFis;
            }

            @Override // com.pixplicity.sharp.Sharp
            protected void close(InputStream inputStream) throws IOException {
                inputStream.close();
                this.mFis.close();
            }
        };
    }

    public static Path loadPath(String pathString) {
        return doPath(pathString);
    }

    /* JADX INFO: Access modifiers changed from: private */
    @NonNull
    public static InputStream readInputStream(InputStream inputStream) {
        StringBuilder svgData = new StringBuilder();
        Scanner scanner = new Scanner(inputStream);
        String lineSeparator = System.getProperty("line.separator");
        while (scanner.hasNextLine()) {
            try {
                svgData.append(scanner.nextLine()).append(lineSeparator);
            } catch (Throwable th) {
                scanner.close();
                throw th;
            }
        }
        scanner.close();
        InputStream inputStream2 = new ByteArrayInputStream(svgData.toString().getBytes());
        return inputStream2;
    }

    private Sharp() {
        sAssumedUnit = null;
        this.mSvgHandler = new SvgHandler();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public AssetManager getAssetManager() {
        return this.mAssetManager;
    }

    public Sharp setOnElementListener(OnSvgElementListener onElementListener) {
        this.mOnElementListener = onElementListener;
        return this;
    }

    public Sharp withAssets(AssetManager assetManager) {
        this.mAssetManager = assetManager;
        return this;
    }

    public void into(@NonNull final View view) {
        SharpDrawable.prepareView(view);
        if (view instanceof ImageView) {
            final SharpDrawable drawable = getDrawable();
            if (Looper.myLooper() == Looper.getMainLooper()) {
                ((ImageView) view).setImageDrawable(drawable);
                return;
            } else {
                view.post(new Runnable() { // from class: com.pixplicity.sharp.Sharp.6
                    @Override // java.lang.Runnable
                    public void run() {
                        ((ImageView) view).setImageDrawable(drawable);
                    }
                });
                return;
            }
        }
        intoBackground(view);
    }

    @TargetApi(16)
    private void intoBackground(final View view) {
        final SharpDrawable drawable = getDrawable(view);
        if (Looper.myLooper() == Looper.getMainLooper()) {
            if (Build.VERSION.SDK_INT < 16) {
                view.setBackgroundDrawable(drawable);
                return;
            } else {
                view.setBackground(drawable);
                return;
            }
        }
        view.post(new Runnable() { // from class: com.pixplicity.sharp.Sharp.7
            @Override // java.lang.Runnable
            public void run() {
                if (Build.VERSION.SDK_INT < 16) {
                    view.setBackgroundDrawable(drawable);
                } else {
                    view.setBackground(drawable);
                }
            }
        });
    }

    public SharpDrawable getDrawable() {
        return getSharpPicture().getDrawable();
    }

    @Deprecated
    public SharpDrawable getDrawable(View view) {
        return getSharpPicture().getDrawable(view);
    }

    public void getDrawable(final View view, final DrawableCallback callback) {
        getSharpPicture(new PictureCallback() { // from class: com.pixplicity.sharp.Sharp.8
            @Override // com.pixplicity.sharp.Sharp.PictureCallback
            public void onPictureReady(SharpPicture sharpPicture) {
                SharpDrawable drawable = sharpPicture.getDrawable(view);
                callback.onDrawableReady(drawable);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public SharpPicture getSharpPicture(InputStream inputStream) throws SvgParseException {
        if (inputStream == null) {
            throw new NullPointerException("An InputStream must be provided");
        }
        try {
            this.mSvgHandler.read(inputStream);
            try {
                close(inputStream);
                SharpPicture result = new SharpPicture(this.mSvgHandler.mPicture, this.mSvgHandler.mBounds);
                if (!Float.isInfinite(this.mSvgHandler.mLimits.top)) {
                    result.setLimits(this.mSvgHandler.mLimits);
                }
                return result;
            } catch (IOException e) {
                throw new SvgParseException(e);
            }
        } catch (Throwable th) {
            try {
                close(inputStream);
                throw th;
            } catch (IOException e2) {
                throw new SvgParseException(e2);
            }
        }
    }

    public SharpPicture getSharpPicture() throws SvgParseException {
        InputStream inputStream = null;
        try {
            try {
                inputStream = getInputStream();
                SharpPicture sharpPicture = getSharpPicture(inputStream);
                if (inputStream != null) {
                    try {
                        close(inputStream);
                    } catch (IOException e) {
                        throw new SvgParseException(e);
                    }
                }
                return sharpPicture;
            } catch (IOException e2) {
                throw new SvgParseException(e2);
            }
        } catch (Throwable th) {
            if (inputStream != null) {
                try {
                    close(inputStream);
                } catch (IOException e3) {
                    throw new SvgParseException(e3);
                }
            }
            throw th;
        }
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [com.pixplicity.sharp.Sharp$9] */
    public void getSharpPicture(final PictureCallback callback) {
        new AsyncTask<Void, Void, SharpPicture>() { // from class: com.pixplicity.sharp.Sharp.9
            /* JADX INFO: Access modifiers changed from: protected */
            @Override // android.os.AsyncTask
            public SharpPicture doInBackground(Void... params) {
                InputStream inputStream = null;
                try {
                    try {
                        inputStream = Sharp.this.getInputStream();
                        SharpPicture sharpPicture = Sharp.this.getSharpPicture(inputStream);
                        if (inputStream != null) {
                            try {
                                Sharp.this.close(inputStream);
                            } catch (IOException e) {
                                throw new SvgParseException(e);
                            }
                        }
                        return sharpPicture;
                    } catch (Throwable th) {
                        if (inputStream != null) {
                            try {
                                Sharp.this.close(inputStream);
                            } catch (IOException e2) {
                                throw new SvgParseException(e2);
                            }
                        }
                        throw th;
                    }
                } catch (IOException e3) {
                    throw new SvgParseException(e3);
                }
            }

            /* JADX INFO: Access modifiers changed from: protected */
            @Override // android.os.AsyncTask
            public void onPostExecute(SharpPicture sharpPicture) {
                callback.onPictureReady(sharpPicture);
            }
        }.execute(new Void[0]);
    }

    private static ArrayList<Float> parseNumbers(String s) {
        int n = s.length();
        int p = 0;
        ArrayList<Float> numbers = new ArrayList<>();
        boolean skipChar = false;
        int i = 1;
        while (true) {
            if (i < n) {
                if (skipChar) {
                    skipChar = false;
                } else {
                    char c = s.charAt(i);
                    switch (c) {
                        case '\t':
                        case '\n':
                        case ' ':
                        case MotionEventCompat.AXIS_GENERIC_13 /* 44 */:
                        case MotionEventCompat.AXIS_GENERIC_14 /* 45 */:
                            String str = s.substring(p, i);
                            if (str.trim().length() > 0) {
                                Float f = Float.valueOf(Float.parseFloat(str));
                                numbers.add(f);
                                if (c == '-') {
                                    p = i;
                                    continue;
                                } else {
                                    p = i + 1;
                                    skipChar = true;
                                    break;
                                }
                            } else {
                                p++;
                                break;
                            }
                        case MotionEventCompat.AXIS_GENERIC_10 /* 41 */:
                        case 'A':
                        case 'C':
                        case 'H':
                        case 'L':
                        case 'M':
                        case 'Q':
                        case 'S':
                        case 'T':
                        case 'V':
                        case 'Z':
                        case 'a':
                        case 'c':
                        case 'h':
                        case TbsListener.ErrorCode.VERIFY_ERROR /* 108 */:
                        case TbsListener.ErrorCode.FILE_RENAME_ERROR /* 109 */:
                        case TbsListener.ErrorCode.DOWNLOAD_FILE_CONTENTLENGTH_NOT_MATCH /* 113 */:
                        case 's':
                        case 't':
                        case 'v':
                        case TbsListener.ErrorCode.DOWNLOAD_HAS_COPY_TBS_ERROR /* 122 */:
                            String str2 = s.substring(p, i);
                            if (str2.trim().length() > 0) {
                                Float f2 = Float.valueOf(Float.parseFloat(str2));
                                numbers.add(f2);
                                break;
                            }
                            break;
                        case 'E':
                        case 'e':
                            skipChar = true;
                            continue;
                    }
                }
                i++;
            } else {
                String last = s.substring(p);
                if (last.length() > 0) {
                    try {
                        numbers.add(Float.valueOf(Float.parseFloat(last)));
                    } catch (NumberFormatException e) {
                    }
                }
            }
        }
        return numbers;
    }

    private static ArrayList<Float> readTransform(String attr, String type) {
        int i;
        int j;
        int i2 = attr.indexOf(type + "(");
        if (i2 > -1 && (j = attr.indexOf(")", (i = i2 + type.length() + 1))) > -1) {
            ArrayList<Float> np = parseNumbers(attr.substring(i, j));
            if (np.size() > 0) {
                return np;
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    @Nullable
    public static Matrix parseTransform(String s) {
        Matrix matrix = null;
        if (s.startsWith("matrix(")) {
            ArrayList<Float> np = parseNumbers(s.substring("matrix(".length()));
            if (np.size() == 6) {
                if (0 == 0) {
                    matrix = new Matrix();
                }
                matrix.setValues(new float[]{np.get(0).floatValue(), np.get(2).floatValue(), np.get(4).floatValue(), np.get(1).floatValue(), np.get(3).floatValue(), np.get(5).floatValue(), 0.0f, 0.0f, 1.0f});
            }
        }
        ArrayList<Float> np2 = readTransform(s, "scale");
        if (np2 != null) {
            float sx = np2.get(0).floatValue();
            float sy = sx;
            if (np2.size() > 1) {
                sy = np2.get(1).floatValue();
            }
            if (matrix == null) {
                matrix = new Matrix();
            }
            matrix.postScale(sx, sy);
        }
        ArrayList<Float> np3 = readTransform(s, "skewX");
        if (np3 != null) {
            float angle = np3.get(0).floatValue();
            if (matrix == null) {
                matrix = new Matrix();
            }
            matrix.preSkew((float) Math.tan(angle), 0.0f);
        }
        ArrayList<Float> np4 = readTransform(s, "skewY");
        if (np4 != null) {
            float angle2 = np4.get(0).floatValue();
            if (matrix == null) {
                matrix = new Matrix();
            }
            matrix.preSkew(0.0f, (float) Math.tan(angle2));
        }
        ArrayList<Float> np5 = readTransform(s, "rotate");
        if (np5 != null) {
            float angle3 = np5.get(0).floatValue();
            if (matrix == null) {
                matrix = new Matrix();
            }
            if (np5.size() > 2) {
                float cx = np5.get(1).floatValue();
                float cy = np5.get(2).floatValue();
                matrix.preRotate(angle3, cx, cy);
            } else {
                matrix.preRotate(angle3);
            }
        }
        ArrayList<Float> np6 = readTransform(s, "translate");
        if (np6 != null) {
            float tx = np6.get(0).floatValue();
            float ty = 0.0f;
            if (np6.size() > 1) {
                ty = np6.get(1).floatValue();
            }
            if (matrix == null) {
                matrix = new Matrix();
            }
            matrix.postTranslate(tx, ty);
        }
        return matrix;
    }

    /* JADX INFO: Access modifiers changed from: private */
    @NonNull
    public static Path doPath(@NonNull String s) {
        int n = s.length();
        SvgParserHelper ph = new SvgParserHelper(s, 0);
        ph.skipWhitespace();
        Path p = new Path();
        float lastX = 0.0f;
        float lastY = 0.0f;
        float lastX1 = 0.0f;
        float lastY1 = 0.0f;
        float subPathStartX = 0.0f;
        float subPathStartY = 0.0f;
        char prevCmd = 0;
        while (ph.pos < n) {
            char cmd = s.charAt(ph.pos);
            switch (cmd) {
                case MotionEventCompat.AXIS_GENERIC_12 /* 43 */:
                case MotionEventCompat.AXIS_GENERIC_14 /* 45 */:
                case '0':
                case '1':
                case Lexer.SINGLE_SYMBOL_DELIMITED_A /* 50 */:
                case Lexer.SINGLE_SYMBOL_DELIMITED_B /* 51 */:
                case '4':
                case '5':
                case '6':
                case '7':
                case '8':
                case '9':
                    if (prevCmd == 'm' || prevCmd == 'M') {
                        cmd = (char) (prevCmd - 1);
                        break;
                    } else if ("lhvcsqta".indexOf(Character.toLowerCase(prevCmd)) >= 0) {
                        cmd = prevCmd;
                        break;
                    }
                    break;
                case MotionEventCompat.AXIS_GENERIC_13 /* 44 */:
                case MotionEventCompat.AXIS_GENERIC_15 /* 46 */:
                case MotionEventCompat.AXIS_GENERIC_16 /* 47 */:
                default:
                    ph.advance();
                    prevCmd = cmd;
                    break;
            }
            boolean wasCurve = false;
            switch (cmd) {
                case 'A':
                case 'a':
                    float rx = ph.nextFloat();
                    float ry = ph.nextFloat();
                    float theta = ph.nextFloat();
                    int largeArc = ph.nextFlag();
                    int sweepArc = ph.nextFlag();
                    float x = ph.nextFloat();
                    float y = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        x += lastX;
                        y += lastY;
                    }
                    drawArc(p, lastX, lastY, x, y, rx, ry, theta, largeArc, sweepArc);
                    lastX = x;
                    lastY = y;
                    break;
                case 'C':
                case 'c':
                    wasCurve = true;
                    float x1 = ph.nextFloat();
                    float y1 = ph.nextFloat();
                    float x2 = ph.nextFloat();
                    float y2 = ph.nextFloat();
                    float x3 = ph.nextFloat();
                    float y3 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        x1 += lastX;
                        x2 += lastX;
                        x3 += lastX;
                        y1 += lastY;
                        y2 += lastY;
                        y3 += lastY;
                    }
                    p.cubicTo(x1, y1, x2, y2, x3, y3);
                    lastX1 = x2;
                    lastY1 = y2;
                    lastX = x3;
                    lastY = y3;
                    break;
                case 'H':
                case 'h':
                    float x4 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        p.rLineTo(x4, 0.0f);
                        lastX += x4;
                        break;
                    } else {
                        p.lineTo(x4, lastY);
                        lastX = x4;
                        break;
                    }
                case 'L':
                case TbsListener.ErrorCode.VERIFY_ERROR /* 108 */:
                    float x5 = ph.nextFloat();
                    float y4 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        p.rLineTo(x5, y4);
                        lastX += x5;
                        lastY += y4;
                        break;
                    } else {
                        p.lineTo(x5, y4);
                        lastX = x5;
                        lastY = y4;
                        break;
                    }
                case 'M':
                case TbsListener.ErrorCode.FILE_RENAME_ERROR /* 109 */:
                    float x6 = ph.nextFloat();
                    float y5 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        subPathStartX += x6;
                        subPathStartY += y5;
                        p.rMoveTo(x6, y5);
                        lastX += x6;
                        lastY += y5;
                        break;
                    } else {
                        subPathStartX = x6;
                        subPathStartY = y5;
                        p.moveTo(x6, y5);
                        lastX = x6;
                        lastY = y5;
                        break;
                    }
                case 'Q':
                case TbsListener.ErrorCode.DOWNLOAD_FILE_CONTENTLENGTH_NOT_MATCH /* 113 */:
                    wasCurve = true;
                    float x12 = ph.nextFloat();
                    float y12 = ph.nextFloat();
                    float x7 = ph.nextFloat();
                    float y6 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        x12 += lastX;
                        x7 += lastX;
                        y12 += lastY;
                        y6 += lastY;
                    }
                    p.quadTo(x12, y12, x7, y6);
                    lastX1 = x12;
                    lastY1 = y12;
                    lastX = x7;
                    lastY = y6;
                    break;
                case 'S':
                case 's':
                    wasCurve = true;
                    float x22 = ph.nextFloat();
                    float y22 = ph.nextFloat();
                    float x8 = ph.nextFloat();
                    float y7 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        x22 += lastX;
                        x8 += lastX;
                        y22 += lastY;
                        y7 += lastY;
                    }
                    p.cubicTo((2.0f * lastX) - lastX1, (2.0f * lastY) - lastY1, x22, y22, x8, y7);
                    lastX1 = x22;
                    lastY1 = y22;
                    lastX = x8;
                    lastY = y7;
                    break;
                case 'T':
                case 't':
                    wasCurve = true;
                    float x9 = ph.nextFloat();
                    float y8 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        x9 += lastX;
                        y8 += lastY;
                    }
                    float x13 = (2.0f * lastX) - lastX1;
                    float y13 = (2.0f * lastY) - lastY1;
                    p.quadTo(x13, y13, x9, y8);
                    lastX1 = x13;
                    lastY1 = y13;
                    lastX = x9;
                    lastY = y8;
                    break;
                case 'V':
                case 'v':
                    float y9 = ph.nextFloat();
                    if (Character.isLowerCase(cmd)) {
                        p.rLineTo(0.0f, y9);
                        lastY += y9;
                        break;
                    } else {
                        p.lineTo(lastX, y9);
                        lastY = y9;
                        break;
                    }
                case 'Z':
                case TbsListener.ErrorCode.DOWNLOAD_HAS_COPY_TBS_ERROR /* 122 */:
                    p.close();
                    p.moveTo(subPathStartX, subPathStartY);
                    lastX = subPathStartX;
                    lastY = subPathStartY;
                    lastX1 = subPathStartX;
                    lastY1 = subPathStartY;
                    wasCurve = true;
                    break;
            }
            if (!wasCurve) {
                lastX1 = lastX;
                lastY1 = lastY;
            }
            ph.skipWhitespace();
        }
        return p;
    }

    private static float angle(float y1, float x1, float y2, float x2) {
        return ((float) Math.toDegrees(Math.atan2(y1, x1) - Math.atan2(y2, x2))) % 360.0f;
    }

    private static void drawArc(Path p, float lastX, float lastY, float x, float y, float rx, float ry, float theta, int largeArc, int sweepArc) {
        if (rx == 0.0f || ry == 0.0f) {
            p.lineTo(x, y);
        } else if (x != lastX || y != lastY) {
            float rx2 = Math.abs(rx);
            float ry2 = Math.abs(ry);
            float thrad = (3.1415927f * theta) / 180.0f;
            float st = (float) Math.sin(thrad);
            float ct = (float) Math.cos(thrad);
            float xc = (lastX - x) / 2.0f;
            float yc = (lastY - y) / 2.0f;
            float x1t = (ct * xc) + (st * yc);
            float y1t = ((-st) * xc) + (ct * yc);
            float x1ts = x1t * x1t;
            float y1ts = y1t * y1t;
            float rxs = rx2 * rx2;
            float rys = ry2 * ry2;
            float lambda = ((x1ts / rxs) + (y1ts / rys)) * 1.001f;
            if (lambda > 1.0f) {
                float lambdasr = (float) Math.sqrt(lambda);
                rx2 *= lambdasr;
                ry2 *= lambdasr;
                rxs = rx2 * rx2;
                rys = ry2 * ry2;
            }
            float R = ((float) Math.sqrt((((rxs * rys) - (rxs * y1ts)) - (rys * x1ts)) / ((rxs * y1ts) + (rys * x1ts)))) * (largeArc == sweepArc ? -1 : 1);
            float cxt = ((R * rx2) * y1t) / ry2;
            float cyt = (((-R) * ry2) * x1t) / rx2;
            float cx = ((ct * cxt) - (st * cyt)) + ((lastX + x) / 2.0f);
            float cy = (st * cxt) + (ct * cyt) + ((lastY + y) / 2.0f);
            float th1 = angle(1.0f, 0.0f, (x1t - cxt) / rx2, (y1t - cyt) / ry2);
            float dth = angle((x1t - cxt) / rx2, (y1t - cyt) / ry2, ((-x1t) - cxt) / rx2, ((-y1t) - cyt) / ry2);
            if (sweepArc == 0 && dth > 0.0f) {
                dth -= 360.0f;
            } else if (sweepArc != 0 && dth < 0.0f) {
                dth += 360.0f;
            }
            if (theta % 360.0f == 0.0f) {
                arcRectf.set(cx - rx2, cy - ry2, cx + rx2, cy + ry2);
                p.arcTo(arcRectf, th1, dth);
                return;
            }
            arcRectf.set(-rx2, -ry2, rx2, ry2);
            arcMatrix.reset();
            arcMatrix.postRotate(theta);
            arcMatrix.postTranslate(cx, cy);
            arcMatrix.invert(arcMatrix2);
            p.transform(arcMatrix2);
            p.arcTo(arcRectf, th1, dth);
            p.transform(arcMatrix);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static ArrayList<Float> getNumberParseAttr(String name, Attributes attributes) {
        int n = attributes.getLength();
        for (int i = 0; i < n; i++) {
            if (attributes.getLocalName(i).equals(name)) {
                return parseNumbers(attributes.getValue(i));
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static String getStringAttr(String name, Attributes attributes) {
        int n = attributes.getLength();
        for (int i = 0; i < n; i++) {
            if (attributes.getLocalName(i).equals(name)) {
                return attributes.getValue(i);
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static Float getFloatAttr(String name, Attributes attributes) {
        return getFloatAttr(name, attributes, null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static Float getFloatAttr(String name, Attributes attributes, Float defaultValue) {
        String value = getStringAttr(name, attributes);
        return parseFloat(value, defaultValue);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static Float parseFloat(String value, Float defaultValue) {
        if (value != null) {
            float scaleFactor = 1.0f;
            Unit unit = Unit.matches(value);
            if (unit != null) {
                value = value.substring(0, value.length() - unit.mAbbreviation.length());
            }
            float valueF = Float.parseFloat(value);
            if (unit != null) {
                switch (unit) {
                    case PT:
                        valueF += 0.5f;
                        break;
                    case PERCENT:
                        valueF /= 100.0f;
                        break;
                }
                checkAssumedUnits(unit.mAbbreviation);
                scaleFactor = unit.mScaleFactor;
            }
            Float defaultValue2 = Float.valueOf(valueF * scaleFactor);
            return defaultValue2;
        }
        return defaultValue;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void onSvgStart(@NonNull Canvas canvas, @Nullable RectF bounds) {
        if (this.mOnElementListener != null) {
            this.mOnElementListener.onSvgStart(canvas, bounds);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void onSvgEnd(@NonNull Canvas canvas, @Nullable RectF bounds) {
        if (this.mOnElementListener != null) {
            this.mOnElementListener.onSvgEnd(canvas, bounds);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public <T> T onSvgElement(@Nullable String id, @NonNull T element, @Nullable RectF elementBounds, @NonNull Canvas canvas, @Nullable RectF canvasBounds, @Nullable Paint paint) {
        if (this.mOnElementListener != null) {
            return (T) this.mOnElementListener.onSvgElement(id, element, elementBounds, canvas, canvasBounds, paint);
        }
        return element;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public <T> void onSvgElementDrawn(@Nullable String id, @NonNull T element, @NonNull Canvas canvas, @Nullable Paint paint) {
        if (this.mOnElementListener != null) {
            this.mOnElementListener.onSvgElementDrawn(id, element, canvas, paint);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class Gradient {
        public boolean mBoundingBox;
        private ArrayList<Integer> mColors;
        private String mId;
        private boolean mIsLinear;
        private Matrix mMatrix;
        private ArrayList<Float> mPositions;
        private float mRadius;
        public Shader mShader;
        public Shader.TileMode mTileMode;
        private float mX;
        private float mX1;
        private float mX2;
        private String mXlink;
        private float mY;
        private float mY1;
        private float mY2;

        private Gradient() {
            this.mPositions = new ArrayList<>();
            this.mColors = new ArrayList<>();
            this.mMatrix = null;
            this.mShader = null;
            this.mBoundingBox = false;
        }

        public void inherit(Gradient parent) {
            this.mXlink = parent.mId;
            this.mPositions = parent.mPositions;
            this.mColors = parent.mColors;
            if (this.mMatrix == null) {
                this.mMatrix = parent.mMatrix;
            } else if (parent.mMatrix != null) {
                Matrix m = new Matrix(parent.mMatrix);
                m.preConcat(this.mMatrix);
                this.mMatrix = m;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class StyleSet {
        HashMap<String, String> styleMap;

        private StyleSet(String string) {
            this.styleMap = new HashMap<>();
            String[] styles = string.split(";");
            for (String s : styles) {
                String[] style = s.split(":");
                if (style.length == 2) {
                    this.styleMap.put(style[0], style[1]);
                }
            }
        }

        public String getStyle(String name) {
            return this.styleMap.get(name);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class Properties {
        Attributes mAttrs;
        StyleSet mStyles;

        private Properties(Attributes attrs) {
            this.mStyles = null;
            this.mAttrs = attrs;
            String styleAttr = Sharp.getStringAttr("style", attrs);
            if (styleAttr != null) {
                this.mStyles = new StyleSet(styleAttr);
            }
        }

        public String getAttr(String name) {
            String v = null;
            if (this.mStyles != null) {
                v = this.mStyles.getStyle(name);
            }
            if (v == null) {
                String v2 = Sharp.getStringAttr(name, this.mAttrs);
                return v2;
            }
            return v;
        }

        public String getString(String name) {
            return getAttr(name);
        }

        private Integer rgb(int r, int g, int b) {
            return Integer.valueOf(((r & 255) << 16) | ((g & 255) << 8) | (b & 255));
        }

        private int parseNum(String v) throws NumberFormatException {
            return v.endsWith("%") ? Math.round((Float.parseFloat(v.substring(0, v.length() - 1)) / 100.0f) * 255.0f) : Integer.parseInt(v);
        }

        public Integer getColor(String name) {
            String v = getAttr(name);
            if (v == null) {
                return null;
            }
            if (v.startsWith("#")) {
                try {
                    int c = Integer.parseInt(v.substring(1), 16);
                    if (v.length() == 4) {
                        c = hex3Tohex6(c);
                    }
                    return Integer.valueOf(c);
                } catch (NumberFormatException e) {
                    return null;
                }
            } else if (v.startsWith("rgb(") && v.endsWith(")")) {
                String[] values = v.substring(4, v.length() - 1).split(",");
                try {
                    return rgb(parseNum(values[0]), parseNum(values[1]), parseNum(values[2]));
                } catch (ArrayIndexOutOfBoundsException e2) {
                    return null;
                } catch (NumberFormatException e3) {
                    return null;
                }
            } else {
                return SvgColors.mapColor(v);
            }
        }

        private int hex3Tohex6(int x) {
            return ((x & 3840) << 8) | ((x & 3840) << 12) | ((x & TbsListener.ErrorCode.TPATCH_VERSION_FAILED) << 4) | ((x & TbsListener.ErrorCode.TPATCH_VERSION_FAILED) << 8) | ((x & 15) << 4) | (x & 15);
        }

        public Float getFloat(String name, float defaultValue) {
            Float v = getFloat(name);
            if (v == null) {
                return Float.valueOf(defaultValue);
            }
            return v;
        }

        public Float getFloat(String name) {
            String v = getAttr(name);
            if (v == null) {
                return null;
            }
            try {
                return Float.valueOf(Float.parseFloat(v));
            } catch (NumberFormatException e) {
                return null;
            }
        }
    }

    /* loaded from: classes.dex */
    public static class SvgHandler extends DefaultHandler {
        private boolean boundsMode;
        private final Matrix gradMatrix;
        private boolean hidden;
        private int hiddenLevel;
        private final RectF limitRect;
        private RectF mBounds;
        private Canvas mCanvas;
        private HashMap<String, String> mDefs;
        private Paint mFillPaint;
        private Stack<Paint> mFillPaintStack;
        private boolean mFillSet;
        private Stack<Boolean> mFillSetStack;
        private Gradient mGradient;
        private HashMap<String, Gradient> mGradientMap;
        private final Stack<SvgGroup> mGroupStack;
        private RectF mLimits;
        private RectF mLine;
        private Stack<Matrix> mMatrixStack;
        private Picture mPicture;
        private Stack<String> mReadIgnoreStack;
        private boolean mReadingDefs;
        private RectF mRect;
        private final Sharp mSharp;
        private Paint mStrokePaint;
        private Stack<Paint> mStrokePaintStack;
        private boolean mStrokeSet;
        private Stack<Boolean> mStrokeSetStack;
        private final Stack<SvgText> mTextStack;
        private Stack<Boolean> mTransformStack;

        private SvgHandler(Sharp sharp) {
            this.mStrokeSet = false;
            this.mStrokePaintStack = new Stack<>();
            this.mStrokeSetStack = new Stack<>();
            this.mFillSet = false;
            this.mFillPaintStack = new Stack<>();
            this.mFillSetStack = new Stack<>();
            this.mLine = new RectF();
            this.mRect = new RectF();
            this.mBounds = null;
            this.mLimits = new RectF(Float.POSITIVE_INFINITY, Float.POSITIVE_INFINITY, Float.NEGATIVE_INFINITY, Float.NEGATIVE_INFINITY);
            this.mTransformStack = new Stack<>();
            this.mMatrixStack = new Stack<>();
            this.mGradientMap = new HashMap<>();
            this.mGradient = null;
            this.mTextStack = new Stack<>();
            this.mGroupStack = new Stack<>();
            this.mDefs = new HashMap<>();
            this.mReadingDefs = false;
            this.mReadIgnoreStack = new Stack<>();
            this.gradMatrix = new Matrix();
            this.hidden = false;
            this.hiddenLevel = 0;
            this.boundsMode = false;
            this.limitRect = new RectF();
            this.mSharp = sharp;
        }

        private void onSvgStart() {
            this.mSharp.onSvgStart(this.mCanvas, this.mBounds);
        }

        private void onSvgEnd() {
            this.mSharp.onSvgEnd(this.mCanvas, this.mBounds);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public <T> T onSvgElement(@Nullable String id, @NonNull T element, @Nullable RectF elementBounds, @Nullable Paint paint) {
            return (T) this.mSharp.onSvgElement(id, element, elementBounds, this.mCanvas, this.mBounds, paint);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public <T> void onSvgElementDrawn(@Nullable String id, @NonNull T element, @Nullable Paint paint) {
            this.mSharp.onSvgElementDrawn(id, element, this.mCanvas, paint);
        }

        public void read(InputStream in) {
            this.mPicture = new Picture();
            try {
                long start = System.currentTimeMillis();
                if (in.markSupported()) {
                    in.mark(4);
                    byte[] magic = new byte[2];
                    int r = in.read(magic, 0, 2);
                    int magicInt = (magic[0] + (magic[1] << 8)) & SupportMenu.USER_MASK;
                    in.reset();
                    if (r == 2 && magicInt == 35615) {
                        Log.d(Sharp.TAG, "SVG is gzipped");
                        in = new GZIPInputStream(in);
                    }
                }
                SAXParserFactory spf = SAXParserFactory.newInstance();
                SAXParser sp = spf.newSAXParser();
                XMLReader xr = sp.getXMLReader();
                xr.setContentHandler(this);
                xr.parse(new InputSource(in));
                if (Sharp.sTextDynamic != null) {
                    Sharp.sTextDynamic.clear();
                    HashMap unused = Sharp.sTextDynamic = null;
                }
                Log.v(Sharp.TAG, "Parsing complete in " + (System.currentTimeMillis() - start) + " ms.");
            } catch (IOException | ParserConfigurationException | SAXException e) {
                Log.e(Sharp.TAG, "Failed parsing SVG", e);
                throw new SvgParseException(e);
            }
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void startDocument() throws SAXException {
            this.mStrokePaint = new Paint();
            this.mStrokePaint.setAntiAlias(true);
            this.mStrokePaint.setStyle(Paint.Style.STROKE);
            this.mFillPaint = new Paint();
            this.mFillPaint.setAntiAlias(true);
            this.mFillPaint.setStyle(Paint.Style.FILL);
            this.mMatrixStack.push(new Matrix());
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void endDocument() throws SAXException {
            this.mDefs.clear();
            this.mMatrixStack.clear();
        }

        /* JADX INFO: Access modifiers changed from: private */
        public boolean doFill(Properties atts, RectF boundingBox) {
            if ("none".equals(atts.getString("display"))) {
                return false;
            }
            String fillString = atts.getString("fill");
            if (fillString != null) {
                if (fillString.startsWith("url(#")) {
                    String id = fillString.substring("url(#".length(), fillString.length() - 1);
                    Gradient g = this.mGradientMap.get(id);
                    Shader shader = null;
                    if (g != null) {
                        shader = g.mShader;
                    }
                    if (shader != null) {
                        this.mFillPaint.setShader(shader);
                        if (boundingBox != null) {
                            this.gradMatrix.set(g.mMatrix);
                            if (g.mBoundingBox) {
                                this.gradMatrix.preTranslate(boundingBox.left, boundingBox.top);
                                this.gradMatrix.preScale(boundingBox.width(), boundingBox.height());
                            }
                            shader.setLocalMatrix(this.gradMatrix);
                            return true;
                        }
                        return true;
                    }
                    Log.d(Sharp.TAG, "Didn't find shader, using black: " + id);
                    this.mFillPaint.setShader(null);
                    doColor(atts, -16777216, true, this.mFillPaint);
                    return true;
                } else if (fillString.equalsIgnoreCase("none")) {
                    this.mFillPaint.setShader(null);
                    this.mFillPaint.setColor(0);
                    return false;
                } else {
                    this.mFillPaint.setShader(null);
                    Integer color = atts.getColor("fill");
                    if (color != null) {
                        doColor(atts, color, true, this.mFillPaint);
                        return true;
                    }
                    Log.d(Sharp.TAG, "Unrecognized fill color, using black: " + fillString);
                    doColor(atts, -16777216, true, this.mFillPaint);
                    return true;
                }
            } else if (this.mFillSet) {
                return this.mFillPaint.getColor() != 0;
            } else {
                this.mFillPaint.setShader(null);
                this.mFillPaint.setColor(-16777216);
                return true;
            }
        }

        /* JADX INFO: Access modifiers changed from: private */
        public boolean doText(Attributes atts, Properties props, Paint paint) {
            if (!"none".equals(atts.getValue("display"))) {
                Float fontSize = Sharp.getFloatAttr("font-size", atts);
                if (fontSize == null) {
                    fontSize = Sharp.parseFloat(props.getString("font-size"), null);
                }
                if (fontSize != null) {
                    paint.setTextSize(fontSize.floatValue());
                }
                Typeface typeface = setTypeface(atts, props, this.mSharp.getAssetManager(), paint.getTypeface());
                if (typeface != null) {
                    paint.setTypeface(typeface);
                }
                Paint.Align align = getTextAlign(atts);
                if (align != null) {
                    paint.setTextAlign(getTextAlign(atts));
                }
                return true;
            }
            return false;
        }

        /* JADX INFO: Access modifiers changed from: private */
        public boolean doStroke(Properties atts, RectF boundingBox) {
            if ("none".equals(atts.getString("display"))) {
                return false;
            }
            String strokeString = atts.getString("stroke");
            if (strokeString != null) {
                if (strokeString.equalsIgnoreCase("none")) {
                    this.mStrokePaint.setShader(null);
                    this.mStrokePaint.setColor(0);
                    return false;
                }
                Float width = atts.getFloat("stroke-width");
                if (width != null) {
                    this.mStrokePaint.setStrokeWidth(width.floatValue());
                }
                String linecap = atts.getString("stroke-linecap");
                if ("round".equals(linecap)) {
                    this.mStrokePaint.setStrokeCap(Paint.Cap.ROUND);
                } else if ("square".equals(linecap)) {
                    this.mStrokePaint.setStrokeCap(Paint.Cap.SQUARE);
                } else if ("butt".equals(linecap)) {
                    this.mStrokePaint.setStrokeCap(Paint.Cap.BUTT);
                }
                String linejoin = atts.getString("stroke-linejoin");
                if ("miter".equals(linejoin)) {
                    this.mStrokePaint.setStrokeJoin(Paint.Join.MITER);
                } else if ("round".equals(linejoin)) {
                    this.mStrokePaint.setStrokeJoin(Paint.Join.ROUND);
                } else if ("bevel".equals(linejoin)) {
                    this.mStrokePaint.setStrokeJoin(Paint.Join.BEVEL);
                }
                this.mStrokePaint.setStyle(Paint.Style.STROKE);
                if (strokeString.startsWith("url(#")) {
                    String id = strokeString.substring("url(#".length(), strokeString.length() - 1);
                    Gradient g = this.mGradientMap.get(id);
                    Shader shader = null;
                    if (g != null) {
                        shader = g.mShader;
                    }
                    if (shader != null) {
                        this.mStrokePaint.setShader(shader);
                        if (boundingBox != null) {
                            this.gradMatrix.set(g.mMatrix);
                            if (g.mBoundingBox) {
                                this.gradMatrix.preTranslate(boundingBox.left, boundingBox.top);
                                this.gradMatrix.preScale(boundingBox.width(), boundingBox.height());
                            }
                            shader.setLocalMatrix(this.gradMatrix);
                        }
                        return true;
                    }
                    Log.d(Sharp.TAG, "Didn't find shader, using black: " + id);
                    this.mStrokePaint.setShader(null);
                    doColor(atts, -16777216, true, this.mStrokePaint);
                    return true;
                }
                Integer color = atts.getColor("stroke");
                if (color != null) {
                    doColor(atts, color, false, this.mStrokePaint);
                    return true;
                }
                Log.d(Sharp.TAG, "Unrecognized stroke color, using black: " + strokeString);
                doColor(atts, -16777216, true, this.mStrokePaint);
                return true;
            } else if (this.mStrokeSet) {
                return this.mStrokePaint.getColor() != 0;
            } else {
                this.mStrokePaint.setShader(null);
                this.mStrokePaint.setColor(0);
                return false;
            }
        }

        private Gradient doGradient(boolean isLinear, Attributes atts) {
            Shader.TileMode tileMode;
            Gradient gradient = new Gradient();
            gradient.mId = Sharp.getStringAttr("id", atts);
            gradient.mIsLinear = isLinear;
            if (isLinear) {
                gradient.mX1 = Sharp.getFloatAttr("x1", atts, Float.valueOf(0.0f)).floatValue();
                gradient.mX2 = Sharp.getFloatAttr("x2", atts, Float.valueOf(1.0f)).floatValue();
                gradient.mY1 = Sharp.getFloatAttr("y1", atts, Float.valueOf(0.0f)).floatValue();
                gradient.mY2 = Sharp.getFloatAttr("y2", atts, Float.valueOf(0.0f)).floatValue();
            } else {
                gradient.mX = Sharp.getFloatAttr("cx", atts, Float.valueOf(0.0f)).floatValue();
                gradient.mY = Sharp.getFloatAttr("cy", atts, Float.valueOf(0.0f)).floatValue();
                gradient.mRadius = Sharp.getFloatAttr("r", atts, Float.valueOf(0.0f)).floatValue();
            }
            String transform = Sharp.getStringAttr("gradientTransform", atts);
            if (transform != null) {
                gradient.mMatrix = Sharp.parseTransform(transform);
            }
            String spreadMethod = Sharp.getStringAttr("spreadMethod", atts);
            if (spreadMethod == null) {
                spreadMethod = "pad";
            }
            if (spreadMethod.equals("reflect")) {
                tileMode = Shader.TileMode.MIRROR;
            } else {
                tileMode = spreadMethod.equals("repeat") ? Shader.TileMode.REPEAT : Shader.TileMode.CLAMP;
            }
            gradient.mTileMode = tileMode;
            String unit = Sharp.getStringAttr("gradientUnits", atts);
            if (unit == null) {
                unit = "objectBoundingBox";
            }
            gradient.mBoundingBox = !unit.equals("userSpaceOnUse");
            String xlink = Sharp.getStringAttr("href", atts);
            if (xlink != null) {
                if (xlink.startsWith("#")) {
                    xlink = xlink.substring(1);
                }
                gradient.mXlink = xlink;
            }
            return gradient;
        }

        private void finishGradients() {
            Gradient parent;
            for (Gradient gradient : this.mGradientMap.values()) {
                if (gradient.mXlink != null && (parent = this.mGradientMap.get(gradient.mXlink)) != null) {
                    gradient.inherit(parent);
                }
                int[] colors = new int[gradient.mColors.size()];
                for (int i = 0; i < colors.length; i++) {
                    colors[i] = ((Integer) gradient.mColors.get(i)).intValue();
                }
                float[] positions = new float[gradient.mPositions.size()];
                for (int i2 = 0; i2 < positions.length; i2++) {
                    positions[i2] = ((Float) gradient.mPositions.get(i2)).floatValue();
                }
                if (colors.length == 0) {
                    Log.w(Sharp.TAG, "bad gradient, id=" + gradient.mId);
                }
                if (gradient.mIsLinear) {
                    gradient.mShader = new LinearGradient(gradient.mX1, gradient.mY1, gradient.mX2, gradient.mY2, colors, positions, gradient.mTileMode);
                } else {
                    gradient.mShader = new RadialGradient(gradient.mX, gradient.mY, gradient.mRadius, colors, positions, gradient.mTileMode);
                }
            }
        }

        private void doColor(Properties atts, Integer color, boolean fillMode, Paint paint) {
            int c = (16777215 & color.intValue()) | (-16777216);
            paint.setShader(null);
            paint.setColor(c);
            Float opacity = atts.getFloat("opacity");
            Float opacity2 = atts.getFloat(fillMode ? "fill-opacity" : "stroke-opacity");
            if (opacity == null) {
                opacity = opacity2;
            } else if (opacity2 != null) {
                opacity = Float.valueOf(opacity.floatValue() * opacity2.floatValue());
            }
            if (opacity == null) {
                paint.setAlpha(255);
            } else {
                paint.setAlpha((int) (255.0f * opacity.floatValue()));
            }
        }

        private void doLimits(float x, float y) {
            if (x < this.mLimits.left) {
                this.mLimits.left = x;
            }
            if (x > this.mLimits.right) {
                this.mLimits.right = x;
            }
            if (y < this.mLimits.top) {
                this.mLimits.top = y;
            }
            if (y > this.mLimits.bottom) {
                this.mLimits.bottom = y;
            }
        }

        private void doLimits(RectF box, Paint paint) {
            Matrix m = this.mMatrixStack.peek();
            m.mapRect(this.limitRect, box);
            float width2 = paint == null ? 0.0f : this.mStrokePaint.getStrokeWidth() / 2.0f;
            doLimits(this.limitRect.left - width2, this.limitRect.top - width2);
            doLimits(this.limitRect.right + width2, this.limitRect.bottom + width2);
        }

        private void doLimits(RectF box) {
            doLimits(box, (Paint) null);
        }

        private void pushTransform(Attributes atts) {
            String transform = Sharp.getStringAttr("transform", atts);
            boolean pushed = transform != null;
            this.mTransformStack.push(Boolean.valueOf(pushed));
            if (pushed) {
                this.mCanvas.save();
                Matrix matrix = Sharp.parseTransform(transform);
                if (matrix != null) {
                    this.mCanvas.concat(matrix);
                    matrix.postConcat(this.mMatrixStack.peek());
                    this.mMatrixStack.push(matrix);
                }
            }
        }

        private void popTransform() {
            if (this.mTransformStack.pop().booleanValue()) {
                this.mCanvas.restore();
                this.mMatrixStack.pop();
            }
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void startElement(String namespaceURI, String localName, String qName, Attributes atts) throws SAXException {
            Float radiusY;
            Float radiusX;
            if (this.mReadIgnoreStack.empty()) {
                String id = Sharp.getStringAttr("id", atts);
                this.mStrokePaint.setAlpha(255);
                this.mFillPaint.setAlpha(255);
                if (this.boundsMode) {
                    if (localName.equals("rect")) {
                        Float x = Sharp.getFloatAttr("x", atts);
                        if (x == null) {
                            x = Float.valueOf(0.0f);
                        }
                        Float y = Sharp.getFloatAttr("y", atts);
                        if (y == null) {
                            y = Float.valueOf(0.0f);
                        }
                        this.mBounds = new RectF(x.floatValue(), y.floatValue(), x.floatValue() + Sharp.getFloatAttr("width", atts).floatValue(), y.floatValue() + Sharp.getFloatAttr("height", atts).floatValue());
                        return;
                    }
                    return;
                }
                if (!this.hidden && localName.equals("use")) {
                    localName = "path";
                }
                if (localName.equals("svg")) {
                    float width = -1.0f;
                    float height = -1.0f;
                    String viewBox = Sharp.getStringAttr("viewBox", atts);
                    if (viewBox == null) {
                        Float svgWidth = Sharp.getFloatAttr("width", atts);
                        Float svgHeight = Sharp.getFloatAttr("height", atts);
                        if (svgWidth != null && svgHeight != null) {
                            width = (int) Math.ceil(svgWidth.floatValue());
                            height = (int) Math.ceil(svgHeight.floatValue());
                        }
                    } else {
                        String[] coords = viewBox.split(" ");
                        if (coords.length == 4) {
                            width = Sharp.parseFloat(coords[2], Float.valueOf(-1.0f)).floatValue();
                            height = Sharp.parseFloat(coords[3], Float.valueOf(-1.0f)).floatValue();
                        }
                    }
                    if (width < 0.0f || height < 0.0f) {
                        width = 100.0f;
                        height = 100.0f;
                        Log.w(Sharp.TAG, "element '" + localName + "' does not provide its dimensions; using 100.0x100.0");
                    }
                    this.mBounds = new RectF(0.0f, 0.0f, width, height);
                    this.mCanvas = this.mPicture.beginRecording((int) Math.ceil(this.mBounds.width()), (int) Math.ceil(this.mBounds.height()));
                    onSvgStart();
                } else if (localName.equals("defs")) {
                    this.mReadingDefs = true;
                } else if (localName.equals("linearGradient")) {
                    this.mGradient = doGradient(true, atts);
                } else if (localName.equals("radialGradient")) {
                    this.mGradient = doGradient(false, atts);
                } else if (localName.equals("stop")) {
                    if (this.mGradient != null) {
                        Properties props = new Properties(atts);
                        float offset = props.getFloat("offset", 0.0f).floatValue();
                        int color = props.getColor("stop-color").intValue();
                        float alpha = props.getFloat("stop-opacity", 1.0f).floatValue();
                        int alphaInt = Math.round(255.0f * alpha);
                        this.mGradient.mPositions.add(Float.valueOf(offset));
                        this.mGradient.mColors.add(Integer.valueOf(color | (alphaInt << 24)));
                    }
                } else if (localName.equals("g")) {
                    Properties props2 = new Properties(atts);
                    if ("bounds".equalsIgnoreCase(id)) {
                        this.boundsMode = true;
                    }
                    if (this.hidden) {
                        this.hiddenLevel++;
                    }
                    if ("none".equals(props2.getString("display")) && !this.hidden) {
                        this.hidden = true;
                        this.hiddenLevel = 1;
                    }
                    Float opacity = Sharp.getFloatAttr("opacity", atts);
                    if (opacity == null) {
                        opacity = props2.getFloat("opacity");
                    }
                    if (opacity != null && opacity.floatValue() < 1.0f) {
                        Matrix m = this.mCanvas.getMatrix();
                        m.invert(m);
                        RectF r = new RectF(0.0f, 0.0f, this.mCanvas.getWidth(), this.mCanvas.getHeight());
                        m.mapRect(r);
                        this.mCanvas.saveLayerAlpha(r, (int) (255.0f * opacity.floatValue()), 31);
                    } else {
                        this.mCanvas.save();
                    }
                    pushTransform(atts);
                    this.mFillPaintStack.push(new Paint(this.mFillPaint));
                    this.mStrokePaintStack.push(new Paint(this.mStrokePaint));
                    this.mFillSetStack.push(Boolean.valueOf(this.mFillSet));
                    this.mStrokeSetStack.push(Boolean.valueOf(this.mStrokeSet));
                    doFill(props2, null);
                    doStroke(props2, null);
                    this.mFillSet = (props2.getString("fill") != null) | this.mFillSet;
                    this.mStrokeSet = (props2.getString("stroke") != null) | this.mStrokeSet;
                    SvgGroup group = new SvgGroup(id);
                    this.mGroupStack.push(group);
                    onSvgElement(id, group, null, null);
                } else if (!this.hidden && localName.equals("rect")) {
                    Float x2 = Sharp.getFloatAttr("x", atts, Float.valueOf(0.0f));
                    Float y2 = Sharp.getFloatAttr("y", atts, Float.valueOf(0.0f));
                    Float width2 = Sharp.getFloatAttr("width", atts);
                    Float height2 = Sharp.getFloatAttr("height", atts);
                    Float rx = Sharp.getFloatAttr("rx", atts);
                    Float ry = Sharp.getFloatAttr("ry", atts);
                    if (ry == null) {
                        ry = rx;
                    }
                    if (rx == null) {
                        rx = ry;
                    }
                    if (rx == null || rx.floatValue() < 0.0f) {
                        rx = Float.valueOf(0.0f);
                    }
                    if (ry == null || ry.floatValue() < 0.0f) {
                        ry = Float.valueOf(0.0f);
                    }
                    if (rx.floatValue() > width2.floatValue() / 2.0f) {
                        rx = Float.valueOf(width2.floatValue() / 2.0f);
                    }
                    if (ry.floatValue() > height2.floatValue() / 2.0f) {
                        ry = Float.valueOf(height2.floatValue() / 2.0f);
                    }
                    pushTransform(atts);
                    Properties props3 = new Properties(atts);
                    this.mRect.set(x2.floatValue(), y2.floatValue(), x2.floatValue() + width2.floatValue(), y2.floatValue() + height2.floatValue());
                    if (doFill(props3, this.mRect)) {
                        this.mRect = (RectF) onSvgElement(id, this.mRect, this.mRect, this.mFillPaint);
                        if (this.mRect != null) {
                            this.mCanvas.drawRoundRect(this.mRect, rx.floatValue(), ry.floatValue(), this.mFillPaint);
                            onSvgElementDrawn(id, this.mRect, this.mFillPaint);
                        }
                        doLimits(this.mRect);
                    }
                    if (doStroke(props3, this.mRect)) {
                        this.mRect = (RectF) onSvgElement(id, this.mRect, this.mRect, this.mStrokePaint);
                        if (this.mRect != null) {
                            this.mCanvas.drawRoundRect(this.mRect, rx.floatValue(), ry.floatValue(), this.mStrokePaint);
                            onSvgElementDrawn(id, this.mRect, this.mStrokePaint);
                        }
                        doLimits(this.mRect, this.mStrokePaint);
                    }
                    popTransform();
                } else if (!this.hidden && localName.equals("line")) {
                    Float x1 = Sharp.getFloatAttr("x1", atts);
                    Float x22 = Sharp.getFloatAttr("x2", atts);
                    Float y1 = Sharp.getFloatAttr("y1", atts);
                    Float y22 = Sharp.getFloatAttr("y2", atts);
                    if (doStroke(new Properties(atts), this.mRect)) {
                        pushTransform(atts);
                        this.mLine.set(x1.floatValue(), y1.floatValue(), x22.floatValue(), y22.floatValue());
                        this.mRect.set(this.mLine);
                        this.mLine = (RectF) onSvgElement(id, this.mLine, this.mRect, this.mStrokePaint);
                        if (this.mLine != null) {
                            this.mCanvas.drawLine(this.mLine.left, this.mLine.top, this.mLine.right, this.mLine.bottom, this.mStrokePaint);
                            onSvgElementDrawn(id, this.mLine, this.mStrokePaint);
                        }
                        doLimits(this.mRect, this.mStrokePaint);
                        popTransform();
                    }
                } else if (!this.hidden && (localName.equals("circle") || localName.equals("ellipse"))) {
                    Float centerX = Sharp.getFloatAttr("cx", atts);
                    Float centerY = Sharp.getFloatAttr("cy", atts);
                    if (localName.equals("ellipse")) {
                        radiusX = Sharp.getFloatAttr("rx", atts);
                        radiusY = Sharp.getFloatAttr("ry", atts);
                    } else {
                        radiusY = Sharp.getFloatAttr("r", atts);
                        radiusX = radiusY;
                    }
                    if (centerX != null && centerY != null && radiusX != null && radiusY != null) {
                        pushTransform(atts);
                        Properties props4 = new Properties(atts);
                        this.mRect.set(centerX.floatValue() - radiusX.floatValue(), centerY.floatValue() - radiusY.floatValue(), centerX.floatValue() + radiusX.floatValue(), centerY.floatValue() + radiusY.floatValue());
                        if (doFill(props4, this.mRect)) {
                            this.mRect = (RectF) onSvgElement(id, this.mRect, this.mRect, this.mFillPaint);
                            if (this.mRect != null) {
                                this.mCanvas.drawOval(this.mRect, this.mFillPaint);
                                onSvgElementDrawn(id, this.mRect, this.mFillPaint);
                            }
                            doLimits(this.mRect);
                        }
                        if (doStroke(props4, this.mRect)) {
                            this.mRect = (RectF) onSvgElement(id, this.mRect, this.mRect, this.mStrokePaint);
                            if (this.mRect != null) {
                                this.mCanvas.drawOval(this.mRect, this.mStrokePaint);
                                onSvgElementDrawn(id, this.mRect, this.mStrokePaint);
                            }
                            doLimits(this.mRect, this.mStrokePaint);
                        }
                        popTransform();
                    }
                } else if (!this.hidden && (localName.equals("polygon") || localName.equals("polyline"))) {
                    ArrayList<Float> points = Sharp.getNumberParseAttr("points", atts);
                    if (points != null) {
                        Path p = new Path();
                        if (points.size() > 1) {
                            pushTransform(atts);
                            Properties props5 = new Properties(atts);
                            p.moveTo(points.get(0).floatValue(), points.get(1).floatValue());
                            for (int i = 2; i < points.size(); i += 2) {
                                p.lineTo(points.get(i).floatValue(), points.get(i + 1).floatValue());
                            }
                            if (localName.equals("polygon")) {
                                p.close();
                            }
                            p.computeBounds(this.mRect, false);
                            if (doFill(props5, this.mRect)) {
                                p = (Path) onSvgElement(id, p, this.mRect, this.mFillPaint);
                                if (p != null) {
                                    this.mCanvas.drawPath(p, this.mFillPaint);
                                    onSvgElementDrawn(id, p, this.mFillPaint);
                                }
                                doLimits(this.mRect);
                            }
                            if (doStroke(props5, this.mRect)) {
                                Path p2 = (Path) onSvgElement(id, p, this.mRect, this.mStrokePaint);
                                if (p2 != null) {
                                    this.mCanvas.drawPath(p2, this.mStrokePaint);
                                    onSvgElementDrawn(id, p2, this.mStrokePaint);
                                }
                                doLimits(this.mRect, this.mStrokePaint);
                            }
                            popTransform();
                        }
                    }
                } else if (!this.hidden && localName.equals("path")) {
                    String d = Sharp.getStringAttr("d", atts);
                    if (this.mReadingDefs) {
                        this.mDefs.put(id, Sharp.getStringAttr("d", atts));
                        return;
                    }
                    if (d == null) {
                        String href = Sharp.getStringAttr("href", atts);
                        if (href != null && href.startsWith("#")) {
                            href = href.substring(1);
                        }
                        if (href != null && this.mDefs.containsKey(href)) {
                            d = this.mDefs.get(href);
                        }
                        if (d == null) {
                            return;
                        }
                    }
                    Path p3 = Sharp.doPath(d);
                    pushTransform(atts);
                    Properties props6 = new Properties(atts);
                    p3.computeBounds(this.mRect, false);
                    if (doFill(props6, this.mRect)) {
                        p3 = (Path) onSvgElement(id, p3, this.mRect, this.mFillPaint);
                        if (p3 != null) {
                            this.mCanvas.drawPath(p3, this.mFillPaint);
                            onSvgElementDrawn(id, p3, this.mFillPaint);
                        }
                        doLimits(this.mRect);
                    }
                    if (doStroke(props6, this.mRect)) {
                        Path p4 = (Path) onSvgElement(id, p3, this.mRect, this.mStrokePaint);
                        if (p4 != null) {
                            this.mCanvas.drawPath(p4, this.mStrokePaint);
                            onSvgElementDrawn(id, p4, this.mStrokePaint);
                        }
                        doLimits(this.mRect, this.mStrokePaint);
                    }
                    popTransform();
                } else if (!this.hidden && localName.equals("text")) {
                    pushTransform(atts);
                    this.mTextStack.push(new SvgText(atts, this.mTextStack.isEmpty() ? null : this.mTextStack.peek()));
                } else if (!this.hidden && localName.equals("tspan")) {
                    this.mTextStack.push(new SvgText(atts, this.mTextStack.isEmpty() ? null : this.mTextStack.peek()));
                } else if (!this.hidden) {
                    char c = 65535;
                    switch (localName.hashCode()) {
                        case -450004177:
                            if (localName.equals("metadata")) {
                                c = 0;
                                break;
                            }
                            break;
                    }
                    switch (c) {
                        case 0:
                            this.mReadIgnoreStack.push(localName);
                            return;
                        default:
                            Log.w(Sharp.TAG, "Unrecognized SVG command: " + localName);
                            return;
                    }
                }
            }
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void characters(char[] ch, int start, int length) {
            if (!this.mTextStack.isEmpty()) {
                this.mTextStack.peek().setText(ch, start, length);
            }
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void endElement(String namespaceURI, String localName, String qName) throws SAXException {
            SvgText text;
            if (!this.mReadIgnoreStack.empty() && localName.equals(this.mReadIgnoreStack.peek())) {
                this.mReadIgnoreStack.pop();
                return;
            }
            char c = 65535;
            switch (localName.hashCode()) {
                case -916589195:
                    if (localName.equals("linearGradient")) {
                        c = 3;
                        break;
                    }
                    break;
                case 103:
                    if (localName.equals("g")) {
                        c = 6;
                        break;
                    }
                    break;
                case 114276:
                    if (localName.equals("svg")) {
                        c = 0;
                        break;
                    }
                    break;
                case 3079438:
                    if (localName.equals("defs")) {
                        c = 5;
                        break;
                    }
                    break;
                case 3556653:
                    if (localName.equals("text")) {
                        c = 1;
                        break;
                    }
                    break;
                case 110665150:
                    if (localName.equals("tspan")) {
                        c = 2;
                        break;
                    }
                    break;
                case 763377263:
                    if (localName.equals("radialGradient")) {
                        c = 4;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    onSvgEnd();
                    this.mPicture.endRecording();
                    return;
                case 1:
                case 2:
                    if (!this.mTextStack.isEmpty() && (text = this.mTextStack.pop()) != null) {
                        text.render(this.mCanvas);
                    }
                    if (localName.equals("text")) {
                        popTransform();
                        return;
                    }
                    return;
                case 3:
                case 4:
                    if (this.mGradient.mId != null) {
                        this.mGradientMap.put(this.mGradient.mId, this.mGradient);
                        return;
                    }
                    return;
                case 5:
                    finishGradients();
                    this.mReadingDefs = false;
                    return;
                case 6:
                    SvgGroup group = this.mGroupStack.pop();
                    onSvgElementDrawn(group.id, group, null);
                    if (this.boundsMode) {
                        this.boundsMode = false;
                    }
                    if (this.hidden) {
                        this.hiddenLevel--;
                        if (this.hiddenLevel == 0) {
                            this.hidden = false;
                        }
                    }
                    popTransform();
                    this.mFillPaint = this.mFillPaintStack.pop();
                    this.mFillSet = this.mFillSetStack.pop().booleanValue();
                    this.mStrokePaint = this.mStrokePaintStack.pop();
                    this.mStrokeSet = this.mStrokeSetStack.pop().booleanValue();
                    this.mCanvas.restore();
                    return;
                default:
                    return;
            }
        }

        /* loaded from: classes.dex */
        public class SvgGroup {
            private final String id;

            public SvgGroup(String id) {
                this.id = id;
            }
        }

        /* loaded from: classes.dex */
        public class SvgText {
            private static final int BOTTOM = 0;
            private static final int CENTER = 1;
            private static final int LEFT = 0;
            private static final int MIDDLE = 1;
            private static final int RIGHT = 2;
            private static final int TOP = 2;
            private RectF bounds = new RectF();
            private TextPaint fill;
            private int hAlign;
            private final String id;
            private TextPaint stroke;
            private String text;
            private int vAlign;
            private final float x;
            private final String[] xCoords;
            private float xOffset;
            private final float y;
            private float yOffset;

            public SvgText(Attributes atts, SvgText parentText) {
                this.stroke = null;
                this.fill = null;
                this.hAlign = 0;
                this.vAlign = 0;
                this.id = Sharp.getStringAttr("id", atts);
                String xStr = Sharp.getStringAttr("x", atts);
                if (xStr == null || (!xStr.contains(",") && !xStr.contains(" "))) {
                    this.x = Sharp.parseFloat(xStr, Float.valueOf(parentText != null ? parentText.x : 0.0f)).floatValue();
                    this.xCoords = parentText != null ? parentText.xCoords : null;
                } else {
                    this.x = parentText != null ? parentText.x : 0.0f;
                    this.xCoords = xStr.split("[, ]");
                }
                this.y = Sharp.getFloatAttr("y", atts, Float.valueOf(parentText != null ? parentText.y : 0.0f)).floatValue();
                this.text = null;
                Properties props = new Properties(atts);
                if (SvgHandler.this.doFill(props, null)) {
                    this.fill = new TextPaint((parentText == null || parentText.fill == null) ? SvgHandler.this.mFillPaint : parentText.fill);
                    this.fill.setLinearText(true);
                    SvgHandler.this.doText(atts, props, this.fill);
                }
                if (SvgHandler.this.doStroke(props, null)) {
                    this.stroke = new TextPaint((parentText == null || parentText.stroke == null) ? SvgHandler.this.mStrokePaint : parentText.stroke);
                    this.stroke.setLinearText(true);
                    SvgHandler.this.doText(atts, props, this.stroke);
                }
                String halign = Sharp.getStringAttr("text-align", atts);
                halign = halign == null ? props.getString("text-align") : halign;
                if (halign == null && parentText != null) {
                    this.hAlign = parentText.hAlign;
                } else if ("center".equals(halign)) {
                    this.hAlign = 1;
                } else if ("right".equals(halign)) {
                    this.hAlign = 2;
                }
                String valign = Sharp.getStringAttr("alignment-baseline", atts);
                valign = valign == null ? props.getString("alignment-baseline") : valign;
                if (valign == null && parentText != null) {
                    this.vAlign = parentText.vAlign;
                } else if ("middle".equals(valign)) {
                    this.vAlign = 1;
                } else if ("top".equals(valign)) {
                    this.vAlign = 2;
                }
            }

            public void setText(char[] ch, int start, int len) {
                if (this.text == null) {
                    this.text = new String(ch, start, len);
                } else {
                    this.text += new String(ch, start, len);
                }
                if (Sharp.sTextDynamic != null && Sharp.sTextDynamic.containsKey(this.text)) {
                    this.text = (String) Sharp.sTextDynamic.get(this.text);
                }
            }

            public void render(Canvas canvas) {
                if (this.text != null) {
                    Rect bounds = new Rect();
                    Paint paint = this.stroke == null ? this.fill : this.stroke;
                    paint.getTextBounds(this.text, 0, this.text.length(), bounds);
                    switch (this.vAlign) {
                        case 1:
                            this.yOffset = -bounds.centerY();
                            break;
                        case 2:
                            this.yOffset = bounds.height();
                            break;
                    }
                    float width = paint.measureText(this.text);
                    switch (this.hAlign) {
                        case 1:
                            this.xOffset = (-width) / 2.0f;
                            break;
                        case 2:
                            this.xOffset = -width;
                            break;
                    }
                    this.bounds.set(this.x, this.y, this.x + width, this.y + bounds.height());
                    if (this.text != null) {
                        if (this.fill != null) {
                            drawText(canvas, this, true);
                        }
                        if (this.stroke != null) {
                            drawText(canvas, this, false);
                        }
                    }
                }
            }

            private void drawText(Canvas canvas, SvgText text, boolean fill) {
                TextPaint paint = fill ? text.fill : text.stroke;
                SvgText text2 = (SvgText) SvgHandler.this.onSvgElement(this.id, text, text.bounds, paint);
                if (text2 != null) {
                    if (text2.xCoords != null && text2.xCoords.length > 0) {
                        int i = 0;
                        Float thisX = Sharp.parseFloat(text2.xCoords[0], null);
                        Float nextX = Float.valueOf(0.0f);
                        if (thisX != null) {
                            float x = thisX.floatValue();
                            i = 0;
                            while (true) {
                                if (i < text2.text.length()) {
                                    if (i >= text2.xCoords.length) {
                                        i--;
                                        break;
                                    } else if (i + 1 < text2.xCoords.length && (nextX = Sharp.parseFloat(text2.xCoords[i + 1], null)) == null) {
                                        i--;
                                        break;
                                    } else {
                                        String s = new String(new char[]{text2.text.charAt(i)});
                                        canvas.drawText(s, text2.xOffset + x, text2.y + text2.yOffset, paint);
                                        x = nextX.floatValue();
                                        i++;
                                    }
                                } else {
                                    break;
                                }
                            }
                        }
                        if (i < text2.text.length()) {
                            canvas.drawText(text2.text.substring(i), this.x + text2.xOffset, text2.y + text2.yOffset, paint);
                        }
                    } else {
                        canvas.drawText(text2.text, text2.x + text2.xOffset, text2.y + text2.yOffset, paint);
                    }
                    SvgHandler.this.onSvgElementDrawn(text2.id, text2, paint);
                }
            }
        }

        private Paint.Align getTextAlign(Attributes atts) {
            String align = Sharp.getStringAttr("text-anchor", atts);
            if (align == null) {
                return null;
            }
            if ("middle".equals(align)) {
                return Paint.Align.CENTER;
            }
            if ("end".equals(align)) {
                return Paint.Align.RIGHT;
            }
            return Paint.Align.LEFT;
        }

        private Typeface setTypeface(Attributes atts, Properties props, AssetManager assetManager, Typeface defaultTypeface) {
            Typeface plain;
            String family = Sharp.getStringAttr("font-family", atts);
            if (family == null) {
                family = props.getString("font-family");
            }
            String style = Sharp.getStringAttr("font-style", atts);
            if (style == null) {
                style = props.getString("font-style");
            }
            String weight = Sharp.getStringAttr("font-weight", atts);
            if (weight == null) {
                weight = props.getString("font-weight");
            }
            int styleParam = 0;
            if ("italic".equals(style)) {
                styleParam = 0 | 2;
            }
            if ("bold".equals(weight)) {
                styleParam |= 1;
            }
            if (family != null) {
                if (assetManager != null) {
                    Pattern pattern = Pattern.compile("'(.+?)'(?:,'(.+?)')*");
                    Matcher matcher = pattern.matcher(family);
                    if (matcher.matches()) {
                        for (int i = 1; i < matcher.groupCount() + 1; i++) {
                            if (matcher.group(i) != null) {
                                family = matcher.group(i);
                            }
                        }
                    }
                    String typefaceFile = "fonts/" + family + ".ttf";
                    try {
                        plain = Typeface.createFromAsset(assetManager, typefaceFile);
                        Log.d(Sharp.TAG, "loaded typeface from assets: " + typefaceFile);
                    } catch (RuntimeException e) {
                        boolean found = true;
                        try {
                            String[] fonts = assetManager.list("fonts/");
                            found = false;
                            for (String font : fonts) {
                                if (typefaceFile.equals(font)) {
                                    found = true;
                                }
                            }
                        } catch (IOException e2) {
                            Log.e(Sharp.TAG, "Failed listing assets directory for /fonts", e);
                        }
                        if (!found) {
                            Log.e(Sharp.TAG, "Typeface is missing from assets: " + typefaceFile);
                        } else {
                            Log.e(Sharp.TAG, "Failed to create typeface from assets: " + typefaceFile, e);
                        }
                        plain = null;
                    }
                    if (plain != null) {
                        return Typeface.create(plain, styleParam);
                    }
                } else {
                    Log.e(Sharp.TAG, "Typefaces can only be loaded if assets are provided; invoke " + Sharp.class.getSimpleName() + " with .withAssets()");
                }
            }
            if (defaultTypeface == null) {
                return Typeface.create(family, styleParam);
            }
            return Typeface.create(defaultTypeface, styleParam);
        }
    }

    public static void checkAssumedUnits(String unit) {
        if (sAssumedUnit == null) {
            sAssumedUnit = unit;
        }
        if (!sAssumedUnit.equals(unit)) {
            throw new IllegalStateException("Mixing units; SVG contains both " + sAssumedUnit + " and " + unit);
        }
    }
}
